"""Auto-generated reference molecule data"""
# DO NOT EDIT - generated by gen_refmol.py

from enum import StrEnum
from typing import Literal
from .dclass import RefMolInfo


class RefMolID(StrEnum):
    """Enum of reference molecule IDs"""
    ADENINE = "Adenine"
    CYTOSINE = "Cytosine"
    GUANINE = "Guanine"
    TMT126 = "TMT126"
    TMT126_ETD = "TMT126-ETD"
    TMT127C = "TMT127C"
    TMT127C_ETD = "TMT127C-ETD"
    TMT127N = "TMT127N"
    TMT127N_ETD = "TMT127N-ETD"
    TMT128C = "TMT128C"
    TMT128C_ETD = "TMT128C-ETD"
    TMT128N = "TMT128N"
    TMT128N_ETD = "TMT128N-ETD"
    TMT129C = "TMT129C"
    TMT129C_ETD = "TMT129C-ETD"
    TMT129N = "TMT129N"
    TMT129N_ETD = "TMT129N-ETD"
    TMT130C = "TMT130C"
    TMT130C_ETD = "TMT130C-ETD"
    TMT130N = "TMT130N"
    TMT130N_ETD = "TMT130N-ETD"
    TMT131C = "TMT131C"
    TMT131C_ETD = "TMT131C-ETD"
    TMT131N = "TMT131N"
    TMT131N_ETD = "TMT131N-ETD"
    TMT132C = "TMT132C"
    TMT132N = "TMT132N"
    TMT133C = "TMT133C"
    TMT133N = "TMT133N"
    TMT134C = "TMT134C"
    TMT134N = "TMT134N"
    TMT135N = "TMT135N"
    TMT2PLEX = "TMT2plex"
    TMT6PLEX = "TMT6plex"
    TMTPRO = "TMTpro"
    TMTPRO_ZERO = "TMTpro_zero"
    TMTZERO = "TMTzero"
    THYMINE = "Thymine"
    URACIL = "Uracil"
    ITRAQ113 = "iTRAQ113"
    ITRAQ114 = "iTRAQ114"
    ITRAQ115 = "iTRAQ115"
    ITRAQ116 = "iTRAQ116"
    ITRAQ117 = "iTRAQ117"
    ITRAQ118 = "iTRAQ118"
    ITRAQ119 = "iTRAQ119"
    ITRAQ121 = "iTRAQ121"
    ITRAQ4PLEX = "iTRAQ4plex"
    ITRAQ8PLEX = "iTRAQ8plex"
    SIDECHAIN_A = "sidechain_A"
    SIDECHAIN_C = "sidechain_C"
    SIDECHAIN_D = "sidechain_D"
    SIDECHAIN_E = "sidechain_E"
    SIDECHAIN_F = "sidechain_F"
    SIDECHAIN_G = "sidechain_G"
    SIDECHAIN_H = "sidechain_H"
    SIDECHAIN_I = "sidechain_I"
    SIDECHAIN_J = "sidechain_J"
    SIDECHAIN_K = "sidechain_K"
    SIDECHAIN_L = "sidechain_L"
    SIDECHAIN_M = "sidechain_M"
    SIDECHAIN_N = "sidechain_N"
    SIDECHAIN_O = "sidechain_O"
    SIDECHAIN_Q = "sidechain_Q"
    SIDECHAIN_R = "sidechain_R"
    SIDECHAIN_S = "sidechain_S"
    SIDECHAIN_T = "sidechain_T"
    SIDECHAIN_U = "sidechain_U"
    SIDECHAIN_V = "sidechain_V"
    SIDECHAIN_W = "sidechain_W"
    SIDECHAIN_Y = "sidechain_Y"


RefMolLiteral = Literal[
    "Adenine",
    "Cytosine",
    "Guanine",
    "TMT126",
    "TMT126-ETD",
    "TMT127C",
    "TMT127C-ETD",
    "TMT127N",
    "TMT127N-ETD",
    "TMT128C",
    "TMT128C-ETD",
    "TMT128N",
    "TMT128N-ETD",
    "TMT129C",
    "TMT129C-ETD",
    "TMT129N",
    "TMT129N-ETD",
    "TMT130C",
    "TMT130C-ETD",
    "TMT130N",
    "TMT130N-ETD",
    "TMT131C",
    "TMT131C-ETD",
    "TMT131N",
    "TMT131N-ETD",
    "TMT132C",
    "TMT132N",
    "TMT133C",
    "TMT133N",
    "TMT134C",
    "TMT134N",
    "TMT135N",
    "TMT2plex",
    "TMT6plex",
    "TMTpro",
    "TMTpro_zero",
    "TMTzero",
    "Thymine",
    "Uracil",
    "iTRAQ113",
    "iTRAQ114",
    "iTRAQ115",
    "iTRAQ116",
    "iTRAQ117",
    "iTRAQ118",
    "iTRAQ119",
    "iTRAQ121",
    "iTRAQ4plex",
    "iTRAQ8plex",
    "sidechain_A",
    "sidechain_C",
    "sidechain_D",
    "sidechain_E",
    "sidechain_F",
    "sidechain_G",
    "sidechain_H",
    "sidechain_I",
    "sidechain_J",
    "sidechain_K",
    "sidechain_L",
    "sidechain_M",
    "sidechain_N",
    "sidechain_O",
    "sidechain_Q",
    "sidechain_R",
    "sidechain_S",
    "sidechain_T",
    "sidechain_U",
    "sidechain_V",
    "sidechain_W",
    "sidechain_Y",
]


REFMOL_DICT: dict[RefMolID, RefMolInfo] = {
RefMolID.ADENINE: RefMolInfo(
    name="Adenine",
    label_type="",
    molecule_type="nucleobase",
    chemical_formula='C5H5N5',
    monoisotopic_mass=135.0544951833,
    average_mass=135.1268993111841,
    dict_composition={'C': 5, 'H': 5, 'N': 5},
),
RefMolID.CYTOSINE: RefMolInfo(
    name="Cytosine",
    label_type="",
    molecule_type="nucleobase",
    chemical_formula='C4H5N3O',
    monoisotopic_mass=111.04326179401,
    average_mass=111.10216191587554,
    dict_composition={'C': 4, 'H': 5, 'N': 3, 'O': 1},
),
RefMolID.GUANINE: RefMolInfo(
    name="Guanine",
    label_type="",
    molecule_type="nucleobase",
    chemical_formula='C5H5N5O',
    monoisotopic_mass=151.04940980287,
    average_mass=151.12630423550237,
    dict_composition={'C': 5, 'H': 5, 'N': 5, 'O': 1},
),
RefMolID.TMT126: RefMolInfo(
    name="TMT126",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C8N1H15',
    monoisotopic_mass=125.12044948788001,
    average_mass=125.21170169616444,
    dict_composition={'C': 8, 'N': 1, 'H': 15},
),
RefMolID.TMT126_ETD: RefMolInfo(
    name="TMT126-ETD",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C7N1H15',
    monoisotopic_mass=113.12044948788001,
    average_mass=113.2009657994292,
    dict_composition={'C': 7, 'N': 1, 'H': 15},
),
RefMolID.TMT127C: RefMolInfo(
    name="TMT127C",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C7[13C1]N1H15',
    monoisotopic_mass=126.12380432295001,
    average_mass=126.2043206344992,
    dict_composition={'C': 7, '13C': 1, 'N': 1, 'H': 15},
),
RefMolID.TMT127C_ETD: RefMolInfo(
    name="TMT127C-ETD",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C7N1H15',
    monoisotopic_mass=113.12044948788001,
    average_mass=113.2009657994292,
    dict_composition={'C': 7, 'N': 1, 'H': 15},
),
RefMolID.TMT127N: RefMolInfo(
    name="TMT127N",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C8[15N1]H15',
    monoisotopic_mass=126.11748438233,
    average_mass=126.20510738359864,
    dict_composition={'C': 8, '15N': 1, 'H': 15},
),
RefMolID.TMT127N_ETD: RefMolInfo(
    name="TMT127N-ETD",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C7[15N1]H15',
    monoisotopic_mass=114.11748438233,
    average_mass=114.1943714868634,
    dict_composition={'C': 7, '15N': 1, 'H': 15},
),
RefMolID.TMT128C: RefMolInfo(
    name="TMT128C",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C6[13C2]N1H15',
    monoisotopic_mass=127.12715915802,
    average_mass=127.19693957283394,
    dict_composition={'C': 6, '13C': 2, 'N': 1, 'H': 15},
),
RefMolID.TMT128C_ETD: RefMolInfo(
    name="TMT128C-ETD",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C5[13C2]N1H15',
    monoisotopic_mass=115.12715915802,
    average_mass=115.1862036760987,
    dict_composition={'C': 5, '13C': 2, 'N': 1, 'H': 15},
),
RefMolID.TMT128N: RefMolInfo(
    name="TMT128N",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C7[13C1][15N1]H15',
    monoisotopic_mass=127.1208392174,
    average_mass=127.1977263219334,
    dict_composition={'C': 7, '13C': 1, '15N': 1, 'H': 15},
),
RefMolID.TMT128N_ETD: RefMolInfo(
    name="TMT128N-ETD",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C7[15N1]H15',
    monoisotopic_mass=114.11748438233,
    average_mass=114.1943714868634,
    dict_composition={'C': 7, '15N': 1, 'H': 15},
),
RefMolID.TMT129C: RefMolInfo(
    name="TMT129C",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C5[13C3]N1H15',
    monoisotopic_mass=128.13051399309,
    average_mass=128.18955851116868,
    dict_composition={'C': 5, '13C': 3, 'N': 1, 'H': 15},
),
RefMolID.TMT129C_ETD: RefMolInfo(
    name="TMT129C-ETD",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C5[13C2]N1H15',
    monoisotopic_mass=115.12715915802,
    average_mass=115.1862036760987,
    dict_composition={'C': 5, '13C': 2, 'N': 1, 'H': 15},
),
RefMolID.TMT129N: RefMolInfo(
    name="TMT129N",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C6[13C2][15N1]H15',
    monoisotopic_mass=128.12419405247,
    average_mass=128.19034526026815,
    dict_composition={'C': 6, '13C': 2, '15N': 1, 'H': 15},
),
RefMolID.TMT129N_ETD: RefMolInfo(
    name="TMT129N-ETD",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C5[13C2][15N1]H15',
    monoisotopic_mass=116.12419405247,
    average_mass=116.1796093635329,
    dict_composition={'C': 5, '13C': 2, '15N': 1, 'H': 15},
),
RefMolID.TMT130C: RefMolInfo(
    name="TMT130C",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C4[13C4]N1H15',
    monoisotopic_mass=129.13386882816,
    average_mass=129.18217744950346,
    dict_composition={'C': 4, '13C': 4, 'N': 1, 'H': 15},
),
RefMolID.TMT130C_ETD: RefMolInfo(
    name="TMT130C-ETD",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C3[13C4]N1H15',
    monoisotopic_mass=117.13386882816,
    average_mass=117.1714415527682,
    dict_composition={'C': 3, '13C': 4, 'N': 1, 'H': 15},
),
RefMolID.TMT130N: RefMolInfo(
    name="TMT130N",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C5[13C3][15N1]H15',
    monoisotopic_mass=129.12754888754,
    average_mass=129.18296419860292,
    dict_composition={'C': 5, '13C': 3, '15N': 1, 'H': 15},
),
RefMolID.TMT130N_ETD: RefMolInfo(
    name="TMT130N-ETD",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C5[13C2][15N1]H15',
    monoisotopic_mass=116.12419405247,
    average_mass=116.1796093635329,
    dict_composition={'C': 5, '13C': 2, '15N': 1, 'H': 15},
),
RefMolID.TMT131C: RefMolInfo(
    name="TMT131C",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C3[13C5]N1H15',
    monoisotopic_mass=130.13722366323,
    average_mass=130.17479638783823,
    dict_composition={'C': 3, '13C': 5, 'N': 1, 'H': 15},
),
RefMolID.TMT131C_ETD: RefMolInfo(
    name="TMT131C-ETD",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C3[13C4]N1H15',
    monoisotopic_mass=117.13386882816,
    average_mass=117.1714415527682,
    dict_composition={'C': 3, '13C': 4, 'N': 1, 'H': 15},
),
RefMolID.TMT131N: RefMolInfo(
    name="TMT131N",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C4[13C4][15N1]H15',
    monoisotopic_mass=130.13090372261,
    average_mass=130.17558313693763,
    dict_composition={'C': 4, '13C': 4, '15N': 1, 'H': 15},
),
RefMolID.TMT131N_ETD: RefMolInfo(
    name="TMT131N-ETD",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C3[13C4][15N1]H15',
    monoisotopic_mass=118.13090372261,
    average_mass=118.1648472402024,
    dict_composition={'C': 3, '13C': 4, '15N': 1, 'H': 15},
),
RefMolID.TMT132C: RefMolInfo(
    name="TMT132C",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C2[13C6]N1H15',
    monoisotopic_mass=131.14057849830002,
    average_mass=131.16741532617294,
    dict_composition={'C': 2, '13C': 6, 'N': 1, 'H': 15},
),
RefMolID.TMT132N: RefMolInfo(
    name="TMT132N",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C3[13C5][15N1]H15',
    monoisotopic_mass=131.13425855768,
    average_mass=131.1682020752724,
    dict_composition={'C': 3, '13C': 5, '15N': 1, 'H': 15},
),
RefMolID.TMT133C: RefMolInfo(
    name="TMT133C",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C1[13C7]N1H15',
    monoisotopic_mass=132.14393333337,
    average_mass=132.16003426450771,
    dict_composition={'C': 1, '13C': 7, 'N': 1, 'H': 15},
),
RefMolID.TMT133N: RefMolInfo(
    name="TMT133N",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C2[13C6][15N1]H15',
    monoisotopic_mass=132.13761339275,
    average_mass=132.16082101360718,
    dict_composition={'C': 2, '13C': 6, '15N': 1, 'H': 15},
),
RefMolID.TMT134C: RefMolInfo(
    name="TMT134C",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='[13C8]N1H15',
    monoisotopic_mass=133.14728816844,
    average_mass=133.15265320284246,
    dict_composition={'13C': 8, 'N': 1, 'H': 15},
),
RefMolID.TMT134N: RefMolInfo(
    name="TMT134N",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='C1[13C7][15N1]H15',
    monoisotopic_mass=133.14096822782,
    average_mass=133.1534399519419,
    dict_composition={'C': 1, '13C': 7, '15N': 1, 'H': 15},
),
RefMolID.TMT135N: RefMolInfo(
    name="TMT135N",
    label_type="TMT",
    molecule_type="reporter",
    chemical_formula='[13C8][15N1]H15',
    monoisotopic_mass=134.14432306289,
    average_mass=134.14605889027666,
    dict_composition={'13C': 8, '15N': 1, 'H': 15},
),
RefMolID.TMT2PLEX: RefMolInfo(
    name="TMT2plex",
    label_type="TMT2plex",
    molecule_type="reporter+balance",
    chemical_formula='C11[13C1]H20N2O2',
    monoisotopic_mass=225.15583272767,
    average_mass=225.29248105180142,
    dict_composition={'C': 11, '13C': 1, 'H': 20, 'N': 2, 'O': 2},
),
RefMolID.TMT6PLEX: RefMolInfo(
    name="TMT6plex",
    label_type="TMT6plex",
    molecule_type="reporter+balance",
    chemical_formula='C8[13C4]H20N1[15N1]O2',
    monoisotopic_mass=229.16293212732998,
    average_mass=229.26374355423985,
    dict_composition={'C': 8, '13C': 4, 'H': 20, 'N': 1, '15N': 1, 'O': 2},
),
RefMolID.TMTPRO: RefMolInfo(
    name="TMTpro",
    label_type="TMTpro",
    molecule_type="reporter+balance",
    chemical_formula='C8[13C7]H25[15N2]N1O3',
    monoisotopic_mass=304.20714531214,
    average_mass=304.3130256529271,
    dict_composition={'C': 8, '13C': 7, 'H': 25, '15N': 2, 'N': 1, 'O': 3},
),
RefMolID.TMTPRO_ZERO: RefMolInfo(
    name="TMTpro_zero",
    label_type="TMTpro_zero",
    molecule_type="reporter+balance",
    chemical_formula='C15H25N3O3',
    monoisotopic_mass=295.18959167775006,
    average_mass=295.3778817097154,
    dict_composition={'C': 15, 'H': 25, 'N': 3, 'O': 3},
),
RefMolID.TMTZERO: RefMolInfo(
    name="TMTzero",
    label_type="TMTzero",
    molecule_type="reporter+balance",
    chemical_formula='C12H20N2O2',
    monoisotopic_mass=224.1524778926,
    average_mass=224.29986211346665,
    dict_composition={'C': 12, 'H': 20, 'N': 2, 'O': 2},
),
RefMolID.THYMINE: RefMolInfo(
    name="Thymine",
    label_type="",
    molecule_type="nucleobase",
    chemical_formula='C5H6N2O2',
    monoisotopic_mass=126.04292744137999,
    average_mass=126.11354027953905,
    dict_composition={'C': 5, 'H': 6, 'N': 2, 'O': 2},
),
RefMolID.URACIL: RefMolInfo(
    name="Uracil",
    label_type="",
    molecule_type="nucleobase",
    chemical_formula='C4H4N2O2',
    monoisotopic_mass=112.02727737692001,
    average_mass=112.08692287469225,
    dict_composition={'C': 4, 'H': 4, 'N': 2, 'O': 2},
),
RefMolID.ITRAQ113: RefMolInfo(
    name="iTRAQ113",
    label_type="iTRAQ",
    molecule_type="reporter",
    chemical_formula='C6N2H12',
    monoisotopic_mass=112.10004839562,
    average_mass=112.17311085197241,
    dict_composition={'C': 6, 'N': 2, 'H': 12},
),
RefMolID.ITRAQ114: RefMolInfo(
    name="iTRAQ114",
    label_type="iTRAQ",
    molecule_type="reporter",
    chemical_formula='C5[13C1]N2H12',
    monoisotopic_mass=113.10340323068999,
    average_mass=113.16572979030717,
    dict_composition={'C': 5, '13C': 1, 'N': 2, 'H': 12},
),
RefMolID.ITRAQ115: RefMolInfo(
    name="iTRAQ115",
    label_type="iTRAQ",
    molecule_type="reporter",
    chemical_formula='C5[13C1]N1[15N1]H12',
    monoisotopic_mass=114.10043812514,
    average_mass=114.15913547774137,
    dict_composition={'C': 5, '13C': 1, 'N': 1, '15N': 1, 'H': 12},
),
RefMolID.ITRAQ116: RefMolInfo(
    name="iTRAQ116",
    label_type="iTRAQ",
    molecule_type="reporter",
    chemical_formula='C4[13C2]N1[15N1]H12',
    monoisotopic_mass=115.10379296021,
    average_mass=115.15175441607612,
    dict_composition={'C': 4, '13C': 2, 'N': 1, '15N': 1, 'H': 12},
),
RefMolID.ITRAQ117: RefMolInfo(
    name="iTRAQ117",
    label_type="iTRAQ",
    molecule_type="reporter",
    chemical_formula='C3[13C3]N1[15N1]H12',
    monoisotopic_mass=116.10714779528001,
    average_mass=116.14437335441087,
    dict_composition={'C': 3, '13C': 3, 'N': 1, '15N': 1, 'H': 12},
),
RefMolID.ITRAQ118: RefMolInfo(
    name="iTRAQ118",
    label_type="iTRAQ",
    molecule_type="reporter",
    chemical_formula='C3[13C3][15N2]H12',
    monoisotopic_mass=117.10418268973001,
    average_mass=117.13777904184508,
    dict_composition={'C': 3, '13C': 3, '15N': 2, 'H': 12},
),
RefMolID.ITRAQ119: RefMolInfo(
    name="iTRAQ119",
    label_type="iTRAQ",
    molecule_type="reporter",
    chemical_formula='C2[13C4][15N2]H12',
    monoisotopic_mass=118.1075375248,
    average_mass=118.13039798017984,
    dict_composition={'C': 2, '13C': 4, '15N': 2, 'H': 12},
),
RefMolID.ITRAQ121: RefMolInfo(
    name="iTRAQ121",
    label_type="iTRAQ",
    molecule_type="reporter",
    chemical_formula='[13C6][15N2]H12',
    monoisotopic_mass=120.11424719494,
    average_mass=120.11563585684934,
    dict_composition={'13C': 6, '15N': 2, 'H': 12},
),
RefMolID.ITRAQ4PLEX: RefMolInfo(
    name="iTRAQ4plex",
    label_type="iTRAQ4plex",
    molecule_type="reporter+balance",
    chemical_formula='C4[13C3]N1[15N1]O1H12',
    monoisotopic_mass=144.10206241485002,
    average_mass=144.15451417546439,
    dict_composition={'C': 4, '13C': 3, 'N': 1, '15N': 1, 'O': 1, 'H': 12},
),
RefMolID.ITRAQ8PLEX: RefMolInfo(
    name="iTRAQ8plex",
    label_type="iTRAQ8plex",
    molecule_type="reporter+balance",
    chemical_formula='C7[13C7]N3[15N1]O3H24',
    monoisotopic_mass=304.20535938989,
    average_mass=304.3076465261476,
    dict_composition={'C': 7, '13C': 7, 'N': 3, '15N': 1, 'O': 3, 'H': 24},
),
RefMolID.SIDECHAIN_A: RefMolInfo(
    name="sidechain_A",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C1H3',
    monoisotopic_mass=15.02347509669,
    average_mass=15.03455815890258,
    dict_composition={'C': 1, 'H': 3},
),
RefMolID.SIDECHAIN_C: RefMolInfo(
    name="sidechain_C",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C1H3S1',
    monoisotopic_mass=46.99554627109,
    average_mass=47.09934556502965,
    dict_composition={'C': 1, 'H': 3, 'S': 1},
),
RefMolID.SIDECHAIN_D: RefMolInfo(
    name="sidechain_D",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C2H2O2',
    monoisotopic_mass=58.0054793036,
    average_mass=58.036163150218606,
    dict_composition={'C': 2, 'H': 2, 'O': 2},
),
RefMolID.SIDECHAIN_E: RefMolInfo(
    name="sidechain_E",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C3H4O2',
    monoisotopic_mass=72.02112936806,
    average_mass=72.06278055506542,
    dict_composition={'C': 3, 'H': 4, 'O': 2},
),
RefMolID.SIDECHAIN_F: RefMolInfo(
    name="sidechain_F",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C7H7',
    monoisotopic_mass=91.05477522561,
    average_mass=91.13073655553718,
    dict_composition={'C': 7, 'H': 7},
),
RefMolID.SIDECHAIN_G: RefMolInfo(
    name="sidechain_G",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='H1',
    monoisotopic_mass=1.00782503223,
    average_mass=1.0079407540557772,
    dict_composition={'H': 1},
),
RefMolID.SIDECHAIN_H: RefMolInfo(
    name="sidechain_H",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C4H5N2',
    monoisotopic_mass=81.04527317000999,
    average_mass=81.09605378011148,
    dict_composition={'C': 4, 'H': 5, 'N': 2},
),
RefMolID.SIDECHAIN_I: RefMolInfo(
    name="sidechain_I",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C4H9',
    monoisotopic_mass=57.07042529007,
    average_mass=57.114410373442986,
    dict_composition={'C': 4, 'H': 9},
),
RefMolID.SIDECHAIN_J: RefMolInfo(
    name="sidechain_J",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C4H9',
    monoisotopic_mass=57.07042529007,
    average_mass=57.114410373442986,
    dict_composition={'C': 4, 'H': 9},
),
RefMolID.SIDECHAIN_K: RefMolInfo(
    name="sidechain_K",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C4H10N1',
    monoisotopic_mass=72.08132432673,
    average_mass=72.12905433894457,
    dict_composition={'C': 4, 'H': 10, 'N': 1},
),
RefMolID.SIDECHAIN_L: RefMolInfo(
    name="sidechain_L",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C4H9',
    monoisotopic_mass=57.07042529007,
    average_mass=57.114410373442986,
    dict_composition={'C': 4, 'H': 9},
),
RefMolID.SIDECHAIN_M: RefMolInfo(
    name="sidechain_M",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C3H7S1',
    monoisotopic_mass=75.02684640001,
    average_mass=75.15258037472324,
    dict_composition={'C': 3, 'H': 7, 'S': 1},
),
RefMolID.SIDECHAIN_N: RefMolInfo(
    name="sidechain_N",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C2H4N1O1',
    monoisotopic_mass=58.029288752919996,
    average_mass=58.05934294545768,
    dict_composition={'C': 2, 'H': 4, 'N': 1, 'O': 1},
),
RefMolID.SIDECHAIN_O: RefMolInfo(
    name="sidechain_O",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C9H17N2O1',
    monoisotopic_mass=169.13408817634001,
    average_mass=169.2444272367753,
    dict_composition={'C': 9, 'H': 17, 'N': 2, 'O': 1},
),
RefMolID.SIDECHAIN_Q: RefMolInfo(
    name="sidechain_Q",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C3H6N1O1',
    monoisotopic_mass=72.04493881738,
    average_mass=72.08596035030448,
    dict_composition={'C': 3, 'H': 6, 'N': 1, 'O': 1},
),
RefMolID.SIDECHAIN_R: RefMolInfo(
    name="sidechain_R",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C4H10N3',
    monoisotopic_mass=100.08747233559001,
    average_mass=100.14246076183616,
    dict_composition={'C': 4, 'H': 10, 'N': 3},
),
RefMolID.SIDECHAIN_S: RefMolInfo(
    name="sidechain_S",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C1H3O1',
    monoisotopic_mass=31.01838971626,
    average_mass=31.033963083220858,
    dict_composition={'C': 1, 'H': 3, 'O': 1},
),
RefMolID.SIDECHAIN_T: RefMolInfo(
    name="sidechain_T",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C2H5O1',
    monoisotopic_mass=45.03403978072,
    average_mass=45.06058048806766,
    dict_composition={'C': 2, 'H': 5, 'O': 1},
),
RefMolID.SIDECHAIN_U: RefMolInfo(
    name="sidechain_U",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C1H3Se1',
    monoisotopic_mass=94.93999689668999,
    average_mass=93.9939467159162,
    dict_composition={'C': 1, 'H': 3, 'Se': 1},
),
RefMolID.SIDECHAIN_V: RefMolInfo(
    name="sidechain_V",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C3H7',
    monoisotopic_mass=43.05477522561,
    average_mass=43.08779296859618,
    dict_composition={'C': 3, 'H': 7},
),
RefMolID.SIDECHAIN_W: RefMolInfo(
    name="sidechain_W",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C9H8N1',
    monoisotopic_mass=130.06567426227,
    average_mass=130.16685231450924,
    dict_composition={'C': 9, 'H': 8, 'N': 1},
),
RefMolID.SIDECHAIN_Y: RefMolInfo(
    name="sidechain_Y",
    label_type="",
    molecule_type="sidechain",
    chemical_formula='C7H7O1',
    monoisotopic_mass=107.04968984518,
    average_mass=107.13014147985547,
    dict_composition={'C': 7, 'H': 7, 'O': 1},
),
}
