"""Auto-generated XLMOD data"""
# DO NOT EDIT - generated by gen_xlmod.py

VERSION = "1.5.1"

import warnings

from .dclass import XlModInfo

try:
    XLMOD_MODIFICATIONS: dict[str, XlModInfo] = {
        "01000": XlModInfo(
            id="01000",
            name="hydrolyzed BS3",
            formula="C8H12O3",
            monoisotopic_mass=156.07864431,
            average_mass=156.17939099550614,
            dict_composition={'C': 8, 'H': 12, 'O': 3},
    ),
        "01001": XlModInfo(
            id="01001",
            name="ammonium amidated BS3",
            formula="C8H13NO2",
            monoisotopic_mass=155.094628715,
            average_mass=155.19463003668946,
            dict_composition={'C': 8, 'H': 13, 'O': 2, 'N': 1},
    ),
        "01002": XlModInfo(
            id="01002",
            name="hydrolyzed DSS",
            formula="C8H12O3",
            monoisotopic_mass=156.07864431,
            average_mass=156.17939099550614,
            dict_composition={'C': 8, 'H': 12, 'O': 3},
    ),
        "01003": XlModInfo(
            id="01003",
            name="ammonium amidated DSS",
            formula="C8H13NO2",
            monoisotopic_mass=155.094628715,
            average_mass=155.19463003668946,
            dict_composition={'C': 8, 'H': 13, 'O': 2, 'N': 1},
    ),
        "01004": XlModInfo(
            id="01004",
            name="hydrolyzed DSS-d4",
            formula=None,
            monoisotopic_mass=160.1037416836,
            average_mass=None,
            dict_composition=None,
    ),
        "01005": XlModInfo(
            id="01005",
            name="ammonium amidated DSS-d4",
            formula=None,
            monoisotopic_mass=159.1197260886,
            average_mass=None,
            dict_composition=None,
    ),
        "01006": XlModInfo(
            id="01006",
            name="hydrolyzed DSS-d12",
            formula=None,
            monoisotopic_mass=168.153965238,
            average_mass=None,
            dict_composition=None,
    ),
        "01007": XlModInfo(
            id="01007",
            name="ammonium amidated DSS-d12",
            formula=None,
            monoisotopic_mass=167.169949643,
            average_mass=None,
            dict_composition=None,
    ),
        "01008": XlModInfo(
            id="01008",
            name="hydrolyzed BS3-d4",
            formula="C8H8D4O3",
            monoisotopic_mass=160.103751286,
            average_mass=160.20403509176305,
            dict_composition={'C': 8, 'D': 4, 'H': 8, 'O': 3},
    ),
        "01009": XlModInfo(
            id="01009",
            name="ammonium amidated BS3-d4",
            formula="C8H9D4NO2",
            monoisotopic_mass=159.119735691,
            average_mass=159.21927413294634,
            dict_composition={'C': 8, 'D': 4, 'H': 9, 'N': 1, 'O': 2},
    ),
        "01010": XlModInfo(
            id="01010",
            name="hydrolyzed BS2G",
            formula="C5H6O3",
            monoisotopic_mass=114.0316941,
            average_mass=114.09953878096573,
            dict_composition={'C': 5, 'H': 6, 'O': 3},
    ),
        "01011": XlModInfo(
            id="01011",
            name="ammonium amidated BS2G",
            formula="C5H7NO2",
            monoisotopic_mass=113.047678505,
            average_mass=113.11477782214904,
            dict_composition={'C': 5, 'H': 7, 'N': 1, 'O': 2},
    ),
        "01012": XlModInfo(
            id="01012",
            name="hydrolyzed DSG",
            formula="C5H6O3",
            monoisotopic_mass=114.0316941,
            average_mass=114.09953878096573,
            dict_composition={'C': 5, 'H': 6, 'O': 3},
    ),
        "01013": XlModInfo(
            id="01013",
            name="ammonium amidated DSG",
            formula="C5H7NO2",
            monoisotopic_mass=113.047678505,
            average_mass=113.11477782214904,
            dict_composition={'C': 5, 'H': 7, 'N': 1, 'O': 2},
    ),
        "01014": XlModInfo(
            id="01014",
            name="hydrolyzed DSG-d4",
            formula="C5H2D4O3",
            monoisotopic_mass=118.0567741,
            average_mass=118.12418287722261,
            dict_composition={'C': 5, 'D': 4, 'H': 2, 'O': 3},
    ),
        "01015": XlModInfo(
            id="01015",
            name="ammonium amidated DSG-d4",
            formula="C5H3D4NO2",
            monoisotopic_mass=117.072758505,
            average_mass=117.13942191840592,
            dict_composition={'C': 5, 'D': 4, 'H': 3, 'N': 1, 'O': 2},
    ),
        "01016": XlModInfo(
            id="01016",
            name="hydrolyzed BS2G-d4",
            formula="C5H2D4O3",
            monoisotopic_mass=118.056801076,
            average_mass=118.12418287722261,
            dict_composition={'C': 5, 'D': 4, 'H': 2, 'O': 3},
    ),
        "01017": XlModInfo(
            id="01017",
            name="ammonium amidated BS2G-d4",
            formula="C5H3D4NO2",
            monoisotopic_mass=117.072785481,
            average_mass=117.13942191840592,
            dict_composition={'C': 5, 'D': 4, 'H': 3, 'N': 1, 'O': 2},
    ),
        "01018": XlModInfo(
            id="01018",
            name="BDP-NHP-stump",
            formula=None,
            monoisotopic_mass=197.032422395,
            average_mass=None,
            dict_composition=None,
    ),
        "01019": XlModInfo(
            id="01019",
            name="hydrolyzed DSP",
            formula="C6H8O3S2",
            monoisotopic_mass=191.99148557,
            average_mass=192.25573099806667,
            dict_composition={'C': 6, 'H': 8, 'O': 3, 'S': 2},
    ),
        "01020": XlModInfo(
            id="01020",
            name="ammonium amidated DSP",
            formula="C6H9NO2S2",
            monoisotopic_mass=191.007469975,
            average_mass=191.27097003924996,
            dict_composition={'C': 6, 'H': 9, 'N': 1, 'O': 2, 'S': 2},
    ),
        "01021": XlModInfo(
            id="01021",
            name="hydrolyzed EGS",
            formula="C10H12O7",
            monoisotopic_mass=244.0583027,
            average_mass=244.19848248624976,
            dict_composition={'C': 10, 'H': 12, 'O': 7},
    ),
        "01022": XlModInfo(
            id="01022",
            name="ammonium amidated EGS",
            formula="C10H13NO6",
            monoisotopic_mass=243.074287105,
            average_mass=243.21372152743305,
            dict_composition={'C': 10, 'H': 13, 'N': 1, 'O': 6},
    ),
        "01023": XlModInfo(
            id="01023",
            name="hydrolyzed BiPS",
            formula="C16H18N2O5S2",
            monoisotopic_mass=382.06571,
            average_mass=382.4547137775051,
            dict_composition={'C': 16, 'H': 18, 'N': 2, 'O': 5, 'S': 2},
    ),
        "01024": XlModInfo(
            id="01024",
            name="ammonium amidated BiPS",
            formula="C16H18N3O4S2",
            monoisotopic_mass=381.08169,
            average_mass=380.4620120646326,
            dict_composition={'C': 16, 'H': 18, 'N': 3, 'O': 4, 'S': 2},
    ),
        "01025": XlModInfo(
            id="01025",
            name="hydrolyzed CBDPS",
            formula="C19H25N7O5S3",
            monoisotopic_mass=527.10738,
            average_mass=527.6408102094573,
            dict_composition={'C': 19, 'H': 25, 'N': 7, 'O': 5, 'S': 3},
    ),
        "01026": XlModInfo(
            id="01026",
            name="ammonium amidated CBDPS",
            formula="C19H25N8O4S3",
            monoisotopic_mass=526.12336,
            average_mass=525.6481084965849,
            dict_composition={'C': 19, 'H': 25, 'N': 8, 'O': 4, 'S': 3},
    ),
        "01027": XlModInfo(
            id="01027",
            name="hydrolyzed DSA",
            formula="C6H8O3",
            monoisotopic_mass=128.0468,
            average_mass=128.12615618581253,
            dict_composition={'C': 6, 'H': 8, 'O': 3},
    ),
        "01028": XlModInfo(
            id="01028",
            name="ammonium amidated DSA",
            formula="C6H9NO2",
            monoisotopic_mass=127.06278,
            average_mass=127.14139522699584,
            dict_composition={'C': 6, 'H': 9, 'N': 1, 'O': 2},
    ),
        "01029": XlModInfo(
            id="01029",
            name="hydrolyzed DNBDPS",
            formula="C12H10N2O7S2",
            monoisotopic_mass=357.99294,
            average_mass=358.34705400675443,
            dict_composition={'C': 12, 'H': 10, 'N': 2, 'O': 7, 'S': 2},
    ),
        "01030": XlModInfo(
            id="01030",
            name="ammonium amidated DNBDPS",
            formula="C12H10N3O6S2",
            monoisotopic_mass=357.00892,
            average_mass=356.35435229388196,
            dict_composition={'C': 12, 'H': 10, 'N': 3, 'O': 6, 'S': 2},
    ),
        "01031": XlModInfo(
            id="01031",
            name="hydrolyzed TEABS",
            formula="C28H41N5O12S",
            monoisotopic_mass=671.24724,
            average_mass=671.7173385800493,
            dict_composition={'C': 28, 'H': 41, 'N': 5, 'O': 12, 'S': 1},
    ),
        "01032": XlModInfo(
            id="01032",
            name="ammonium amidated TEABS",
            formula="C28H41N6O11S",
            monoisotopic_mass=670.26322,
            average_mass=669.7246368671767,
            dict_composition={'C': 28, 'H': 41, 'N': 6, 'O': 11, 'S': 1},
    ),
        "01033": XlModInfo(
            id="01033",
            name="hydrolyzed DTSSP-d8",
            formula="C6D8O3S2",
            monoisotopic_mass=191.99149,
            average_mass=200.30501919058045,
            dict_composition={'C': 6, 'D': 8, 'O': 3, 'S': 2},
    ),
        "01034": XlModInfo(
            id="01034",
            name="ammonium amidated DTSSP-d8",
            formula="C6HD8NO2S2",
            monoisotopic_mass=191.00747,
            average_mass=199.32025823176377,
            dict_composition={'C': 6, 'D': 8, 'H': 1, 'N': 1, 'O': 2, 'S': 2},
    ),
        "01035": XlModInfo(
            id="01035",
            name="hydrolyzed DSP-d8",
            formula="C6D8O3S2",
            monoisotopic_mass=200.04165,
            average_mass=200.30501919058045,
            dict_composition={'C': 6, 'D': 8, 'O': 3, 'S': 2},
    ),
        "01036": XlModInfo(
            id="01036",
            name="ammonium amidated DSP-d8",
            formula="C6HD8NO2S2",
            monoisotopic_mass=199.05763,
            average_mass=199.32025823176377,
            dict_composition={'C': 6, 'D': 8, 'H': 1, 'N': 1, 'O': 2, 'S': 2},
    ),
        "01037": XlModInfo(
            id="01037",
            name="hydrolyzed Sulfo-EGS",
            formula="C10H12O7",
            monoisotopic_mass=244.0583028,
            average_mass=244.19848248624976,
            dict_composition={'C': 10, 'H': 12, 'O': 7},
    ),
        "01038": XlModInfo(
            id="01038",
            name="ammonium amidated Sulfo-EGS",
            formula="C10H12NO6",
            monoisotopic_mass=243.07428,
            average_mass=242.20578077337728,
            dict_composition={'C': 10, 'H': 12, 'N': 1, 'O': 6},
    ),
        "01039": XlModInfo(
            id="01039",
            name="hydrolyzed EGS-d12",
            formula="C10D12O7",
            monoisotopic_mass=256.13403,
            average_mass=256.2724147750204,
            dict_composition={'C': 10, 'D': 12, 'O': 7},
    ),
        "01040": XlModInfo(
            id="01040",
            name="ammonium amidated EGS-d12",
            formula="C10D12NO6",
            monoisotopic_mass=255.15001,
            average_mass=254.27971306214795,
            dict_composition={'C': 10, 'D': 12, 'N': 1, 'O': 6},
    ),
        "01041": XlModInfo(
            id="01041",
            name="hydrolyzed Sulfo-EGS-d12",
            formula="C10D12O7",
            monoisotopic_mass=256.13403,
            average_mass=256.2724147750204,
            dict_composition={'C': 10, 'D': 12, 'O': 7},
    ),
        "01042": XlModInfo(
            id="01042",
            name="ammonium amidated Sulfo-EGS-d12",
            formula="C10D12NO6",
            monoisotopic_mass=255.15001,
            average_mass=254.27971306214795,
            dict_composition={'C': 10, 'D': 12, 'N': 1, 'O': 6},
    ),
        "01043": XlModInfo(
            id="01043",
            name="hydrolyzed DSA-13C6",
            formula="H8O3",
            monoisotopic_mass=134.06696,
            average_mass=134.08186981582105,
            dict_composition={'H': 8, 'O': 3},
    ),
        "01044": XlModInfo(
            id="01044",
            name="ammonium amidated DSA-13C6",
            formula="H9NO2",
            monoisotopic_mass=133.08294,
            average_mass=133.09710885700434,
            dict_composition={'H': 9, 'N': 1, 'O': 2},
    ),
        "01045": XlModInfo(
            id="01045",
            name="hydrolyzed CBDPS-d8",
            formula="C19H17D8N7O5S3",
            monoisotopic_mass=535.15754,
            average_mass=535.6900984019711,
            dict_composition={'C': 19, 'D': 8, 'H': 17, 'N': 7, 'O': 5, 'S': 3},
    ),
        "01046": XlModInfo(
            id="01046",
            name="ammonium amidated CBDPS-d8",
            formula="C19H17D8N8O4S3",
            monoisotopic_mass=534.17352,
            average_mass=533.6973966890987,
            dict_composition={'C': 19, 'D': 8, 'H': 17, 'N': 8, 'O': 4, 'S': 3},
    ),
        "01047": XlModInfo(
            id="01047",
            name="hydrolyzed CBDPSS",
            formula="C19H25N7O5S3",
            monoisotopic_mass=527.10738,
            average_mass=527.6408102094573,
            dict_composition={'C': 19, 'H': 25, 'N': 7, 'O': 5, 'S': 3},
    ),
        "01048": XlModInfo(
            id="01048",
            name="ammonium amidated CBDPSS",
            formula="C19H25N8O4S3",
            monoisotopic_mass=526.12336,
            average_mass=525.6481084965849,
            dict_composition={'C': 19, 'H': 25, 'N': 8, 'O': 4, 'S': 3},
    ),
        "01049": XlModInfo(
            id="01049",
            name="hydrolyzed CBDPSS-d8",
            formula="C19H17D8N7O5S3",
            monoisotopic_mass=535.15754,
            average_mass=535.6900984019711,
            dict_composition={'C': 19, 'D': 8, 'H': 17, 'N': 7, 'O': 5, 'S': 3},
    ),
        "01050": XlModInfo(
            id="01050",
            name="ammonium amidated CBDPSS-d8",
            formula="C19H17D8N8O4S3",
            monoisotopic_mass=534.17352,
            average_mass=533.6973966890987,
            dict_composition={'C': 19, 'D': 8, 'H': 17, 'N': 8, 'O': 4, 'S': 3},
    ),
        "01051": XlModInfo(
            id="01051",
            name="hydrolyzed BS3-d12",
            formula="C8D12O3",
            monoisotopic_mass=168.15437,
            average_mass=168.25332328427683,
            dict_composition={'C': 8, 'D': 12, 'O': 3},
    ),
        "01052": XlModInfo(
            id="01052",
            name="ammonium amidated BS3-d12",
            formula="C8HD12NO2",
            monoisotopic_mass=167.17035,
            average_mass=167.26856232546015,
            dict_composition={'C': 8, 'D': 12, 'H': 1, 'N': 1, 'O': 2},
    ),
        "01053": XlModInfo(
            id="01053",
            name="hydrolyzed DSG-d6",
            formula="C5D6O3",
            monoisotopic_mass=120.07483,
            average_mass=120.13650492535106,
            dict_composition={'C': 5, 'D': 6, 'O': 3},
    ),
        "01054": XlModInfo(
            id="01054",
            name="ammonium amidated DSG-d6",
            formula="C5HD6NO2",
            monoisotopic_mass=119.09081,
            average_mass=119.15174396653437,
            dict_composition={'C': 5, 'D': 6, 'H': 1, 'N': 1, 'O': 2},
    ),
        "01055": XlModInfo(
            id="01055",
            name="hydrolyzed BS2G-d6",
            formula="C5D6O3",
            monoisotopic_mass=120.06877,
            average_mass=120.13650492535106,
            dict_composition={'C': 5, 'D': 6, 'O': 3},
    ),
        "01056": XlModInfo(
            id="01056",
            name="ammonium amidated BS2G-d6",
            formula="C5HD6NO2",
            monoisotopic_mass=119.08475,
            average_mass=119.15174396653437,
            dict_composition={'C': 5, 'D': 6, 'H': 1, 'N': 1, 'O': 2},
    ),
        "01057": XlModInfo(
            id="01057",
            name="hydrolyzed SDH",
            formula="C8H16N4O",
            monoisotopic_mass=184.13241119,
            average_mass=184.23915700887588,
            dict_composition={'C': 8, 'H': 16, 'N': 4, 'O': 1},
    ),
        "01058": XlModInfo(
            id="01058",
            name="hydrolyzed SDH-d12",
            formula="C8H4D12N4O",
            monoisotopic_mass=196.207732118,
            average_mass=196.31308929764657,
            dict_composition={'C': 8, 'D': 12, 'H': 4, 'N': 4, 'O': 1},
    ),
        "01059": XlModInfo(
            id="01059",
            name="hydrolyzed ADH",
            formula="C6H12N4O",
            monoisotopic_mass=156.10111105,
            average_mass=156.18592219918227,
            dict_composition={'C': 6, 'H': 12, 'N': 4, 'O': 1},
    ),
        "01060": XlModInfo(
            id="01060",
            name="hydrolyzed ADH-d8",
            formula="C6H4D8N4O",
            monoisotopic_mass=164.151325002,
            average_mass=164.23521039169606,
            dict_composition={'C': 6, 'D': 8, 'H': 4, 'N': 4, 'O': 1},
    ),
        "01061": XlModInfo(
            id="01061",
            name="hydrolyzed GDH",
            formula="C5H10N4O",
            monoisotopic_mass=142.08546098,
            average_mass=142.15930479433547,
            dict_composition={'C': 5, 'H': 10, 'N': 4, 'O': 1},
    ),
        "01062": XlModInfo(
            id="01062",
            name="hydrolyzed GDH-d6",
            formula="C5H4D6N4O",
            monoisotopic_mass=148.123121444,
            average_mass=148.1962709387208,
            dict_composition={'C': 5, 'D': 6, 'H': 4, 'N': 4, 'O': 1},
    ),
        "01063": XlModInfo(
            id="01063",
            name="hydrolyzed BCCL1",
            formula=None,
            monoisotopic_mass=355.12019,
            average_mass=None,
            dict_composition=None,
    ),
        "01064": XlModInfo(
            id="01064",
            name="hydrolyzed BCCL2",
            formula=None,
            monoisotopic_mass=411.18179,
            average_mass=None,
            dict_composition=None,
    ),
        "01065": XlModInfo(
            id="01065",
            name="hydrolyzed IRCX",
            formula=None,
            monoisotopic_mass=348.0,
            average_mass=None,
            dict_composition=None,
    ),
        "01066": XlModInfo(
            id="01066",
            name="hydrolyzed azide-DSG",
            formula=None,
            monoisotopic_mass=229.0,
            average_mass=None,
            dict_composition=None,
    ),
        "01067": XlModInfo(
            id="01067",
            name="hydrolyzed JMV 3378",
            formula=None,
            monoisotopic_mass=286.0,
            average_mass=None,
            dict_composition=None,
    ),
        "01068": XlModInfo(
            id="01068",
            name="hydrolyzed BuTuGPG",
            formula=None,
            monoisotopic_mass=1704.86,
            average_mass=None,
            dict_composition=None,
    ),
        "01070": XlModInfo(
            id="01070",
            name="hydrolyzed DEST",
            formula="C8H14N2O",
            monoisotopic_mass=154.11061312,
            average_mass=154.20986907787272,
            dict_composition={'C': 8, 'H': 14, 'N': 2, 'O': 1},
    ),
        "01071": XlModInfo(
            id="01071",
            name="ammonium amidated DEST",
            formula="C8H15N3",
            monoisotopic_mass=153.126593,
            average_mass=153.22510811905605,
            dict_composition={'C': 8, 'H': 15, 'N': 3},
    ),
        "01072": XlModInfo(
            id="01072",
            name="thioesterized DEST",
            formula="C10H17NOS",
            monoisotopic_mass=199.103084925,
            average_mass=199.31324732819184,
            dict_composition={'C': 10, 'H': 17, 'N': 1, 'O': 1, 'S': 1},
    ),
        "01073": XlModInfo(
            id="01073",
            name="hydrolyzed BS(PEG)5",
            formula="C14H24O8",
            monoisotopic_mass=320.1471147,
            average_mass=320.3361200461784,
            dict_composition={'C': 14, 'H': 24, 'O': 8},
    ),
        "01074": XlModInfo(
            id="01074",
            name="ammonium amidated BS(PEG)5",
            formula="C14H27NO7",
            monoisotopic_mass=320.1471147,
            average_mass=321.3672405954732,
            dict_composition={'C': 14, 'H': 27, 'N': 1, 'O': 7},
    ),
        "01075": XlModInfo(
            id="01075",
            name="hydrolyzed BSOCOES",
            formula="C6H8O7S",
            monoisotopic_mass=223.9990767,
            average_mass=224.18856328921274,
            dict_composition={'C': 6, 'H': 8, 'O': 7, 'S': 1},
    ),
        "01076": XlModInfo(
            id="01076",
            name="ammonium amidated BSOCOES",
            formula="C6H9NO6S",
            monoisotopic_mass=223.015061105,
            average_mass=223.20380233039603,
            dict_composition={'C': 6, 'H': 9, 'N': 1, 'O': 6, 'S': 1},
    ),
        "01077": XlModInfo(
            id="01077",
            name="hydrolyzed DST",
            formula="C4H4O5",
            monoisotopic_mass=132.0058747,
            average_mass=132.07173122475547,
            dict_composition={'C': 4, 'H': 4, 'O': 5},
    ),
        "01078": XlModInfo(
            id="01078",
            name="ammonium amidated DST",
            formula="C4H5NO4",
            monoisotopic_mass=131.021859105,
            average_mass=131.0869702659388,
            dict_composition={'C': 4, 'H': 5, 'N': 1, 'O': 4},
    ),
        "01079": XlModInfo(
            id="01079",
            name="hydrolyzed SDA",
            formula="C5H8O2",
            monoisotopic_mass=100.05242954,
            average_mass=100.11601536475901,
            dict_composition={'C': 5, 'H': 8, 'O': 2},
    ),
        "01080": XlModInfo(
            id="01080",
            name="oxidized SDA",
            formula="C5H6O2",
            monoisotopic_mass=98.03677947,
            average_mass=98.10013385664746,
            dict_composition={'C': 5, 'H': 6, 'O': 2},
    ),
        "01081": XlModInfo(
            id="01081",
            name="alkenized SDA",
            formula="C4H4O",
            monoisotopic_mass=68.02621477,
            average_mass=68.07411152748239,
            dict_composition={'C': 4, 'H': 4, 'O': 1},
    ),
        "01082": XlModInfo(
            id="01082",
            name="hydrolyzed LC-SDA",
            formula="C11H19NO3",
            monoisotopic_mass=213.136493555,
            average_mass=213.27388717554814,
            dict_composition={'C': 11, 'H': 19, 'N': 1, 'O': 3},
    ),
        "01083": XlModInfo(
            id="01083",
            name="oxidized LC-SDA",
            formula="C11H17NO3",
            monoisotopic_mass=211.120843485,
            average_mass=211.25800566743658,
            dict_composition={'C': 11, 'H': 17, 'N': 1, 'O': 3},
    ),
        "01084": XlModInfo(
            id="01084",
            name="alkenized LC-SDA",
            formula="C10H15NO2",
            monoisotopic_mass=181.110278785,
            average_mass=181.2319833382715,
            dict_composition={'C': 10, 'H': 15, 'N': 1, 'O': 2},
    ),
        "01085": XlModInfo(
            id="01085",
            name="hydrolyzed L-Photo-Leucine",
            formula="C-1H-2O",
            monoisotopic_mass=1.97926456,
            average_mass=1.9727875194714741,
            dict_composition={'C': -1, 'H': -2, 'O': 1},
    ),
        "01086": XlModInfo(
            id="01086",
            name="oxidized L-Photo-Leucine",
            formula="C-1H-4O",
            monoisotopic_mass=-0.036385501,
            average_mass=-0.04309398864008074,
            dict_composition={'C': -1, 'H': -4, 'O': 1},
    ),
        "01087": XlModInfo(
            id="01087",
            name="alkenized L-Photo-Leucine",
            formula="C-2H-6",
            monoisotopic_mass=-30.04695021,
            average_mass=-30.06911631780516,
            dict_composition={'C': -2, 'H': -6},
    ),
        "01088": XlModInfo(
            id="01088",
            name="hydrolyzed L-Photo-Methionine",
            formula="CH2OS-1",
            monoisotopic_mass=-1.96150744,
            average_mass=-2.0387650769619867,
            dict_composition={'C': 1, 'H': 2, 'O': 1, 'S': -1},
    ),
        "01089": XlModInfo(
            id="01089",
            name="oxidized L-Photo-Methionine",
            formula="COS-1",
            monoisotopic_mass=-3.97715607,
            average_mass=-4.054646585073542,
            dict_composition={'C': 1, 'O': 1, 'S': -1},
    ),
        "01090": XlModInfo(
            id="01090",
            name="alkenized L-Photo-Methionine",
            formula="H-2S-1",
            monoisotopic_mass=-33.98772221,
            average_mass=-34.08066891423862,
            dict_composition={'H': -2, 'S': -1},
    ),
        "01092": XlModInfo(
            id="01092",
            name="hydrolyzed BMPS",
            formula="C7H7NO4",
            monoisotopic_mass=169.037507765,
            average_mass=169.1350594642561,
            dict_composition={'C': 7, 'H': 7, 'O': 4, 'N': 1},
    ),
        "01093": XlModInfo(
            id="01093",
            name="ammonium amidated BMPS",
            formula="C7H8N2O3",
            monoisotopic_mass=168.05349217,
            average_mass=168.1502985054394,
            dict_composition={'C': 7, 'H': 8, 'O': 3, 'N': 2},
    ),
        "01094": XlModInfo(
            id="01094",
            name="hydrolyzed PDH",
            formula="C7H12N4",
            monoisotopic_mass=170.11676112,
            average_mass=152.19725317159927,
            dict_composition={'C': 7, 'H': 12, 'N': 4},
    ),
        "01095": XlModInfo(
            id="01095",
            name="hydrolyzed PDH-d10",
            formula="C7H2D10N4",
            monoisotopic_mass=180.17952856,
            average_mass=162.25886341224148,
            dict_composition={'C': 7, 'D': 10, 'H': 2, 'N': 4},
    ),
        "01096": XlModInfo(
            id="01096",
            name="hydrolyzed SuDP",
            formula=None,
            monoisotopic_mass=294.0852,
            average_mass=None,
            dict_composition=None,
    ),
        "01097": XlModInfo(
            id="01097",
            name="hydrolyzed L-Photo-Isoleucine",
            formula="C-1H-2O",
            monoisotopic_mass=1.97926456,
            average_mass=1.9727875194714741,
            dict_composition={'C': -1, 'H': -2, 'O': 1},
    ),
        "01098": XlModInfo(
            id="01098",
            name="oxidized L-Photo-Isoleucine",
            formula="C-1H-4O",
            monoisotopic_mass=-0.036385501,
            average_mass=-0.04309398864008074,
            dict_composition={'C': -1, 'H': -4, 'O': 1},
    ),
        "01099": XlModInfo(
            id="01099",
            name="alkenized L-Photo-Isoleucine",
            formula="C-2H-6",
            monoisotopic_mass=-30.04695021,
            average_mass=-30.06911631780516,
            dict_composition={'C': -2, 'H': -6},
    ),
        "01100": XlModInfo(
            id="01100",
            name="hydrolyzed Sulfo-SBED",
            formula=None,
            monoisotopic_mass=652.217,
            average_mass=None,
            dict_composition=None,
    ),
        "01102": XlModInfo(
            id="01102",
            name="hydrolized PL",
            formula=None,
            monoisotopic_mass=334.15,
            average_mass=None,
            dict_composition=None,
    ),
        "01711": XlModInfo(
            id="01711",
            name="bis-[3-(2-ketobutyraldehyde)ether",
            formula=None,
            monoisotopic_mass=230.079,
            average_mass=None,
            dict_composition=None,
    ),
        "01712": XlModInfo(
            id="01712",
            name="mechlorethamine",
            formula=None,
            monoisotopic_mass=83.073,
            average_mass=None,
            dict_composition=None,
    ),
        "01713": XlModInfo(
            id="01713",
            name="4-[bis-(2-chloroethyl)amino]benzenebutanoic acid",
            formula=None,
            monoisotopic_mass=231.126,
            average_mass=None,
            dict_composition=None,
    ),
        "01714": XlModInfo(
            id="01714",
            name="sym-triazine trichloride",
            formula=None,
            monoisotopic_mass=110.962,
            average_mass=None,
            dict_composition=None,
    ),
        "01715": XlModInfo(
            id="01715",
            name="Heteroconjugate 20",
            formula=None,
            monoisotopic_mass=1554.6871,
            average_mass=None,
            dict_composition=None,
    ),
        "01900": XlModInfo(
            id="01900",
            name="L-Photo-Leucine",
            formula="C-1H-4",
            monoisotopic_mass=-16.0313,
            average_mass=-16.042498912958358,
            dict_composition={'C': -1, 'H': -4},
    ),
        "01901": XlModInfo(
            id="01901",
            name="L-Photo-Methionine",
            formula="CS-1",
            monoisotopic_mass=-19.972072,
            average_mass=-20.05405150939182,
            dict_composition={'C': 1, 'S': -1},
    ),
        "01902": XlModInfo(
            id="01902",
            name="L-Photo-Isoleucine",
            formula="C-1H-4",
            monoisotopic_mass=-16.0313,
            average_mass=-16.042498912958358,
            dict_composition={'C': -1, 'H': -4},
    ),
        "02000": XlModInfo(
            id="02000",
            name="BS3",
            formula="C8H10O2",
            monoisotopic_mass=138.06807961,
            average_mass=138.1641045630763,
            dict_composition={'C': 8, 'H': 10, 'O': 2},
    ),
        "02001": XlModInfo(
            id="02001",
            name="DSS",
            formula="C8H10O2",
            monoisotopic_mass=138.06807961,
            average_mass=138.1641045630763,
            dict_composition={'C': 8, 'H': 10, 'O': 2},
    ),
        "02002": XlModInfo(
            id="02002",
            name="DSS-d4",
            formula="C8H6D4O2",
            monoisotopic_mass=142.093186586,
            average_mass=142.1887486593332,
            dict_composition={'C': 8, 'D': 4, 'H': 6, 'O': 2},
    ),
        "02003": XlModInfo(
            id="02003",
            name="DSS-d12",
            formula="C8D10O2",
            monoisotopic_mass=150.143400538,
            average_mass=148.22571480371855,
            dict_composition={'C': 8, 'D': 10, 'O': 2},
    ),
        "02004": XlModInfo(
            id="02004",
            name="BS3-d4",
            formula=None,
            monoisotopic_mass=142.093186586,
            average_mass=None,
            dict_composition=None,
    ),
        "02005": XlModInfo(
            id="02005",
            name="BS2G",
            formula="C5H4O2",
            monoisotopic_mass=96.0211294,
            average_mass=96.0842523485359,
            dict_composition={'C': 5, 'H': 4, 'O': 2},
    ),
        "02006": XlModInfo(
            id="02006",
            name="DSG",
            formula="C5H4O2",
            monoisotopic_mass=96.0211294,
            average_mass=96.0842523485359,
            dict_composition={'C': 5, 'H': 4, 'O': 2},
    ),
        "02007": XlModInfo(
            id="02007",
            name="DSG-d4",
            formula="C5D4O2",
            monoisotopic_mass=100.046236376,
            average_mass=100.10889644479279,
            dict_composition={'C': 5, 'D': 4, 'O': 2},
    ),
        "02008": XlModInfo(
            id="02008",
            name="BS2G-d4",
            formula="C5D4O2",
            monoisotopic_mass=100.046236376,
            average_mass=100.10889644479279,
            dict_composition={'C': 5, 'D': 4, 'O': 2},
    ),
        "02009": XlModInfo(
            id="02009",
            name="Disulfide",
            formula="H-2",
            monoisotopic_mass=-2.01565007,
            average_mass=-2.0158815081115544,
            dict_composition={'H': -2},
    ),
        "02010": XlModInfo(
            id="02010",
            name="1-ethyl-3-(3-Dimethylaminopropyl)carbodiimide hydrochloride",
            formula="H-2O-1",
            monoisotopic_mass=-18.01056027,
            average_mass=-18.015286432429832,
            dict_composition={'H': -2, 'O': -1},
    ),
        "02011": XlModInfo(
            id="02011",
            name="BDP-NHP",
            formula=None,
            monoisotopic_mass=1241.469925525,
            average_mass=None,
            dict_composition=None,
    ),
        "02013": XlModInfo(
            id="02013",
            name="BMPS",
            formula="C7H5NO3",
            monoisotopic_mass=151.026943065,
            average_mass=151.11977303182627,
            dict_composition={'C': 7, 'H': 5, 'O': 3, 'N': 1},
    ),
        "02029": XlModInfo(
            id="02029",
            name="DSP",
            formula="C6H6O2S2",
            monoisotopic_mass=173.98092087,
            average_mass=174.24044456563684,
            dict_composition={'C': 6, 'H': 6, 'O': 2, 'S': 2},
    ),
        "02030": XlModInfo(
            id="02030",
            name="DSP-d8",
            formula="C6D6O2S2",
            monoisotopic_mass=182.0314167,
            average_mass=180.2774107100222,
            dict_composition={'C': 6, 'D': 6, 'O': 2, 'S': 2},
    ),
        "02032": XlModInfo(
            id="02032",
            name="DST",
            formula="C4H2O4",
            monoisotopic_mass=113.99531,
            average_mass=114.05644479232566,
            dict_composition={'C': 4, 'H': 2, 'O': 4},
    ),
        "02033": XlModInfo(
            id="02033",
            name="DTSSP",
            formula="C6H6O2S2",
            monoisotopic_mass=173.98093,
            average_mass=174.24044456563684,
            dict_composition={'C': 6, 'H': 6, 'O': 2, 'S': 2},
    ),
        "02034": XlModInfo(
            id="02034",
            name="EGS",
            formula="C10H10O6",
            monoisotopic_mass=226.047738,
            average_mass=226.18319605381993,
            dict_composition={'C': 10, 'H': 10, 'O': 6},
    ),
        "02035": XlModInfo(
            id="02035",
            name="Sulfo-EGS",
            formula="C10H10O6",
            monoisotopic_mass=226.04774,
            average_mass=226.18319605381993,
            dict_composition={'C': 10, 'H': 10, 'O': 6},
    ),
        "02040": XlModInfo(
            id="02040",
            name="BiPS",
            formula="C16H16N2O4S2",
            monoisotopic_mass=364.05515,
            average_mass=364.4394273450752,
            dict_composition={'C': 16, 'H': 16, 'N': 2, 'O': 4, 'S': 2},
    ),
        "02043": XlModInfo(
            id="02043",
            name="DSA",
            formula="C6H6O2",
            monoisotopic_mass=110.03624,
            average_mass=110.1108697533827,
            dict_composition={'C': 6, 'H': 6, 'O': 2},
    ),
        "02044": XlModInfo(
            id="02044",
            name="DNBDPS",
            formula="C12H9N2O6S2",
            monoisotopic_mass=339.98238,
            average_mass=341.33970832838037,
            dict_composition={'C': 12, 'H': 9, 'N': 2, 'O': 6, 'S': 2},
    ),
        "02045": XlModInfo(
            id="02045",
            name="TEABS",
            formula="C28H39N5O11S",
            monoisotopic_mass=653.23668,
            average_mass=653.7020521476194,
            dict_composition={'C': 28, 'H': 39, 'N': 5, 'O': 11, 'S': 1},
    ),
        "02048": XlModInfo(
            id="02048",
            name="DTSSP-d8",
            formula="C6D6O2S2",
            monoisotopic_mass=182.03109,
            average_mass=180.2774107100222,
            dict_composition={'C': 6, 'D': 6, 'O': 2, 'S': 2},
    ),
        "02049": XlModInfo(
            id="02049",
            name="EGS-d12",
            formula="C10D10O6",
            monoisotopic_mass=238.12347,
            average_mass=236.24480629446214,
            dict_composition={'C': 10, 'D': 10, 'O': 6},
    ),
        "02050": XlModInfo(
            id="02050",
            name="Sulfo-EGS-d12",
            formula="C10D10O6",
            monoisotopic_mass=238.12347,
            average_mass=236.24480629446214,
            dict_composition={'C': 10, 'D': 10, 'O': 6},
    ),
        "02051": XlModInfo(
            id="02051",
            name="PCAS",
            formula="C6H3NO",
            monoisotopic_mass=105.02146,
            average_mass=105.0943457783429,
            dict_composition={'C': 6, 'H': 3, 'N': 1, 'O': 1},
    ),
        "02052": XlModInfo(
            id="02052",
            name="PCAS-d4",
            formula="C6D3NO",
            monoisotopic_mass=109.04812,
            average_mass=108.11282885053555,
            dict_composition={'C': 6, 'D': 3, 'N': 1, 'O': 1},
    ),
        "02053": XlModInfo(
            id="02053",
            name="DSA-13C6",
            formula="H6O2",
            monoisotopic_mass=116.0564,
            average_mass=116.06658338339122,
            dict_composition={'H': 6, 'O': 2},
    ),
        "02054": XlModInfo(
            id="02054",
            name="CBDPS-d8",
            formula="C19H15D8N7O4S3",
            monoisotopic_mass=517.14698,
            average_mass=517.6748119695413,
            dict_composition={'C': 19, 'D': 8, 'H': 15, 'N': 7, 'O': 4, 'S': 3},
    ),
        "02055": XlModInfo(
            id="02055",
            name="CBDPSS",
            formula="C19H23N7O4S3",
            monoisotopic_mass=509.09682,
            average_mass=509.6255237770275,
            dict_composition={'C': 19, 'H': 23, 'N': 7, 'O': 4, 'S': 3},
    ),
        "02056": XlModInfo(
            id="02056",
            name="CBDPSS-d8",
            formula="C19H15D8N7O4S3",
            monoisotopic_mass=517.14698,
            average_mass=517.6748119695413,
            dict_composition={'C': 19, 'D': 8, 'H': 15, 'N': 7, 'O': 4, 'S': 3},
    ),
        "02057": XlModInfo(
            id="02057",
            name="SDH",
            formula="C8H14N4",
            monoisotopic_mass=166.12184649,
            average_mass=166.22387057644605,
            dict_composition={'C': 8, 'H': 14, 'N': 4},
    ),
        "02058": XlModInfo(
            id="02058",
            name="SDH-d12",
            formula="C8H2D12N4",
            monoisotopic_mass=178.1971667418,
            average_mass=178.29780286521674,
            dict_composition={'C': 8, 'D': 12, 'H': 2, 'N': 4},
    ),
        "02059": XlModInfo(
            id="02059",
            name="ADH",
            formula="C6H10N4",
            monoisotopic_mass=138.09054635,
            average_mass=138.17063576675244,
            dict_composition={'C': 6, 'H': 10, 'N': 4},
    ),
        "02060": XlModInfo(
            id="02060",
            name="ADH-d8",
            formula="C6H2D8N4",
            monoisotopic_mass=146.140760302,
            average_mass=146.21992395926623,
            dict_composition={'C': 6, 'D': 8, 'H': 2, 'N': 4},
    ),
        "02061": XlModInfo(
            id="02061",
            name="GDH",
            formula="C5H8N4",
            monoisotopic_mass=124.07489628,
            average_mass=124.14401836190564,
            dict_composition={'C': 5, 'H': 8, 'N': 4},
    ),
        "02062": XlModInfo(
            id="02062",
            name="GDH-d6",
            formula="C5H2D6N4",
            monoisotopic_mass=130.112556744,
            average_mass=130.18098450629097,
            dict_composition={'C': 5, 'D': 6, 'H': 2, 'N': 4},
    ),
        "02063": XlModInfo(
            id="02063",
            name="BS3-d12",
            formula=None,
            monoisotopic_mass=150.14381,
            average_mass=None,
            dict_composition=None,
    ),
        "02064": XlModInfo(
            id="02064",
            name="DSG-d6",
            formula="C5D6O2",
            monoisotopic_mass=102.05821,
            average_mass=104.13710000103279,
            dict_composition={'C': 5, 'D': 6, 'O': 2},
    ),
        "02065": XlModInfo(
            id="02065",
            name="BS2G-d6",
            formula="C5D4O2",
            monoisotopic_mass=100.046236376,
            average_mass=100.10889644479279,
            dict_composition={'C': 5, 'D': 4, 'O': 2},
    ),
        "02078": XlModInfo(
            id="02078",
            name="BSOCOES",
            formula="C6H6O6S",
            monoisotopic_mass=205.988512,
            average_mass=206.17327685678288,
            dict_composition={'C': 6, 'H': 6, 'O': 6, 'S': 1},
    ),
        "02103": XlModInfo(
            id="02103",
            name="1,4-diacetalbenzene",
            formula=None,
            monoisotopic_mass=190.027,
            average_mass=None,
            dict_composition=None,
    ),
        "02107": XlModInfo(
            id="02107",
            name="BCCL1",
            formula=None,
            monoisotopic_mass=337.10962,
            average_mass=None,
            dict_composition=None,
    ),
        "02108": XlModInfo(
            id="02108",
            name="BCCL2",
            formula=None,
            monoisotopic_mass=393.17222,
            average_mass=None,
            dict_composition=None,
    ),
        "02109": XlModInfo(
            id="02109",
            name="SBC",
            formula=None,
            monoisotopic_mass=236.09,
            average_mass=None,
            dict_composition=None,
    ),
        "02110": XlModInfo(
            id="02110",
            name="SBDC",
            formula=None,
            monoisotopic_mass=238.1,
            average_mass=None,
            dict_composition=None,
    ),
        "02114": XlModInfo(
            id="02114",
            name="IRCX",
            formula=None,
            monoisotopic_mass=330.0,
            average_mass=None,
            dict_composition=None,
    ),
        "02115": XlModInfo(
            id="02115",
            name="BAMG",
            formula=None,
            monoisotopic_mass=125.048,
            average_mass=None,
            dict_composition=None,
    ),
        "02116": XlModInfo(
            id="02116",
            name="azide-DSG",
            formula=None,
            monoisotopic_mass=211.0,
            average_mass=None,
            dict_composition=None,
    ),
        "02118": XlModInfo(
            id="02118",
            name="JMV 3378",
            formula=None,
            monoisotopic_mass=268.0,
            average_mass=None,
            dict_composition=None,
    ),
        "02119": XlModInfo(
            id="02119",
            name="BuTuGPG",
            formula=None,
            monoisotopic_mass=1686.84,
            average_mass=None,
            dict_composition=None,
    ),
        "02124": XlModInfo(
            id="02124",
            name="SDAD",
            formula=None,
            monoisotopic_mass=273.0,
            average_mass=None,
            dict_composition=None,
    ),
        "02125": XlModInfo(
            id="02125",
            name="Sulfo-SDAD",
            formula=None,
            monoisotopic_mass=273.0,
            average_mass=None,
            dict_composition=None,
    ),
        "02126": XlModInfo(
            id="02126",
            name="DSSO",
            formula="C6H6O3S",
            monoisotopic_mass=158.0037648,
            average_mass=158.17506208382804,
            dict_composition={'C': 6, 'O': 3, 'S': 1, 'H': 6},
    ),
        "02127": XlModInfo(
            id="02127",
            name="DEST",
            formula="C8H12N2",
            monoisotopic_mass=136.10004842,
            average_mass=136.19458264544292,
            dict_composition={'C': 8, 'H': 12, 'N': 2},
    ),
        "02128": XlModInfo(
            id="02128",
            name="cis-Diamminedichloroplatinum (II)",
            formula=None,
            monoisotopic_mass=225.995,
            average_mass=None,
            dict_composition=None,
    ),
        "02134": XlModInfo(
            id="02134",
            name="SDA",
            formula="C5H6O",
            monoisotopic_mass=82.04186484,
            average_mass=82.10072893232919,
            dict_composition={'C': 5, 'H': 6, 'O': 1},
    ),
        "02135": XlModInfo(
            id="02135",
            name="LC-SDA",
            formula="C11H12NO2",
            monoisotopic_mass=195.125928855,
            average_mass=190.2188969728394,
            dict_composition={'C': 11, 'H': 12, 'N': 1, 'O': 2},
    ),
        "02139": XlModInfo(
            id="02139",
            name="DMP",
            formula="C7H10N2",
            monoisotopic_mass=122.08439835,
            average_mass=122.1679652405961,
            dict_composition={'C': 7, 'H': 10, 'N': 2},
    ),
        "02198": XlModInfo(
            id="02198",
            name="BS(PEG)5",
            formula="C14H22O7",
            monoisotopic_mass=302.13655,
            average_mass=302.3208336137485,
            dict_composition={'C': 14, 'H': 22, 'O': 7},
    ),
        "02206": XlModInfo(
            id="02206",
            name="TPAL",
            formula="C8H6",
            monoisotopic_mass=102.04695021,
            average_mass=102.13353169821664,
            dict_composition={'C': 8, 'H': 6},
    ),
        "02207": XlModInfo(
            id="02207",
            name="DEB",
            formula="C10H6",
            monoisotopic_mass=126.04695021,
            average_mass=126.15500349168714,
            dict_composition={'C': 10, 'H': 6},
    ),
        "02209": XlModInfo(
            id="02209",
            name="PDH",
            formula="C7H12N4",
            monoisotopic_mass=152.10619642,
            average_mass=152.19725317159927,
            dict_composition={'C': 7, 'H': 12, 'N': 4},
    ),
        "02210": XlModInfo(
            id="02210",
            name="PDH-d10",
            formula="C7H2D10N4",
            monoisotopic_mass=162.16896386,
            average_mass=162.25886341224148,
            dict_composition={'C': 7, 'D': 10, 'H': 2, 'N': 4},
    ),
        "02215": XlModInfo(
            id="02215",
            name="SDA-13C5",
            formula="H6O",
            monoisotopic_mass=87.05866484,
            average_mass=87.06382362400294,
            dict_composition={'H': 6, 'O': 1},
    ),
        "02227": XlModInfo(
            id="02227",
            name="PL",
            formula=None,
            monoisotopic_mass=316.14,
            average_mass=None,
            dict_composition=None,
    ),
        "02234": XlModInfo(
            id="02234",
            name="PIR-I",
            formula="C6H10NO2",
            monoisotopic_mass=128.0712,
            average_mass=128.14933598105162,
            dict_composition={'C': 6, 'H': 10, 'O': 2, 'N': 1},
    ),
        "02235": XlModInfo(
            id="02235",
            name="PIR-II",
            formula="C4H6NO2",
            monoisotopic_mass=100.0399,
            average_mass=100.09610117135801,
            dict_composition={'C': 4, 'H': 6, 'O': 2, 'N': 1},
    ),
        "02236": XlModInfo(
            id="02236",
            name="PIR-III",
            formula="C4H6NO2",
            monoisotopic_mass=100.0399,
            average_mass=100.09610117135801,
            dict_composition={'C': 4, 'H': 6, 'O': 2, 'N': 1},
    ),
        "02254": XlModInfo(
            id="02254",
            name="ARGO1",
            formula=None,
            monoisotopic_mass=326.079,
            average_mass=None,
            dict_composition=None,
    ),
        "02255": XlModInfo(
            id="02255",
            name="ARGO2",
            formula=None,
            monoisotopic_mass=370.105,
            average_mass=None,
            dict_composition=None,
    ),
        "02256": XlModInfo(
            id="02256",
            name="ARGO3",
            formula=None,
            monoisotopic_mass=414.131,
            average_mass=None,
            dict_composition=None,
    ),
        "02257": XlModInfo(
            id="02257",
            name="KARGO",
            formula=None,
            monoisotopic_mass=352.095,
            average_mass=None,
            dict_composition=None,
    ),
        "03001": XlModInfo(
            id="03001",
            name="CBDPS",
            formula="C19H23N7O4S3",
            monoisotopic_mass=509.09682,
            average_mass=509.6255237770275,
            dict_composition={'C': 19, 'H': 23, 'N': 7, 'O': 4, 'S': 3},
    ),
        "03002": XlModInfo(
            id="03002",
            name="Sulfo-SBED",
            formula=None,
            monoisotopic_mass=634.207,
            average_mass=None,
            dict_composition=None,
    ),
        "03009": XlModInfo(
            id="03009",
            name="NNP9",
            formula="C7H2D10N4",
            monoisotopic_mass=314.1127,
            average_mass=162.25886341224148,
            dict_composition={'C': 7, 'D': 10, 'H': 2, 'N': 4},
    ),
        "03010": XlModInfo(
            id="03010",
            name="TATA",
            formula=None,
            monoisotopic_mass=200.05,
            average_mass=None,
            dict_composition=None,
    ),
        "03011": XlModInfo(
            id="03011",
            name="TATA-13C6",
            formula=None,
            monoisotopic_mass=206.07016,
            average_mass=None,
            dict_composition=None,
    ),
        "09317": XlModInfo(
            id="09317",
            name="DSAU",
            formula="C5H4N2O3",
            monoisotopic_mass=140.02219198,
            average_mass=140.09706369574576,
            dict_composition={'C': 5, 'H': 4, 'N': 2, 'O': 3},
    ),
        "09320": XlModInfo(
            id="09320",
            name="QKiso",
            formula="H-3N-1",
            monoisotopic_mass=-17.026549,
            average_mass=-17.030525473613128,
            dict_composition={'H': -3, 'N': -1},
    ),
    }

    XLMOD_NAME_TO_ID: dict[str, str] = {
        mod.name: mod.id
        for mod in XLMOD_MODIFICATIONS.values()
    }
except Exception as e:
    warnings.warn(
        f"Exception in xlmod_data: {e}. Using empty dictionaries.",
        UserWarning,
        stacklevel=2
    )
    XLMOD_MODIFICATIONS: dict[str, XlModInfo] = {}
    XLMOD_NAME_TO_ID: dict[str, str] = {}
