"""Auto-generated PSI-MOD data"""
# DO NOT EDIT - generated by gen_psimod.py

import warnings

from .dclass import PsimodInfo

VERSION = "1.032.4"


try:
    PSI_MODIFICATIONS: dict[str, PsimodInfo] = {
    "00007": PsimodInfo(
        id="00007",
        name="selenium substitution for sulfur",
        formula="S-1Se",
        monoisotopic_mass=47.94445,
        average_mass=46.91,
        dict_composition={'S': -1, 'Se': 1},
    ),
    "00010": PsimodInfo(
        id="00010",
        name="L-alanine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00011": PsimodInfo(
        id="00011",
        name="L-arginine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00012": PsimodInfo(
        id="00012",
        name="L-asparagine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00013": PsimodInfo(
        id="00013",
        name="L-aspartic acid residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00014": PsimodInfo(
        id="00014",
        name="L-cysteine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00015": PsimodInfo(
        id="00015",
        name="L-glutamic acid residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00016": PsimodInfo(
        id="00016",
        name="L-glutamine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00017": PsimodInfo(
        id="00017",
        name="glycine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00018": PsimodInfo(
        id="00018",
        name="L-histidine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00019": PsimodInfo(
        id="00019",
        name="L-isoleucine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00020": PsimodInfo(
        id="00020",
        name="L-leucine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00021": PsimodInfo(
        id="00021",
        name="L-lysine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00022": PsimodInfo(
        id="00022",
        name="L-methionine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00023": PsimodInfo(
        id="00023",
        name="L-phenylalanine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00024": PsimodInfo(
        id="00024",
        name="L-proline residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00025": PsimodInfo(
        id="00025",
        name="L-serine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00026": PsimodInfo(
        id="00026",
        name="L-threonine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00027": PsimodInfo(
        id="00027",
        name="L-tryptophan residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00028": PsimodInfo(
        id="00028",
        name="L-tyrosine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00029": PsimodInfo(
        id="00029",
        name="L-valine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00030": PsimodInfo(
        id="00030",
        name="N-formyl-L-methionine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00031": PsimodInfo(
        id="00031",
        name="L-selenocysteine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00034": PsimodInfo(
        id="00034",
        name="L-cystine (cross-link)",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00035": PsimodInfo(
        id="00035",
        name="(2S,3R)-3-hydroxyasparagine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "00036": PsimodInfo(
        id="00036",
        name="(2S,3R)-3-hydroxyaspartic acid",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "00037": PsimodInfo(
        id="00037",
        name="5-hydroxy-L-lysine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "00038": PsimodInfo(
        id="00038",
        name="3-hydroxy-L-proline",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "00039": PsimodInfo(
        id="00039",
        name="4-hydroxy-L-proline",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "00040": PsimodInfo(
        id="00040",
        name="2-pyrrolidone-5-carboxylic acid (Gln)",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "00041": PsimodInfo(
        id="00041",
        name="L-gamma-carboxyglutamic acid",
        formula="CO2",
        monoisotopic_mass=43.989829,
        average_mass=44.01,
        dict_composition={'C': 1, 'O': 2},
    ),
    "00042": PsimodInfo(
        id="00042",
        name="L-aspartic 4-phosphoric anhydride",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
    "00043": PsimodInfo(
        id="00043",
        name="S-phospho-L-cysteine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
    "00044": PsimodInfo(
        id="00044",
        name="1'-phospho-L-histidine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
    "00045": PsimodInfo(
        id="00045",
        name="3'-phospho-L-histidine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
    "00046": PsimodInfo(
        id="00046",
        name="O-phospho-L-serine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
    "00047": PsimodInfo(
        id="00047",
        name="O-phospho-L-threonine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
    "00048": PsimodInfo(
        id="00048",
        name="O4'-phospho-L-tyrosine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
    "00049": PsimodInfo(
        id="00049",
        name="2'-[3-carboxamido-3-(trimethylammonio)propyl]-L-histidine",
        formula="C7H15N2O",
        monoisotopic_mass=143.11789,
        average_mass=143.21,
        dict_composition={'C': 7, 'H': 15, 'N': 2, 'O': 1},
    ),
    "00050": PsimodInfo(
        id="00050",
        name="N-acetyl-L-alanine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00051": PsimodInfo(
        id="00051",
        name="N-acetyl-L-aspartic acid",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00052": PsimodInfo(
        id="00052",
        name="N-acetyl-L-cysteine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00053": PsimodInfo(
        id="00053",
        name="N-acetyl-L-glutamic acid",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00054": PsimodInfo(
        id="00054",
        name="N-acetyl-L-glutamine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00055": PsimodInfo(
        id="00055",
        name="N-acetylglycine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00056": PsimodInfo(
        id="00056",
        name="N-acetyl-L-isoleucine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00057": PsimodInfo(
        id="00057",
        name="N2-acetyl-L-lysine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00058": PsimodInfo(
        id="00058",
        name="N-acetyl-L-methionine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00059": PsimodInfo(
        id="00059",
        name="N-acetyl-L-proline",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00060": PsimodInfo(
        id="00060",
        name="N-acetyl-L-serine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00061": PsimodInfo(
        id="00061",
        name="N-acetyl-L-threonine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00062": PsimodInfo(
        id="00062",
        name="N-acetyl-L-tyrosine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00063": PsimodInfo(
        id="00063",
        name="N-acetyl-L-valine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00064": PsimodInfo(
        id="00064",
        name="N6-acetyl-L-lysine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00065": PsimodInfo(
        id="00065",
        name="S-acetyl-L-cysteine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00066": PsimodInfo(
        id="00066",
        name="N-formylglycine",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
    "00067": PsimodInfo(
        id="00067",
        name="N-D-glucuronoylglycine",
        formula="C6H8O6",
        monoisotopic_mass=176.032088,
        average_mass=176.12,
        dict_composition={'C': 6, 'H': 8, 'O': 6},
    ),
    "00068": PsimodInfo(
        id="00068",
        name="N-myristoylglycine",
        formula="C14H26O",
        monoisotopic_mass=210.198365,
        average_mass=210.36,
        dict_composition={'C': 14, 'H': 26, 'O': 1},
    ),
    "00069": PsimodInfo(
        id="00069",
        name="N-palmitoyl-L-cysteine",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
    "00070": PsimodInfo(
        id="00070",
        name="N-methyl-L-alanine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00071": PsimodInfo(
        id="00071",
        name="N,N,N-trimethyl-L-alanine",
        formula="C3H7",
        monoisotopic_mass=43.054227,
        average_mass=43.09,
        dict_composition={'C': 3, 'H': 7},
    ),
    "00072": PsimodInfo(
        id="00072",
        name="N-methylglycine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00073": PsimodInfo(
        id="00073",
        name="N-methyl-L-methionine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00074": PsimodInfo(
        id="00074",
        name="N-methyl-L-phenylalanine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00075": PsimodInfo(
        id="00075",
        name="N,N-dimethyl-L-proline",
        formula="C2H5",
        monoisotopic_mass=29.038577,
        average_mass=29.06,
        dict_composition={'C': 2, 'H': 5},
    ),
    "00076": PsimodInfo(
        id="00076",
        name="symmetric dimethyl-L-arginine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
    "00077": PsimodInfo(
        id="00077",
        name="asymmetric dimethyl-L-arginine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
    "00078": PsimodInfo(
        id="00078",
        name="omega-N-methyl-L-arginine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00079": PsimodInfo(
        id="00079",
        name="N4-methyl-L-asparagine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00080": PsimodInfo(
        id="00080",
        name="N5-methyl-L-glutamine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00081": PsimodInfo(
        id="00081",
        name="L-glutamic acid 5-methyl ester (Glu)",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00082": PsimodInfo(
        id="00082",
        name="3'-methyl-L-histidine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00083": PsimodInfo(
        id="00083",
        name="N6,N6,N6-trimethyl-L-lysine",
        formula="C3H7",
        monoisotopic_mass=43.054227,
        average_mass=43.09,
        dict_composition={'C': 3, 'H': 7},
    ),
    "00084": PsimodInfo(
        id="00084",
        name="N6,N6-dimethyl-L-lysine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
    "00085": PsimodInfo(
        id="00085",
        name="N6-methyl-L-lysine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00086": PsimodInfo(
        id="00086",
        name="N6-palmitoyl-L-lysine",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
    "00087": PsimodInfo(
        id="00087",
        name="N6-myristoyl-L-lysine",
        formula="C14H26O",
        monoisotopic_mass=210.198365,
        average_mass=210.36,
        dict_composition={'C': 14, 'H': 26, 'O': 1},
    ),
    "00088": PsimodInfo(
        id="00088",
        name="O-palmitoyl-L-threonine",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
    "00089": PsimodInfo(
        id="00089",
        name="O-palmitoyl-L-serine",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
    "00090": PsimodInfo(
        id="00090",
        name="L-alanine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00091": PsimodInfo(
        id="00091",
        name="L-arginine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00092": PsimodInfo(
        id="00092",
        name="L-asparagine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00093": PsimodInfo(
        id="00093",
        name="L-aspartic acid 1-amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00094": PsimodInfo(
        id="00094",
        name="L-cysteine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00095": PsimodInfo(
        id="00095",
        name="L-glutamine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00096": PsimodInfo(
        id="00096",
        name="L-glutamic acid 1-amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00097": PsimodInfo(
        id="00097",
        name="glycine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00098": PsimodInfo(
        id="00098",
        name="L-histidine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00099": PsimodInfo(
        id="00099",
        name="L-isoleucine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00100": PsimodInfo(
        id="00100",
        name="L-leucine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00101": PsimodInfo(
        id="00101",
        name="L-lysine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00102": PsimodInfo(
        id="00102",
        name="L-methionine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00103": PsimodInfo(
        id="00103",
        name="L-phenylalanine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00104": PsimodInfo(
        id="00104",
        name="L-proline amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00105": PsimodInfo(
        id="00105",
        name="L-serine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00106": PsimodInfo(
        id="00106",
        name="L-threonine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00107": PsimodInfo(
        id="00107",
        name="L-tryptophan amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00108": PsimodInfo(
        id="00108",
        name="L-tyrosine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00109": PsimodInfo(
        id="00109",
        name="L-valine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00110": PsimodInfo(
        id="00110",
        name="L-cysteine methyl disulfide",
        formula="CH2S",
        monoisotopic_mass=45.987721,
        average_mass=46.09,
        dict_composition={'C': 1, 'H': 2, 'S': 1},
    ),
    "00111": PsimodInfo(
        id="00111",
        name="S-farnesyl-L-cysteine",
        formula="C15H24",
        monoisotopic_mass=204.187801,
        average_mass=204.36,
        dict_composition={'C': 15, 'H': 24},
    ),
    "00112": PsimodInfo(
        id="00112",
        name="S-12-hydroxyfarnesyl-L-cysteine",
        formula="C15H24O",
        monoisotopic_mass=220.182715,
        average_mass=220.36,
        dict_composition={'C': 15, 'H': 24, 'O': 1},
    ),
    "00113": PsimodInfo(
        id="00113",
        name="S-geranylgeranyl-L-cysteine",
        formula="C20H32",
        monoisotopic_mass=272.250401,
        average_mass=272.48,
        dict_composition={'C': 20, 'H': 32},
    ),
    "00114": PsimodInfo(
        id="00114",
        name="L-cysteine methyl ester",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00115": PsimodInfo(
        id="00115",
        name="S-palmitoyl-L-cysteine",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
    "00117": PsimodInfo(
        id="00117",
        name="S-(L-isoglutamyl)-L-cysteine",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "00118": PsimodInfo(
        id="00118",
        name="2'-(S-L-cysteinyl)-L-histidine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00119": PsimodInfo(
        id="00119",
        name="L-lanthionine (Cys-Ser)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00120": PsimodInfo(
        id="00120",
        name="meso-lanthionine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00121": PsimodInfo(
        id="00121",
        name="(2S,3S,2'R)-3-methyllanthionine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00122": PsimodInfo(
        id="00122",
        name="3'-(S-L-cysteinyl)-L-tyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00123": PsimodInfo(
        id="00123",
        name="N6-carboxy-L-lysine",
        formula="CO2",
        monoisotopic_mass=43.989829,
        average_mass=44.01,
        dict_composition={'C': 1, 'O': 2},
    ),
    "00124": PsimodInfo(
        id="00124",
        name="N6-1-carboxyethyl-L-lysine",
        formula="C3H4O2",
        monoisotopic_mass=72.021129,
        average_mass=72.06,
        dict_composition={'C': 3, 'H': 4, 'O': 2},
    ),
    "00125": PsimodInfo(
        id="00125",
        name="hypusine",
        formula="C4H9NO",
        monoisotopic_mass=87.068414,
        average_mass=87.12,
        dict_composition={'C': 4, 'H': 9, 'N': 1, 'O': 1},
    ),
    "00126": PsimodInfo(
        id="00126",
        name="N6-biotinyl-L-lysine",
        formula="C10H14N2O2S",
        monoisotopic_mass=226.077599,
        average_mass=226.29,
        dict_composition={'C': 10, 'H': 14, 'N': 2, 'O': 2, 'S': 1},
    ),
    "00127": PsimodInfo(
        id="00127",
        name="N6-lipoyl-L-lysine",
        formula="C8H12OS2",
        monoisotopic_mass=188.032957,
        average_mass=188.3,
        dict_composition={'C': 8, 'H': 12, 'O': 1, 'S': 2},
    ),
    "00128": PsimodInfo(
        id="00128",
        name="N6-pyridoxal phosphate-L-lysine",
        formula="C8H8NO5P",
        monoisotopic_mass=229.014009,
        average_mass=229.13,
        dict_composition={'C': 8, 'H': 8, 'N': 1, 'O': 5, 'P': 1},
    ),
    "00129": PsimodInfo(
        id="00129",
        name="N6-retinylidene-L-lysine",
        formula="C20H26",
        monoisotopic_mass=266.203451,
        average_mass=266.43,
        dict_composition={'C': 20, 'H': 26},
    ),
    "00130": PsimodInfo(
        id="00130",
        name="L-allysine",
        formula="H-3N-1O",
        monoisotopic_mass=-1.031634,
        average_mass=-1.03,
        dict_composition={'H': -3, 'N': -1, 'O': 1},
    ),
    "00131": PsimodInfo(
        id="00131",
        name="L-2-aminoadipic acid",
        formula="H-3N-1O2",
        monoisotopic_mass=14.96328,
        average_mass=14.97,
        dict_composition={'H': -3, 'N': -1, 'O': 2},
    ),
    "00132": PsimodInfo(
        id="00132",
        name="L-lysinoalanine (Lys-Ser)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00133": PsimodInfo(
        id="00133",
        name="N6-(L-isoglutamyl)-L-lysine (Gln)",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "00134": PsimodInfo(
        id="00134",
        name="N6-glycyl-L-lysine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00135": PsimodInfo(
        id="00135",
        name="N-(L-isoaspartyl)-glycine (Asn)",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "00136": PsimodInfo(
        id="00136",
        name="pyruvic acid (Cys)",
        formula="H-3N-1OS-1",
        monoisotopic_mass=-33.003705,
        average_mass=-33.09,
        dict_composition={'H': -3, 'N': -1, 'O': 1, 'S': -1},
    ),
    "00137": PsimodInfo(
        id="00137",
        name="L-3-phenyllactic acid",
        formula="H-1N-1O",
        monoisotopic_mass=0.984016,
        average_mass=0.98,
        dict_composition={'H': -1, 'N': -1, 'O': 1},
    ),
    "00138": PsimodInfo(
        id="00138",
        name="2-oxobutanoic acid",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "00139": PsimodInfo(
        id="00139",
        name="N2-succinyl-L-tryptophan",
        formula="C4H4O3",
        monoisotopic_mass=100.016044,
        average_mass=100.07,
        dict_composition={'C': 4, 'H': 4, 'O': 3},
    ),
    "00140": PsimodInfo(
        id="00140",
        name="S-phycocyanobilin-L-cysteine",
        formula="C33H38N4O6",
        monoisotopic_mass=586.279135,
        average_mass=586.69,
        dict_composition={'C': 33, 'H': 38, 'N': 4, 'O': 6},
    ),
    "00141": PsimodInfo(
        id="00141",
        name="S-phycoerythrobilin-L-cysteine",
        formula="C33H40N4O6",
        monoisotopic_mass=588.294785,
        average_mass=588.7,
        dict_composition={'C': 33, 'H': 40, 'N': 4, 'O': 6},
    ),
    "00142": PsimodInfo(
        id="00142",
        name="S-phytochromobilin-L-cysteine",
        formula="C33H36N4O6",
        monoisotopic_mass=584.263485,
        average_mass=584.67,
        dict_composition={'C': 33, 'H': 36, 'N': 4, 'O': 6},
    ),
    "00143": PsimodInfo(
        id="00143",
        name="heme-bis-L-cysteine",
        formula="C34FeH32N4O4",
        monoisotopic_mass=616.177293,
        average_mass=616.5,
        dict_composition={'C': 34, 'Fe': 1, 'H': 32, 'N': 4, 'O': 4},
    ),
    "00144": PsimodInfo(
        id="00144",
        name="heme-L-cysteine",
        formula="C34FeH32N4O4",
        monoisotopic_mass=616.177293,
        average_mass=616.5,
        dict_composition={'C': 34, 'Fe': 1, 'H': 32, 'N': 4, 'O': 4},
    ),
    "00145": PsimodInfo(
        id="00145",
        name="tetrakis-L-cysteinyl iron",
        formula="FeH-4",
        monoisotopic_mass=51.904735,
        average_mass=51.81,
        dict_composition={'Fe': 1, 'H': -4},
    ),
    "00146": PsimodInfo(
        id="00146",
        name="tetrakis-L-cysteinyl diiron disulfide",
        formula="Fe2H-4S2",
        monoisotopic_mass=171.783814,
        average_mass=171.78,
        dict_composition={'Fe': 2, 'H': -4, 'S': 2},
    ),
    "00147": PsimodInfo(
        id="00147",
        name="hexakis-L-cysteinyl triiron trisulfide",
        formula="Fe3H-6S3",
        monoisotopic_mass=257.675721,
        average_mass=257.67,
        dict_composition={'Fe': 3, 'H': -6, 'S': 3},
    ),
    "00148": PsimodInfo(
        id="00148",
        name="tris-L-cysteinyl triiron tetrasulfide",
        formula="Fe3H-3S4",
        monoisotopic_mass=292.671267,
        average_mass=292.75,
        dict_composition={'Fe': 3, 'H': -3, 'S': 4},
    ),
    "00149": PsimodInfo(
        id="00149",
        name="tetrakis-L-cysteinyl tetrairon tetrasulfide",
        formula="Fe4H-4S4",
        monoisotopic_mass=347.597831,
        average_mass=347.59,
        dict_composition={'Fe': 4, 'H': -4, 'S': 4},
    ),
    "00150": PsimodInfo(
        id="00150",
        name="L-cysteinyl-L-histidino-homocitryl molybdenum heptairon nonasulfide",
        formula="C7Fe7H6MoNO7S9",
        monoisotopic_mass=993.213036,
        average_mass=991.53,
        dict_composition={'C': 7, 'Fe': 7, 'H': 6, 'Mo': 1, 'N': 1, 'O': 7, 'S': 9},
    ),
    "00151": PsimodInfo(
        id="00151",
        name="L-cysteinyl molybdopterin",
        formula="C10H11MoN5O8PS2",
        monoisotopic_mass=521.884074,
        average_mass=520.27,
        dict_composition={'C': 10, 'H': 11, 'Mo': 1, 'N': 5, 'O': 8, 'P': 1, 'S': 2},
    ),
    "00152": PsimodInfo(
        id="00152",
        name="S-(8alpha-FAD)-L-cysteine",
        formula="C27H31N9O15P2",
        monoisotopic_mass=783.141485,
        average_mass=783.54,
        dict_composition={'C': 27, 'H': 31, 'N': 9, 'O': 15, 'P': 2},
    ),
    "00153": PsimodInfo(
        id="00153",
        name="3'-(8alpha-FAD)-L-histidine",
        formula="C27H31N9O15P2",
        monoisotopic_mass=783.141485,
        average_mass=783.54,
        dict_composition={'C': 27, 'H': 31, 'N': 9, 'O': 15, 'P': 2},
    ),
    "00154": PsimodInfo(
        id="00154",
        name="O4'-(8alpha-FAD)-L-tyrosine",
        formula="C27H31N9O15P2",
        monoisotopic_mass=783.141485,
        average_mass=783.54,
        dict_composition={'C': 27, 'H': 31, 'N': 9, 'O': 15, 'P': 2},
    ),
    "00155": PsimodInfo(
        id="00155",
        name="L-3',4'-dihydroxyphenylalanine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "00156": PsimodInfo(
        id="00156",
        name="L-2',4',5'-topaquinone",
        formula="H-2O2",
        monoisotopic_mass=29.974179,
        average_mass=29.98,
        dict_composition={'H': -2, 'O': 2},
    ),
    "00157": PsimodInfo(
        id="00157",
        name="L-tryptophyl quinone",
        formula="H-2O2",
        monoisotopic_mass=29.974179,
        average_mass=29.98,
        dict_composition={'H': -2, 'O': 2},
    ),
    "00158": PsimodInfo(
        id="00158",
        name="4'-(L-tryptophan)-L-tryptophyl quinone",
        formula="H-4O2",
        monoisotopic_mass=27.958529,
        average_mass=27.97,
        dict_composition={'H': -4, 'O': 2},
    ),
    "00159": PsimodInfo(
        id="00159",
        name="O-phosphopantetheine-L-serine",
        formula="C11H21N2O6PS",
        monoisotopic_mass=340.085794,
        average_mass=340.33,
        dict_composition={'C': 11, 'H': 21, 'N': 2, 'O': 6, 'P': 1, 'S': 1},
    ),
    "00161": PsimodInfo(
        id="00161",
        name="S-glucosyl-L-cysteine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "00162": PsimodInfo(
        id="00162",
        name="O5-glucosylgalactosyl-L-hydroxylysine",
        formula="C12H20O11",
        monoisotopic_mass=340.100561,
        average_mass=340.28,
        dict_composition={'C': 12, 'H': 20, 'O': 11},
    ),
    "00163": PsimodInfo(
        id="00163",
        name="O-(N-acetylamino)galactosyl-L-serine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "00164": PsimodInfo(
        id="00164",
        name="O-(N-acetylamino)galactosyl-L-threonine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "00165": PsimodInfo(
        id="00165",
        name="1'-mannosyl-L-tryptophan",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "00166": PsimodInfo(
        id="00166",
        name="O4'-glucosyl-L-tyrosine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "00167": PsimodInfo(
        id="00167",
        name="N-asparaginyl-glycosylphosphatidylinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
    "00168": PsimodInfo(
        id="00168",
        name="N-aspartyl-glycosylphosphatidylinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
    "00169": PsimodInfo(
        id="00169",
        name="N-cysteinyl-glycosylphosphatidylinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
    "00170": PsimodInfo(
        id="00170",
        name="N-glycyl-glycosylphosphatidylinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
    "00171": PsimodInfo(
        id="00171",
        name="N-seryl-glycosylphosphatidylinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
    "00172": PsimodInfo(
        id="00172",
        name="N-alanyl-glycosylphosphatidylinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
    "00173": PsimodInfo(
        id="00173",
        name="N-threonyl-glycosylphosphatidylinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
    "00174": PsimodInfo(
        id="00174",
        name="N-glycyl-glycosylsphingolipidinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
    "00175": PsimodInfo(
        id="00175",
        name="N-seryl-glycosylsphingolipidinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
    "00176": PsimodInfo(
        id="00176",
        name="O-(phosphoribosyl dephospho-coenzyme A)-L-serine",
        formula="C26H42N7O19P3S",
        monoisotopic_mass=881.146903,
        average_mass=881.63,
        dict_composition={'C': 26, 'H': 42, 'N': 7, 'O': 19, 'P': 3, 'S': 1},
    ),
    "00177": PsimodInfo(
        id="00177",
        name="omega-N-(ADP-ribosyl)-L-arginine",
        formula="C15H21N5O13P2",
        monoisotopic_mass=541.061109,
        average_mass=541.3,
        dict_composition={'C': 15, 'H': 21, 'N': 5, 'O': 13, 'P': 2},
    ),
    "00178": PsimodInfo(
        id="00178",
        name="S-(ADP-ribosyl)-L-cysteine",
        formula="C15H21N5O13P2",
        monoisotopic_mass=541.061109,
        average_mass=541.3,
        dict_composition={'C': 15, 'H': 21, 'N': 5, 'O': 13, 'P': 2},
    ),
    "00179": PsimodInfo(
        id="00179",
        name="L-glutamyl 5-glycerylphosphorylethanolamine",
        formula="C5H12NO5P",
        monoisotopic_mass=197.045309,
        average_mass=197.13,
        dict_composition={'C': 5, 'H': 12, 'N': 1, 'O': 5, 'P': 1},
    ),
    "00180": PsimodInfo(
        id="00180",
        name="S-sulfo-L-cysteine",
        formula="O3S",
        monoisotopic_mass=79.956815,
        average_mass=80.06,
        dict_composition={'O': 3, 'S': 1},
    ),
    "00181": PsimodInfo(
        id="00181",
        name="O4'-sulfo-L-tyrosine",
        formula="O3S",
        monoisotopic_mass=79.956815,
        average_mass=80.06,
        dict_composition={'O': 3, 'S': 1},
    ),
    "00182": PsimodInfo(
        id="00182",
        name="L-bromohistidine",
        formula="BrH-1",
        monoisotopic_mass=77.910512,
        average_mass=78.9,
        dict_composition={'Br': 1, 'H': -1},
    ),
    "00183": PsimodInfo(
        id="00183",
        name="L-2'-bromophenylalanine",
        formula="BrH-1",
        monoisotopic_mass=77.910512,
        average_mass=78.9,
        dict_composition={'Br': 1, 'H': -1},
    ),
    "00184": PsimodInfo(
        id="00184",
        name="L-3'-bromophenylalanine",
        formula="BrH-1",
        monoisotopic_mass=77.910512,
        average_mass=78.9,
        dict_composition={'Br': 1, 'H': -1},
    ),
    "00185": PsimodInfo(
        id="00185",
        name="L-4'-bromophenylalanine",
        formula="BrH-1",
        monoisotopic_mass=77.910512,
        average_mass=78.9,
        dict_composition={'Br': 1, 'H': -1},
    ),
    "00186": PsimodInfo(
        id="00186",
        name="3,3',5-triiodo-L-thyronine",
        formula="C6HI3O",
        monoisotopic_mass=469.716158,
        average_mass=469.79,
        dict_composition={'C': 6, 'H': 1, 'I': 3, 'O': 1},
    ),
    "00187": PsimodInfo(
        id="00187",
        name="L-thyroxine",
        formula="C6I4O",
        monoisotopic_mass=595.612805,
        average_mass=595.68,
        dict_composition={'C': 6, 'I': 4, 'O': 1},
    ),
    "00188": PsimodInfo(
        id="00188",
        name="6'-bromo-L-tryptophan",
        formula="BrH-1",
        monoisotopic_mass=77.910512,
        average_mass=78.9,
        dict_composition={'Br': 1, 'H': -1},
    ),
    "00189": PsimodInfo(
        id="00189",
        name="dehydroalanine (Ser)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00190": PsimodInfo(
        id="00190",
        name="dehydrobutyrine (Thr)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00191": PsimodInfo(
        id="00191",
        name="(Z)-2,3-didehydrotyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00192": PsimodInfo(
        id="00192",
        name="L-serine 5-imidazolinone glycine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00193": PsimodInfo(
        id="00193",
        name="L-3-oxoalanine (Cys)",
        formula="H-2OS-1",
        monoisotopic_mass=-17.992806,
        average_mass=-18.08,
        dict_composition={'H': -2, 'O': 1, 'S': -1},
    ),
    "00194": PsimodInfo(
        id="00194",
        name="lactic acid",
        formula="H-1N-1",
        monoisotopic_mass=-15.010899,
        average_mass=-15.02,
        dict_composition={'H': -1, 'N': -1},
    ),
    "00195": PsimodInfo(
        id="00195",
        name="L-alanine 5-imidazolinone glycine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00196": PsimodInfo(
        id="00196",
        name="L-cysteine 5-imidazolinone glycine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00197": PsimodInfo(
        id="00197",
        name="2-imino-glutamine 5-imidazolinone glycine",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "00198": PsimodInfo(
        id="00198",
        name="D-alanine (Ala)",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00199": PsimodInfo(
        id="00199",
        name="D-allo-isoleucine",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00200": PsimodInfo(
        id="00200",
        name="D-methionine",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00201": PsimodInfo(
        id="00201",
        name="D-phenylalanine",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00202": PsimodInfo(
        id="00202",
        name="D-serine (Ser)",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00203": PsimodInfo(
        id="00203",
        name="D-asparagine",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00204": PsimodInfo(
        id="00204",
        name="D-leucine",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00205": PsimodInfo(
        id="00205",
        name="D-tryptophan",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00208": PsimodInfo(
        id="00208",
        name="O4'-(phospho-5'-adenosine)-L-tyrosine",
        formula="C10H12N5O6P",
        monoisotopic_mass=329.05252,
        average_mass=329.21,
        dict_composition={'C': 10, 'H': 12, 'N': 5, 'O': 6, 'P': 1},
    ),
    "00209": PsimodInfo(
        id="00209",
        name="S-(2-aminovinyl)-D-cysteine (Cys-Ser)",
        formula="C-1H-4O-3",
        monoisotopic_mass=-64.016044,
        average_mass=-64.04,
        dict_composition={'C': -1, 'H': -4, 'O': -3},
    ),
    "00210": PsimodInfo(
        id="00210",
        name="L-cysteine sulfenic acid",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "00211": PsimodInfo(
        id="00211",
        name="S-(glycyl)-L-cysteine (Cys-Gly)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00212": PsimodInfo(
        id="00212",
        name="S-4-hydroxycinnamyl-L-cysteine",
        formula="C9H6O2",
        monoisotopic_mass=146.036779,
        average_mass=146.14,
        dict_composition={'C': 9, 'H': 6, 'O': 2},
    ),
    "00216": PsimodInfo(
        id="00216",
        name="N6-formyl-L-lysine",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
    "00217": PsimodInfo(
        id="00217",
        name="O4-arabinosyl-L-hydroxyproline",
        formula="C5H8O5",
        monoisotopic_mass=148.037173,
        average_mass=148.11,
        dict_composition={'C': 5, 'H': 8, 'O': 5},
    ),
    "00219": PsimodInfo(
        id="00219",
        name="L-citrulline",
        formula="H-1N-1O",
        monoisotopic_mass=0.984016,
        average_mass=0.98,
        dict_composition={'H': -1, 'N': -1, 'O': 1},
    ),
    "00220": PsimodInfo(
        id="00220",
        name="4-hydroxy-L-arginine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "00221": PsimodInfo(
        id="00221",
        name="N-(L-isoaspartyl)-L-cysteine",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "00222": PsimodInfo(
        id="00222",
        name="2'-alpha-mannosyl-L-tryptophan",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "00225": PsimodInfo(
        id="00225",
        name="S-(6-FMN)-L-cysteine",
        formula="C17H19N4O9P",
        monoisotopic_mass=454.088965,
        average_mass=454.33,
        dict_composition={'C': 17, 'H': 19, 'N': 4, 'O': 9, 'P': 1},
    ),
    "00226": PsimodInfo(
        id="00226",
        name="1'-(8alpha-FAD)-L-histidine",
        formula="C27H31N9O15P2",
        monoisotopic_mass=783.141485,
        average_mass=783.54,
        dict_composition={'C': 27, 'H': 31, 'N': 9, 'O': 15, 'P': 2},
    ),
    "00227": PsimodInfo(
        id="00227",
        name="omega-N-phospho-L-arginine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
    "00228": PsimodInfo(
        id="00228",
        name="S-diphytanylglycerol diether-L-cysteine",
        formula="C43H86O2",
        monoisotopic_mass=634.662782,
        average_mass=635.16,
        dict_composition={'C': 43, 'H': 86, 'O': 2},
    ),
    "00229": PsimodInfo(
        id="00229",
        name="alpha-1-microglobulin-Ig alpha complex chromophore",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00230": PsimodInfo(
        id="00230",
        name="bis-L-cysteinyl bis-L-histidino diiron disulfide",
        formula="Fe2H-4S2",
        monoisotopic_mass=171.783814,
        average_mass=171.78,
        dict_composition={'Fe': 2, 'H': -4, 'S': 2},
    ),
    "00231": PsimodInfo(
        id="00231",
        name="hexakis-L-cysteinyl hexairon hexasulfide",
        formula="Fe6H-6S6",
        monoisotopic_mass=521.395649,
        average_mass=521.38,
        dict_composition={'Fe': 6, 'H': -6, 'S': 6},
    ),
    "00232": PsimodInfo(
        id="00232",
        name="N6-(phospho-5'-adenosine)-L-lysine",
        formula="C10H12N5O6P",
        monoisotopic_mass=329.05252,
        average_mass=329.21,
        dict_composition={'C': 10, 'H': 12, 'N': 5, 'O': 6, 'P': 1},
    ),
    "00233": PsimodInfo(
        id="00233",
        name="N6-(phospho-5'-guanosine)-L-lysine",
        formula="C10H12N5O7P",
        monoisotopic_mass=345.047434,
        average_mass=345.21,
        dict_composition={'C': 10, 'H': 12, 'N': 5, 'O': 7, 'P': 1},
    ),
    "00234": PsimodInfo(
        id="00234",
        name="L-cysteine glutathione disulfide",
        formula="C10H15N3O6S",
        monoisotopic_mass=305.068156,
        average_mass=305.3,
        dict_composition={'C': 10, 'H': 15, 'N': 3, 'O': 6, 'S': 1},
    ),
    "00235": PsimodInfo(
        id="00235",
        name="S-nitrosyl-L-cysteine",
        formula="H-1NO",
        monoisotopic_mass=28.990164,
        average_mass=29.0,
        dict_composition={'H': -1, 'N': 1, 'O': 1},
    ),
    "00236": PsimodInfo(
        id="00236",
        name="N4-(ADP-ribosyl)-L-asparagine",
        formula="C15H21N5O13P2",
        monoisotopic_mass=541.061109,
        average_mass=541.3,
        dict_composition={'C': 15, 'H': 21, 'N': 5, 'O': 13, 'P': 2},
    ),
    "00237": PsimodInfo(
        id="00237",
        name="L-beta-methylthioaspartic acid",
        formula="CH2S",
        monoisotopic_mass=45.987721,
        average_mass=46.09,
        dict_composition={'C': 1, 'H': 2, 'S': 1},
    ),
    "00238": PsimodInfo(
        id="00238",
        name="5'-(N6-L-lysine)-L-topaquinone",
        formula="H-4O",
        monoisotopic_mass=11.963614,
        average_mass=11.97,
        dict_composition={'H': -4, 'O': 1},
    ),
    "00239": PsimodInfo(
        id="00239",
        name="S-methyl-L-cysteine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00240": PsimodInfo(
        id="00240",
        name="4-hydroxy-L-lysine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "00241": PsimodInfo(
        id="00241",
        name="N4-hydroxymethyl-L-asparagine",
        formula="CH2O",
        monoisotopic_mass=30.010565,
        average_mass=30.03,
        dict_composition={'C': 1, 'H': 2, 'O': 1},
    ),
    "00242": PsimodInfo(
        id="00242",
        name="O-(ADP-ribosyl)-L-serine",
        formula="C15H21N5O13P2",
        monoisotopic_mass=541.061109,
        average_mass=541.3,
        dict_composition={'C': 15, 'H': 21, 'N': 5, 'O': 13, 'P': 2},
    ),
    "00243": PsimodInfo(
        id="00243",
        name="L-cysteine oxazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "00244": PsimodInfo(
        id="00244",
        name="L-cysteine oxazoline-4-carboxylic acid",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00245": PsimodInfo(
        id="00245",
        name="glycine oxazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "00246": PsimodInfo(
        id="00246",
        name="glycine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "00247": PsimodInfo(
        id="00247",
        name="L-serine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "00248": PsimodInfo(
        id="00248",
        name="L-phenylalanine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "00249": PsimodInfo(
        id="00249",
        name="L-cysteine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "00250": PsimodInfo(
        id="00250",
        name="L-lysine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "00253": PsimodInfo(
        id="00253",
        name="L-selenocysteinyl molybdenum bis(molybdopterin guanine dinucleotide) (Sec)",
        formula="C40H47MoN20O26P4S4",
        monoisotopic_mass=1572.985775,
        average_mass=1572.02,
        dict_composition={'C': 40, 'H': 47, 'Mo': 1, 'N': 20, 'O': 26, 'P': 4, 'S': 4},
    ),
    "00255": PsimodInfo(
        id="00255",
        name="3-(3'-L-histidyl)-L-tyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00256": PsimodInfo(
        id="00256",
        name="L-methionine sulfone",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "00257": PsimodInfo(
        id="00257",
        name="dipyrrolylmethanemethyl-L-cysteine",
        formula="C20H22N2O8",
        monoisotopic_mass=418.137616,
        average_mass=418.4,
        dict_composition={'C': 20, 'H': 22, 'N': 2, 'O': 8},
    ),
    "00258": PsimodInfo(
        id="00258",
        name="S-(2-aminovinyl)-3-methyl-D-cysteine",
        formula="C-1H-4O-3",
        monoisotopic_mass=-64.016044,
        average_mass=-64.04,
        dict_composition={'C': -1, 'H': -4, 'O': -3},
    ),
    "00260": PsimodInfo(
        id="00260",
        name="O-(phospho-5'-DNA)-L-threonine",
        formula="O3P",
        monoisotopic_mass=78.958505,
        average_mass=78.97,
        dict_composition={'O': 3, 'P': 1},
    ),
    "00261": PsimodInfo(
        id="00261",
        name="O4'-(phospho-5'-uridine)-L-tyrosine",
        formula="C9H11N2O8P",
        monoisotopic_mass=306.025302,
        average_mass=306.17,
        dict_composition={'C': 9, 'H': 11, 'N': 2, 'O': 8, 'P': 1},
    ),
    "00262": PsimodInfo(
        id="00262",
        name="N-(L-glutamyl)-L-tyrosine",
        formula="H-1O-1",
        monoisotopic_mass=-17.00274,
        average_mass=-17.01,
        dict_composition={'H': -1, 'O': -1},
    ),
    "00263": PsimodInfo(
        id="00263",
        name="S-phycoviolobilin-L-cysteine",
        formula="C33H38N4O6",
        monoisotopic_mass=586.279135,
        average_mass=586.69,
        dict_composition={'C': 33, 'H': 38, 'N': 4, 'O': 6},
    ),
    "00264": PsimodInfo(
        id="00264",
        name="phycoerythrobilin-bis-L-cysteine",
        formula="C33H38N4O6",
        monoisotopic_mass=586.279135,
        average_mass=586.69,
        dict_composition={'C': 33, 'H': 38, 'N': 4, 'O': 6},
    ),
    "00265": PsimodInfo(
        id="00265",
        name="phycourobilin-bis-L-cysteine",
        formula="C33H38N4O6",
        monoisotopic_mass=586.279135,
        average_mass=586.69,
        dict_composition={'C': 33, 'H': 38, 'N': 4, 'O': 6},
    ),
    "00267": PsimodInfo(
        id="00267",
        name="L-cysteine sulfinic acid",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "00268": PsimodInfo(
        id="00268",
        name="L-3',4',5'-trihydroxyphenylalanine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "00269": PsimodInfo(
        id="00269",
        name="O-(sn-1-glycerophosphoryl)-L-serine",
        formula="C3H7O5P",
        monoisotopic_mass=154.00311,
        average_mass=154.06,
        dict_composition={'C': 3, 'H': 7, 'O': 5, 'P': 1},
    ),
    "00270": PsimodInfo(
        id="00270",
        name="1-thioglycine (internal)",
        formula="O-1S",
        monoisotopic_mass=15.977156,
        average_mass=16.06,
        dict_composition={'O': -1, 'S': 1},
    ),
    "00271": PsimodInfo(
        id="00271",
        name="heme P460-bis-L-cysteine-L-tyrosine",
        formula="C34FeH30N4O4",
        monoisotopic_mass=614.161643,
        average_mass=614.48,
        dict_composition={'C': 34, 'Fe': 1, 'H': 30, 'N': 4, 'O': 4},
    ),
    "00272": PsimodInfo(
        id="00272",
        name="O-(phospho-5'-adenosine)-L-threonine",
        formula="C10H12N5O6P",
        monoisotopic_mass=329.05252,
        average_mass=329.21,
        dict_composition={'C': 10, 'H': 12, 'N': 5, 'O': 6, 'P': 1},
    ),
    "00273": PsimodInfo(
        id="00273",
        name="tris-L-cysteinyl L-cysteine persulfido bis-L-glutamato L-histidino tetrairon disulfide trioxide",
        formula="Fe4H-7O3S3",
        monoisotopic_mass=360.585932,
        average_mass=360.5,
        dict_composition={'Fe': 4, 'H': -7, 'O': 3, 'S': 3},
    ),
    "00274": PsimodInfo(
        id="00274",
        name="L-cysteine persulfide",
        formula="S",
        monoisotopic_mass=31.972071,
        average_mass=32.06,
        dict_composition={'S': 1},
    ),
    "00275": PsimodInfo(
        id="00275",
        name="3'-(1'-L-histidyl)-L-tyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00276": PsimodInfo(
        id="00276",
        name="heme P460-bis-L-cysteine-L-lysine",
        formula="C34FeH30N4O4",
        monoisotopic_mass=614.161643,
        average_mass=614.48,
        dict_composition={'C': 34, 'Fe': 1, 'H': 30, 'N': 4, 'O': 4},
    ),
    "00277": PsimodInfo(
        id="00277",
        name="5-methyl-L-arginine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00278": PsimodInfo(
        id="00278",
        name="2-methyl-L-glutamine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00279": PsimodInfo(
        id="00279",
        name="N-pyruvic acid 2-iminyl-L-cysteine",
        formula="C3H2O2",
        monoisotopic_mass=70.005479,
        average_mass=70.05,
        dict_composition={'C': 3, 'H': 2, 'O': 2},
    ),
    "00280": PsimodInfo(
        id="00280",
        name="N-pyruvic acid 2-iminyl-L-valine",
        formula="C3H2O2",
        monoisotopic_mass=70.005479,
        average_mass=70.05,
        dict_composition={'C': 3, 'H': 2, 'O': 2},
    ),
    "00281": PsimodInfo(
        id="00281",
        name="3'-heme-L-histidine",
        formula="C34FeH32N4O4",
        monoisotopic_mass=616.177293,
        average_mass=616.5,
        dict_composition={'C': 34, 'Fe': 1, 'H': 32, 'N': 4, 'O': 4},
    ),
    "00282": PsimodInfo(
        id="00282",
        name="S-selenyl-L-cysteine",
        formula="Se",
        monoisotopic_mass=79.916521,
        average_mass=78.97,
        dict_composition={'Se': 1},
    ),
    "00284": PsimodInfo(
        id="00284",
        name="dihydroxyheme-L-aspartate ester-L-glutamate ester",
        formula="C34FeH28N4O4",
        monoisotopic_mass=612.145993,
        average_mass=612.47,
        dict_composition={'C': 34, 'Fe': 1, 'H': 28, 'N': 4, 'O': 4},
    ),
    "00285": PsimodInfo(
        id="00285",
        name="dihydroxyheme-L-aspartate ester-L-glutamate ester-L-methionine sulfonium",
        formula="C34FeH29N4O4",
        monoisotopic_mass=613.153269,
        average_mass=613.47,
        dict_composition={'C': 34, 'Fe': 1, 'H': 29, 'N': 4, 'O': 4},
    ),
    "00286": PsimodInfo(
        id="00286",
        name="L-cysteinyl molybdenum bis(molybdopterin guanine dinucleotide)",
        formula="C40H47MoN20O26P4S4",
        monoisotopic_mass=1572.985775,
        average_mass=1572.02,
        dict_composition={'C': 40, 'H': 47, 'Mo': 1, 'N': 20, 'O': 26, 'P': 4, 'S': 4},
    ),
    "00287": PsimodInfo(
        id="00287",
        name="(2S,3R,4S)-3,4-dihydroxyproline",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "00288": PsimodInfo(
        id="00288",
        name="pyrroloquinoline quinone",
        formula="H-10O3",
        monoisotopic_mass=37.906494,
        average_mass=37.92,
        dict_composition={'H': -10, 'O': 3},
    ),
    "00289": PsimodInfo(
        id="00289",
        name="tris-L-cysteinyl L-N1'-histidino tetrairon tetrasulfide",
        formula="Fe4H-4S4",
        monoisotopic_mass=347.597831,
        average_mass=347.59,
        dict_composition={'Fe': 4, 'H': -4, 'S': 4},
    ),
    "00290": PsimodInfo(
        id="00290",
        name="tris-L-cysteinyl L-N3'-histidino tetrairon tetrasulfide",
        formula="Fe4H-4S4",
        monoisotopic_mass=347.597831,
        average_mass=347.59,
        dict_composition={'Fe': 4, 'H': -4, 'S': 4},
    ),
    "00291": PsimodInfo(
        id="00291",
        name="tris-L-cysteinyl L-aspartato tetrairon tetrasulfide",
        formula="Fe4H-4S4",
        monoisotopic_mass=347.597831,
        average_mass=347.59,
        dict_composition={'Fe': 4, 'H': -4, 'S': 4},
    ),
    "00292": PsimodInfo(
        id="00292",
        name="N6-pyruvic acid 2-iminyl-L-lysine",
        formula="C3H2O2",
        monoisotopic_mass=70.005479,
        average_mass=70.05,
        dict_composition={'C': 3, 'H': 2, 'O': 2},
    ),
    "00293": PsimodInfo(
        id="00293",
        name="tris-L-cysteinyl L-serinyl tetrairon tetrasulfide",
        formula="Fe4H-4S4",
        monoisotopic_mass=347.597831,
        average_mass=347.59,
        dict_composition={'Fe': 4, 'H': -4, 'S': 4},
    ),
    "00294": PsimodInfo(
        id="00294",
        name="bis-L-cysteinyl L-N3'-histidino L-serinyl tetrairon tetrasulfide",
        formula="Fe4H-4S4",
        monoisotopic_mass=347.597831,
        average_mass=347.59,
        dict_composition={'Fe': 4, 'H': -4, 'S': 4},
    ),
    "00295": PsimodInfo(
        id="00295",
        name="O-octanoyl-L-serine",
        formula="C8H14O",
        monoisotopic_mass=126.104465,
        average_mass=126.2,
        dict_composition={'C': 8, 'H': 14, 'O': 1},
    ),
    "00296": PsimodInfo(
        id="00296",
        name="O-D-glucuronosyl-L-serine",
        formula="C6H8O6",
        monoisotopic_mass=176.032088,
        average_mass=176.12,
        dict_composition={'C': 6, 'H': 8, 'O': 6},
    ),
    "00297": PsimodInfo(
        id="00297",
        name="tris-L-cysteinyl L-cysteine persulfido bis-L-glutamato L-histidino nickel triiron disulfide trioxide",
        formula="Fe3H-7NiO3S3",
        monoisotopic_mass=362.586337,
        average_mass=363.35,
        dict_composition={'Fe': 3, 'H': -7, 'Ni': 1, 'O': 3, 'S': 3},
    ),
    "00298": PsimodInfo(
        id="00298",
        name="tris-L-cysteinyl L-cysteine persulfido L-glutamato L-histidino L-serinyl nickel triiron disulfide trioxide",
        formula="Fe3H-7NiO3S3",
        monoisotopic_mass=362.586337,
        average_mass=363.35,
        dict_composition={'Fe': 3, 'H': -7, 'Ni': 1, 'O': 3, 'S': 3},
    ),
    "00299": PsimodInfo(
        id="00299",
        name="N6-(L-isoaspartyl)-L-lysine (Asn)",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "00301": PsimodInfo(
        id="00301",
        name="O-(N-acetylglucosamine-1-phosphoryl)-L-serine",
        formula="C8H14NO8P",
        monoisotopic_mass=283.045703,
        average_mass=283.17,
        dict_composition={'C': 8, 'H': 14, 'N': 1, 'O': 8, 'P': 1},
    ),
    "00302": PsimodInfo(
        id="00302",
        name="O-(phosphoglycosyl-D-mannose-1-phosphoryl)-L-serine",
        formula="C6H11O8P",
        monoisotopic_mass=242.019154,
        average_mass=242.12,
        dict_composition={'C': 6, 'H': 11, 'O': 8, 'P': 1},
    ),
    "00303": PsimodInfo(
        id="00303",
        name="heptakis-L-histidino tetracopper mu4-sulfide hydroxide",
        formula="Cu4H-6OS",
        monoisotopic_mass=293.638425,
        average_mass=296.19,
        dict_composition={'Cu': 4, 'H': -6, 'O': 1, 'S': 1},
    ),
    "00304": PsimodInfo(
        id="00304",
        name="L-leucine methyl ester",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00305": PsimodInfo(
        id="00305",
        name="hexakis-L-cysteinyl L-serinyl octairon heptasulfide",
        formula="Fe8H-8S7",
        monoisotopic_mass=663.223042,
        average_mass=663.12,
        dict_composition={'Fe': 8, 'H': -8, 'S': 7},
    ),
    "00306": PsimodInfo(
        id="00306",
        name="residues isobaric at 113.084064 Da",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00307": PsimodInfo(
        id="00307",
        name="L-aspartimide",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00308": PsimodInfo(
        id="00308",
        name="L-glutamimide",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00309": PsimodInfo(
        id="00309",
        name="L-beta-carboxyaspartic acid",
        formula="CO2",
        monoisotopic_mass=43.989829,
        average_mass=44.01,
        dict_composition={'C': 1, 'O': 2},
    ),
    "00310": PsimodInfo(
        id="00310",
        name="N5-methyl-L-arginine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00311": PsimodInfo(
        id="00311",
        name="L-cysteine coenzyme A disulfide",
        formula="C21H34N7O16P3S",
        monoisotopic_mass=765.099559,
        average_mass=765.52,
        dict_composition={'C': 21, 'H': 34, 'N': 7, 'O': 16, 'P': 3, 'S': 1},
    ),
    "00312": PsimodInfo(
        id="00312",
        name="S-myristoyl-L-cysteine",
        formula="C14H26O",
        monoisotopic_mass=210.198365,
        average_mass=210.36,
        dict_composition={'C': 14, 'H': 26, 'O': 1},
    ),
    "00313": PsimodInfo(
        id="00313",
        name="S-palmitoleyl-L-cysteine",
        formula="C16H28O",
        monoisotopic_mass=236.214016,
        average_mass=236.4,
        dict_composition={'C': 16, 'H': 28, 'O': 1},
    ),
    "00314": PsimodInfo(
        id="00314",
        name="glycine cholesterol ester",
        formula="C27H44",
        monoisotopic_mass=368.344301,
        average_mass=368.65,
        dict_composition={'C': 27, 'H': 44},
    ),
    "00315": PsimodInfo(
        id="00315",
        name="pentakis-L-cysteinyl L-histidino nickel tetrairon pentasulfide",
        formula="Fe4H-6NiS5",
        monoisotopic_mass=435.488498,
        average_mass=436.33,
        dict_composition={'Fe': 4, 'H': -6, 'Ni': 1, 'S': 5},
    ),
    "00316": PsimodInfo(
        id="00316",
        name="N4,N4-dimethyl-L-asparagine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
    "00317": PsimodInfo(
        id="00317",
        name="N6-3,4-didehydroretinylidene-L-lysine",
        formula="C20H24",
        monoisotopic_mass=264.187801,
        average_mass=264.41,
        dict_composition={'C': 20, 'H': 24},
    ),
    "00318": PsimodInfo(
        id="00318",
        name="4'-(S-L-cysteinyl)-L-tryptophyl quinone",
        formula="H-4O2",
        monoisotopic_mass=27.958529,
        average_mass=27.97,
        dict_composition={'H': -4, 'O': 2},
    ),
    "00319": PsimodInfo(
        id="00319",
        name="3-(S-L-cysteinyl)-L-aspartic acid",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00320": PsimodInfo(
        id="00320",
        name="4-(S-L-cysteinyl)-L-glutamic acid",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00321": PsimodInfo(
        id="00321",
        name="cis-14-hydroxy-10,13-dioxo-7-heptadecenoic acid L-aspartate ester",
        formula="C17H26O4",
        monoisotopic_mass=294.183109,
        average_mass=294.39,
        dict_composition={'C': 17, 'H': 26, 'O': 4},
    ),
    "00322": PsimodInfo(
        id="00322",
        name="1'-methyl-L-histidine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00323": PsimodInfo(
        id="00323",
        name="L-lysine methyl ester",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00324": PsimodInfo(
        id="00324",
        name="L-serinyl molybdenum bis(molybdopterin guanine dinucleotide)",
        formula="C40H47MoN20O27P4S4",
        monoisotopic_mass=1588.98069,
        average_mass=1588.01,
        dict_composition={'C': 40, 'H': 47, 'Mo': 1, 'N': 20, 'O': 27, 'P': 4, 'S': 4},
    ),
    "00325": PsimodInfo(
        id="00325",
        name="L-beta-methylthioasparagine",
        formula="CH2S",
        monoisotopic_mass=45.987721,
        average_mass=46.09,
        dict_composition={'C': 1, 'H': 2, 'S': 1},
    ),
    "00326": PsimodInfo(
        id="00326",
        name="L-pyrrolysine (Lys)",
        formula="C6H7NO",
        monoisotopic_mass=109.052764,
        average_mass=109.13,
        dict_composition={'C': 6, 'H': 7, 'N': 1, 'O': 1},
    ),
    "00327": PsimodInfo(
        id="00327",
        name="3-hydroxy-L-tryptophan",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "00329": PsimodInfo(
        id="00329",
        name="hydroxyheme-L-glutamate ester",
        formula="C34FeH30N4O4",
        monoisotopic_mass=614.161643,
        average_mass=614.48,
        dict_composition={'C': 34, 'Fe': 1, 'H': 30, 'N': 4, 'O': 4},
    ),
    "00330": PsimodInfo(
        id="00330",
        name="(phospho-5'-guanosine)-L-histidine",
        formula="C10H12N5O7P",
        monoisotopic_mass=345.047434,
        average_mass=345.21,
        dict_composition={'C': 10, 'H': 12, 'N': 5, 'O': 7, 'P': 1},
    ),
    "00331": PsimodInfo(
        id="00331",
        name="tetrakis-L-cysteinyl triiron tetrasulfide",
        formula="Fe3H-4S4",
        monoisotopic_mass=291.663442,
        average_mass=291.74,
        dict_composition={'Fe': 3, 'H': -4, 'S': 4},
    ),
    "00332": PsimodInfo(
        id="00332",
        name="omega-N-glucosyl-L-arginine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "00333": PsimodInfo(
        id="00333",
        name="(3-aminopropyl)(L-aspartyl-1-amino)phosphoryl-5'-adenosine",
        formula="C13H19N6O6P",
        monoisotopic_mass=386.110369,
        average_mass=386.3,
        dict_composition={'C': 13, 'H': 19, 'N': 6, 'O': 6, 'P': 1},
    ),
    "00334": PsimodInfo(
        id="00334",
        name="1'-heme-L-histidine",
        formula="C34FeH32N4O4",
        monoisotopic_mass=616.177293,
        average_mass=616.5,
        dict_composition={'C': 34, 'Fe': 1, 'H': 32, 'N': 4, 'O': 4},
    ),
    "00335": PsimodInfo(
        id="00335",
        name="(2S,3S,2'R)-3-methyllanthionine sulfoxide",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00336": PsimodInfo(
        id="00336",
        name="tris-L-cysteinyl L-aspartato diiron disulfide",
        formula="Fe2H-4S2",
        monoisotopic_mass=171.783814,
        average_mass=171.78,
        dict_composition={'Fe': 2, 'H': -4, 'S': 2},
    ),
    "00337": PsimodInfo(
        id="00337",
        name="S-carbamoyl-L-cysteine",
        formula="CHNO",
        monoisotopic_mass=43.005814,
        average_mass=43.02,
        dict_composition={'C': 1, 'H': 1, 'N': 1, 'O': 1},
    ),
    "00338": PsimodInfo(
        id="00338",
        name="S-cyano-L-cysteine",
        formula="CH-1N",
        monoisotopic_mass=24.995249,
        average_mass=25.01,
        dict_composition={'C': 1, 'H': -1, 'N': 1},
    ),
    "00339": PsimodInfo(
        id="00339",
        name="L-cysteinyl hydrogenase diiron subcluster",
        formula="C5Fe2H-1N2O5S2",
        monoisotopic_mass=342.786913,
        average_mass=342.87,
        dict_composition={'C': 5, 'Fe': 2, 'H': -1, 'N': 2, 'O': 5, 'S': 2},
    ),
    "00340": PsimodInfo(
        id="00340",
        name="S-amidino-L-cysteine",
        formula="CH2N2",
        monoisotopic_mass=42.021798,
        average_mass=42.04,
        dict_composition={'C': 1, 'H': 2, 'N': 2},
    ),
    "00341": PsimodInfo(
        id="00341",
        name="N-methyl-L-isoleucine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00342": PsimodInfo(
        id="00342",
        name="N-methyl-L-leucine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00343": PsimodInfo(
        id="00343",
        name="N-methyl-L-tyrosine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00344": PsimodInfo(
        id="00344",
        name="N-palmitoylglycine",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
    "00345": PsimodInfo(
        id="00345",
        name="2-(S-L-cysteinyl)-L-phenylalanine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00346": PsimodInfo(
        id="00346",
        name="2-(S-L-cysteinyl)-D-phenylalanine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00347": PsimodInfo(
        id="00347",
        name="2-(S-L-cysteinyl)-D-allo-threonine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00348": PsimodInfo(
        id="00348",
        name="N-carbamoyl-L-alanine",
        formula="CHNO",
        monoisotopic_mass=43.005814,
        average_mass=43.02,
        dict_composition={'C': 1, 'H': 1, 'N': 1, 'O': 1},
    ),
    "00349": PsimodInfo(
        id="00349",
        name="4-amino-3-isothiazolidinone-L-serine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00351": PsimodInfo(
        id="00351",
        name="N-glycyl-1-(phosphatidyl)ethanolamine",
        formula="C39H74NO7P",
        monoisotopic_mass=699.52029,
        average_mass=699.99,
        dict_composition={'C': 39, 'H': 74, 'N': 1, 'O': 7, 'P': 1},
    ),
    "00352": PsimodInfo(
        id="00352",
        name="L-glutamyl 5-omega-hydroxyceramide ester",
        formula="C50H96O4",
        monoisotopic_mass=760.730862,
        average_mass=761.31,
        dict_composition={'C': 50, 'H': 96, 'O': 4},
    ),
    "00353": PsimodInfo(
        id="00353",
        name="S-[5'-(L-tryptoph-6'-yl)-L-tyrosin-3'-yl]-L-methionin-S-ium",
        formula="H-3",
        monoisotopic_mass=-3.024024,
        average_mass=-3.02,
        dict_composition={'H': -3},
    ),
    "00354": PsimodInfo(
        id="00354",
        name="O-(riboflavin phosphoryl)-L-threonine",
        formula="C17H19N4O8P",
        monoisotopic_mass=438.09405,
        average_mass=438.33,
        dict_composition={'C': 17, 'H': 19, 'N': 4, 'O': 8, 'P': 1},
    ),
    "00355": PsimodInfo(
        id="00355",
        name="O-(riboflavin phosphoryl)-L-serine",
        formula="C17H19N4O8P",
        monoisotopic_mass=438.09405,
        average_mass=438.33,
        dict_composition={'C': 17, 'H': 19, 'N': 4, 'O': 8, 'P': 1},
    ),
    "00356": PsimodInfo(
        id="00356",
        name="S-(4alpha-FMN)-L-cysteine",
        formula="C17H21N4O9P",
        monoisotopic_mass=456.104615,
        average_mass=456.35,
        dict_composition={'C': 17, 'H': 21, 'N': 4, 'O': 9, 'P': 1},
    ),
    "00357": PsimodInfo(
        id="00357",
        name="1'-(8alpha-FMN)-L-histidine",
        formula="C17H19N4O9P",
        monoisotopic_mass=454.088965,
        average_mass=454.33,
        dict_composition={'C': 17, 'H': 19, 'N': 4, 'O': 9, 'P': 1},
    ),
    "00358": PsimodInfo(
        id="00358",
        name="3'-(8alpha-FMN)-L-histidine",
        formula="C17H19N4O9P",
        monoisotopic_mass=454.088965,
        average_mass=454.33,
        dict_composition={'C': 17, 'H': 19, 'N': 4, 'O': 9, 'P': 1},
    ),
    "00359": PsimodInfo(
        id="00359",
        name="N2-acetyl-L-arginine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00360": PsimodInfo(
        id="00360",
        name="L-cysteinyl copper sulfido molybdopterin cytosine dinuncleotide",
        formula="C19CuH24MoN8O15P2S3",
        monoisotopic_mass=922.834854,
        average_mass=922.07,
        dict_composition={'C': 19, 'Cu': 1, 'H': 24, 'Mo': 1, 'N': 8, 'O': 15, 'P': 2, 'S': 3},
    ),
    "00361": PsimodInfo(
        id="00361",
        name="tris-L-cysteinyl S-adenosylmethion-N,O-diyl tetrairon tetrasulfide",
        formula="C15Fe4H19N6O5S5",
        monoisotopic_mass=746.742346,
        average_mass=747.03,
        dict_composition={'C': 15, 'Fe': 4, 'H': 19, 'N': 6, 'O': 5, 'S': 5},
    ),
    "00362": PsimodInfo(
        id="00362",
        name="tris-L-cysteinyl L-arginyl diiron disulfide",
        formula="Fe2H-3S2",
        monoisotopic_mass=172.791639,
        average_mass=172.79,
        dict_composition={'Fe': 2, 'H': -3, 'S': 2},
    ),
    "00363": PsimodInfo(
        id="00363",
        name="L-cysteinyl-L-selenocysteine (Cys-Sec)",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00364": PsimodInfo(
        id="00364",
        name="5-hydroxy-N6,N6,N6-trimethyl-L-lysine",
        formula="C3H7O",
        monoisotopic_mass=59.049141,
        average_mass=59.09,
        dict_composition={'C': 3, 'H': 7, 'O': 1},
    ),
    "00365": PsimodInfo(
        id="00365",
        name="N-(L-isoglutamyl)-glycine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00366": PsimodInfo(
        id="00366",
        name="O-sulfo-L-serine",
        formula="O3S",
        monoisotopic_mass=79.956815,
        average_mass=80.06,
        dict_composition={'O': 3, 'S': 1},
    ),
    "00367": PsimodInfo(
        id="00367",
        name="O-sulfo-L-threonine",
        formula="O3S",
        monoisotopic_mass=79.956815,
        average_mass=80.06,
        dict_composition={'O': 3, 'S': 1},
    ),
    "00368": PsimodInfo(
        id="00368",
        name="N-carboxy-L-methionine",
        formula="CO2",
        monoisotopic_mass=43.989829,
        average_mass=44.01,
        dict_composition={'C': 1, 'O': 2},
    ),
    "00369": PsimodInfo(
        id="00369",
        name="O-acetyl-L-serine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00370": PsimodInfo(
        id="00370",
        name="(E)-2,3-didehydrotyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00371": PsimodInfo(
        id="00371",
        name="bis-L-aspartato tris-L-glutamato L-histidino calcium tetramanganese tetroxide",
        formula="CaH-6Mn4O4",
        monoisotopic_mass=317.64748,
        average_mass=317.78,
        dict_composition={'Ca': 1, 'H': -6, 'Mn': 4, 'O': 4},
    ),
    "00372": PsimodInfo(
        id="00372",
        name="3'-(3'-L-tyrosinyl)-L-tyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00373": PsimodInfo(
        id="00373",
        name="3'-(O4'-L-tyrosinyl)-L-tyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00374": PsimodInfo(
        id="00374",
        name="3,4-dihydroxy-L-arginine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "00375": PsimodInfo(
        id="00375",
        name="4,5-dihydroxy-L-lysine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "00376": PsimodInfo(
        id="00376",
        name="1'-(phospho-5'-adenosine)-L-histidine",
        formula="C10H12N5O6P",
        monoisotopic_mass=329.05252,
        average_mass=329.21,
        dict_composition={'C': 10, 'H': 12, 'N': 5, 'O': 6, 'P': 1},
    ),
    "00377": PsimodInfo(
        id="00377",
        name="1'-(phospho-5'-uridine)-L-histidine",
        formula="C9H11N2O8P",
        monoisotopic_mass=306.025302,
        average_mass=306.17,
        dict_composition={'C': 9, 'H': 11, 'N': 2, 'O': 8, 'P': 1},
    ),
    "00378": PsimodInfo(
        id="00378",
        name="L-aspartyl semialdehyde",
        formula="O-1",
        monoisotopic_mass=-15.994915,
        average_mass=-16.0,
        dict_composition={'O': -1},
    ),
    "00379": PsimodInfo(
        id="00379",
        name="L-serine microcin E492 siderophore ester",
        formula="C36H37N3O20",
        monoisotopic_mass=831.197041,
        average_mass=831.69,
        dict_composition={'C': 36, 'H': 37, 'N': 3, 'O': 20},
    ),
    "00380": PsimodInfo(
        id="00380",
        name="L-aspartyl molybdenum bis(molybdopterin guanine dinucleotide)",
        formula="C40H47MoN20O26P4S4",
        monoisotopic_mass=1572.985775,
        average_mass=1572.02,
        dict_composition={'C': 40, 'H': 47, 'Mo': 1, 'N': 20, 'O': 26, 'P': 4, 'S': 4},
    ),
    "00381": PsimodInfo(
        id="00381",
        name="L-selenocysteinyl tungsten bis(molybdopterin guanine dinucleotide) (Sec)",
        formula="C40H47N20O26P4S5W",
        monoisotopic_mass=1691.003369,
        average_mass=1691.97,
        dict_composition={'C': 40, 'H': 47, 'N': 20, 'O': 26, 'P': 4, 'S': 5, 'W': 1},
    ),
    "00382": PsimodInfo(
        id="00382",
        name="3-(2-methylthio)ethyl-6-(4-hydroxybenzylidene)-5-iminopiperazin-2-one",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "00383": PsimodInfo(
        id="00383",
        name="2-imino-glutamic acid 5-imidazolinone glycine",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "00384": PsimodInfo(
        id="00384",
        name="2-imino-methionine 5-imidazolinone glycine",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "00385": PsimodInfo(
        id="00385",
        name="L-asparagine 5-imidazolinone glycine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00386": PsimodInfo(
        id="00386",
        name="L-lysine 5-imidazolinone glycine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00387": PsimodInfo(
        id="00387",
        name="2-tetrahydropyridinyl-5-imidazolinone glycine",
        formula="H-7N-1O-1",
        monoisotopic_mass=-37.052764,
        average_mass=-37.06,
        dict_composition={'H': -7, 'N': -1, 'O': -1},
    ),
    "00389": PsimodInfo(
        id="00389",
        name="N-formyl-L-proline",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
    "00390": PsimodInfo(
        id="00390",
        name="O-decanoyl-L-serine",
        formula="C10H18O",
        monoisotopic_mass=154.135765,
        average_mass=154.25,
        dict_composition={'C': 10, 'H': 18, 'O': 1},
    ),
    "00391": PsimodInfo(
        id="00391",
        name="O-octanoyl-L-threonine",
        formula="C8H14O",
        monoisotopic_mass=126.104465,
        average_mass=126.2,
        dict_composition={'C': 8, 'H': 14, 'O': 1},
    ),
    "00392": PsimodInfo(
        id="00392",
        name="O-decanoyl-L-threonine",
        formula="C10H18O",
        monoisotopic_mass=154.135765,
        average_mass=154.25,
        dict_composition={'C': 10, 'H': 18, 'O': 1},
    ),
    "00394": PsimodInfo(
        id="00394",
        name="monoacetylated residue",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00397": PsimodInfo(
        id="00397",
        name="iodoacetamide derivatized residue",
        formula="C2H3NO",
        monoisotopic_mass=57.021464,
        average_mass=57.05,
        dict_composition={'C': 2, 'H': 3, 'N': 1, 'O': 1},
    ),
    "00398": PsimodInfo(
        id="00398",
        name="carbamoylated residue",
        formula="CHNO",
        monoisotopic_mass=43.005814,
        average_mass=43.02,
        dict_composition={'C': 1, 'H': 1, 'N': 1, 'O': 1},
    ),
    "00399": PsimodInfo(
        id="00399",
        name="iodoacetic acid derivatized residue",
        formula="C2H2O2",
        monoisotopic_mass=58.005479,
        average_mass=58.04,
        dict_composition={'C': 2, 'H': 2, 'O': 2},
    ),
    "00400": PsimodInfo(
        id="00400",
        name="deamidated residue",
        formula="H-1N-1O",
        monoisotopic_mass=0.984016,
        average_mass=0.98,
        dict_composition={'H': -1, 'N': -1, 'O': 1},
    ),
    "00401": PsimodInfo(
        id="00401",
        name="Gygi ICAT(TM) d0 modified cysteine",
        formula="C22H38N4O6S",
        monoisotopic_mass=486.251206,
        average_mass=486.63,
        dict_composition={'C': 22, 'H': 38, 'N': 4, 'O': 6, 'S': 1},
    ),
    "00402": PsimodInfo(
        id="00402",
        name="Gygi ICAT(TM) d8 modified cysteine",
        formula="C22[1H30][2H8]N4O6S",
        monoisotopic_mass=494.30142,
        average_mass=494.3,
        dict_composition={'C': 22, '1H': 30, '2H': 8, 'N': 4, 'O': 6, 'S': 1},
    ),
    "00403": PsimodInfo(
        id="00403",
        name="homoserine",
        formula="C-1H-2OS-1",
        monoisotopic_mass=-29.992806,
        average_mass=-30.09,
        dict_composition={'C': -1, 'H': -2, 'O': 1, 'S': -1},
    ),
    "00404": PsimodInfo(
        id="00404",
        name="homoserine lactone",
        formula="C-1H-4S-1",
        monoisotopic_mass=-48.003371,
        average_mass=-48.1,
        dict_composition={'C': -1, 'H': -4, 'S': -1},
    ),
    "00405": PsimodInfo(
        id="00405",
        name="Applied Biosystems original ICAT(TM) d8 modified cysteine",
        formula="C20[1H26][2H8]N4O5S",
        monoisotopic_mass=450.275205,
        average_mass=450.28,
        dict_composition={'C': 20, '1H': 26, '2H': 8, 'N': 4, 'O': 5, 'S': 1},
    ),
    "00406": PsimodInfo(
        id="00406",
        name="Applied Biosystems original ICAT(TM) d0 modified cysteine",
        formula="C20[1H34]N4O5S",
        monoisotopic_mass=442.224991,
        average_mass=442.22,
        dict_composition={'C': 20, '1H': 34, 'N': 4, 'O': 5, 'S': 1},
    ),
    "00408": PsimodInfo(
        id="00408",
        name="mono N-acetylated residue",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00409": PsimodInfo(
        id="00409",
        name="N-formylated residue",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
    "00410": PsimodInfo(
        id="00410",
        name="S-(N-isopropylcarboxamidomethyl)-L-cysteine",
        formula="C5H9NO",
        monoisotopic_mass=99.068414,
        average_mass=99.13,
        dict_composition={'C': 5, 'H': 9, 'N': 1, 'O': 1},
    ),
    "00413": PsimodInfo(
        id="00413",
        name="biotinyl-iodoacetamidyl-3,6-dioxaoctanediamine derivatized cysteine",
        formula="C18H30N4O5S",
        monoisotopic_mass=414.193691,
        average_mass=414.52,
        dict_composition={'C': 18, 'H': 30, 'N': 4, 'O': 5, 'S': 1},
    ),
    "00414": PsimodInfo(
        id="00414",
        name="monomethylated L-arginine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00416": PsimodInfo(
        id="00416",
        name="phosphorylation of an hydroxyl amino acid with prompt loss of phosphate",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00417": PsimodInfo(
        id="00417",
        name="S-carboxamidoethyl-L-cysteine",
        formula="C3H5NO",
        monoisotopic_mass=71.037114,
        average_mass=71.08,
        dict_composition={'C': 3, 'H': 5, 'N': 1, 'O': 1},
    ),
    "00418": PsimodInfo(
        id="00418",
        name="pyridylacetylated residue",
        formula="C7H5NO",
        monoisotopic_mass=119.037114,
        average_mass=119.12,
        dict_composition={'C': 7, 'H': 5, 'N': 1, 'O': 1},
    ),
    "00419": PsimodInfo(
        id="00419",
        name="(R)-5-oxo-1,4-tetrahydrothiazine-3-carboxylic acid",
        formula="C2O",
        monoisotopic_mass=39.994915,
        average_mass=40.02,
        dict_composition={'C': 2, 'O': 1},
    ),
    "00420": PsimodInfo(
        id="00420",
        name="2-pyrrolidone-5-carboxylic acid (Glu)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00422": PsimodInfo(
        id="00422",
        name="alpha-amino morpholine-2-acetylated residue",
        formula="C6H9NO2",
        monoisotopic_mass=127.063329,
        average_mass=127.14,
        dict_composition={'C': 6, 'H': 9, 'N': 1, 'O': 2},
    ),
    "00423": PsimodInfo(
        id="00423",
        name="monosodium salt",
        formula="H-1Na",
        monoisotopic_mass=21.981944,
        average_mass=21.98,
        dict_composition={'H': -1, 'Na': 1},
    ),
    "00424": PsimodInfo(
        id="00424",
        name="S-pyridylethyl-L-cysteine",
        formula="C7H7N",
        monoisotopic_mass=105.057849,
        average_mass=105.14,
        dict_composition={'C': 7, 'H': 7, 'N': 1},
    ),
    "00425": PsimodInfo(
        id="00425",
        name="monohydroxylated residue",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "00428": PsimodInfo(
        id="00428",
        name="dihydroxylated residue",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "00429": PsimodInfo(
        id="00429",
        name="dimethylated residue",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
    "00430": PsimodInfo(
        id="00430",
        name="trimethylated residue",
        formula="C3H6",
        monoisotopic_mass=42.04695,
        average_mass=42.08,
        dict_composition={'C': 3, 'H': 6},
    ),
    "00433": PsimodInfo(
        id="00433",
        name="monoglucosylated residue",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "00435": PsimodInfo(
        id="00435",
        name="O-phospho-L-serine with neutral loss of phosphate",
        formula="H-3O-4P-1",
        monoisotopic_mass=-97.976895,
        average_mass=-97.99,
        dict_composition={'H': -3, 'O': -4, 'P': -1},
    ),
    "00436": PsimodInfo(
        id="00436",
        name="N-acetylhexosaminylated residue",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "00437": PsimodInfo(
        id="00437",
        name="farnesylated residue",
        formula="C15H24",
        monoisotopic_mass=204.187801,
        average_mass=204.36,
        dict_composition={'C': 15, 'H': 24},
    ),
    "00438": PsimodInfo(
        id="00438",
        name="myristoylated residue",
        formula="C14H26O",
        monoisotopic_mass=210.198365,
        average_mass=210.36,
        dict_composition={'C': 14, 'H': 26, 'O': 1},
    ),
    "00439": PsimodInfo(
        id="00439",
        name="O-phospho-L-threonine with neutral loss of phosphate",
        formula="H-3O-4P-1",
        monoisotopic_mass=-97.976895,
        average_mass=-97.99,
        dict_composition={'H': -3, 'O': -4, 'P': -1},
    ),
    "00440": PsimodInfo(
        id="00440",
        name="palmitoylated residue",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
    "00441": PsimodInfo(
        id="00441",
        name="geranylgeranylated residue",
        formula="C20H32",
        monoisotopic_mass=272.250401,
        average_mass=272.48,
        dict_composition={'C': 20, 'H': 32},
    ),
    "00442": PsimodInfo(
        id="00442",
        name="protonated omega-N,omega-N'-dimethylated L-arginine with secondary neutral loss of N,N'-carbodiimide",
        formula="CH2N2",
        monoisotopic_mass=42.021798,
        average_mass=42.04,
        dict_composition={'C': 1, 'H': 2, 'N': 2},
    ),
    "00443": PsimodInfo(
        id="00443",
        name="protonated omega-N,omega-N-dimethlyated L-arginine with secondary neutral loss of N,N-dimethylamine",
        formula="C2H7N2",
        monoisotopic_mass=59.060923,
        average_mass=59.09,
        dict_composition={'C': 2, 'H': 7, 'N': 2},
    ),
    "00444": PsimodInfo(
        id="00444",
        name="N-palmitoyl-S-(sn-1-2,3-dipalmitoyl-glycerol)cysteine",
        formula="C51H96O5",
        monoisotopic_mass=788.725776,
        average_mass=789.32,
        dict_composition={'C': 51, 'H': 96, 'O': 5},
    ),
    "00445": PsimodInfo(
        id="00445",
        name="L-homoarginine",
        formula="CH2N2",
        monoisotopic_mass=42.021798,
        average_mass=42.04,
        dict_composition={'C': 1, 'H': 2, 'N': 2},
    ),
    "00446": PsimodInfo(
        id="00446",
        name="4-hydroxynonenal adduct",
        formula="C9H16O2",
        monoisotopic_mass=156.11503,
        average_mass=156.22,
        dict_composition={'C': 9, 'H': 16, 'O': 2},
    ),
    "00447": PsimodInfo(
        id="00447",
        name="N-glucuronylated residue",
        formula="C6H8O6",
        monoisotopic_mass=176.032088,
        average_mass=176.12,
        dict_composition={'C': 6, 'H': 8, 'O': 6},
    ),
    "00448": PsimodInfo(
        id="00448",
        name="mono-N-acetylaminoglucosylated residue",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "00449": PsimodInfo(
        id="00449",
        name="acetate labeling reagent (N-term) (heavy form, +3amu)",
        formula="C2[1H-1][2H3]O",
        monoisotopic_mass=45.029395,
        average_mass=45.03,
        dict_composition={'C': 2, '1H': -1, '2H': 3, 'O': 1},
    ),
    "00451": PsimodInfo(
        id="00451",
        name="alpha-amino propanoylated residue",
        formula="C3H4O",
        monoisotopic_mass=56.026215,
        average_mass=56.06,
        dict_composition={'C': 3, 'H': 4, 'O': 1},
    ),
    "00452": PsimodInfo(
        id="00452",
        name="alpha-amino 3x(13)C-labeled propanoylated residue",
        formula="[13C3]H4O",
        monoisotopic_mass=59.036279,
        average_mass=59.04,
        dict_composition={'13C': 3, 'H': 4, 'O': 1},
    ),
    "00453": PsimodInfo(
        id="00453",
        name="quaternary amine labeling reagent light form (N-term & K)",
        formula="C7H13NO",
        monoisotopic_mass=127.099714,
        average_mass=127.19,
        dict_composition={'C': 7, 'H': 13, 'N': 1, 'O': 1},
    ),
    "00454": PsimodInfo(
        id="00454",
        name="quaternary amine labeling reagent heavy form (+3amu) (N-term & K)",
        formula="C7[1H10][2H3]NO",
        monoisotopic_mass=130.118544,
        average_mass=130.12,
        dict_composition={'C': 7, '1H': 10, '2H': 3, 'N': 1, 'O': 1},
    ),
    "00455": PsimodInfo(
        id="00455",
        name="quaternary amine labeling reagent heavy form (+6amu) (N-term & K)",
        formula="C7H7[2H6]NO",
        monoisotopic_mass=133.137375,
        average_mass=133.14,
        dict_composition={'C': 7, 'H': 7, '2H': 6, 'N': 1, 'O': 1},
    ),
    "00456": PsimodInfo(
        id="00456",
        name="quaternary amine labeling reagent heavy form (+9amu) (N-term & K)",
        formula="C7[1H4][2H9]NO",
        monoisotopic_mass=136.156205,
        average_mass=136.16,
        dict_composition={'C': 7, '1H': 4, '2H': 9, 'N': 1, 'O': 1},
    ),
    "00457": PsimodInfo(
        id="00457",
        name="4x(12)C, 4x(1)H labeled alpha-amino succinylated residue",
        formula="[12C4][1H4]O3",
        monoisotopic_mass=100.016044,
        average_mass=100.03,
        dict_composition={'12C': 4, '1H': 4, 'O': 3},
    ),
    "00458": PsimodInfo(
        id="00458",
        name="4x(2)H labeled alpha-amino succinylated residue",
        formula="C4[2H4]O3",
        monoisotopic_mass=104.041151,
        average_mass=104.04,
        dict_composition={'C': 4, '2H': 4, 'O': 3},
    ),
    "00459": PsimodInfo(
        id="00459",
        name="4x(13)C labeled alpha-amino succinylated residue",
        formula="[13C4]H4O3",
        monoisotopic_mass=104.029463,
        average_mass=104.03,
        dict_composition={'13C': 4, 'H': 4, 'O': 3},
    ),
    "00460": PsimodInfo(
        id="00460",
        name="L-cysteic acid (L-cysteine sulfonic acid)",
        formula="O3",
        monoisotopic_mass=47.984744,
        average_mass=48.0,
        dict_composition={'O': 3},
    ),
    "00461": PsimodInfo(
        id="00461",
        name="nitrated residue",
        formula="H-1NO2",
        monoisotopic_mass=44.985078,
        average_mass=45.0,
        dict_composition={'H': -1, 'N': 1, 'O': 2},
    ),
    "00462": PsimodInfo(
        id="00462",
        name="L-kynurenine",
        formula="C-1O",
        monoisotopic_mass=3.994915,
        average_mass=3.99,
        dict_composition={'C': -1, 'O': 1},
    ),
    "00463": PsimodInfo(
        id="00463",
        name="3'-hydroxy-L-kynurenine",
        formula="C-1O2",
        monoisotopic_mass=19.989829,
        average_mass=19.99,
        dict_composition={'C': -1, 'O': 2},
    ),
    "00464": PsimodInfo(
        id="00464",
        name="N'-formyl-L-kynurenine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "00465": PsimodInfo(
        id="00465",
        name="dihydroxyphenylalanine (Phe)",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "00467": PsimodInfo(
        id="00467",
        name="iminobiotinyl modified residue",
        formula="C10H15N3OS",
        monoisotopic_mass=225.093583,
        average_mass=225.31,
        dict_composition={'C': 10, 'H': 15, 'N': 3, 'O': 1, 'S': 1},
    ),
    "00468": PsimodInfo(
        id="00468",
        name="ESP-Tag light d0",
        formula="C16H26N4O2S",
        monoisotopic_mass=338.177647,
        average_mass=338.47,
        dict_composition={'C': 16, 'H': 26, 'N': 4, 'O': 2, 'S': 1},
    ),
    "00469": PsimodInfo(
        id="00469",
        name="ESP-Tag heavy d10",
        formula="C16[1H16][2H10]N4O2S",
        monoisotopic_mass=348.240415,
        average_mass=348.24,
        dict_composition={'C': 16, '1H': 16, '2H': 10, 'N': 4, 'O': 2, 'S': 1},
    ),
    "00470": PsimodInfo(
        id="00470",
        name="NHS-LC-Biotin",
        formula="C16H25N3O3S",
        monoisotopic_mass=339.161663,
        average_mass=339.45,
        dict_composition={'C': 16, 'H': 25, 'N': 3, 'O': 3, 'S': 1},
    ),
    "00471": PsimodInfo(
        id="00471",
        name="EDT-maleimide-PEO-biotin",
        formula="C25H39N5O6S3",
        monoisotopic_mass=601.206247,
        average_mass=601.8,
        dict_composition={'C': 25, 'H': 39, 'N': 5, 'O': 6, 'S': 3},
    ),
    "00472": PsimodInfo(
        id="00472",
        name="IMID d0",
        formula="C3[1H4]N2",
        monoisotopic_mass=68.037448,
        average_mass=68.04,
        dict_composition={'C': 3, '1H': 4, 'N': 2},
    ),
    "00473": PsimodInfo(
        id="00473",
        name="IMID d4",
        formula="C3[2H4]N2",
        monoisotopic_mass=72.062555,
        average_mass=72.06,
        dict_composition={'C': 3, '2H': 4, 'N': 2},
    ),
    "00474": PsimodInfo(
        id="00474",
        name="S-([1,1,2-(2)H3]-carboxamidoethyl)-L-cysteine",
        formula="C3[1H2][2H3]NO",
        monoisotopic_mass=74.055944,
        average_mass=74.06,
        dict_composition={'C': 3, '1H': 2, '2H': 3, 'N': 1, 'O': 1},
    ),
    "00475": PsimodInfo(
        id="00475",
        name="2-amino-L-tyrosine",
        formula="HN",
        monoisotopic_mass=15.010899,
        average_mass=15.02,
        dict_composition={'H': 1, 'N': 1},
    ),
    "00476": PsimodInfo(
        id="00476",
        name="monogalactosylated residue",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "00477": PsimodInfo(
        id="00477",
        name="2-pyrrolidone",
        formula="C-1H-1",
        monoisotopic_mass=-13.007825,
        average_mass=-13.02,
        dict_composition={'C': -1, 'H': -1},
    ),
    "00478": PsimodInfo(
        id="00478",
        name="glutamyl semialdehyde (Pro)",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "00479": PsimodInfo(
        id="00479",
        name="glutamyl semialdehyde (Arg)",
        formula="C-1H-5N-3O",
        monoisotopic_mass=-43.053433,
        average_mass=-43.07,
        dict_composition={'C': -1, 'H': -5, 'N': -3, 'O': 1},
    ),
    "00480": PsimodInfo(
        id="00480",
        name="Applied Biosystems cleavable ICAT(TM) light",
        formula="C10H17N3O3",
        monoisotopic_mass=227.126991,
        average_mass=227.26,
        dict_composition={'C': 10, 'H': 17, 'N': 3, 'O': 3},
    ),
    "00481": PsimodInfo(
        id="00481",
        name="Applied Biosystems cleavable ICAT(TM) heavy",
        formula="[12C][13C9]H17N3O3",
        monoisotopic_mass=236.157185,
        average_mass=236.16,
        dict_composition={'12C': 1, '13C': 9, 'H': 17, 'N': 3, 'O': 3},
    ),
    "00482": PsimodInfo(
        id="00482",
        name="N-formyl-L-methionine (Met)",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
    "00483": PsimodInfo(
        id="00483",
        name="N-ethylmaleimide derivatized cysteine",
        formula="C6H7NO2",
        monoisotopic_mass=125.047678,
        average_mass=125.13,
        dict_composition={'C': 6, 'H': 7, 'N': 1, 'O': 2},
    ),
    "00484": PsimodInfo(
        id="00484",
        name="oxidized lysine biotinylated with biotin-LC-hydrazide, reduced",
        formula="C16H26N4O3S",
        monoisotopic_mass=354.172562,
        average_mass=354.47,
        dict_composition={'C': 16, 'H': 26, 'N': 4, 'O': 3, 'S': 1},
    ),
    "00485": PsimodInfo(
        id="00485",
        name="oxidized lysine biotinylated with biotin-LC-hydrazide",
        formula="C16H24N4O3S",
        monoisotopic_mass=352.156912,
        average_mass=352.45,
        dict_composition={'C': 16, 'H': 24, 'N': 4, 'O': 3, 'S': 1},
    ),
    "00486": PsimodInfo(
        id="00486",
        name="oxidized proline biotinylated with biotin-LC-hydrazide, reduced",
        formula="C16H29N5O3S",
        monoisotopic_mass=371.199111,
        average_mass=371.5,
        dict_composition={'C': 16, 'H': 29, 'N': 5, 'O': 3, 'S': 1},
    ),
    "00487": PsimodInfo(
        id="00487",
        name="oxidized proline biotinylated with biotin-LC-hydrazide",
        formula="C16H27N5O3S",
        monoisotopic_mass=369.183461,
        average_mass=369.48,
        dict_composition={'C': 16, 'H': 27, 'N': 5, 'O': 3, 'S': 1},
    ),
    "00488": PsimodInfo(
        id="00488",
        name="oxidized arginine biotinylated with biotin-LC-hydrazide",
        formula="C15H22N2O3S",
        monoisotopic_mass=310.135114,
        average_mass=310.41,
        dict_composition={'C': 15, 'H': 22, 'N': 2, 'O': 3, 'S': 1},
    ),
    "00489": PsimodInfo(
        id="00489",
        name="oxidized arginine biotinylated with biotin-LC-hydrazide, reduced",
        formula="C15H24N2O3S",
        monoisotopic_mass=312.150764,
        average_mass=312.43,
        dict_composition={'C': 15, 'H': 24, 'N': 2, 'O': 3, 'S': 1},
    ),
    "00490": PsimodInfo(
        id="00490",
        name="EDT-iodo-PEO-biotin",
        formula="C20H34N4O4S3",
        monoisotopic_mass=490.174219,
        average_mass=490.7,
        dict_composition={'C': 20, 'H': 34, 'N': 4, 'O': 4, 'S': 3},
    ),
    "00491": PsimodInfo(
        id="00491",
        name="thio ether formation - BTP Adduct",
        formula="C22H21P",
        monoisotopic_mass=316.138087,
        average_mass=316.38,
        dict_composition={'C': 22, 'H': 21, 'P': 1},
    ),
    "00492": PsimodInfo(
        id="00492",
        name="ubiquitination signature dipeptidyl lysine",
        formula="C4H6N2O2",
        monoisotopic_mass=114.042927,
        average_mass=114.1,
        dict_composition={'C': 4, 'H': 6, 'N': 2, 'O': 2},
    ),
    "00493": PsimodInfo(
        id="00493",
        name="formylated residue",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
    "00494": PsimodInfo(
        id="00494",
        name="N-iodoacetyl, p-chlorobenzyl-12C6-glucamine",
        formula="C15ClH20NO6",
        monoisotopic_mass=345.097915,
        average_mass=345.78,
        dict_composition={'C': 15, 'Cl': 1, 'H': 20, 'N': 1, 'O': 6},
    ),
    "00495": PsimodInfo(
        id="00495",
        name="N-iodoacetyl, p-chlorobenzyl-13C6-glucamine",
        formula="[12C9][13C6]ClH20NO6",
        monoisotopic_mass=351.118044,
        average_mass=351.12,
        dict_composition={'12C': 9, '13C': 6, 'Cl': 1, 'H': 20, 'N': 1, 'O': 6},
    ),
    "00497": PsimodInfo(
        id="00497",
        name="3-sulfanylpropanoyl (N-term and Lys)",
        formula="C3H4OS",
        monoisotopic_mass=87.998286,
        average_mass=88.12,
        dict_composition={'C': 3, 'H': 4, 'O': 1, 'S': 1},
    ),
    "00499": PsimodInfo(
        id="00499",
        name="5-iodoacetamidofluorescein",
        formula="C22H14NO6",
        monoisotopic_mass=388.082112,
        average_mass=388.35,
        dict_composition={'C': 22, 'H': 14, 'N': 1, 'O': 6},
    ),
    "00500": PsimodInfo(
        id="00500",
        name="monoiodinated residue",
        formula="H-1I",
        monoisotopic_mass=125.896648,
        average_mass=125.9,
        dict_composition={'H': -1, 'I': 1},
    ),
    "00501": PsimodInfo(
        id="00501",
        name="diiodinated residue",
        formula="H-2I2",
        monoisotopic_mass=251.793295,
        average_mass=251.79,
        dict_composition={'H': -2, 'I': 2},
    ),
    "00502": PsimodInfo(
        id="00502",
        name="triiodinated residue",
        formula="H-3I3",
        monoisotopic_mass=377.689943,
        average_mass=377.69,
        dict_composition={'H': -3, 'I': 3},
    ),
    "00503": PsimodInfo(
        id="00503",
        name="N-(cis-delta 5)-tetradecaenoylglycine",
        formula="C14H24O",
        monoisotopic_mass=208.182715,
        average_mass=208.35,
        dict_composition={'C': 14, 'H': 24, 'O': 1},
    ),
    "00504": PsimodInfo(
        id="00504",
        name="N-(cis,cis-delta 5,delta 8)-tetradecadienoylglycine",
        formula="C14H22O",
        monoisotopic_mass=206.167065,
        average_mass=206.33,
        dict_composition={'C': 14, 'H': 22, 'O': 1},
    ),
    "00505": PsimodInfo(
        id="00505",
        name="benzoyl labeling reagent light form (N-term and K)",
        formula="C7H4O",
        monoisotopic_mass=104.026215,
        average_mass=104.11,
        dict_composition={'C': 7, 'H': 4, 'O': 1},
    ),
    "00506": PsimodInfo(
        id="00506",
        name="N-linked glycan core N4-glycosylated asparagine",
        formula="C46H76N2O35",
        monoisotopic_mass=1216.422862,
        average_mass=1217.09,
        dict_composition={'C': 46, 'H': 76, 'N': 2, 'O': 35},
    ),
    "00509": PsimodInfo(
        id="00509",
        name="amidination of lysines or N-terminal amines with methyl acetimidate",
        formula="C2H3N",
        monoisotopic_mass=41.026549,
        average_mass=41.05,
        dict_composition={'C': 2, 'H': 3, 'N': 1},
    ),
    "00510": PsimodInfo(
        id="00510",
        name="HexNAc1dHex1 N4-glycosylated asparagine",
        formula="C14H23NO9",
        monoisotopic_mass=349.137281,
        average_mass=349.34,
        dict_composition={'C': 14, 'H': 23, 'N': 1, 'O': 9},
    ),
    "00511": PsimodInfo(
        id="00511",
        name="HexNAc2 N4-glycosylated asparagine",
        formula="C16H26N2O10",
        monoisotopic_mass=406.158745,
        average_mass=406.39,
        dict_composition={'C': 16, 'H': 26, 'N': 2, 'O': 10},
    ),
    "00512": PsimodInfo(
        id="00512",
        name="Hex3 N4-glycosylated asparagine",
        formula="C18H30O15",
        monoisotopic_mass=486.15847,
        average_mass=486.42,
        dict_composition={'C': 18, 'H': 30, 'O': 15},
    ),
    "00513": PsimodInfo(
        id="00513",
        name="HexNAc1dHex2 N4-glycosylated asparagine",
        formula="C20H33NO13",
        monoisotopic_mass=495.19519,
        average_mass=495.48,
        dict_composition={'C': 20, 'H': 33, 'N': 1, 'O': 13},
    ),
    "00514": PsimodInfo(
        id="00514",
        name="Hex1HexNAc1dHex1 N4-glycosylated asparagine",
        formula="C20H33NO14",
        monoisotopic_mass=511.190105,
        average_mass=511.48,
        dict_composition={'C': 20, 'H': 33, 'N': 1, 'O': 14},
    ),
    "00515": PsimodInfo(
        id="00515",
        name="HexNAc2dHex1 N4-glycosylated asparagine",
        formula="C22H36N2O14",
        monoisotopic_mass=552.216654,
        average_mass=552.53,
        dict_composition={'C': 22, 'H': 36, 'N': 2, 'O': 14},
    ),
    "00516": PsimodInfo(
        id="00516",
        name="Hex1HexNAc2 N4-glycosylated asparagine",
        formula="C22H36N2O15",
        monoisotopic_mass=568.211568,
        average_mass=568.53,
        dict_composition={'C': 22, 'H': 36, 'N': 2, 'O': 15},
    ),
    "00517": PsimodInfo(
        id="00517",
        name="Hex1HexNAc1NeuAc1 glycosylated residue",
        formula="C25H41N2O18",
        monoisotopic_mass=657.235437,
        average_mass=657.6,
        dict_composition={'C': 25, 'H': 41, 'N': 2, 'O': 18},
    ),
    "00518": PsimodInfo(
        id="00518",
        name="HexNAc2dHex2 N4-glycosylated asparagine",
        formula="C28H46N2O18",
        monoisotopic_mass=698.274563,
        average_mass=698.67,
        dict_composition={'C': 28, 'H': 46, 'N': 2, 'O': 18},
    ),
    "00519": PsimodInfo(
        id="00519",
        name="Hex1HexNAc2Pent1 N4-glycosylated asparagine",
        formula="C27H44N2O19",
        monoisotopic_mass=700.253827,
        average_mass=700.64,
        dict_composition={'C': 27, 'H': 44, 'N': 2, 'O': 19},
    ),
    "00520": PsimodInfo(
        id="00520",
        name="Hex1HexNAc2dHex1 N4-glycosylated asparagine",
        formula="C28H46N2O19",
        monoisotopic_mass=714.269477,
        average_mass=714.67,
        dict_composition={'C': 28, 'H': 46, 'N': 2, 'O': 19},
    ),
    "00521": PsimodInfo(
        id="00521",
        name="Hex2HexNAc2 N4-glycosylated asparagine",
        formula="C28H46N2O20",
        monoisotopic_mass=730.264392,
        average_mass=730.67,
        dict_composition={'C': 28, 'H': 46, 'N': 2, 'O': 20},
    ),
    "00522": PsimodInfo(
        id="00522",
        name="Hex3HexNAc1Pent1 N4-glycosylated asparagine",
        formula="C31H51NO24",
        monoisotopic_mass=821.280102,
        average_mass=821.73,
        dict_composition={'C': 31, 'H': 51, 'N': 1, 'O': 24},
    ),
    "00523": PsimodInfo(
        id="00523",
        name="Hex1HexNAc2dHex1Pent1 N4-glycosylated asparagine",
        formula="C33H54N2O23",
        monoisotopic_mass=846.311736,
        average_mass=846.79,
        dict_composition={'C': 33, 'H': 54, 'N': 2, 'O': 23},
    ),
    "00524": PsimodInfo(
        id="00524",
        name="Hex1HexNAc2dHex2 N4-glycosylated asparagine",
        formula="C34H56N2O23",
        monoisotopic_mass=860.327386,
        average_mass=860.81,
        dict_composition={'C': 34, 'H': 56, 'N': 2, 'O': 23},
    ),
    "00525": PsimodInfo(
        id="00525",
        name="Hex2HexNAc2Pent1 N4-glycosylated asparagine",
        formula="C33H54N2O24",
        monoisotopic_mass=862.306651,
        average_mass=862.79,
        dict_composition={'C': 33, 'H': 54, 'N': 2, 'O': 24},
    ),
    "00526": PsimodInfo(
        id="00526",
        name="Hex2HexNAc2dHex1 N4-glycosylated asparagine",
        formula="C34H56N2O24",
        monoisotopic_mass=876.322301,
        average_mass=876.81,
        dict_composition={'C': 34, 'H': 56, 'N': 2, 'O': 24},
    ),
    "00527": PsimodInfo(
        id="00527",
        name="Hex3HexNAc2 N4-glycosylated asparagine",
        formula="C34H56N2O25",
        monoisotopic_mass=892.317215,
        average_mass=892.81,
        dict_composition={'C': 34, 'H': 56, 'N': 2, 'O': 25},
    ),
    "00528": PsimodInfo(
        id="00528",
        name="Hex1HexNAc1NeuAc2 glycosylated residue",
        formula="C36H57N3O26",
        monoisotopic_mass=947.323029,
        average_mass=947.85,
        dict_composition={'C': 36, 'H': 57, 'N': 3, 'O': 26},
    ),
    "00529": PsimodInfo(
        id="00529",
        name="Hex3HexNAc2P1 N4-glycosylated asparagine",
        formula="C34H57N2O28P",
        monoisotopic_mass=972.283546,
        average_mass=972.79,
        dict_composition={'C': 34, 'H': 57, 'N': 2, 'O': 28, 'P': 1},
    ),
    "00530": PsimodInfo(
        id="00530",
        name="L-selenomethionine",
        formula="S-1Se",
        monoisotopic_mass=47.94445,
        average_mass=46.91,
        dict_composition={'S': -1, 'Se': 1},
    ),
    "00531": PsimodInfo(
        id="00531",
        name="(18)O labeled deglycosylated asparagine",
        formula="H-1N-1[18O]",
        monoisotopic_mass=2.988262,
        average_mass=2.99,
        dict_composition={'H': -1, 'N': -1, '18O': 1},
    ),
    "00532": PsimodInfo(
        id="00532",
        name="Shimadzu 13CNBS",
        formula="[13C6]H3NO2S",
        monoisotopic_mass=159.008578,
        average_mass=159.01,
        dict_composition={'13C': 6, 'H': 3, 'N': 1, 'O': 2, 'S': 1},
    ),
    "00533": PsimodInfo(
        id="00533",
        name="Shimadzu 12CNBS",
        formula="[12C6]H3NO2S",
        monoisotopic_mass=152.988449,
        average_mass=152.99,
        dict_composition={'12C': 6, 'H': 3, 'N': 1, 'O': 2, 'S': 1},
    ),
    "00534": PsimodInfo(
        id="00534",
        name="Michael addition of BHT quinone methide to cysteine and lysine",
        formula="C15H22O",
        monoisotopic_mass=218.167065,
        average_mass=218.34,
        dict_composition={'C': 15, 'H': 22, 'O': 1},
    ),
    "00535": PsimodInfo(
        id="00535",
        name="phosphorylation to amine thiol",
        formula="C4H9NO-1S",
        monoisotopic_mass=87.050656,
        average_mass=87.18,
        dict_composition={'C': 4, 'H': 9, 'N': 1, 'O': -1, 'S': 1},
    ),
    "00537": PsimodInfo(
        id="00537",
        name="L-alanine residue (Thr)",
        formula="C-1H-2O-1",
        monoisotopic_mass=-30.010565,
        average_mass=-30.03,
        dict_composition={'C': -1, 'H': -2, 'O': -1},
    ),
    "00540": PsimodInfo(
        id="00540",
        name="9x(13)C labeled residue",
        formula="[12C-9][13C9]",
        monoisotopic_mass=9.030194,
        average_mass=9.03,
        dict_composition={'12C': -9, '13C': 9},
    ),
    "00541": PsimodInfo(
        id="00541",
        name="9x(13)C labeled L-phosphotyrosine",
        formula="[12C-9][13C9]HO3P",
        monoisotopic_mass=88.996524,
        average_mass=89.0,
        dict_composition={'12C': -9, '13C': 9, 'H': 1, 'O': 3, 'P': 1},
    ),
    "00542": PsimodInfo(
        id="00542",
        name="hydroxyphenylglyoxal arginine",
        formula="C8H4O2",
        monoisotopic_mass=132.021129,
        average_mass=132.12,
        dict_composition={'C': 8, 'H': 4, 'O': 2},
    ),
    "00543": PsimodInfo(
        id="00543",
        name="bis(hydroxyphenylglyoxal) arginine",
        formula="C16H10O5",
        monoisotopic_mass=282.052823,
        average_mass=282.25,
        dict_composition={'C': 16, 'H': 10, 'O': 5},
    ),
    "00544": PsimodInfo(
        id="00544",
        name="6x(13)C labeled residue",
        formula="[12C-6][13C6]",
        monoisotopic_mass=6.020129,
        average_mass=6.02,
        dict_composition={'12C': -6, '13C': 6},
    ),
    "00546": PsimodInfo(
        id="00546",
        name="(18)O label at both C-terminal oxygens",
        formula="[16O-2][18O2]",
        monoisotopic_mass=4.008493,
        average_mass=4.01,
        dict_composition={'16O': -2, '18O': 2},
    ),
    "00547": PsimodInfo(
        id="00547",
        name="6-aminoquinolyl-N-hydroxysuccinimidyl carbamate",
        formula="C10H6N2O",
        monoisotopic_mass=170.048013,
        average_mass=170.17,
        dict_composition={'C': 10, 'H': 6, 'N': 2, 'O': 1},
    ),
    "00548": PsimodInfo(
        id="00548",
        name="APTA",
        formula="C9H19N2O",
        monoisotopic_mass=171.149738,
        average_mass=171.26,
        dict_composition={'C': 9, 'H': 19, 'N': 2, 'O': 1},
    ),
    "00549": PsimodInfo(
        id="00549",
        name="APTA d3",
        formula="C9[1H16][2H3]N2O",
        monoisotopic_mass=174.168568,
        average_mass=174.17,
        dict_composition={'C': 9, '1H': 16, '2H': 3, 'N': 2, 'O': 1},
    ),
    "00550": PsimodInfo(
        id="00550",
        name="EAPTA d0",
        formula="C10H20N2O",
        monoisotopic_mass=184.157563,
        average_mass=184.28,
        dict_composition={'C': 10, 'H': 20, 'N': 2, 'O': 1},
    ),
    "00551": PsimodInfo(
        id="00551",
        name="EAPTA d5",
        formula="C10[1H15][2H5]N2O",
        monoisotopic_mass=189.188947,
        average_mass=189.19,
        dict_composition={'C': 10, '1H': 15, '2H': 5, 'N': 2, 'O': 1},
    ),
    "00552": PsimodInfo(
        id="00552",
        name="4x(2)H labeled dimethylated residue",
        formula="C2[2H4]",
        monoisotopic_mass=32.056407,
        average_mass=32.06,
        dict_composition={'C': 2, '2H': 4},
    ),
    "00553": PsimodInfo(
        id="00553",
        name="1,2-ethanedithiol modified residue",
        formula="C2H4O-1S2",
        monoisotopic_mass=75.980528,
        average_mass=76.18,
        dict_composition={'C': 2, 'H': 4, 'O': -1, 'S': 2},
    ),
    "00561": PsimodInfo(
        id="00561",
        name="N-ethyl iodoacetamide-",
        formula="C4H7NO",
        monoisotopic_mass=85.052764,
        average_mass=85.11,
        dict_composition={'C': 4, 'H': 7, 'N': 1, 'O': 1},
    ),
    "00562": PsimodInfo(
        id="00562",
        name="N-ethyl iodoacetamide-d5",
        formula="C4[1H2][2H5]NO",
        monoisotopic_mass=90.084148,
        average_mass=90.08,
        dict_composition={'C': 4, '1H': 2, '2H': 5, 'N': 1, 'O': 1},
    ),
    "00563": PsimodInfo(
        id="00563",
        name="mono-N-acetylaminogalactosylated residue",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "00565": PsimodInfo(
        id="00565",
        name="deglycosylated asparagine",
        formula="H-1N-1O",
        monoisotopic_mass=0.984016,
        average_mass=0.98,
        dict_composition={'H': -1, 'N': -1, 'O': 1},
    ),
    "00566": PsimodInfo(
        id="00566",
        name="label cysteine with IGBP reagent",
        formula="BrC12H13N2O2",
        monoisotopic_mass=296.01604,
        average_mass=297.15,
        dict_composition={'Br': 1, 'C': 12, 'H': 13, 'N': 2, 'O': 2},
    ),
    "00571": PsimodInfo(
        id="00571",
        name="2-pyrrolidone-5-carboxylic acid (Pro)",
        formula="H-2O",
        monoisotopic_mass=13.979265,
        average_mass=13.98,
        dict_composition={'H': -2, 'O': 1},
    ),
    "00572": PsimodInfo(
        id="00572",
        name="oxidized arginine biotinylated with biotin hydrazide",
        formula="C9H13NO2S",
        monoisotopic_mass=199.0667,
        average_mass=199.27,
        dict_composition={'C': 9, 'H': 13, 'N': 1, 'O': 2, 'S': 1},
    ),
    "00573": PsimodInfo(
        id="00573",
        name="oxidized lysine biotinylated with biotin hydrazide",
        formula="C10H15N3O2S",
        monoisotopic_mass=241.088498,
        average_mass=241.31,
        dict_composition={'C': 10, 'H': 15, 'N': 3, 'O': 2, 'S': 1},
    ),
    "00574": PsimodInfo(
        id="00574",
        name="oxidized proline biotinylated with biotin hydrazide",
        formula="C10H18N4O2S",
        monoisotopic_mass=258.115047,
        average_mass=258.34,
        dict_composition={'C': 10, 'H': 18, 'N': 4, 'O': 2, 'S': 1},
    ),
    "00575": PsimodInfo(
        id="00575",
        name="oxidized threonine biotinylated with biotin hydrazide",
        formula="C10H16N4OS",
        monoisotopic_mass=240.104482,
        average_mass=240.32,
        dict_composition={'C': 10, 'H': 16, 'N': 4, 'O': 1, 'S': 1},
    ),
    "00576": PsimodInfo(
        id="00576",
        name="crotonylated residue",
        formula="C4H6O",
        monoisotopic_mass=70.041865,
        average_mass=70.09,
        dict_composition={'C': 4, 'H': 6, 'O': 1},
    ),
    "00577": PsimodInfo(
        id="00577",
        name="acetaldehyde crosslinked penta-L-lysine",
        formula="C2H2",
        monoisotopic_mass=26.01565,
        average_mass=26.04,
        dict_composition={'C': 2, 'H': 2},
    ),
    "00581": PsimodInfo(
        id="00581",
        name="(18)O monosubstituted residue",
        formula="[16O-1][18O]",
        monoisotopic_mass=2.004246,
        average_mass=2.0,
        dict_composition={'16O': -1, '18O': 1},
    ),
    "00582": PsimodInfo(
        id="00582",
        name="6x(13)C,2x(15)N labeled L-lysine",
        formula="[12C-6][13C6][14N-2][15N2]",
        monoisotopic_mass=8.014199,
        average_mass=8.01,
        dict_composition={'12C': -6, '13C': 6, '14N': -2, '15N': 2},
    ),
    "00583": PsimodInfo(
        id="00583",
        name="thiophosphorylated residue",
        formula="HO2PS",
        monoisotopic_mass=95.943487,
        average_mass=96.04,
        dict_composition={'H': 1, 'O': 2, 'P': 1, 'S': 1},
    ),
    "00584": PsimodInfo(
        id="00584",
        name="4-sulfophenyl isothiocyanate derivatized residue",
        formula="C7H5NO3S2",
        monoisotopic_mass=214.971085,
        average_mass=215.24,
        dict_composition={'C': 7, 'H': 5, 'N': 1, 'O': 3, 'S': 2},
    ),
    "00585": PsimodInfo(
        id="00585",
        name="deuterium trisubstituted residue",
        formula="[1H-3][2H3]",
        monoisotopic_mass=3.01883,
        average_mass=3.02,
        dict_composition={'1H': -3, '2H': 3},
    ),
    "00586": PsimodInfo(
        id="00586",
        name="pyridyl thiol modified residue",
        formula="C7H7NO-1S",
        monoisotopic_mass=121.035006,
        average_mass=121.2,
        dict_composition={'C': 7, 'H': 7, 'N': 1, 'O': -1, 'S': 1},
    ),
    "00587": PsimodInfo(
        id="00587",
        name="6x(13)C,4x(15)N labeled L-arginine",
        formula="[12C-6][13C6][14N-4][15N4]",
        monoisotopic_mass=10.008269,
        average_mass=10.01,
        dict_composition={'12C': -6, '13C': 6, '14N': -4, '15N': 4},
    ),
    "00588": PsimodInfo(
        id="00588",
        name="5x(13)C,1x(15)N labeled L-valine",
        formula="[12C-5][13C5][14N-1][15N]",
        monoisotopic_mass=6.013809,
        average_mass=6.01,
        dict_composition={'12C': -5, '13C': 5, '14N': -1, '15N': 1},
    ),
    "00589": PsimodInfo(
        id="00589",
        name="9x(13)C,1x(15)N labeled L-phenylalanine",
        formula="[12C-9][13C9][14N-1][15N]",
        monoisotopic_mass=10.027228,
        average_mass=10.03,
        dict_composition={'12C': -9, '13C': 9, '14N': -1, '15N': 1},
    ),
    "00592": PsimodInfo(
        id="00592",
        name="sulfonation of N-terminal",
        formula="C3H4O4S",
        monoisotopic_mass=135.98303,
        average_mass=136.12,
        dict_composition={'C': 3, 'H': 4, 'O': 4, 'S': 1},
    ),
    "00595": PsimodInfo(
        id="00595",
        name="monomannosylated residue",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "00596": PsimodInfo(
        id="00596",
        name="4-(2-aminoethyl)benzenesulfonyl fluoride derivatized residue",
        formula="C8H9NO2S",
        monoisotopic_mass=183.0354,
        average_mass=183.23,
        dict_composition={'C': 8, 'H': 9, 'N': 1, 'O': 2, 'S': 1},
    ),
    "00598": PsimodInfo(
        id="00598",
        name="S-(2-hydroxyethyl)cysteine",
        formula="C2H4O",
        monoisotopic_mass=44.026215,
        average_mass=44.05,
        dict_composition={'C': 2, 'H': 4, 'O': 1},
    ),
    "00599": PsimodInfo(
        id="00599",
        name="monomethylated residue",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00600": PsimodInfo(
        id="00600",
        name="L-glutamic acid 5-ethyl ester",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
    "00604": PsimodInfo(
        id="00604",
        name="2x(2)H monomethylated L-lysine",
        formula="C[2H2]",
        monoisotopic_mass=16.028204,
        average_mass=16.03,
        dict_composition={'C': 1, '2H': 2},
    ),
    "00605": PsimodInfo(
        id="00605",
        name="Sulfanilic Acid (SA), light C12",
        formula="[12C6]H5NO2S",
        monoisotopic_mass=155.004099,
        average_mass=155.0,
        dict_composition={'12C': 6, 'H': 5, 'N': 1, 'O': 2, 'S': 1},
    ),
    "00606": PsimodInfo(
        id="00606",
        name="Sulfanilic Acid (SA), heavy C13",
        formula="[13C6]H5NO2S",
        monoisotopic_mass=161.024228,
        average_mass=161.02,
        dict_composition={'13C': 6, 'H': 5, 'N': 1, 'O': 2, 'S': 1},
    ),
    "00607": PsimodInfo(
        id="00607",
        name="dioxoindolealanine lactone",
        formula="H-1O2",
        monoisotopic_mass=30.982004,
        average_mass=30.99,
        dict_composition={'H': -1, 'O': 2},
    ),
    "00609": PsimodInfo(
        id="00609",
        name="Pierce EZ-Link Biotin-HPDP modified L-cysteine",
        formula="C19H32N4O3S2",
        monoisotopic_mass=428.191583,
        average_mass=428.61,
        dict_composition={'C': 19, 'H': 32, 'N': 4, 'O': 3, 'S': 2},
    ),
    "00610": PsimodInfo(
        id="00610",
        name="cysteinyl mercury",
        formula="Hg",
        monoisotopic_mass=201.970643,
        average_mass=200.59,
        dict_composition={'Hg': 1},
    ),
    "00611": PsimodInfo(
        id="00611",
        name="iodouridine monophosphate derivatized residue",
        formula="C9H11N2O9P",
        monoisotopic_mass=322.020217,
        average_mass=322.17,
        dict_composition={'C': 9, 'H': 11, 'N': 2, 'O': 9, 'P': 1},
    ),
    "00612": PsimodInfo(
        id="00612",
        name="3-(carboxamidomethylthio)propanoylated residue",
        formula="C5H7NO2S",
        monoisotopic_mass=145.019749,
        average_mass=145.18,
        dict_composition={'C': 5, 'H': 7, 'N': 1, 'O': 2, 'S': 1},
    ),
    "00613": PsimodInfo(
        id="00613",
        name="biotinoyl-iodoacetyl-ethylenediamine",
        formula="C14H22N4O3S",
        monoisotopic_mass=326.141262,
        average_mass=326.42,
        dict_composition={'C': 14, 'H': 22, 'N': 4, 'O': 3, 'S': 1},
    ),
    "00614": PsimodInfo(
        id="00614",
        name="fucosylated residue",
        formula="C6H10O4",
        monoisotopic_mass=146.057909,
        average_mass=146.14,
        dict_composition={'C': 6, 'H': 10, 'O': 4},
    ),
    "00617": PsimodInfo(
        id="00617",
        name="3x(2)H residue methyl ester",
        formula="C[1H-1][2H3]",
        monoisotopic_mass=17.03448,
        average_mass=17.03,
        dict_composition={'C': 1, '1H': -1, '2H': 3},
    ),
    "00618": PsimodInfo(
        id="00618",
        name="tryptophan carboxylation",
        formula="CO2",
        monoisotopic_mass=43.989829,
        average_mass=44.01,
        dict_composition={'C': 1, 'O': 2},
    ),
    "00620": PsimodInfo(
        id="00620",
        name="cysteine monobromobimane derivative",
        formula="C10H10N2O2",
        monoisotopic_mass=190.074228,
        average_mass=190.2,
        dict_composition={'C': 10, 'H': 10, 'N': 2, 'O': 2},
    ),
    "00621": PsimodInfo(
        id="00621",
        name="menadione quinone derivative",
        formula="C11H6O2",
        monoisotopic_mass=170.036779,
        average_mass=170.17,
        dict_composition={'C': 11, 'H': 6, 'O': 2},
    ),
    "00622": PsimodInfo(
        id="00622",
        name="cysteine mercaptoethanol",
        formula="C2H4OS",
        monoisotopic_mass=75.998286,
        average_mass=76.11,
        dict_composition={'C': 2, 'H': 4, 'O': 1, 'S': 1},
    ),
    "00623": PsimodInfo(
        id="00623",
        name="fucosylated biantennary (-2 galactose) N4-glycosylated asparagine",
        formula="C56H90N4O39",
        monoisotopic_mass=1442.518219,
        average_mass=1443.33,
        dict_composition={'C': 56, 'H': 90, 'N': 4, 'O': 39},
    ),
    "00625": PsimodInfo(
        id="00625",
        name="N-methylmaleimide derivatized residue",
        formula="C5H5NO2",
        monoisotopic_mass=111.032028,
        average_mass=111.1,
        dict_composition={'C': 5, 'H': 5, 'N': 1, 'O': 2},
    ),
    "00626": PsimodInfo(
        id="00626",
        name="fluorescein-5-thiosemicarbazide modified residue",
        formula="C21H15N3O5S",
        monoisotopic_mass=421.073242,
        average_mass=421.43,
        dict_composition={'C': 21, 'H': 15, 'N': 3, 'O': 5, 'S': 1},
    ),
    "00627": PsimodInfo(
        id="00627",
        name="2,5-dimethylpyrrole lysine from 2,5-hexanedione adduct",
        formula="C6H6",
        monoisotopic_mass=78.04695,
        average_mass=78.11,
        dict_composition={'C': 6, 'H': 6},
    ),
    "00628": PsimodInfo(
        id="00628",
        name="Hex2",
        formula="C12H20O10",
        monoisotopic_mass=324.105647,
        average_mass=324.28,
        dict_composition={'C': 12, 'H': 20, 'O': 10},
    ),
    "00629": PsimodInfo(
        id="00629",
        name="MDA adduct +62",
        formula="C5H2",
        monoisotopic_mass=62.01565,
        average_mass=62.07,
        dict_composition={'C': 5, 'H': 2},
    ),
    "00630": PsimodInfo(
        id="00630",
        name="C3-H2-O adduct (+54 amu) of malondialdehyde with lysine or methylglyoxal with arginine.",
        formula="C3H2O",
        monoisotopic_mass=54.010565,
        average_mass=54.05,
        dict_composition={'C': 3, 'H': 2, 'O': 1},
    ),
    "00631": PsimodInfo(
        id="00631",
        name="hydrolyzed N-ethylmaleimide adduct",
        formula="C6H9NO3",
        monoisotopic_mass=143.058243,
        average_mass=143.14,
        dict_composition={'C': 6, 'H': 9, 'N': 1, 'O': 3},
    ),
    "00633": PsimodInfo(
        id="00633",
        name="bis-N-I-sulfonerahodamine",
        formula="C31H30IN4O6S",
        monoisotopic_mass=713.093078,
        average_mass=713.57,
        dict_composition={'C': 31, 'H': 30, 'I': 1, 'N': 4, 'O': 6, 'S': 1},
    ),
    "00634": PsimodInfo(
        id="00634",
        name="dimethyl 3,3'-dithiobispropionimidate",
        formula="C3ClH6NS",
        monoisotopic_mass=122.990948,
        average_mass=123.6,
        dict_composition={'C': 3, 'Cl': 1, 'H': 6, 'N': 1, 'S': 1},
    ),
    "00635": PsimodInfo(
        id="00635",
        name="10-fluoroethoxyphosphinyl-N-(biotinamidopentyl)decanamide",
        formula="C27H49N4O5PS",
        monoisotopic_mass=572.316128,
        average_mass=572.75,
        dict_composition={'C': 27, 'H': 49, 'N': 4, 'O': 5, 'P': 1, 'S': 1},
    ),
    "00636": PsimodInfo(
        id="00636",
        name="S-ethylcysteine (Ser)",
        formula="C2H4O-1S",
        monoisotopic_mass=44.008457,
        average_mass=44.11,
        dict_composition={'C': 2, 'H': 4, 'O': -1, 'S': 1},
    ),
    "00637": PsimodInfo(
        id="00637",
        name="1x(13)C,3x(2)H labeled monomethylated L-arginine",
        formula="[13C][1H-1][2H3]",
        monoisotopic_mass=18.037835,
        average_mass=18.04,
        dict_composition={'13C': 1, '1H': -1, '2H': 3},
    ),
    "00638": PsimodInfo(
        id="00638",
        name="2x(13)C,6x(2)H labeled dimethylated L-arginine",
        formula="[13C2][1H-2][2H6]",
        monoisotopic_mass=36.07567,
        average_mass=36.08,
        dict_composition={'13C': 2, '1H': -2, '2H': 6},
    ),
    "00639": PsimodInfo(
        id="00639",
        name="thiophosphate labeled with biotin-HPDP",
        formula="C19H34N4O5PS3",
        monoisotopic_mass=525.142895,
        average_mass=525.66,
        dict_composition={'C': 19, 'H': 34, 'N': 4, 'O': 5, 'P': 1, 'S': 3},
    ),
    "00640": PsimodInfo(
        id="00640",
        name="6-N-biotinylaminohexyl isopropyl phosphorofluoridate",
        formula="C19FH35N3O5PS",
        monoisotopic_mass=467.201907,
        average_mass=467.54,
        dict_composition={'C': 19, 'F': 1, 'H': 35, 'N': 3, 'O': 5, 'P': 1, 'S': 1},
    ),
    "00642": PsimodInfo(
        id="00642",
        name="reduced 4-hydroxynonenal adduct",
        formula="C9H18O2",
        monoisotopic_mass=158.13068,
        average_mass=158.24,
        dict_composition={'C': 9, 'H': 18, 'O': 2},
    ),
    "00643": PsimodInfo(
        id="00643",
        name="methylamine Michael addition derivatized residue",
        formula="CH3NO-1",
        monoisotopic_mass=13.031634,
        average_mass=13.04,
        dict_composition={'C': 1, 'H': 3, 'N': 1, 'O': -1},
    ),
    "00644": PsimodInfo(
        id="00644",
        name="mono O-acetylated residue",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00645": PsimodInfo(
        id="00645",
        name="mono S-acetylated residue",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00646": PsimodInfo(
        id="00646",
        name="monoacetylated L-cysteine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00647": PsimodInfo(
        id="00647",
        name="monoacetylated L-serine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00648": PsimodInfo(
        id="00648",
        name="N,O-diacetylated L-serine",
        formula="C4H4O2",
        monoisotopic_mass=84.021129,
        average_mass=84.07,
        dict_composition={'C': 4, 'H': 4, 'O': 2},
    ),
    "00650": PsimodInfo(
        id="00650",
        name="N-myristoylated residue",
        formula="C14H26O",
        monoisotopic_mass=210.198365,
        average_mass=210.36,
        dict_composition={'C': 14, 'H': 26, 'O': 1},
    ),
    "00651": PsimodInfo(
        id="00651",
        name="N-palmitoylated residue",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
    "00652": PsimodInfo(
        id="00652",
        name="O-palmitoylated residue",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
    "00653": PsimodInfo(
        id="00653",
        name="S-palmitoylated residue",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
    "00655": PsimodInfo(
        id="00655",
        name="S-myristoylated residue",
        formula="C14H26O",
        monoisotopic_mass=210.198365,
        average_mass=210.36,
        dict_composition={'C': 14, 'H': 26, 'O': 1},
    ),
    "00657": PsimodInfo(
        id="00657",
        name="L-glutamic acid 5-methyl ester (Gln)",
        formula="CHN-1O",
        monoisotopic_mass=14.999666,
        average_mass=15.01,
        dict_composition={'C': 1, 'H': 1, 'N': -1, 'O': 1},
    ),
    "00666": PsimodInfo(
        id="00666",
        name="octanoylated residue",
        formula="C8H14O",
        monoisotopic_mass=126.104465,
        average_mass=126.2,
        dict_composition={'C': 8, 'H': 14, 'O': 1},
    ),
    "00667": PsimodInfo(
        id="00667",
        name="decanoylated residue",
        formula="C10H18O",
        monoisotopic_mass=154.135765,
        average_mass=154.25,
        dict_composition={'C': 10, 'H': 18, 'O': 1},
    ),
    "00668": PsimodInfo(
        id="00668",
        name="O-decanoylated residue",
        formula="C10H18O",
        monoisotopic_mass=154.135765,
        average_mass=154.25,
        dict_composition={'C': 10, 'H': 18, 'O': 1},
    ),
    "00669": PsimodInfo(
        id="00669",
        name="O-octanoylated residue",
        formula="C8H14O",
        monoisotopic_mass=126.104465,
        average_mass=126.2,
        dict_composition={'C': 8, 'H': 14, 'O': 1},
    ),
    "00674": PsimodInfo(
        id="00674",
        name="amidated residue",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00684": PsimodInfo(
        id="00684",
        name="deamidated L-asparagine",
        formula="H-1N-1O",
        monoisotopic_mass=0.984016,
        average_mass=0.98,
        dict_composition={'H': -1, 'N': -1, 'O': 1},
    ),
    "00685": PsimodInfo(
        id="00685",
        name="deamidated L-glutamine",
        formula="H-1N-1O",
        monoisotopic_mass=0.984016,
        average_mass=0.98,
        dict_composition={'H': -1, 'N': -1, 'O': 1},
    ),
    "00686": PsimodInfo(
        id="00686",
        name="L-selenocysteine (Cys)",
        formula="S-1Se",
        monoisotopic_mass=47.94445,
        average_mass=46.91,
        dict_composition={'S': -1, 'Se': 1},
    ),
    "00695": PsimodInfo(
        id="00695",
        name="sulfated residue",
        formula="O3S",
        monoisotopic_mass=79.956815,
        average_mass=80.06,
        dict_composition={'O': 3, 'S': 1},
    ),
    "00696": PsimodInfo(
        id="00696",
        name="phosphorylated residue",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
    "00704": PsimodInfo(
        id="00704",
        name="dehydrated residue",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00705": PsimodInfo(
        id="00705",
        name="D-valine",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00706": PsimodInfo(
        id="00706",
        name="dehydrogenated tyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00711": PsimodInfo(
        id="00711",
        name="trimethylated protonated-residue",
        formula="C3H7",
        monoisotopic_mass=43.054227,
        average_mass=43.09,
        dict_composition={'C': 3, 'H': 7},
    ),
    "00719": PsimodInfo(
        id="00719",
        name="L-methionine sulfoxide",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "00720": PsimodInfo(
        id="00720",
        name="L-methionine (R)-sulfoxide",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "00721": PsimodInfo(
        id="00721",
        name="L-methionine (S)-sulfoxide",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "00722": PsimodInfo(
        id="00722",
        name="monomethylated L-glutamine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00723": PsimodInfo(
        id="00723",
        name="N-acetylated L-lysine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00724": PsimodInfo(
        id="00724",
        name="N-methylated L-histidine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00729": PsimodInfo(
        id="00729",
        name="pentosylated residue",
        formula="C5H8O4",
        monoisotopic_mass=132.042259,
        average_mass=132.12,
        dict_composition={'C': 5, 'H': 8, 'O': 4},
    ),
    "00730": PsimodInfo(
        id="00730",
        name="arabinosylated residue",
        formula="C5H8O4",
        monoisotopic_mass=132.042259,
        average_mass=132.12,
        dict_composition={'C': 5, 'H': 8, 'O': 4},
    ),
    "00731": PsimodInfo(
        id="00731",
        name="ribosylated residue",
        formula="C5H8O4",
        monoisotopic_mass=132.042259,
        average_mass=132.12,
        dict_composition={'C': 5, 'H': 8, 'O': 4},
    ),
    "00732": PsimodInfo(
        id="00732",
        name="xylosylated residue",
        formula="C5H8O4",
        monoisotopic_mass=132.042259,
        average_mass=132.12,
        dict_composition={'C': 5, 'H': 8, 'O': 4},
    ),
    "00733": PsimodInfo(
        id="00733",
        name="N-acetylaminoglucosylated residue",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "00734": PsimodInfo(
        id="00734",
        name="N-acetylaminogalactosylated residue",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "00735": PsimodInfo(
        id="00735",
        name="hexosuronylated residue",
        formula="C6H8O6",
        monoisotopic_mass=176.032088,
        average_mass=176.12,
        dict_composition={'C': 6, 'H': 8, 'O': 6},
    ),
    "00736": PsimodInfo(
        id="00736",
        name="deoxyhexosylated residue",
        formula="C6H10O4",
        monoisotopic_mass=146.057909,
        average_mass=146.14,
        dict_composition={'C': 6, 'H': 10, 'O': 4},
    ),
    "00737": PsimodInfo(
        id="00737",
        name="N-acetylneuraminylated residue",
        formula="C11H17NO8",
        monoisotopic_mass=291.095417,
        average_mass=291.26,
        dict_composition={'C': 11, 'H': 17, 'N': 1, 'O': 8},
    ),
    "00752": PsimodInfo(
        id="00752",
        name="monoadenosine diphosphoribosyl (ADP-ribosyl) modified residue",
        formula="C15H21N5O13P2",
        monoisotopic_mass=541.061109,
        average_mass=541.3,
        dict_composition={'C': 15, 'H': 21, 'N': 5, 'O': 13, 'P': 2},
    ),
    "00756": PsimodInfo(
        id="00756",
        name="4-hydroxy-D-valine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "00757": PsimodInfo(
        id="00757",
        name="O4-galactosyl-L-hydroxyproline",
        formula="C6H10O6",
        monoisotopic_mass=178.047738,
        average_mass=178.14,
        dict_composition={'C': 6, 'H': 10, 'O': 6},
    ),
    "00758": PsimodInfo(
        id="00758",
        name="O4-(N-acetylamino)glucosyl-L-hydroxyproline",
        formula="C8H13NO6",
        monoisotopic_mass=219.074287,
        average_mass=219.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 6},
    ),
    "00759": PsimodInfo(
        id="00759",
        name="fucosylated biantennary (-1 galactose) N4-glycosylated asparagine",
        formula="C62H102N4O44",
        monoisotopic_mass=1606.586693,
        average_mass=1607.48,
        dict_composition={'C': 62, 'H': 102, 'N': 4, 'O': 44},
    ),
    "00760": PsimodInfo(
        id="00760",
        name="biantennary N4-glycosylated asparagine",
        formula="C62H102N4O45",
        monoisotopic_mass=1622.581607,
        average_mass=1623.48,
        dict_composition={'C': 62, 'H': 102, 'N': 4, 'O': 45},
    ),
    "00761": PsimodInfo(
        id="00761",
        name="monohexosylated residue",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "00762": PsimodInfo(
        id="00762",
        name="biantennary (-2 galactose) N4-glycosylated asparagine",
        formula="C50H82N4O35",
        monoisotopic_mass=1298.47596,
        average_mass=1299.2,
        dict_composition={'C': 50, 'H': 82, 'N': 4, 'O': 35},
    ),
    "00763": PsimodInfo(
        id="00763",
        name="biantennary (-1 galactose) N4-glycosylated asparagine",
        formula="C56H92N4O40",
        monoisotopic_mass=1460.528784,
        average_mass=1461.34,
        dict_composition={'C': 56, 'H': 92, 'N': 4, 'O': 40},
    ),
    "00765": PsimodInfo(
        id="00765",
        name="cysteinylation (disulfide with free L-cysteine)",
        formula="C3H5NO2S",
        monoisotopic_mass=119.004099,
        average_mass=119.14,
        dict_composition={'C': 3, 'H': 5, 'N': 1, 'O': 2, 'S': 1},
    ),
    "00768": PsimodInfo(
        id="00768",
        name="methionine oxidation with neutral loss of 80 Da",
        formula="C-1H-4O-2S-1",
        monoisotopic_mass=-79.9932,
        average_mass=-80.1,
        dict_composition={'C': -1, 'H': -4, 'O': -2, 'S': -1},
    ),
    "00775": PsimodInfo(
        id="00775",
        name="L-asparagine (His)",
        formula="C-2H-1N-1O",
        monoisotopic_mass=-23.015984,
        average_mass=-23.04,
        dict_composition={'C': -2, 'H': -1, 'N': -1, 'O': 1},
    ),
    "00776": PsimodInfo(
        id="00776",
        name="L-aspartic acid (His)",
        formula="C-2H-2N-2O2",
        monoisotopic_mass=-22.031969,
        average_mass=-22.05,
        dict_composition={'C': -2, 'H': -2, 'N': -2, 'O': 2},
    ),
    "00780": PsimodInfo(
        id="00780",
        name="N-acetyl-L-asparagine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00781": PsimodInfo(
        id="00781",
        name="N2-acetyl-L-histidine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00782": PsimodInfo(
        id="00782",
        name="N-acetyl-L-leucine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00783": PsimodInfo(
        id="00783",
        name="dimethylated L-arginine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
    "00784": PsimodInfo(
        id="00784",
        name="N-acetyl-L-phenylalanine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00785": PsimodInfo(
        id="00785",
        name="N2-acetyl-L-tryptophan",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "00787": PsimodInfo(
        id="00787",
        name="diisopropylphosphoserine",
        formula="C6H13O3P",
        monoisotopic_mass=164.060231,
        average_mass=164.14,
        dict_composition={'C': 6, 'H': 13, 'O': 3, 'P': 1},
    ),
    "00788": PsimodInfo(
        id="00788",
        name="isopropylphosphotyrosine",
        formula="C3H7O3P",
        monoisotopic_mass=122.013281,
        average_mass=122.06,
        dict_composition={'C': 3, 'H': 7, 'O': 3, 'P': 1},
    ),
    "00789": PsimodInfo(
        id="00789",
        name="Bruker Daltonics SERVA-ICPL(TM) quantification chemistry, heavy form",
        formula="[13C6]H3NO",
        monoisotopic_mass=111.041593,
        average_mass=111.04,
        dict_composition={'13C': 6, 'H': 3, 'N': 1, 'O': 1},
    ),
    "00790": PsimodInfo(
        id="00790",
        name="Bruker Daltonics SERVA-ICPL(TM) quantification chemistry, light form",
        formula="[12C6]H3NO",
        monoisotopic_mass=105.021464,
        average_mass=105.02,
        dict_composition={'12C': 6, 'H': 3, 'N': 1, 'O': 1},
    ),
    "00791": PsimodInfo(
        id="00791",
        name="1x(18)O labeled deamidated L-glutamine",
        formula="H-1N-1[18O]",
        monoisotopic_mass=2.988262,
        average_mass=2.99,
        dict_composition={'H': -1, 'N': -1, '18O': 1},
    ),
    "00793": PsimodInfo(
        id="00793",
        name="dehydroalanine (Cys)",
        formula="H-2S-1",
        monoisotopic_mass=-33.987721,
        average_mass=-34.08,
        dict_composition={'H': -2, 'S': -1},
    ),
    "00795": PsimodInfo(
        id="00795",
        name="Michael addition of hydroxymethylvinyl ketone to cysteine",
        formula="C4H6O2",
        monoisotopic_mass=86.036779,
        average_mass=86.09,
        dict_composition={'C': 4, 'H': 6, 'O': 2},
    ),
    "00796": PsimodInfo(
        id="00796",
        name="L-ornithine (Arg)",
        formula="C-1H-2N-2",
        monoisotopic_mass=-42.021798,
        average_mass=-42.04,
        dict_composition={'C': -1, 'H': -2, 'N': -2},
    ),
    "00797": PsimodInfo(
        id="00797",
        name="2-(S-L-cysteinyl)pyruvic acid O-phosphothioketal",
        formula="C3H5O6P",
        monoisotopic_mass=167.982375,
        average_mass=168.04,
        dict_composition={'C': 3, 'H': 5, 'O': 6, 'P': 1},
    ),
    "00798": PsimodInfo(
        id="00798",
        name="half cystine",
        formula="H-1",
        monoisotopic_mass=-1.007825,
        average_mass=-1.01,
        dict_composition={'H': -1},
    ),
    "00799": PsimodInfo(
        id="00799",
        name="S-galactosyl-L-cysteine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "00800": PsimodInfo(
        id="00800",
        name="L-cysteinyl-L-histidino-homocitryl vanadium heptairon nonasulfide",
        formula="C7Fe7H6O7S9V",
        monoisotopic_mass=932.248513,
        average_mass=932.51,
        dict_composition={'C': 7, 'Fe': 7, 'H': 6, 'O': 7, 'S': 9, 'V': 1},
    ),
    "00801": PsimodInfo(
        id="00801",
        name="L-cysteinyl-L-histidino-homocitryl octairon nonasulfide",
        formula="C7Fe8H6O7S9",
        monoisotopic_mass=937.240588,
        average_mass=937.42,
        dict_composition={'C': 7, 'Fe': 8, 'H': 6, 'O': 7, 'S': 9},
    ),
    "00802": PsimodInfo(
        id="00802",
        name="L-histidino vanadium tetraoxide",
        formula="H2O4V",
        monoisotopic_mass=116.939268,
        average_mass=116.95,
        dict_composition={'H': 2, 'O': 4, 'V': 1},
    ),
    "00803": PsimodInfo(
        id="00803",
        name="3-(S-L-cysteinyl)-L-tyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00804": PsimodInfo(
        id="00804",
        name="O-glucosyl-L-serine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "00805": PsimodInfo(
        id="00805",
        name="O-(N-acetylamino)glucosyl-L-serine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "00806": PsimodInfo(
        id="00806",
        name="O-(N-acetylamino)glucosyl-L-threonine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "00807": PsimodInfo(
        id="00807",
        name="pyruvic acid (Ser)",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "00808": PsimodInfo(
        id="00808",
        name="O-galactosyl-L-serine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "00809": PsimodInfo(
        id="00809",
        name="O-galactosyl-L-threonine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "00810": PsimodInfo(
        id="00810",
        name="O-mannosyl-L-serine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "00811": PsimodInfo(
        id="00811",
        name="O-mannosyl-L-threonine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "00812": PsimodInfo(
        id="00812",
        name="O-fucosyl-L-serine",
        formula="C6H10O4",
        monoisotopic_mass=146.057909,
        average_mass=146.14,
        dict_composition={'C': 6, 'H': 10, 'O': 4},
    ),
    "00813": PsimodInfo(
        id="00813",
        name="O-fucosyl-L-threonine",
        formula="C6H10O4",
        monoisotopic_mass=146.057909,
        average_mass=146.14,
        dict_composition={'C': 6, 'H': 10, 'O': 4},
    ),
    "00814": PsimodInfo(
        id="00814",
        name="O-xylosyl-L-serine",
        formula="C5H8O4",
        monoisotopic_mass=132.042259,
        average_mass=132.12,
        dict_composition={'C': 5, 'H': 8, 'O': 4},
    ),
    "00816": PsimodInfo(
        id="00816",
        name="S-stearoyl-L-cysteine",
        formula="C18H34O",
        monoisotopic_mass=266.260966,
        average_mass=266.47,
        dict_composition={'C': 18, 'H': 34, 'O': 1},
    ),
    "00817": PsimodInfo(
        id="00817",
        name="3'-geranyl-2',3'-dihydro-2',N2-cyclo-L-tryptophan",
        formula="C10H16",
        monoisotopic_mass=136.125201,
        average_mass=136.24,
        dict_composition={'C': 10, 'H': 16},
    ),
    "00818": PsimodInfo(
        id="00818",
        name="glycosylphosphatidylinositolated residue",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
    "00819": PsimodInfo(
        id="00819",
        name="L-2-aminobutanoic acid (Glu)",
        formula="C-1O-2",
        monoisotopic_mass=-43.989829,
        average_mass=-44.01,
        dict_composition={'C': -1, 'O': -2},
    ),
    "00820": PsimodInfo(
        id="00820",
        name="2-imino-alanine 5-imidazolinone glycine",
        formula="C-1H-4O-3",
        monoisotopic_mass=-64.016044,
        average_mass=-64.04,
        dict_composition={'C': -1, 'H': -4, 'O': -3},
    ),
    "00821": PsimodInfo(
        id="00821",
        name="S-(L-alanyl)-L-cysteine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00822": PsimodInfo(
        id="00822",
        name="S-(L-leucyl)-L-cysteine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00823": PsimodInfo(
        id="00823",
        name="S-(L-methionyl)-L-cysteine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00824": PsimodInfo(
        id="00824",
        name="dehydroalanine (Tyr)",
        formula="C-6H-6O-1",
        monoisotopic_mass=-94.041865,
        average_mass=-94.11,
        dict_composition={'C': -6, 'H': -6, 'O': -1},
    ),
    "00825": PsimodInfo(
        id="00825",
        name="S-(L-phenylalanyl)-L-cysteine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00826": PsimodInfo(
        id="00826",
        name="S-(L-threonyl)-L-cysteine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00827": PsimodInfo(
        id="00827",
        name="S-(L-tyrosyl)-L-cysteine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00828": PsimodInfo(
        id="00828",
        name="S-(L-tryptophanyl)-L-cysteine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00829": PsimodInfo(
        id="00829",
        name="O-(L-phenylalanyl)-L-serine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00830": PsimodInfo(
        id="00830",
        name="N-methyl-L-proline",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "00831": PsimodInfo(
        id="00831",
        name="N4-(N-acetylamino)glucosyl-L-asparagine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "00832": PsimodInfo(
        id="00832",
        name="N4-(N-acetylamino)galactosyl-L-asparagine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "00833": PsimodInfo(
        id="00833",
        name="N4-glucosyl-L-asparagine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "00834": PsimodInfo(
        id="00834",
        name="O-(N-acetylamino)fucosyl-L-serine",
        formula="C8H13NO4",
        monoisotopic_mass=187.084458,
        average_mass=187.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 4},
    ),
    "00835": PsimodInfo(
        id="00835",
        name="L-3-oxoalanine (Ser)",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "00838": PsimodInfo(
        id="00838",
        name="3x(2)H labeled L-leucine",
        formula="[1H-3][2H3]",
        monoisotopic_mass=3.01883,
        average_mass=3.02,
        dict_composition={'1H': -3, '2H': 3},
    ),
    "00852": PsimodInfo(
        id="00852",
        name="1x(18)O labeled deamidated residue",
        formula="H-1N-1[18O]",
        monoisotopic_mass=2.988262,
        average_mass=2.99,
        dict_composition={'H': -1, 'N': -1, '18O': 1},
    ),
    "00853": PsimodInfo(
        id="00853",
        name="2x(18)O labeled deamidated residue",
        formula="H-1N-1[16O-1][18O2]",
        monoisotopic_mass=4.992508,
        average_mass=4.99,
        dict_composition={'H': -1, 'N': -1, '16O': -1, '18O': 2},
    ),
    "00854": PsimodInfo(
        id="00854",
        name="protonated L-lysine (L-lysinium) residue",
        formula="H",
        monoisotopic_mass=1.007276,
        average_mass=1.01,
        dict_composition={'H': 1},
    ),
    "00855": PsimodInfo(
        id="00855",
        name="N6,N6,N6-trimethyl-L-lysine (from L-lysinium residue)",
        formula="C3H6",
        monoisotopic_mass=42.046402,
        average_mass=42.08,
        dict_composition={'C': 3, 'H': 6},
    ),
    "00856": PsimodInfo(
        id="00856",
        name="protonated L-alanine (L-alaninium) residue",
        formula="H",
        monoisotopic_mass=1.007276,
        average_mass=1.01,
        dict_composition={'H': 1},
    ),
    "00857": PsimodInfo(
        id="00857",
        name="N,N,N-trimethyl-L-alanine (from L-alaninium)",
        formula="C3H6",
        monoisotopic_mass=42.046402,
        average_mass=42.08,
        dict_composition={'C': 3, 'H': 6},
    ),
    "00858": PsimodInfo(
        id="00858",
        name="D-alanine (Ser)",
        formula="O-1",
        monoisotopic_mass=-15.994915,
        average_mass=-16.0,
        dict_composition={'O': -1},
    ),
    "00863": PsimodInfo(
        id="00863",
        name="D-allo-threonine",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "00864": PsimodInfo(
        id="00864",
        name="tris-L-cysteinyl L-histidino diiron disulfide",
        formula="Fe2H-4S2",
        monoisotopic_mass=171.783814,
        average_mass=171.78,
        dict_composition={'Fe': 2, 'H': -4, 'S': 2},
    ),
    "00865": PsimodInfo(
        id="00865",
        name="N-aspartyl-glycosylsphingolipidinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
    "00866": PsimodInfo(
        id="00866",
        name="dihydroxylated proline",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "00867": PsimodInfo(
        id="00867",
        name="L-cysteinyl-L-selenocysteine (Cys-Cys)",
        formula="H-2S-1Se",
        monoisotopic_mass=45.9288,
        average_mass=44.9,
        dict_composition={'H': -2, 'S': -1, 'Se': 1},
    ),
    "00869": PsimodInfo(
        id="00869",
        name="L-alanine residue (Asp)",
        formula="C-1O-2",
        monoisotopic_mass=-43.989829,
        average_mass=-44.01,
        dict_composition={'C': -1, 'O': -2},
    ),
    "00870": PsimodInfo(
        id="00870",
        name="phenyl isocyanate derivatized residue",
        formula="C7H5NO",
        monoisotopic_mass=119.037114,
        average_mass=119.12,
        dict_composition={'C': 7, 'H': 5, 'N': 1, 'O': 1},
    ),
    "00871": PsimodInfo(
        id="00871",
        name="(2)H5-phenyl isocyanate derivatized residue",
        formula="C7[2H5]NO",
        monoisotopic_mass=124.068498,
        average_mass=124.07,
        dict_composition={'C': 7, '2H': 5, 'N': 1, 'O': 1},
    ),
    "00873": PsimodInfo(
        id="00873",
        name="L-isoglutamyl diglutamic acid",
        formula="C10H14N2O6",
        monoisotopic_mass=258.085186,
        average_mass=258.23,
        dict_composition={'C': 10, 'H': 14, 'N': 2, 'O': 6},
    ),
    "00874": PsimodInfo(
        id="00874",
        name="L-isoglutamyl triglutamic acid",
        formula="C15H21N3O9",
        monoisotopic_mass=387.127779,
        average_mass=387.35,
        dict_composition={'C': 15, 'H': 21, 'N': 3, 'O': 9},
    ),
    "00875": PsimodInfo(
        id="00875",
        name="L-isoglutamyl tetraglutamic acid",
        formula="C20H28N4O12",
        monoisotopic_mass=516.170372,
        average_mass=516.46,
        dict_composition={'C': 20, 'H': 28, 'N': 4, 'O': 12},
    ),
    "00876": PsimodInfo(
        id="00876",
        name="hexosaminylated residue",
        formula="C6H11NO4",
        monoisotopic_mass=161.068808,
        average_mass=161.16,
        dict_composition={'C': 6, 'H': 11, 'N': 1, 'O': 4},
    ),
    "00877": PsimodInfo(
        id="00877",
        name="imidoester crosslink dimethyl pimelimidate singly attached",
        formula="C8H14N2O",
        monoisotopic_mass=154.110613,
        average_mass=154.21,
        dict_composition={'C': 8, 'H': 14, 'N': 2, 'O': 1},
    ),
    "00878": PsimodInfo(
        id="00878",
        name="imidoester crosslink dimethyl pimelimidate doubly attached",
        formula="C7H10N2",
        monoisotopic_mass=122.084398,
        average_mass=122.17,
        dict_composition={'C': 7, 'H': 10, 'N': 2},
    ),
    "00879": PsimodInfo(
        id="00879",
        name="naphthalene-2,3-dicarboxaldehyde",
        formula="C13H5N",
        monoisotopic_mass=175.042199,
        average_mass=175.19,
        dict_composition={'C': 13, 'H': 5, 'N': 1},
    ),
    "00880": PsimodInfo(
        id="00880",
        name="6x(13)C labeled 4-sulfophenyl isothiocyanate derivatized residue",
        formula="[12C][13C6]H5NO3S2",
        monoisotopic_mass=220.991214,
        average_mass=220.99,
        dict_composition={'12C': 1, '13C': 6, 'H': 5, 'N': 1, 'O': 3, 'S': 2},
    ),
    "00882": PsimodInfo(
        id="00882",
        name="S-(2-aminoethyl)cysteine (Ser)",
        formula="C2H5NO-1S",
        monoisotopic_mass=59.019356,
        average_mass=59.13,
        dict_composition={'C': 2, 'H': 5, 'N': 1, 'O': -1, 'S': 1},
    ),
    "00883": PsimodInfo(
        id="00883",
        name="C1-amidated residue",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "00884": PsimodInfo(
        id="00884",
        name="S-aminoethylcysteine (Cys)",
        formula="C2H5N",
        monoisotopic_mass=43.042199,
        average_mass=43.07,
        dict_composition={'C': 2, 'H': 5, 'N': 1},
    ),
    "00886": PsimodInfo(
        id="00886",
        name="6'-chloro-L-tryptophan",
        formula="ClH-1",
        monoisotopic_mass=33.961028,
        average_mass=34.44,
        dict_composition={'Cl': 1, 'H': -1},
    ),
    "00888": PsimodInfo(
        id="00888",
        name="protonated L-proline (L-prolinium) residue",
        formula="H",
        monoisotopic_mass=1.007276,
        average_mass=1.01,
        dict_composition={'H': 1},
    ),
    "00889": PsimodInfo(
        id="00889",
        name="N,N-dimethyl-L-proline (from L-prolinium)",
        formula="C2H4",
        monoisotopic_mass=28.030752,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
    "00890": PsimodInfo(
        id="00890",
        name="phosphorylated L-histidine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
    "00892": PsimodInfo(
        id="00892",
        name="D-serine (Cys)",
        formula="OS-1",
        monoisotopic_mass=-15.977156,
        average_mass=-16.06,
        dict_composition={'O': 1, 'S': -1},
    ),
    "00895": PsimodInfo(
        id="00895",
        name="FAD modified residue",
        formula="C27H31N9O15P2",
        monoisotopic_mass=783.141485,
        average_mass=783.54,
        dict_composition={'C': 27, 'H': 31, 'N': 9, 'O': 15, 'P': 2},
    ),
    "00897": PsimodInfo(
        id="00897",
        name="N-acetyl-S-archeol-cysteine",
        formula="C45H88O3",
        monoisotopic_mass=676.673347,
        average_mass=677.2,
        dict_composition={'C': 45, 'H': 88, 'O': 3},
    ),
    "00898": PsimodInfo(
        id="00898",
        name="S-(sn-1-2-oleoyl-3-palmitoyl-glycerol)cysteine",
        formula="C37H68O4",
        monoisotopic_mass=576.511761,
        average_mass=576.95,
        dict_composition={'C': 37, 'H': 68, 'O': 4},
    ),
    "00900": PsimodInfo(
        id="00900",
        name="N-palmitoyl-S-(sn-1-2-oleoyl-3-palmitoyl-glycerol)cysteine",
        formula="C53H98O5",
        monoisotopic_mass=814.741426,
        average_mass=815.36,
        dict_composition={'C': 53, 'H': 98, 'O': 5},
    ),
    "00922": PsimodInfo(
        id="00922",
        name="Cy3 CyDye DIGE Fluor saturation dye",
        formula="C37H44N4O6S",
        monoisotopic_mass=672.298156,
        average_mass=672.84,
        dict_composition={'C': 37, 'H': 44, 'N': 4, 'O': 6, 'S': 1},
    ),
    "00923": PsimodInfo(
        id="00923",
        name="Cy5 CyDye DIGE Fluor saturation dye",
        formula="C38H44N4O6S",
        monoisotopic_mass=684.298156,
        average_mass=684.85,
        dict_composition={'C': 38, 'H': 44, 'N': 4, 'O': 6, 'S': 1},
    ),
    "00924": PsimodInfo(
        id="00924",
        name="N6-(L-threonyl)-L-lysine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00925": PsimodInfo(
        id="00925",
        name="heptosylated residue",
        formula="C7H12O6",
        monoisotopic_mass=192.063388,
        average_mass=192.17,
        dict_composition={'C': 7, 'H': 12, 'O': 6},
    ),
    "00927": PsimodInfo(
        id="00927",
        name="2x(13)C,4x(2)H labeled dimethylated residue",
        formula="[13C2][2H4]",
        monoisotopic_mass=34.063117,
        average_mass=34.06,
        dict_composition={'13C': 2, '2H': 4},
    ),
    "00928": PsimodInfo(
        id="00928",
        name="[3-(2,5)-dioxopyrrolidin-1-yloxycarbonyl)-propyl]dimethyloctylammonium",
        formula="C14H29NO",
        monoisotopic_mass=227.224915,
        average_mass=227.39,
        dict_composition={'C': 14, 'H': 29, 'N': 1, 'O': 1},
    ),
    "00929": PsimodInfo(
        id="00929",
        name="lactose glycated lysine",
        formula="C12H22O11",
        monoisotopic_mass=342.116212,
        average_mass=342.3,
        dict_composition={'C': 12, 'H': 22, 'O': 11},
    ),
    "00930": PsimodInfo(
        id="00930",
        name="propyl-NAG tyrosine adduct",
        formula="C9H14NO4S",
        monoisotopic_mass=232.064354,
        average_mass=232.27,
        dict_composition={'C': 9, 'H': 14, 'N': 1, 'O': 4, 'S': 1},
    ),
    "00931": PsimodInfo(
        id="00931",
        name="Michael addition of t-butyl hydroxylated BHT (BHTOH) to C, H or K",
        formula="C15H22O2",
        monoisotopic_mass=234.16198,
        average_mass=234.34,
        dict_composition={'C': 15, 'H': 22, 'O': 2},
    ),
    "00932": PsimodInfo(
        id="00932",
        name="IDBEST tag for quantitation",
        formula="Br[12C10][13C2]H13N2O2",
        monoisotopic_mass=298.022749,
        average_mass=298.02,
        dict_composition={'Br': 1, '12C': 10, '13C': 2, 'H': 13, 'N': 2, 'O': 2},
    ),
    "00933": PsimodInfo(
        id="00933",
        name="methylglyoxal arginine adduct (+54 amu)",
        formula="C3H2O",
        monoisotopic_mass=54.010565,
        average_mass=54.05,
        dict_composition={'C': 3, 'H': 2, 'O': 1},
    ),
    "00934": PsimodInfo(
        id="00934",
        name="Levuglandinyl - arginine hydroxylactam adduct",
        formula="C19H26N-2O5",
        monoisotopic_mass=306.171876,
        average_mass=306.4,
        dict_composition={'C': 19, 'H': 26, 'N': -2, 'O': 5},
    ),
    "00935": PsimodInfo(
        id="00935",
        name="methionine oxidation with neutral loss of 64 Da",
        formula="C-1H-4O-1S-1",
        monoisotopic_mass=-63.998286,
        average_mass=-64.1,
        dict_composition={'C': -1, 'H': -4, 'O': -1, 'S': -1},
    ),
    "00936": PsimodInfo(
        id="00936",
        name="Levuglandinyl - hydroxylactam adduct, K and N-term",
        formula="C20H28O5",
        monoisotopic_mass=348.193674,
        average_mass=348.44,
        dict_composition={'C': 20, 'H': 28, 'O': 5},
    ),
    "00937": PsimodInfo(
        id="00937",
        name="Levuglandinyl - arginine lactam adduct",
        formula="C19H26N-2O4",
        monoisotopic_mass=290.176961,
        average_mass=290.4,
        dict_composition={'C': 19, 'H': 26, 'N': -2, 'O': 4},
    ),
    "00938": PsimodInfo(
        id="00938",
        name="Levuglandinyl - lactam adduct, K and N-term",
        formula="C20H28O4",
        monoisotopic_mass=332.198759,
        average_mass=332.44,
        dict_composition={'C': 20, 'H': 28, 'O': 4},
    ),
    "00939": PsimodInfo(
        id="00939",
        name="hydrolyzed N-methylmaleimide cysteine adduct",
        formula="C5H7NO3",
        monoisotopic_mass=129.042593,
        average_mass=129.12,
        dict_composition={'C': 5, 'H': 7, 'N': 1, 'O': 3},
    ),
    "00940": PsimodInfo(
        id="00940",
        name="3-methyl-2-pyridyl isocyanate derivatized residue",
        formula="C7H6N2O",
        monoisotopic_mass=134.048013,
        average_mass=134.14,
        dict_composition={'C': 7, 'H': 6, 'N': 2, 'O': 1},
    ),
    "00941": PsimodInfo(
        id="00941",
        name="dehydropyrrolizidine alkaloid (dehydroretronecine) derivatized cysteine",
        formula="C8H8N",
        monoisotopic_mass=118.065674,
        average_mass=118.16,
        dict_composition={'C': 8, 'H': 8, 'N': 1},
    ),
    "00942": PsimodInfo(
        id="00942",
        name="(4,4,5,5-(2)H4)-L-lysine",
        formula="[1H-4][2H4]",
        monoisotopic_mass=4.025107,
        average_mass=4.03,
        dict_composition={'1H': -4, '2H': 4},
    ),
    "00943": PsimodInfo(
        id="00943",
        name="4-trimethylammoniumbutanoyl derivatized residue",
        formula="C7H14NO",
        monoisotopic_mass=128.107539,
        average_mass=128.19,
        dict_composition={'C': 7, 'H': 14, 'N': 1, 'O': 1},
    ),
    "00944": PsimodInfo(
        id="00944",
        name="d9-4-trimethylammoniumbutanoyl derivatized residue",
        formula="C7[1H5][2H9]NO",
        monoisotopic_mass=137.16403,
        average_mass=137.16,
        dict_composition={'C': 7, '1H': 5, '2H': 9, 'N': 1, 'O': 1},
    ),
    "00951": PsimodInfo(
        id="00951",
        name="L-gamma-carboxyglutamic acid with neutral loss of carbon dioxide",
        formula="C-1O-2",
        monoisotopic_mass=-43.989829,
        average_mass=-44.01,
        dict_composition={'C': -1, 'O': -2},
    ),
    "00952": PsimodInfo(
        id="00952",
        name="(2-aminosuccinimidyl)acetic acid (Asp)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00953": PsimodInfo(
        id="00953",
        name="O-(L-isoglutamyl)-L-serine (Glu-Ser)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00955": PsimodInfo(
        id="00955",
        name="alaninohistidine (serine crosslinked to tele or pros nitrogen of histidine)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "00956": PsimodInfo(
        id="00956",
        name="misincorporation of norleucine for methionine",
        formula="CH2S-1",
        monoisotopic_mass=-17.956421,
        average_mass=-18.03,
        dict_composition={'C': 1, 'H': 2, 'S': -1},
    ),
    "00957": PsimodInfo(
        id="00957",
        name="modified residue with neutral loss of carbon dioxide",
        formula="C-1O-2",
        monoisotopic_mass=-43.989829,
        average_mass=-44.01,
        dict_composition={'C': -1, 'O': -2},
    ),
    "00960": PsimodInfo(
        id="00960",
        name="decarboxylated residue",
        formula="C-1O-2",
        monoisotopic_mass=-43.989829,
        average_mass=-44.01,
        dict_composition={'C': -1, 'O': -2},
    ),
    "00961": PsimodInfo(
        id="00961",
        name="reduction of disulfide crosslink in cystine to two cysteines",
        formula="H2",
        monoisotopic_mass=2.01565,
        average_mass=2.02,
        dict_composition={'H': 2},
    ),
    "00962": PsimodInfo(
        id="00962",
        name="2',3'-dihydrotryptophan",
        formula="H2",
        monoisotopic_mass=2.01565,
        average_mass=2.02,
        dict_composition={'H': 2},
    ),
    "00964": PsimodInfo(
        id="00964",
        name="lysine epsilon amino to imine + 12 amu",
        formula="C",
        monoisotopic_mass=12.0,
        average_mass=12.01,
        dict_composition={'C': 1},
    ),
    "00965": PsimodInfo(
        id="00965",
        name="4-thiazolidinecarboxylic acid",
        formula="C",
        monoisotopic_mass=12.0,
        average_mass=12.01,
        dict_composition={'C': 1},
    ),
    "00966": PsimodInfo(
        id="00966",
        name="1,2,3,4-tetrahydro-beta-carboline-3-carboxylic acid",
        formula="C",
        monoisotopic_mass=12.0,
        average_mass=12.01,
        dict_composition={'C': 1},
    ),
    "00967": PsimodInfo(
        id="00967",
        name="syndesine",
        formula="H-3N-2O3",
        monoisotopic_mass=16.955121,
        average_mass=16.96,
        dict_composition={'H': -3, 'N': -2, 'O': 3},
    ),
    "00971": PsimodInfo(
        id="00971",
        name="2-Oxohistidine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "00972": PsimodInfo(
        id="00972",
        name="monobrominated L-phenylalanine",
        formula="BrH-1",
        monoisotopic_mass=77.910512,
        average_mass=78.9,
        dict_composition={'Br': 1, 'H': -1},
    ),
    "00974": PsimodInfo(
        id="00974",
        name="(35)Cl labeled 3'-chlorotyrosine",
        formula="[35Cl]H-1",
        monoisotopic_mass=33.961028,
        average_mass=33.96,
        dict_composition={'35Cl': 1, 'H': -1},
    ),
    "00975": PsimodInfo(
        id="00975",
        name="(37)Cl labeled 3'-chlorotyrosine",
        formula="[37Cl]H-1",
        monoisotopic_mass=35.958078,
        average_mass=35.96,
        dict_composition={'37Cl': 1, 'H': -1},
    ),
    "00977": PsimodInfo(
        id="00977",
        name="disodium salt",
        formula="H-2Na2",
        monoisotopic_mass=43.963888,
        average_mass=43.96,
        dict_composition={'H': -2, 'Na': 2},
    ),
    "00981": PsimodInfo(
        id="00981",
        name="sodium and potassium salt",
        formula="H-2KNa",
        monoisotopic_mass=59.937826,
        average_mass=60.07,
        dict_composition={'H': -2, 'K': 1, 'Na': 1},
    ),
    "00982": PsimodInfo(
        id="00982",
        name="L-selenocysteine (Ser)",
        formula="O-1Se",
        monoisotopic_mass=63.921607,
        average_mass=62.97,
        dict_composition={'O': -1, 'Se': 1},
    ),
    "00984": PsimodInfo(
        id="00984",
        name="(35)Cl labeled 3',5'-dichlorotyrosine",
        formula="[35Cl2]H-2",
        monoisotopic_mass=67.922055,
        average_mass=67.92,
        dict_composition={'35Cl': 2, 'H': -2},
    ),
    "00986": PsimodInfo(
        id="00986",
        name="(35)Cl and (37)Cl labeled 3',5'-dichlorotyrosine",
        formula="[35Cl][37Cl]H-2",
        monoisotopic_mass=69.919105,
        average_mass=69.92,
        dict_composition={'35Cl': 1, '37Cl': 1, 'H': -2},
    ),
    "00990": PsimodInfo(
        id="00990",
        name="(37)Cl labeled 3',5'-dichlorotyrosine",
        formula="[37Cl2]H-2",
        monoisotopic_mass=71.916155,
        average_mass=71.92,
        dict_composition={'37Cl': 2, 'H': -2},
    ),
    "00991": PsimodInfo(
        id="00991",
        name="S-(sn-1-glyceryl)-L-cysteine",
        formula="C3H6O2",
        monoisotopic_mass=74.036779,
        average_mass=74.08,
        dict_composition={'C': 3, 'H': 6, 'O': 2},
    ),
    "00992": PsimodInfo(
        id="00992",
        name="glutamate 5-glycerol ester",
        formula="C3H6O2",
        monoisotopic_mass=74.036779,
        average_mass=74.08,
        dict_composition={'C': 3, 'H': 6, 'O': 2},
    ),
    "00993": PsimodInfo(
        id="00993",
        name="phenyl ester",
        formula="C6H4",
        monoisotopic_mass=76.0313,
        average_mass=76.1,
        dict_composition={'C': 6, 'H': 4},
    ),
    "00994": PsimodInfo(
        id="00994",
        name="(79)Br labeled 3'-bromotyrosine",
        formula="[79Br]H-1",
        monoisotopic_mass=77.910512,
        average_mass=77.91,
        dict_composition={'79Br': 1, 'H': -1},
    ),
    "00995": PsimodInfo(
        id="00995",
        name="(81)Br labeled 2'-bromophenylalanine",
        formula="[81Br]H-1",
        monoisotopic_mass=79.908466,
        average_mass=79.91,
        dict_composition={'81Br': 1, 'H': -1},
    ),
    "00996": PsimodInfo(
        id="00996",
        name="(81)Br labeled 3'-bromotyrosine",
        formula="[81Br]H-1",
        monoisotopic_mass=79.908466,
        average_mass=79.91,
        dict_composition={'81Br': 1, 'H': -1},
    ),
    "00997": PsimodInfo(
        id="00997",
        name="cyclohexyl ester",
        formula="C6H10",
        monoisotopic_mass=82.07825,
        average_mass=82.15,
        dict_composition={'C': 6, 'H': 10},
    ),
    "01002": PsimodInfo(
        id="01002",
        name="gamma-aminobutyryl",
        formula="C4H7NO",
        monoisotopic_mass=85.052764,
        average_mass=85.11,
        dict_composition={'C': 4, 'H': 7, 'N': 1, 'O': 1},
    ),
    "01004": PsimodInfo(
        id="01004",
        name="diaminopropionyl",
        formula="C3H6N2O",
        monoisotopic_mass=86.048013,
        average_mass=86.09,
        dict_composition={'C': 3, 'H': 6, 'N': 2, 'O': 1},
    ),
    "01007": PsimodInfo(
        id="01007",
        name="anisyl modified residue",
        formula="C7H6",
        monoisotopic_mass=90.04695,
        average_mass=90.13,
        dict_composition={'C': 7, 'H': 6},
    ),
    "01008": PsimodInfo(
        id="01008",
        name="benzyl (Bzl) and benzyl ester (OBzl) modified residue",
        formula="C7H6",
        monoisotopic_mass=90.04695,
        average_mass=90.13,
        dict_composition={'C': 7, 'H': 6},
    ),
    "01009": PsimodInfo(
        id="01009",
        name="dehydrogenated proline",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01010": PsimodInfo(
        id="01010",
        name="trifluoroacetylated residue",
        formula="C2F3H-1O",
        monoisotopic_mass=95.982299,
        average_mass=96.01,
        dict_composition={'C': 2, 'F': 3, 'H': -1, 'O': 1},
    ),
    "01012": PsimodInfo(
        id="01012",
        name="oxidation of disulfide crosslink in cystine to two cysteic acids",
        formula="H2O6",
        monoisotopic_mass=97.985138,
        average_mass=98.01,
        dict_composition={'H': 2, 'O': 6},
    ),
    "01022": PsimodInfo(
        id="01022",
        name="2-piperidinecarboxylic acid",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "01023": PsimodInfo(
        id="01023",
        name="3',5'-dibromo-L-tyrosine",
        formula="Br2H-2",
        monoisotopic_mass=155.821024,
        average_mass=157.79,
        dict_composition={'Br': 2, 'H': -2},
    ),
    "01024": PsimodInfo(
        id="01024",
        name="monohydroxylated proline",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01025": PsimodInfo(
        id="01025",
        name="3'-bromo-L-tyrosine",
        formula="BrH-1",
        monoisotopic_mass=77.910512,
        average_mass=78.9,
        dict_composition={'Br': 1, 'H': -1},
    ),
    "01028": PsimodInfo(
        id="01028",
        name="monochlorinated L-tyrosine",
        formula="ClH-1",
        monoisotopic_mass=33.961028,
        average_mass=34.44,
        dict_composition={'Cl': 1, 'H': -1},
    ),
    "01029": PsimodInfo(
        id="01029",
        name="succinylated residue",
        formula="C4H4O3",
        monoisotopic_mass=100.016044,
        average_mass=100.07,
        dict_composition={'C': 4, 'H': 4, 'O': 3},
    ),
    "01032": PsimodInfo(
        id="01032",
        name="benzyloxymethyl modified residue",
        formula="C8H8O",
        monoisotopic_mass=120.057515,
        average_mass=120.15,
        dict_composition={'C': 8, 'H': 8, 'O': 1},
    ),
    "01033": PsimodInfo(
        id="01033",
        name="p-methoxybenzyl modified residue",
        formula="C8H8O",
        monoisotopic_mass=120.057515,
        average_mass=120.15,
        dict_composition={'C': 8, 'H': 8, 'O': 1},
    ),
    "01034": PsimodInfo(
        id="01034",
        name="4-nitrophenyl modified residue",
        formula="C6H3NO2",
        monoisotopic_mass=121.016378,
        average_mass=121.1,
        dict_composition={'C': 6, 'H': 3, 'N': 1, 'O': 2},
    ),
    "01037": PsimodInfo(
        id="01037",
        name="dichlorinated tyrosine",
        formula="Cl2H-2",
        monoisotopic_mass=67.922055,
        average_mass=68.88,
        dict_composition={'Cl': 2, 'H': -2},
    ),
    "01041": PsimodInfo(
        id="01041",
        name="benzyloxycarbonyl modified residue",
        formula="C8H6O2",
        monoisotopic_mass=134.036779,
        average_mass=134.13,
        dict_composition={'C': 8, 'H': 6, 'O': 2},
    ),
    "01042": PsimodInfo(
        id="01042",
        name="adamantyl modified residue",
        formula="C10H14",
        monoisotopic_mass=134.10955,
        average_mass=134.22,
        dict_composition={'C': 10, 'H': 14},
    ),
    "01043": PsimodInfo(
        id="01043",
        name="p-nitrobenzyl ester modified residue",
        formula="C7H5NO2",
        monoisotopic_mass=135.032028,
        average_mass=135.12,
        dict_composition={'C': 7, 'H': 5, 'N': 1, 'O': 2},
    ),
    "01045": PsimodInfo(
        id="01045",
        name="3',5'-dichloro-L-tyrosine",
        formula="Cl2H-2",
        monoisotopic_mass=67.922055,
        average_mass=68.88,
        dict_composition={'Cl': 2, 'H': -2},
    ),
    "01046": PsimodInfo(
        id="01046",
        name="3'-chloro-L-tyrosine",
        formula="ClH-1",
        monoisotopic_mass=33.961028,
        average_mass=34.44,
        dict_composition={'Cl': 1, 'H': -1},
    ),
    "01047": PsimodInfo(
        id="01047",
        name="monohydroxylated lysine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01056": PsimodInfo(
        id="01056",
        name="(79)Br labeled 3',5'-dibromotyrosine",
        formula="[79Br2]H-2",
        monoisotopic_mass=155.821024,
        average_mass=155.82,
        dict_composition={'79Br': 2, 'H': -2},
    ),
    "01057": PsimodInfo(
        id="01057",
        name="(79)Br and (81)Br labeled 3',5'-dibromotyrosine",
        formula="[79Br][81Br]H-2",
        monoisotopic_mass=157.818978,
        average_mass=157.82,
        dict_composition={'79Br': 1, '81Br': 1, 'H': -2},
    ),
    "01059": PsimodInfo(
        id="01059",
        name="(81)Br labeled 3',5'-dibromotyrosine",
        formula="[81Br2]H-2",
        monoisotopic_mass=159.816931,
        average_mass=159.82,
        dict_composition={'81Br': 2, 'H': -2},
    ),
    "01060": PsimodInfo(
        id="01060",
        name="S-carboxamidomethyl-L-cysteine",
        formula="C2H3NO",
        monoisotopic_mass=57.021464,
        average_mass=57.05,
        dict_composition={'C': 2, 'H': 3, 'N': 1, 'O': 1},
    ),
    "01061": PsimodInfo(
        id="01061",
        name="S-carboxymethyl-L-cysteine",
        formula="C2H2O2",
        monoisotopic_mass=58.005479,
        average_mass=58.04,
        dict_composition={'C': 2, 'H': 2, 'O': 2},
    ),
    "01063": PsimodInfo(
        id="01063",
        name="monomethylated phenylalanine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "01065": PsimodInfo(
        id="01065",
        name="hexose glycated N-terminal",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "01069": PsimodInfo(
        id="01069",
        name="2,4-dinitrophenyl modified residue",
        formula="C6H2N2O4",
        monoisotopic_mass=166.001457,
        average_mass=166.09,
        dict_composition={'C': 6, 'H': 2, 'N': 2, 'O': 4},
    ),
    "01070": PsimodInfo(
        id="01070",
        name="pentafluorophenyl modified residue",
        formula="C6F5H-1",
        monoisotopic_mass=165.984191,
        average_mass=166.05,
        dict_composition={'C': 6, 'F': 5, 'H': -1},
    ),
    "01071": PsimodInfo(
        id="01071",
        name="diphenylmethyl modified residue",
        formula="C13H10",
        monoisotopic_mass=166.07825,
        average_mass=166.22,
        dict_composition={'C': 13, 'H': 10},
    ),
    "01072": PsimodInfo(
        id="01072",
        name="monopotassium salt",
        formula="H-1K",
        monoisotopic_mass=37.955882,
        average_mass=38.09,
        dict_composition={'H': -1, 'K': 1},
    ),
    "01073": PsimodInfo(
        id="01073",
        name="2-chlorobenzyloxycarbonyl modified residue",
        formula="C8ClH6O2",
        monoisotopic_mass=169.005632,
        average_mass=169.58,
        dict_composition={'C': 8, 'Cl': 1, 'H': 6, 'O': 2},
    ),
    "01074": PsimodInfo(
        id="01074",
        name="napthylacetyl modified residue",
        formula="C12H9O",
        monoisotopic_mass=169.06534,
        average_mass=169.2,
        dict_composition={'C': 12, 'H': 9, 'O': 1},
    ),
    "01078": PsimodInfo(
        id="01078",
        name="S-(2-aminoethyl)-3-methylcysteine (Thr)",
        formula="C2H5NO-1S",
        monoisotopic_mass=59.019356,
        average_mass=59.13,
        dict_composition={'C': 2, 'H': 5, 'N': 1, 'O': -1, 'S': 1},
    ),
    "01079": PsimodInfo(
        id="01079",
        name="S-(acetylamino)methyl-L-cysteine",
        formula="C3H5NO",
        monoisotopic_mass=71.037114,
        average_mass=71.08,
        dict_composition={'C': 3, 'H': 5, 'N': 1, 'O': 1},
    ),
    "01081": PsimodInfo(
        id="01081",
        name="delta-glycosyloxy- (of lysine) or beta-glycosyloxy- (of phenylalanine or tyrosine)",
        formula="C6H10O6",
        monoisotopic_mass=178.047738,
        average_mass=178.14,
        dict_composition={'C': 6, 'H': 10, 'O': 6},
    ),
    "01083": PsimodInfo(
        id="01083",
        name="O-benzyl-L-serine",
        formula="C7H6",
        monoisotopic_mass=90.04695,
        average_mass=90.13,
        dict_composition={'C': 7, 'H': 6},
    ),
    "01084": PsimodInfo(
        id="01084",
        name="iodoacetic acid derivatized amino-terminal residue",
        formula="C2H2O2",
        monoisotopic_mass=58.005479,
        average_mass=58.04,
        dict_composition={'C': 2, 'H': 2, 'O': 2},
    ),
    "01085": PsimodInfo(
        id="01085",
        name="alpha-N-gluconoylated L-histidine",
        formula="C6H11O6",
        monoisotopic_mass=179.055563,
        average_mass=179.15,
        dict_composition={'C': 6, 'H': 11, 'O': 6},
    ),
    "01087": PsimodInfo(
        id="01087",
        name="2,4,5-trichlorophenyl modified residue",
        formula="C6Cl3H",
        monoisotopic_mass=177.914383,
        average_mass=179.42,
        dict_composition={'C': 6, 'Cl': 3, 'H': 1},
    ),
    "01088": PsimodInfo(
        id="01088",
        name="2,4,6-trimethyloxybenzyl modified residue",
        formula="C10H12O3",
        monoisotopic_mass=180.078644,
        average_mass=180.2,
        dict_composition={'C': 10, 'H': 12, 'O': 3},
    ),
    "01090": PsimodInfo(
        id="01090",
        name="iodoacetamide derivatized amino-terminal residue",
        formula="C2H3NO",
        monoisotopic_mass=57.021464,
        average_mass=57.05,
        dict_composition={'C': 2, 'H': 3, 'N': 1, 'O': 1},
    ),
    "01091": PsimodInfo(
        id="01091",
        name="monochlorinated L-phenylalanine",
        formula="ClH-1",
        monoisotopic_mass=33.961028,
        average_mass=34.44,
        dict_composition={'Cl': 1, 'H': -1},
    ),
    "01094": PsimodInfo(
        id="01094",
        name="N6-carboxymethyl-L-lysine",
        formula="C2H2O2",
        monoisotopic_mass=58.005479,
        average_mass=58.04,
        dict_composition={'C': 2, 'H': 2, 'O': 2},
    ),
    "01096": PsimodInfo(
        id="01096",
        name="O-benzyl-L-threonine",
        formula="C7H6",
        monoisotopic_mass=90.04695,
        average_mass=90.13,
        dict_composition={'C': 7, 'H': 6},
    ),
    "01097": PsimodInfo(
        id="01097",
        name="S-benzyl-L-cysteine",
        formula="C7H6",
        monoisotopic_mass=90.04695,
        average_mass=90.13,
        dict_composition={'C': 7, 'H': 6},
    ),
    "01099": PsimodInfo(
        id="01099",
        name="succinyl beta-aspartyl anhydride",
        formula="C4H2O2",
        monoisotopic_mass=82.005479,
        average_mass=82.06,
        dict_composition={'C': 4, 'H': 2, 'O': 2},
    ),
    "01106": PsimodInfo(
        id="01106",
        name="N-formyl-L-tryptophan",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
    "01107": PsimodInfo(
        id="01107",
        name="O5-benzyl-L-glutamate",
        formula="C7H6",
        monoisotopic_mass=90.04695,
        average_mass=90.13,
        dict_composition={'C': 7, 'H': 6},
    ),
    "01108": PsimodInfo(
        id="01108",
        name="2-amino-5-(4-methoxyphenyl)-5-oxopentanoic acid (Glu)",
        formula="C7H6",
        monoisotopic_mass=90.04695,
        average_mass=90.13,
        dict_composition={'C': 7, 'H': 6},
    ),
    "01111": PsimodInfo(
        id="01111",
        name="dimethoxybenzhydryl modified residue",
        formula="C15H14O2",
        monoisotopic_mass=226.09938,
        average_mass=226.27,
        dict_composition={'C': 15, 'H': 14, 'O': 2},
    ),
    "01112": PsimodInfo(
        id="01112",
        name="nicotinoyl lysine",
        formula="C6H3NO",
        monoisotopic_mass=105.021464,
        average_mass=105.1,
        dict_composition={'C': 6, 'H': 3, 'N': 1, 'O': 1},
    ),
    "01114": PsimodInfo(
        id="01114",
        name="triphenylmethyl",
        formula="C19H14",
        monoisotopic_mass=242.10955,
        average_mass=242.32,
        dict_composition={'C': 19, 'H': 14},
    ),
    "01116": PsimodInfo(
        id="01116",
        name="S-farnesyl-L-cysteine methyl ester",
        formula="C16H26",
        monoisotopic_mass=218.203451,
        average_mass=218.38,
        dict_composition={'C': 16, 'H': 26},
    ),
    "01118": PsimodInfo(
        id="01118",
        name="alpha-N-6-phosphogluconoylated L-histidine",
        formula="C6H12O9P",
        monoisotopic_mass=259.021894,
        average_mass=259.12,
        dict_composition={'C': 6, 'H': 12, 'O': 9, 'P': 1},
    ),
    "01119": PsimodInfo(
        id="01119",
        name="S-geranylgeranyl-L-cysteine methyl ester",
        formula="C21H34",
        monoisotopic_mass=286.266051,
        average_mass=286.5,
        dict_composition={'C': 21, 'H': 34},
    ),
    "01120": PsimodInfo(
        id="01120",
        name="2,2,5,7,8-pentamethylchroman-6-sulfonyl chloride derivatized residue",
        formula="C14H18O3S",
        monoisotopic_mass=266.097665,
        average_mass=266.36,
        dict_composition={'C': 14, 'H': 18, 'O': 3, 'S': 1},
    ),
    "01124": PsimodInfo(
        id="01124",
        name="aldohexosyl lysyl",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "01133": PsimodInfo(
        id="01133",
        name="S-12-hydroxyfarnesyl-L-cysteine methyl ester",
        formula="C16H26O",
        monoisotopic_mass=234.198365,
        average_mass=234.38,
        dict_composition={'C': 16, 'H': 26, 'O': 1},
    ),
    "01137": PsimodInfo(
        id="01137",
        name="N6-(2,2,5,7,8-pentamethylchroman-6-sulfonyl)-L-lysine",
        formula="C14H18O3S",
        monoisotopic_mass=266.097665,
        average_mass=266.36,
        dict_composition={'C': 14, 'H': 18, 'O': 3, 'S': 1},
    ),
    "01140": PsimodInfo(
        id="01140",
        name="diiodinated tyrosine",
        formula="H-2I2",
        monoisotopic_mass=251.793295,
        average_mass=251.79,
        dict_composition={'H': -2, 'I': 2},
    ),
    "01141": PsimodInfo(
        id="01141",
        name="omega-N-(2,2,5,7,8-pentamethylchroman-6-sulfonyl)-L-arginine",
        formula="C14H18O3S",
        monoisotopic_mass=266.097665,
        average_mass=266.36,
        dict_composition={'C': 14, 'H': 18, 'O': 3, 'S': 1},
    ),
    "01142": PsimodInfo(
        id="01142",
        name="S-15,16-dihydrobiliverdin-L-cysteine",
        formula="C33H36N4O6",
        monoisotopic_mass=584.263485,
        average_mass=584.67,
        dict_composition={'C': 33, 'H': 36, 'N': 4, 'O': 6},
    ),
    "01143": PsimodInfo(
        id="01143",
        name="15,16-dihydrobiliverdin-bis-L-cysteine",
        formula="C33H36N4O6",
        monoisotopic_mass=584.263485,
        average_mass=584.67,
        dict_composition={'C': 33, 'H': 36, 'N': 4, 'O': 6},
    ),
    "01144": PsimodInfo(
        id="01144",
        name="S-(sn-1-2,3-dipalmitoylglycerol)-L-cysteine",
        formula="C35H66O4",
        monoisotopic_mass=550.496111,
        average_mass=550.91,
        dict_composition={'C': 35, 'H': 66, 'O': 4},
    ),
    "01145": PsimodInfo(
        id="01145",
        name="N-tau-(ADP-ribosyl)diphthamide",
        formula="C22H36N7O14P2",
        monoisotopic_mass=684.178999,
        average_mass=684.51,
        dict_composition={'C': 22, 'H': 36, 'N': 7, 'O': 14, 'P': 2},
    ),
    "01146": PsimodInfo(
        id="01146",
        name="S-(6-FAD)-L-cysteine",
        formula="C27H31N9O15P2",
        monoisotopic_mass=783.141485,
        average_mass=783.54,
        dict_composition={'C': 27, 'H': 31, 'N': 9, 'O': 15, 'P': 2},
    ),
    "01147": PsimodInfo(
        id="01147",
        name="dHex1Hex3HexNAc2 N4-glycosylated asparagine",
        formula="C40H66N2O29",
        monoisotopic_mass=1038.375124,
        average_mass=1038.95,
        dict_composition={'C': 40, 'H': 66, 'N': 2, 'O': 29},
    ),
    "01151": PsimodInfo(
        id="01151",
        name="phosphorylated residue with neutral loss of phosphate",
        formula="H-3O-4P-1",
        monoisotopic_mass=-97.976895,
        average_mass=-97.99,
        dict_composition={'H': -3, 'O': -4, 'P': -1},
    ),
    "01152": PsimodInfo(
        id="01152",
        name="carboxylated residue",
        formula="CO2",
        monoisotopic_mass=43.989829,
        average_mass=44.01,
        dict_composition={'C': 1, 'O': 2},
    ),
    "01153": PsimodInfo(
        id="01153",
        name="methylthiolated residue",
        formula="CH2S",
        monoisotopic_mass=45.987721,
        average_mass=46.09,
        dict_composition={'C': 1, 'H': 2, 'S': 1},
    ),
    "01160": PsimodInfo(
        id="01160",
        name="deaminated residue",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "01161": PsimodInfo(
        id="01161",
        name="deoxygenated residue",
        formula="O-1",
        monoisotopic_mass=-15.994915,
        average_mass=-16.0,
        dict_composition={'O': -1},
    ),
    "01162": PsimodInfo(
        id="01162",
        name="fucosylated biantennary",
        formula="C68H112N4O49",
        monoisotopic_mass=1768.639516,
        average_mass=1769.62,
        dict_composition={'C': 68, 'H': 112, 'N': 4, 'O': 49},
    ),
    "01163": PsimodInfo(
        id="01163",
        name="guanylated residue",
        formula="C10H12N5O7P",
        monoisotopic_mass=345.047434,
        average_mass=345.21,
        dict_composition={'C': 10, 'H': 12, 'N': 5, 'O': 7, 'P': 1},
    ),
    "01164": PsimodInfo(
        id="01164",
        name="riboflavin-phosphorylated residue",
        formula="C17H19N4O8P",
        monoisotopic_mass=438.09405,
        average_mass=438.33,
        dict_composition={'C': 17, 'H': 19, 'N': 4, 'O': 8, 'P': 1},
    ),
    "01165": PsimodInfo(
        id="01165",
        name="adenylated residue",
        formula="C10H12N5O6P",
        monoisotopic_mass=329.05252,
        average_mass=329.21,
        dict_composition={'C': 10, 'H': 12, 'N': 5, 'O': 6, 'P': 1},
    ),
    "01166": PsimodInfo(
        id="01166",
        name="uridylated residue",
        formula="C9H11N2O8P",
        monoisotopic_mass=306.025302,
        average_mass=306.17,
        dict_composition={'C': 9, 'H': 11, 'N': 2, 'O': 8, 'P': 1},
    ),
    "01167": PsimodInfo(
        id="01167",
        name="molybdopterin guanine dinucleotide",
        formula="C40H47MoN20O26P4S4",
        monoisotopic_mass=1572.985775,
        average_mass=1572.02,
        dict_composition={'C': 40, 'H': 47, 'Mo': 1, 'N': 20, 'O': 26, 'P': 4, 'S': 4},
    ),
    "01170": PsimodInfo(
        id="01170",
        name="pyruvic acid iminylated residue",
        formula="C3H2O2",
        monoisotopic_mass=70.005479,
        average_mass=70.05,
        dict_composition={'C': 3, 'H': 2, 'O': 2},
    ),
    "01171": PsimodInfo(
        id="01171",
        name="O-acetyl-L-threonine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "01172": PsimodInfo(
        id="01172",
        name="N-alanyl-glycosylsphingolipidinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
    "01173": PsimodInfo(
        id="01173",
        name="N-asparaginyl-glycosylsphingolipidinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
    "01174": PsimodInfo(
        id="01174",
        name="S-(15-deoxy-Delta12,14-prostaglandin J2-9-yl)-L-cysteine",
        formula="C20H28O3",
        monoisotopic_mass=316.203845,
        average_mass=316.44,
        dict_composition={'C': 20, 'H': 28, 'O': 3},
    ),
    "01175": PsimodInfo(
        id="01175",
        name="S-phycourobilin-L-cysteine",
        formula="C33H38N4O6",
        monoisotopic_mass=586.279135,
        average_mass=586.69,
        dict_composition={'C': 33, 'H': 38, 'N': 4, 'O': 6},
    ),
    "01176": PsimodInfo(
        id="01176",
        name="L-dehydrolysinonorleucine",
        formula="H-5N-1",
        monoisotopic_mass=-19.042199,
        average_mass=-19.05,
        dict_composition={'H': -5, 'N': -1},
    ),
    "01177": PsimodInfo(
        id="01177",
        name="1'-(1,2,3-trihydroxyprop-2-yl)-L-histidine",
        formula="C3H6O3",
        monoisotopic_mass=90.031694,
        average_mass=90.08,
        dict_composition={'C': 3, 'H': 6, 'O': 3},
    ),
    "01178": PsimodInfo(
        id="01178",
        name="S-(aspart-4-yloxy) thiocarbonate",
        formula="CO2S",
        monoisotopic_mass=75.9619,
        average_mass=76.07,
        dict_composition={'C': 1, 'O': 2, 'S': 1},
    ),
    "01179": PsimodInfo(
        id="01179",
        name="N,N-dimethyl-L-alanine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
    "01180": PsimodInfo(
        id="01180",
        name="2-hydroxyglycine observational artifact",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01181": PsimodInfo(
        id="01181",
        name="L-aspartic acid 4-methyl ester",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "01182": PsimodInfo(
        id="01182",
        name="6-(S-L-cysteinyl)-8alpha-(-3'-L-histidino)-FAD",
        formula="C27H29N9O15P2",
        monoisotopic_mass=781.125835,
        average_mass=781.52,
        dict_composition={'C': 27, 'H': 29, 'N': 9, 'O': 15, 'P': 2},
    ),
    "01183": PsimodInfo(
        id="01183",
        name="L-selenocystine (oxidized selenocysteine) (Sec-Sec)",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01184": PsimodInfo(
        id="01184",
        name="L-selenocystine (selenium disubstituted L-cystine)",
        formula="H-2S-2Se2",
        monoisotopic_mass=93.87325,
        average_mass=91.81,
        dict_composition={'H': -2, 'S': -2, 'Se': 2},
    ),
    "01185": PsimodInfo(
        id="01185",
        name="4-amidated L-aspartic acid",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "01186": PsimodInfo(
        id="01186",
        name="monoacetylated L-threonine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "01187": PsimodInfo(
        id="01187",
        name="L-pyrrolysine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "01188": PsimodInfo(
        id="01188",
        name="N-ethyl iodoacetamide-d5 - site Y",
        formula="C4[1H2][2H5]NO",
        monoisotopic_mass=90.084148,
        average_mass=90.08,
        dict_composition={'C': 4, '1H': 2, '2H': 5, 'N': 1, 'O': 1},
    ),
    "01189": PsimodInfo(
        id="01189",
        name="N-ethyl iodoacetamide-d5 - site C",
        formula="C4[1H2][2H5]NO",
        monoisotopic_mass=90.084148,
        average_mass=90.08,
        dict_composition={'C': 4, '1H': 2, '2H': 5, 'N': 1, 'O': 1},
    ),
    "01191": PsimodInfo(
        id="01191",
        name="N-ethyl iodoacetamide-d0 - site C",
        formula="C4H7NO",
        monoisotopic_mass=85.052764,
        average_mass=85.11,
        dict_composition={'C': 4, 'H': 7, 'N': 1, 'O': 1},
    ),
    "01192": PsimodInfo(
        id="01192",
        name="N-ethyl iodoacetamide-d0 - site Y",
        formula="C4H7NO",
        monoisotopic_mass=85.052764,
        average_mass=85.11,
        dict_composition={'C': 4, 'H': 7, 'N': 1, 'O': 1},
    ),
    "01193": PsimodInfo(
        id="01193",
        name="pyridyl thiol modified L-threonine",
        formula="C7H7NO-1S",
        monoisotopic_mass=121.035006,
        average_mass=121.2,
        dict_composition={'C': 7, 'H': 7, 'N': 1, 'O': -1, 'S': 1},
    ),
    "01194": PsimodInfo(
        id="01194",
        name="pyridyl thiol modified L-serine",
        formula="C7H7NO-1S",
        monoisotopic_mass=121.035006,
        average_mass=121.2,
        dict_composition={'C': 7, 'H': 7, 'N': 1, 'O': -1, 'S': 1},
    ),
    "01195": PsimodInfo(
        id="01195",
        name="benzoyl labeling reagent light form - site K",
        formula="C7H4O",
        monoisotopic_mass=104.026215,
        average_mass=104.11,
        dict_composition={'C': 7, 'H': 4, 'O': 1},
    ),
    "01197": PsimodInfo(
        id="01197",
        name="N-heptosyl-L-glutamine",
        formula="C7H12O6",
        monoisotopic_mass=192.063388,
        average_mass=192.17,
        dict_composition={'C': 7, 'H': 12, 'O': 6},
    ),
    "01198": PsimodInfo(
        id="01198",
        name="O-heptosyl-L-serine",
        formula="C7H12O6",
        monoisotopic_mass=192.063388,
        average_mass=192.17,
        dict_composition={'C': 7, 'H': 12, 'O': 6},
    ),
    "01199": PsimodInfo(
        id="01199",
        name="N-heptosyl-L-arginine",
        formula="C7H12O6",
        monoisotopic_mass=192.063388,
        average_mass=192.17,
        dict_composition={'C': 7, 'H': 12, 'O': 6},
    ),
    "01200": PsimodInfo(
        id="01200",
        name="O-heptosyl-L-threonine",
        formula="C7H12O6",
        monoisotopic_mass=192.063388,
        average_mass=192.17,
        dict_composition={'C': 7, 'H': 12, 'O': 6},
    ),
    "01201": PsimodInfo(
        id="01201",
        name="N6-heptosyl-L-lysine",
        formula="C7H12O6",
        monoisotopic_mass=192.063388,
        average_mass=192.17,
        dict_composition={'C': 7, 'H': 12, 'O': 6},
    ),
    "01202": PsimodInfo(
        id="01202",
        name="N-heptosyl-L-asparagine",
        formula="C7H12O6",
        monoisotopic_mass=192.063388,
        average_mass=192.17,
        dict_composition={'C': 7, 'H': 12, 'O': 6},
    ),
    "01203": PsimodInfo(
        id="01203",
        name="N6-(pyridylacetyl)lysine",
        formula="C7H5NO",
        monoisotopic_mass=119.037114,
        average_mass=119.12,
        dict_composition={'C': 7, 'H': 5, 'N': 1, 'O': 1},
    ),
    "01204": PsimodInfo(
        id="01204",
        name="prompt loss of methanethiol from oxidixed methionine",
        formula="C-1H-4S-1",
        monoisotopic_mass=-48.003371,
        average_mass=-48.1,
        dict_composition={'C': -1, 'H': -4, 'S': -1},
    ),
    "01205": PsimodInfo(
        id="01205",
        name="Hex1HexNAc1NeuAc2 O-glycosylated serine",
        formula="C36H57N3O26",
        monoisotopic_mass=947.323029,
        average_mass=947.85,
        dict_composition={'C': 36, 'H': 57, 'N': 3, 'O': 26},
    ),
    "01206": PsimodInfo(
        id="01206",
        name="Hex1HexNAc1NeuAc2 O-glycosylated threonine",
        formula="C36H57N3O26",
        monoisotopic_mass=947.323029,
        average_mass=947.85,
        dict_composition={'C': 36, 'H': 57, 'N': 3, 'O': 26},
    ),
    "01207": PsimodInfo(
        id="01207",
        name="Hex1HexNAc1NeuAc2 N4-glycosylated asparagine",
        formula="C36H57N3O26",
        monoisotopic_mass=947.323029,
        average_mass=947.85,
        dict_composition={'C': 36, 'H': 57, 'N': 3, 'O': 26},
    ),
    "01208": PsimodInfo(
        id="01208",
        name="copper(1+) carboxylate C-terminal residue",
        formula="CuH-1",
        monoisotopic_mass=61.921772,
        average_mass=62.54,
        dict_composition={'Cu': 1, 'H': -1},
    ),
    "01209": PsimodInfo(
        id="01209",
        name="copper(1+) L-aspartate",
        formula="CuH-1",
        monoisotopic_mass=61.921772,
        average_mass=62.54,
        dict_composition={'Cu': 1, 'H': -1},
    ),
    "01210": PsimodInfo(
        id="01210",
        name="copper(1+) L-glutamate",
        formula="CuH-1",
        monoisotopic_mass=61.921772,
        average_mass=62.54,
        dict_composition={'Cu': 1, 'H': -1},
    ),
    "01211": PsimodInfo(
        id="01211",
        name="N6-(morpholine-2-acetyl)-lysine",
        formula="C6H9NO2",
        monoisotopic_mass=127.063329,
        average_mass=127.14,
        dict_composition={'C': 6, 'H': 9, 'N': 1, 'O': 2},
    ),
    "01212": PsimodInfo(
        id="01212",
        name="iodoacetamide N6-derivatized lysine",
        formula="C2H3NO",
        monoisotopic_mass=57.021464,
        average_mass=57.05,
        dict_composition={'C': 2, 'H': 3, 'N': 1, 'O': 1},
    ),
    "01213": PsimodInfo(
        id="01213",
        name="iodoacetamide derivatized histidine",
        formula="C2H3NO",
        monoisotopic_mass=57.021464,
        average_mass=57.05,
        dict_composition={'C': 2, 'H': 3, 'N': 1, 'O': 1},
    ),
    "01215": PsimodInfo(
        id="01215",
        name="iodoacetamide derivatized aspartic acid",
        formula="C2H3NO",
        monoisotopic_mass=57.021464,
        average_mass=57.05,
        dict_composition={'C': 2, 'H': 3, 'N': 1, 'O': 1},
    ),
    "01216": PsimodInfo(
        id="01216",
        name="iodoacetamide derivatized glutamic acid",
        formula="C2H3NO",
        monoisotopic_mass=57.021464,
        average_mass=57.05,
        dict_composition={'C': 2, 'H': 3, 'N': 1, 'O': 1},
    ),
    "01217": PsimodInfo(
        id="01217",
        name="Sulfanilic Acid (SA), light C12 - site D",
        formula="[12C6]H5NO2S",
        monoisotopic_mass=155.004099,
        average_mass=155.0,
        dict_composition={'12C': 6, 'H': 5, 'N': 1, 'O': 2, 'S': 1},
    ),
    "01218": PsimodInfo(
        id="01218",
        name="Sulfanilic Acid (SA), light C12 - site E",
        formula="[12C6]H5NO2S",
        monoisotopic_mass=155.004099,
        average_mass=155.0,
        dict_composition={'12C': 6, 'H': 5, 'N': 1, 'O': 2, 'S': 1},
    ),
    "01219": PsimodInfo(
        id="01219",
        name="Sulfanilic Acid (SA), heavy C13 - site D",
        formula="[13C6]H5NO2S",
        monoisotopic_mass=161.024228,
        average_mass=161.02,
        dict_composition={'13C': 6, 'H': 5, 'N': 1, 'O': 2, 'S': 1},
    ),
    "01220": PsimodInfo(
        id="01220",
        name="Sulfanilic Acid (SA), heavy C13 - site E",
        formula="[13C6]H5NO2S",
        monoisotopic_mass=161.024228,
        average_mass=161.02,
        dict_composition={'13C': 6, 'H': 5, 'N': 1, 'O': 2, 'S': 1},
    ),
    "01221": PsimodInfo(
        id="01221",
        name="O-formyl-L-threonine",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
    "01222": PsimodInfo(
        id="01222",
        name="O-formyl-L-serine",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
    "01223": PsimodInfo(
        id="01223",
        name="thioacylation of primary amines - site N-term",
        formula="C3H4OS",
        monoisotopic_mass=87.998286,
        average_mass=88.12,
        dict_composition={'C': 3, 'H': 4, 'O': 1, 'S': 1},
    ),
    "01224": PsimodInfo(
        id="01224",
        name="thioacylation of primary amines - site K",
        formula="C3H4OS",
        monoisotopic_mass=87.998286,
        average_mass=88.12,
        dict_composition={'C': 3, 'H': 4, 'O': 1, 'S': 1},
    ),
    "01225": PsimodInfo(
        id="01225",
        name="monofluorinated L-tyrosine",
        formula="FH-1",
        monoisotopic_mass=17.990578,
        average_mass=17.99,
        dict_composition={'F': 1, 'H': -1},
    ),
    "01226": PsimodInfo(
        id="01226",
        name="monofluorinated L-tryptophan",
        formula="FH-1",
        monoisotopic_mass=17.990578,
        average_mass=17.99,
        dict_composition={'F': 1, 'H': -1},
    ),
    "01227": PsimodInfo(
        id="01227",
        name="monofluorinated L-phenylalanine",
        formula="FH-1",
        monoisotopic_mass=17.990578,
        average_mass=17.99,
        dict_composition={'F': 1, 'H': -1},
    ),
    "01228": PsimodInfo(
        id="01228",
        name="monoiodinated tyrosine",
        formula="H-1I",
        monoisotopic_mass=125.896648,
        average_mass=125.9,
        dict_composition={'H': -1, 'I': 1},
    ),
    "01229": PsimodInfo(
        id="01229",
        name="L-iodohistidine",
        formula="H-1I",
        monoisotopic_mass=125.896648,
        average_mass=125.9,
        dict_composition={'H': -1, 'I': 1},
    ),
    "01230": PsimodInfo(
        id="01230",
        name="Bruker Daltonics SERVA-ICPL(TM) quantification chemistry, light form - site K",
        formula="[12C6]H3NO",
        monoisotopic_mass=105.021464,
        average_mass=105.02,
        dict_composition={'12C': 6, 'H': 3, 'N': 1, 'O': 1},
    ),
    "01231": PsimodInfo(
        id="01231",
        name="3x(13)C labeled N6-propanoyl-L-lysine",
        formula="[13C3]H4O",
        monoisotopic_mass=59.036279,
        average_mass=59.04,
        dict_composition={'13C': 3, 'H': 4, 'O': 1},
    ),
    "01232": PsimodInfo(
        id="01232",
        name="3x(12)C labeled N6-propanoyl-L-lysine",
        formula="[12C3]H4O",
        monoisotopic_mass=56.026215,
        average_mass=56.03,
        dict_composition={'12C': 3, 'H': 4, 'O': 1},
    ),
    "01233": PsimodInfo(
        id="01233",
        name="3x(2)H labeled N6-acetyl-L-lysine",
        formula="C2[1H-1][2H3]O",
        monoisotopic_mass=45.029395,
        average_mass=45.03,
        dict_composition={'C': 2, '1H': -1, '2H': 3, 'O': 1},
    ),
    "01234": PsimodInfo(
        id="01234",
        name="(18)O monosubstituted L-serine",
        formula="[16O-1][18O]",
        monoisotopic_mass=2.004246,
        average_mass=2.0,
        dict_composition={'16O': -1, '18O': 1},
    ),
    "01235": PsimodInfo(
        id="01235",
        name="(18)O monosubstituted L-threonine",
        formula="[16O-1][18O]",
        monoisotopic_mass=2.004246,
        average_mass=2.0,
        dict_composition={'16O': -1, '18O': 1},
    ),
    "01236": PsimodInfo(
        id="01236",
        name="(18)O monosubstituted L-tyrosine",
        formula="[16O-1][18O]",
        monoisotopic_mass=2.004246,
        average_mass=2.0,
        dict_composition={'16O': -1, '18O': 1},
    ),
    "01237": PsimodInfo(
        id="01237",
        name="cysteine 4-hydroxynonenal adduct",
        formula="C9H16O2",
        monoisotopic_mass=156.11503,
        average_mass=156.22,
        dict_composition={'C': 9, 'H': 16, 'O': 2},
    ),
    "01238": PsimodInfo(
        id="01238",
        name="lysine 4-hydroxynonenal adduct",
        formula="C9H16O2",
        monoisotopic_mass=156.11503,
        average_mass=156.22,
        dict_composition={'C': 9, 'H': 16, 'O': 2},
    ),
    "01239": PsimodInfo(
        id="01239",
        name="histidine 4-hydroxynonenal adduct",
        formula="C9H16O2",
        monoisotopic_mass=156.11503,
        average_mass=156.22,
        dict_composition={'C': 9, 'H': 16, 'O': 2},
    ),
    "01240": PsimodInfo(
        id="01240",
        name="ubiquitination signature tetrapeptidyl lysine",
        formula="C16H29N7O4",
        monoisotopic_mass=383.228102,
        average_mass=383.45,
        dict_composition={'C': 16, 'H': 29, 'N': 7, 'O': 4},
    ),
    "01241": PsimodInfo(
        id="01241",
        name="3x(2)H labeled L-aspartic acid 4-methyl ester",
        formula="C[1H-1][2H3]",
        monoisotopic_mass=17.03448,
        average_mass=17.03,
        dict_composition={'C': 1, '1H': -1, '2H': 3},
    ),
    "01242": PsimodInfo(
        id="01242",
        name="3x(2)H labeled L-glutamic acid 5-methyl ester",
        formula="C[1H-1][2H3]",
        monoisotopic_mass=17.03448,
        average_mass=17.03,
        dict_composition={'C': 1, '1H': -1, '2H': 3},
    ),
    "01243": PsimodInfo(
        id="01243",
        name="potassium carboxylate C-terminal residue",
        formula="H-1K",
        monoisotopic_mass=37.955882,
        average_mass=38.09,
        dict_composition={'H': -1, 'K': 1},
    ),
    "01244": PsimodInfo(
        id="01244",
        name="potassium L-glutamate",
        formula="H-1K",
        monoisotopic_mass=37.955882,
        average_mass=38.09,
        dict_composition={'H': -1, 'K': 1},
    ),
    "01245": PsimodInfo(
        id="01245",
        name="potassium L-aspartate",
        formula="H-1K",
        monoisotopic_mass=37.955882,
        average_mass=38.09,
        dict_composition={'H': -1, 'K': 1},
    ),
    "01248": PsimodInfo(
        id="01248",
        name="iodouridine monophosphate derivatized tyrosine",
        formula="C9H11N2O9P",
        monoisotopic_mass=322.020217,
        average_mass=322.17,
        dict_composition={'C': 9, 'H': 11, 'N': 2, 'O': 9, 'P': 1},
    ),
    "01249": PsimodInfo(
        id="01249",
        name="iodouridine monophosphate derivatized tryptophan",
        formula="C9H11N2O9P",
        monoisotopic_mass=322.020217,
        average_mass=322.17,
        dict_composition={'C': 9, 'H': 11, 'N': 2, 'O': 9, 'P': 1},
    ),
    "01250": PsimodInfo(
        id="01250",
        name="iodouridine monophosphate derivatized phenylalanine",
        formula="C9H11N2O9P",
        monoisotopic_mass=322.020217,
        average_mass=322.17,
        dict_composition={'C': 9, 'H': 11, 'N': 2, 'O': 9, 'P': 1},
    ),
    "01251": PsimodInfo(
        id="01251",
        name="N6-[3-(carboxamidomethylthio)propanoyl]lysine",
        formula="C5H7NO2S",
        monoisotopic_mass=145.019749,
        average_mass=145.18,
        dict_composition={'C': 5, 'H': 7, 'N': 1, 'O': 2, 'S': 1},
    ),
    "01253": PsimodInfo(
        id="01253",
        name="malondialdehyde lysine adduct (+54 amu)",
        formula="C3H2O",
        monoisotopic_mass=54.010565,
        average_mass=54.05,
        dict_composition={'C': 3, 'H': 2, 'O': 1},
    ),
    "01254": PsimodInfo(
        id="01254",
        name="4x(2)H labeled dimethylated L-lysine",
        formula="C2[2H4]",
        monoisotopic_mass=32.056407,
        average_mass=32.06,
        dict_composition={'C': 2, '2H': 4},
    ),
    "01255": PsimodInfo(
        id="01255",
        name="S-(2-sulfanylethyl)cysteine (Ser)",
        formula="C2H4O-1S2",
        monoisotopic_mass=75.980528,
        average_mass=76.18,
        dict_composition={'C': 2, 'H': 4, 'O': -1, 'S': 2},
    ),
    "01256": PsimodInfo(
        id="01256",
        name="3-methyl-S-(2-sulfanylethyl)cysteine (Thr)",
        formula="C2H4O-1S2",
        monoisotopic_mass=75.980528,
        average_mass=76.18,
        dict_composition={'C': 2, 'H': 4, 'O': -1, 'S': 2},
    ),
    "01257": PsimodInfo(
        id="01257",
        name="6-aminoquinolyl-N-hydroxysuccinimidyl carbamate - site K",
        formula="C10H6N2O",
        monoisotopic_mass=170.048013,
        average_mass=170.17,
        dict_composition={'C': 10, 'H': 6, 'N': 2, 'O': 1},
    ),
    "01258": PsimodInfo(
        id="01258",
        name="N-methylmaleimide modified L-cysteine",
        formula="C5H5NO2",
        monoisotopic_mass=111.032028,
        average_mass=111.1,
        dict_composition={'C': 5, 'H': 5, 'N': 1, 'O': 2},
    ),
    "01259": PsimodInfo(
        id="01259",
        name="N-methylmaleimide modified L-lysine",
        formula="C5H5NO2",
        monoisotopic_mass=111.032028,
        average_mass=111.1,
        dict_composition={'C': 5, 'H': 5, 'N': 1, 'O': 2},
    ),
    "01272": PsimodInfo(
        id="01272",
        name="iminobiotinylation - site K",
        formula="C10H15N3OS",
        monoisotopic_mass=225.093583,
        average_mass=225.31,
        dict_composition={'C': 10, 'H': 15, 'N': 3, 'O': 1, 'S': 1},
    ),
    "01273": PsimodInfo(
        id="01273",
        name="O-[4-(2-aminoethyl)benzenesulfonyl] serine",
        formula="C8H9NO2S",
        monoisotopic_mass=183.0354,
        average_mass=183.23,
        dict_composition={'C': 8, 'H': 9, 'N': 1, 'O': 2, 'S': 1},
    ),
    "01274": PsimodInfo(
        id="01274",
        name="N'-[4-(2-aminoethyl)benzenesulfonyl] derivatized histidine",
        formula="C8H9NO2S",
        monoisotopic_mass=183.0354,
        average_mass=183.23,
        dict_composition={'C': 8, 'H': 9, 'N': 1, 'O': 2, 'S': 1},
    ),
    "01275": PsimodInfo(
        id="01275",
        name="N6-[4-(2-aminoethyl)benzenesulfonyl]lysine",
        formula="C8H9NO2S",
        monoisotopic_mass=183.0354,
        average_mass=183.23,
        dict_composition={'C': 8, 'H': 9, 'N': 1, 'O': 2, 'S': 1},
    ),
    "01276": PsimodInfo(
        id="01276",
        name="O4'-[4-(2-aminoethyl)benzenesulfonyl]tyrosine",
        formula="C8H9NO2S",
        monoisotopic_mass=183.0354,
        average_mass=183.23,
        dict_composition={'C': 8, 'H': 9, 'N': 1, 'O': 2, 'S': 1},
    ),
    "01277": PsimodInfo(
        id="01277",
        name="crotonylated L-cysteine",
        formula="C4H6O",
        monoisotopic_mass=70.041865,
        average_mass=70.09,
        dict_composition={'C': 4, 'H': 6, 'O': 1},
    ),
    "01278": PsimodInfo(
        id="01278",
        name="crotonylated L-lysine",
        formula="C4H6O",
        monoisotopic_mass=70.041865,
        average_mass=70.09,
        dict_composition={'C': 4, 'H': 6, 'O': 1},
    ),
    "01279": PsimodInfo(
        id="01279",
        name="crotonylated L-histidine",
        formula="C4H6O",
        monoisotopic_mass=70.041865,
        average_mass=70.09,
        dict_composition={'C': 4, 'H': 6, 'O': 1},
    ),
    "01280": PsimodInfo(
        id="01280",
        name="EDT-iodo-PEO-biotin - site T",
        formula="C20H34N4O4S3",
        monoisotopic_mass=490.174219,
        average_mass=490.7,
        dict_composition={'C': 20, 'H': 34, 'N': 4, 'O': 4, 'S': 3},
    ),
    "01281": PsimodInfo(
        id="01281",
        name="EDT-iodo-PEO-biotin - site S",
        formula="C20H34N4O4S3",
        monoisotopic_mass=490.174219,
        average_mass=490.7,
        dict_composition={'C': 20, 'H': 34, 'N': 4, 'O': 4, 'S': 3},
    ),
    "01285": PsimodInfo(
        id="01285",
        name="6x(13)C,1x(15)N labeled L-leucine",
        formula="[12C-6][13C6][14N-1][15N]",
        monoisotopic_mass=7.017164,
        average_mass=7.02,
        dict_composition={'12C': -6, '13C': 6, '14N': -1, '15N': 1},
    ),
    "01286": PsimodInfo(
        id="01286",
        name="6x(13)C,1x(15)N labeled L-isoleucine",
        formula="[12C-6][13C6][14N-1][15N]",
        monoisotopic_mass=7.017164,
        average_mass=7.02,
        dict_composition={'12C': -6, '13C': 6, '14N': -1, '15N': 1},
    ),
    "01287": PsimodInfo(
        id="01287",
        name="Bruker Daltonics SERVA-ICPL(TM) quantification chemistry, heavy form - site K",
        formula="[13C6]H3NO",
        monoisotopic_mass=111.041593,
        average_mass=111.04,
        dict_composition={'13C': 6, 'H': 3, 'N': 1, 'O': 1},
    ),
    "01293": PsimodInfo(
        id="01293",
        name="1x(18)O labeled deamidated L-asparagine",
        formula="H-1N-1[18O]",
        monoisotopic_mass=2.988262,
        average_mass=2.99,
        dict_composition={'H': -1, 'N': -1, '18O': 1},
    ),
    "01295": PsimodInfo(
        id="01295",
        name="monosodium L-aspartate",
        formula="H-1Na",
        monoisotopic_mass=21.981944,
        average_mass=21.98,
        dict_composition={'H': -1, 'Na': 1},
    ),
    "01296": PsimodInfo(
        id="01296",
        name="monosodium L-glutamate",
        formula="H-1Na",
        monoisotopic_mass=21.981944,
        average_mass=21.98,
        dict_composition={'H': -1, 'Na': 1},
    ),
    "01297": PsimodInfo(
        id="01297",
        name="5x(13)C labeled L-proline",
        formula="[12C-5][13C5]",
        monoisotopic_mass=5.016774,
        average_mass=5.02,
        dict_composition={'12C': -5, '13C': 5},
    ),
    "01298": PsimodInfo(
        id="01298",
        name="reduced cysteine 4-hydroxynonenal adduct",
        formula="C9H18O2",
        monoisotopic_mass=158.13068,
        average_mass=158.24,
        dict_composition={'C': 9, 'H': 18, 'O': 2},
    ),
    "01299": PsimodInfo(
        id="01299",
        name="reduced lysine 4-hydroxynonenal adduct",
        formula="C9H18O2",
        monoisotopic_mass=158.13068,
        average_mass=158.24,
        dict_composition={'C': 9, 'H': 18, 'O': 2},
    ),
    "01300": PsimodInfo(
        id="01300",
        name="reduced histidine 4-hydroxynonenal adduct",
        formula="C9H18O2",
        monoisotopic_mass=158.13068,
        average_mass=158.24,
        dict_composition={'C': 9, 'H': 18, 'O': 2},
    ),
    "01301": PsimodInfo(
        id="01301",
        name="methylamine Michael addition derivatized threonine",
        formula="CH3NO-1",
        monoisotopic_mass=13.031634,
        average_mass=13.04,
        dict_composition={'C': 1, 'H': 3, 'N': 1, 'O': -1},
    ),
    "01302": PsimodInfo(
        id="01302",
        name="methylamine Michael addition derivatized serine",
        formula="CH3NO-1",
        monoisotopic_mass=13.031634,
        average_mass=13.04,
        dict_composition={'C': 1, 'H': 3, 'N': 1, 'O': -1},
    ),
    "01303": PsimodInfo(
        id="01303",
        name="N4-hexosaminylated asparagine",
        formula="C6H11NO4",
        monoisotopic_mass=161.068808,
        average_mass=161.16,
        dict_composition={'C': 6, 'H': 11, 'N': 1, 'O': 4},
    ),
    "01304": PsimodInfo(
        id="01304",
        name="N6-hexosaminylated lysine",
        formula="C6H11NO4",
        monoisotopic_mass=161.068808,
        average_mass=161.16,
        dict_composition={'C': 6, 'H': 11, 'N': 1, 'O': 4},
    ),
    "01305": PsimodInfo(
        id="01305",
        name="N1'-hexosaminylated tryptophan",
        formula="C6H11NO4",
        monoisotopic_mass=161.068808,
        average_mass=161.16,
        dict_composition={'C': 6, 'H': 11, 'N': 1, 'O': 4},
    ),
    "01306": PsimodInfo(
        id="01306",
        name="O-hexosaminylated threonine",
        formula="C6H11NO4",
        monoisotopic_mass=161.068808,
        average_mass=161.16,
        dict_composition={'C': 6, 'H': 11, 'N': 1, 'O': 4},
    ),
    "01307": PsimodInfo(
        id="01307",
        name="thiophosphate labeled with biotin-HPDP -site S",
        formula="C19H34N4O5PS3",
        monoisotopic_mass=525.142895,
        average_mass=525.66,
        dict_composition={'C': 19, 'H': 34, 'N': 4, 'O': 5, 'P': 1, 'S': 3},
    ),
    "01308": PsimodInfo(
        id="01308",
        name="thiophosphate labeled with biotin-HPDP -site T",
        formula="C19H34N4O5PS3",
        monoisotopic_mass=525.142895,
        average_mass=525.66,
        dict_composition={'C': 19, 'H': 34, 'N': 4, 'O': 5, 'P': 1, 'S': 3},
    ),
    "01309": PsimodInfo(
        id="01309",
        name="thiophosphate labeled with biotin-HPDP - site Y",
        formula="C19H34N4O5PS3",
        monoisotopic_mass=525.142895,
        average_mass=525.66,
        dict_composition={'C': 19, 'H': 34, 'N': 4, 'O': 5, 'P': 1, 'S': 3},
    ),
    "01310": PsimodInfo(
        id="01310",
        name="quaternary amine labeling reagent light form N6-L-lysine",
        formula="C3[1H9]N",
        monoisotopic_mass=59.073499,
        average_mass=59.07,
        dict_composition={'C': 3, '1H': 9, 'N': 1},
    ),
    "01311": PsimodInfo(
        id="01311",
        name="quaternary amine labeling reagent heavy form (+3amu) N6-L-lysine",
        formula="C3[1H6][2H3]N",
        monoisotopic_mass=62.09233,
        average_mass=62.09,
        dict_composition={'C': 3, '1H': 6, '2H': 3, 'N': 1},
    ),
    "01312": PsimodInfo(
        id="01312",
        name="quaternary amine labeling reagent heavy form (+6amu) N6-L-lysine",
        formula="C3[1H3][2H6]N",
        monoisotopic_mass=65.11116,
        average_mass=65.11,
        dict_composition={'C': 3, '1H': 3, '2H': 6, 'N': 1},
    ),
    "01313": PsimodInfo(
        id="01313",
        name="quaternary amine labeling reagent heavy form (+9amu) N6-L-lysine",
        formula="C3[2H9]N",
        monoisotopic_mass=68.12999,
        average_mass=68.13,
        dict_composition={'C': 3, '2H': 9, 'N': 1},
    ),
    "01314": PsimodInfo(
        id="01314",
        name="4x(1)H,4x(12)C-labeled N6-succinyl-L-lysine",
        formula="[12C4][1H4]O3",
        monoisotopic_mass=100.016044,
        average_mass=100.02,
        dict_composition={'12C': 4, '1H': 4, 'O': 3},
    ),
    "01315": PsimodInfo(
        id="01315",
        name="4x(2)H labeled N6-succinyl-L-lysine",
        formula="C4[2H4]O3",
        monoisotopic_mass=104.041151,
        average_mass=104.04,
        dict_composition={'C': 4, '2H': 4, 'O': 3},
    ),
    "01316": PsimodInfo(
        id="01316",
        name="4x(13)C labeled N6-succinyl-L-lysine",
        formula="[13C4]H4O3",
        monoisotopic_mass=104.029463,
        average_mass=104.03,
        dict_composition={'13C': 4, 'H': 4, 'O': 3},
    ),
    "01317": PsimodInfo(
        id="01317",
        name="phosphorylation to amine thiol - site T",
        formula="C4H9NO-1S",
        monoisotopic_mass=87.050656,
        average_mass=87.18,
        dict_composition={'C': 4, 'H': 9, 'N': 1, 'O': -1, 'S': 1},
    ),
    "01318": PsimodInfo(
        id="01318",
        name="phosphorylation to amine thiol - site S",
        formula="C4H9NO-1S",
        monoisotopic_mass=87.050656,
        average_mass=87.18,
        dict_composition={'C': 4, 'H': 9, 'N': 1, 'O': -1, 'S': 1},
    ),
    "01319": PsimodInfo(
        id="01319",
        name="Michael addition of BHT quinone methide to histidine",
        formula="C15H22O",
        monoisotopic_mass=218.167065,
        average_mass=218.34,
        dict_composition={'C': 15, 'H': 22, 'O': 1},
    ),
    "01320": PsimodInfo(
        id="01320",
        name="Michael addition of BHT quinone methide to lysine",
        formula="C15H22O",
        monoisotopic_mass=218.167065,
        average_mass=218.34,
        dict_composition={'C': 15, 'H': 22, 'O': 1},
    ),
    "01321": PsimodInfo(
        id="01321",
        name="Michael addition of BHT quinone methide to cysteine",
        formula="C15H22O",
        monoisotopic_mass=218.167065,
        average_mass=218.34,
        dict_composition={'C': 15, 'H': 22, 'O': 1},
    ),
    "01326": PsimodInfo(
        id="01326",
        name="9x(13)C labeled L-tyrosine",
        formula="[12C-9][13C9]",
        monoisotopic_mass=9.030194,
        average_mass=9.03,
        dict_composition={'12C': -9, '13C': 9},
    ),
    "01327": PsimodInfo(
        id="01327",
        name="9x(13)C labeled L-phenylalanine",
        formula="[12C-9][13C9]",
        monoisotopic_mass=9.030194,
        average_mass=9.03,
        dict_composition={'12C': -9, '13C': 9},
    ),
    "01328": PsimodInfo(
        id="01328",
        name="iodoacetic acid - site W",
        formula="C2H2O2",
        monoisotopic_mass=58.005479,
        average_mass=58.04,
        dict_composition={'C': 2, 'H': 2, 'O': 2},
    ),
    "01331": PsimodInfo(
        id="01331",
        name="6x(13)C labeled L-arginine",
        formula="[12C-6][13C6]",
        monoisotopic_mass=6.020129,
        average_mass=6.02,
        dict_composition={'12C': -6, '13C': 6},
    ),
    "01332": PsimodInfo(
        id="01332",
        name="6x(13)C labeled L-leucine",
        formula="[12C-6][13C6]",
        monoisotopic_mass=6.020129,
        average_mass=6.02,
        dict_composition={'12C': -6, '13C': 6},
    ),
    "01333": PsimodInfo(
        id="01333",
        name="6x(13)C labeled L-isoleucine",
        formula="[12C-6][13C6]",
        monoisotopic_mass=6.020129,
        average_mass=6.02,
        dict_composition={'12C': -6, '13C': 6},
    ),
    "01334": PsimodInfo(
        id="01334",
        name="6x(13)C labeled L-lysine",
        formula="[12C-6][13C6]",
        monoisotopic_mass=6.020129,
        average_mass=6.02,
        dict_composition={'12C': -6, '13C': 6},
    ),
    "01335": PsimodInfo(
        id="01335",
        name="6x(13)C labeled 4-sulfophenyl isothiocyanate derivatized lysine",
        formula="[12C][13C6]H5NO3S2",
        monoisotopic_mass=220.991214,
        average_mass=220.99,
        dict_composition={'12C': 1, '13C': 6, 'H': 5, 'N': 1, 'O': 3, 'S': 2},
    ),
    "01337": PsimodInfo(
        id="01337",
        name="deamidated 4-methyl esterified asparagine",
        formula="CHN-1O",
        monoisotopic_mass=14.999666,
        average_mass=15.01,
        dict_composition={'C': 1, 'H': 1, 'N': -1, 'O': 1},
    ),
    "01338": PsimodInfo(
        id="01338",
        name="N6-ethyl-L-lysine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
    "01339": PsimodInfo(
        id="01339",
        name="ethylated residue",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
    "01340": PsimodInfo(
        id="01340",
        name="ESP-Tag heavy d10 - site K",
        formula="C16[1H16][2H10]N4O2S",
        monoisotopic_mass=348.240415,
        average_mass=348.24,
        dict_composition={'C': 16, '1H': 16, '2H': 10, 'N': 4, 'O': 2, 'S': 1},
    ),
    "01341": PsimodInfo(
        id="01341",
        name="ESP-Tag light d0 - site K",
        formula="C16H26N4O2S",
        monoisotopic_mass=338.177647,
        average_mass=338.47,
        dict_composition={'C': 16, 'H': 26, 'N': 4, 'O': 2, 'S': 1},
    ),
    "01345": PsimodInfo(
        id="01345",
        name="2-amino-3-oxobutanoic acid",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01346": PsimodInfo(
        id="01346",
        name="N4-hexosylated asparagine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "01347": PsimodInfo(
        id="01347",
        name="hexose glycated L-lysine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "01348": PsimodInfo(
        id="01348",
        name="O-hexosylated threonine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "01349": PsimodInfo(
        id="01349",
        name="hydrolyzed N-ethylmaleimide cysteine adduct",
        formula="C6H9NO3",
        monoisotopic_mass=143.058243,
        average_mass=143.14,
        dict_composition={'C': 6, 'H': 9, 'N': 1, 'O': 3},
    ),
    "01350": PsimodInfo(
        id="01350",
        name="hydrolyzed N-ethylmaleimide lysine adduct",
        formula="C6H9NO3",
        monoisotopic_mass=143.058243,
        average_mass=143.14,
        dict_composition={'C': 6, 'H': 9, 'N': 1, 'O': 3},
    ),
    "01351": PsimodInfo(
        id="01351",
        name="nitrated L-tryptophan",
        formula="H-1NO2",
        monoisotopic_mass=44.985078,
        average_mass=45.0,
        dict_composition={'H': -1, 'N': 1, 'O': 2},
    ),
    "01352": PsimodInfo(
        id="01352",
        name="nitrated L-tyrosine",
        formula="H-1NO2",
        monoisotopic_mass=44.985078,
        average_mass=45.0,
        dict_composition={'H': -1, 'N': 1, 'O': 2},
    ),
    "01353": PsimodInfo(
        id="01353",
        name="amidination of lysines or N-terminal amines with methyl acetimidate - site K",
        formula="C2H3N",
        monoisotopic_mass=41.026549,
        average_mass=41.05,
        dict_composition={'C': 2, 'H': 3, 'N': 1},
    ),
    "01354": PsimodInfo(
        id="01354",
        name="Hex1HexNAc1NeuAc1 N4-glycosylated asparagine",
        formula="C25H41N2O18",
        monoisotopic_mass=657.235437,
        average_mass=657.6,
        dict_composition={'C': 25, 'H': 41, 'N': 2, 'O': 18},
    ),
    "01355": PsimodInfo(
        id="01355",
        name="Hex1HexNAc1NeuAc1 O-glycosylated threonine",
        formula="C25H41N2O18",
        monoisotopic_mass=657.235437,
        average_mass=657.6,
        dict_composition={'C': 25, 'H': 41, 'N': 2, 'O': 18},
    ),
    "01356": PsimodInfo(
        id="01356",
        name="Hex1HexNAc1NeuAc1 O-glycosylated serine",
        formula="C25H41N2O18",
        monoisotopic_mass=657.235437,
        average_mass=657.6,
        dict_composition={'C': 25, 'H': 41, 'N': 2, 'O': 18},
    ),
    "01357": PsimodInfo(
        id="01357",
        name="2x(13)C,4x(2)H labeled dimethylated L-lysine",
        formula="[13C2][2H4]",
        monoisotopic_mass=34.063117,
        average_mass=34.06,
        dict_composition={'13C': 2, '2H': 4},
    ),
    "01358": PsimodInfo(
        id="01358",
        name="Bruker Daltonics SERVA-ICPL(TM) quantification chemistry, medium form - site N-term",
        formula="C6[1H-1][2H4]NO",
        monoisotopic_mass=109.046571,
        average_mass=109.05,
        dict_composition={'C': 6, '1H': -1, '2H': 4, 'N': 1, 'O': 1},
    ),
    "01359": PsimodInfo(
        id="01359",
        name="Bruker Daltonics SERVA-ICPL(TM) quantification chemistry, medium form - site K",
        formula="C6[1H-1][2H4]NO",
        monoisotopic_mass=109.046571,
        average_mass=109.05,
        dict_composition={'C': 6, '1H': -1, '2H': 4, 'N': 1, 'O': 1},
    ),
    "01360": PsimodInfo(
        id="01360",
        name="4-sulfophenyl isothiocyanate N6-derivatized lysine",
        formula="C7H5NO3S2",
        monoisotopic_mass=214.971085,
        average_mass=215.24,
        dict_composition={'C': 7, 'H': 5, 'N': 1, 'O': 3, 'S': 2},
    ),
    "01361": PsimodInfo(
        id="01361",
        name="O-thiophospho-L-threonine",
        formula="HO2PS",
        monoisotopic_mass=95.943487,
        average_mass=96.04,
        dict_composition={'H': 1, 'O': 2, 'P': 1, 'S': 1},
    ),
    "01362": PsimodInfo(
        id="01362",
        name="O-thiophospho-L-serine",
        formula="HO2PS",
        monoisotopic_mass=95.943487,
        average_mass=96.04,
        dict_composition={'H': 1, 'O': 2, 'P': 1, 'S': 1},
    ),
    "01363": PsimodInfo(
        id="01363",
        name="O4'-thiophospho-L-tyrosine",
        formula="HO2PS",
        monoisotopic_mass=95.943487,
        average_mass=96.04,
        dict_composition={'H': 1, 'O': 2, 'P': 1, 'S': 1},
    ),
    "01364": PsimodInfo(
        id="01364",
        name="fluorescein-5-thiosemicarbazide - site S",
        formula="C21H15N3O5S",
        monoisotopic_mass=421.073242,
        average_mass=421.43,
        dict_composition={'C': 21, 'H': 15, 'N': 3, 'O': 5, 'S': 1},
    ),
    "01365": PsimodInfo(
        id="01365",
        name="fluorescein-5-thiosemicarbazide - site C",
        formula="C21H15N3O5S",
        monoisotopic_mass=421.073242,
        average_mass=421.43,
        dict_composition={'C': 21, 'H': 15, 'N': 3, 'O': 5, 'S': 1},
    ),
    "01366": PsimodInfo(
        id="01366",
        name="fluorescein-5-thiosemicarbazide - site K",
        formula="C21H15N3O5S",
        monoisotopic_mass=421.073242,
        average_mass=421.43,
        dict_composition={'C': 21, 'H': 15, 'N': 3, 'O': 5, 'S': 1},
    ),
    "01367": PsimodInfo(
        id="01367",
        name="fluorescein-5-thiosemicarbazide - site P",
        formula="C21H15N3O5S",
        monoisotopic_mass=421.073242,
        average_mass=421.43,
        dict_composition={'C': 21, 'H': 15, 'N': 3, 'O': 5, 'S': 1},
    ),
    "01368": PsimodInfo(
        id="01368",
        name="fluorescein-5-thiosemicarbazide - site R",
        formula="C21H15N3O5S",
        monoisotopic_mass=421.073242,
        average_mass=421.43,
        dict_composition={'C': 21, 'H': 15, 'N': 3, 'O': 5, 'S': 1},
    ),
    "01369": PsimodInfo(
        id="01369",
        name="deamidated and methyl esterified residue",
        formula="CHN-1O",
        monoisotopic_mass=14.999666,
        average_mass=15.01,
        dict_composition={'C': 1, 'H': 1, 'N': -1, 'O': 1},
    ),
    "01370": PsimodInfo(
        id="01370",
        name="6x(13)C,1x(15)N labeled residue",
        formula="[12C-6][13C6][14N-1][15N]",
        monoisotopic_mass=7.017164,
        average_mass=7.02,
        dict_composition={'12C': -6, '13C': 6, '14N': -1, '15N': 1},
    ),
    "01372": PsimodInfo(
        id="01372",
        name="(2S)-4-hydroxyleucine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01373": PsimodInfo(
        id="01373",
        name="(2S,4R)-5-hydroxyleucine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01374": PsimodInfo(
        id="01374",
        name="(2S,4R)-5-oxoleucine",
        formula="H-2O",
        monoisotopic_mass=13.979265,
        average_mass=13.98,
        dict_composition={'H': -2, 'O': 1},
    ),
    "01375": PsimodInfo(
        id="01375",
        name="(2S,4R)-4,5-dihydroxyleucine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "01376": PsimodInfo(
        id="01376",
        name="(2S,3S,4R)-3,4-dihydroxyisoleucine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "01377": PsimodInfo(
        id="01377",
        name="(2S,3R,4S)-4-hydroxyisoleucine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01378": PsimodInfo(
        id="01378",
        name="(2S,3R,4R)-4,5-dihydroxyisoleucine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "01379": PsimodInfo(
        id="01379",
        name="2'-methylsulfonyl-L-tryptophan",
        formula="CH2O2S",
        monoisotopic_mass=77.97755,
        average_mass=78.09,
        dict_composition={'C': 1, 'H': 2, 'O': 2, 'S': 1},
    ),
    "01380": PsimodInfo(
        id="01380",
        name="2'-(S-L-cysteinyl)-6'-hydroxy-L-tryptophan sulfoxide",
        formula="H-2O2",
        monoisotopic_mass=29.974179,
        average_mass=29.98,
        dict_composition={'H': -2, 'O': 2},
    ),
    "01381": PsimodInfo(
        id="01381",
        name="O-palmitoleyl-L-serine",
        formula="C16H28O",
        monoisotopic_mass=236.214016,
        average_mass=236.4,
        dict_composition={'C': 16, 'H': 28, 'O': 1},
    ),
    "01382": PsimodInfo(
        id="01382",
        name="N,N,N-trimethyl-L-methionine",
        formula="C3H7",
        monoisotopic_mass=43.054227,
        average_mass=43.09,
        dict_composition={'C': 3, 'H': 7},
    ),
    "01383": PsimodInfo(
        id="01383",
        name="L-cystine S-oxide",
        formula="H-2O",
        monoisotopic_mass=13.979265,
        average_mass=13.98,
        dict_composition={'H': -2, 'O': 1},
    ),
    "01384": PsimodInfo(
        id="01384",
        name="aminomalonic acid (Ser)",
        formula="H-2O",
        monoisotopic_mass=13.979265,
        average_mass=13.98,
        dict_composition={'H': -2, 'O': 1},
    ),
    "01385": PsimodInfo(
        id="01385",
        name="3-hydroxy-L-phenylalanine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01386": PsimodInfo(
        id="01386",
        name="3-hydroxy-L-valine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01387": PsimodInfo(
        id="01387",
        name="O-methyl-L-threonine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "01388": PsimodInfo(
        id="01388",
        name="1-amino-2-propanol",
        formula="C-1O-2",
        monoisotopic_mass=-43.989829,
        average_mass=-44.01,
        dict_composition={'C': -1, 'O': -2},
    ),
    "01389": PsimodInfo(
        id="01389",
        name="L-isoleucine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "01390": PsimodInfo(
        id="01390",
        name="L-valine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "01391": PsimodInfo(
        id="01391",
        name="L-valine 5-(methoxymethyl)thiazole-4-carboxylic acid",
        formula="C2",
        monoisotopic_mass=24.0,
        average_mass=24.02,
        dict_composition={'C': 2},
    ),
    "01392": PsimodInfo(
        id="01392",
        name="L-asparagine 5-methylthiazole-4-carboxylic acid",
        formula="CH-2O-1",
        monoisotopic_mass=-6.010565,
        average_mass=-6.0,
        dict_composition={'C': 1, 'H': -2, 'O': -1},
    ),
    "01393": PsimodInfo(
        id="01393",
        name="L-cysteine pyridine-2,5-dicarboxylic acid",
        formula="H-8N-1O-3",
        monoisotopic_mass=-70.050418,
        average_mass=-70.07,
        dict_composition={'H': -8, 'N': -1, 'O': -3},
    ),
    "01394": PsimodInfo(
        id="01394",
        name="L-cysteine 5-amino-3,4,5,6-tetrahydropyridine-2,5-dicarboxylic acid",
        formula="H-5O-3",
        monoisotopic_mass=-53.023869,
        average_mass=-53.04,
        dict_composition={'H': -5, 'O': -3},
    ),
    "01395": PsimodInfo(
        id="01395",
        name="4-(1-hydroxyethyl)-7-isoleucino-2-(threonin-O3-ylcarbonyl)-7,8-dihydroquinolin-8-ol",
        formula="C12H9NO3",
        monoisotopic_mass=215.058243,
        average_mass=215.21,
        dict_composition={'C': 12, 'H': 9, 'N': 1, 'O': 3},
    ),
    "01396": PsimodInfo(
        id="01396",
        name="5-hydroxy-3-methyl-L-proline (Pro)",
        formula="CH2O",
        monoisotopic_mass=30.010565,
        average_mass=30.03,
        dict_composition={'C': 1, 'H': 2, 'O': 1},
    ),
    "01397": PsimodInfo(
        id="01397",
        name="L-serine 5-methyloxazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "01398": PsimodInfo(
        id="01398",
        name="N6-propanoyl-L-lysine",
        formula="C3H4O",
        monoisotopic_mass=56.026215,
        average_mass=56.06,
        dict_composition={'C': 3, 'H': 4, 'O': 1},
    ),
    "01399": PsimodInfo(
        id="01399",
        name="N6-(ADP-ribosyl)-L-lysine",
        formula="C15H21N5O13P2",
        monoisotopic_mass=541.061109,
        average_mass=541.3,
        dict_composition={'C': 15, 'H': 21, 'N': 5, 'O': 13, 'P': 2},
    ),
    "01401": PsimodInfo(
        id="01401",
        name="(2S,3S)-3-hydroxyasparagine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01402": PsimodInfo(
        id="01402",
        name="(2S,3R,4R)-3,4-dihydroxyproline",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "01403": PsimodInfo(
        id="01403",
        name="(2S)-4,5,5'-trihydroxyleucine",
        formula="O3",
        monoisotopic_mass=47.984744,
        average_mass=48.0,
        dict_composition={'O': 3},
    ),
    "01404": PsimodInfo(
        id="01404",
        name="L-asparagine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "01405": PsimodInfo(
        id="01405",
        name="L-proline thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "01406": PsimodInfo(
        id="01406",
        name="L-threonine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "01407": PsimodInfo(
        id="01407",
        name="L-phenylalanine thiazoline-4-carboxylic acid",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01408": PsimodInfo(
        id="01408",
        name="L-threonine thiazoline-4-carboxylic acid",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01409": PsimodInfo(
        id="01409",
        name="trihydroxylated residue",
        formula="O3",
        monoisotopic_mass=47.984744,
        average_mass=48.0,
        dict_composition={'O': 3},
    ),
    "01411": PsimodInfo(
        id="01411",
        name="monohydroxylated leucine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01412": PsimodInfo(
        id="01412",
        name="dihydroxylated leucine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "01413": PsimodInfo(
        id="01413",
        name="trihydroxylated leucine",
        formula="O3",
        monoisotopic_mass=47.984744,
        average_mass=48.0,
        dict_composition={'O': 3},
    ),
    "01415": PsimodInfo(
        id="01415",
        name="monohydroxylated isoleucine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01416": PsimodInfo(
        id="01416",
        name="dihydroxylated isoleucine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "01417": PsimodInfo(
        id="01417",
        name="monomethylated proline",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "01423": PsimodInfo(
        id="01423",
        name="palmitoleylated residue",
        formula="C16H28O",
        monoisotopic_mass=236.214016,
        average_mass=236.4,
        dict_composition={'C': 16, 'H': 28, 'O': 1},
    ),
    "01432": PsimodInfo(
        id="01432",
        name="(2S,4S)-4,5-dihydroxyleucine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "01433": PsimodInfo(
        id="01433",
        name="1-amino-2-propanone",
        formula="C-1H-2O-2",
        monoisotopic_mass=-46.005479,
        average_mass=-46.03,
        dict_composition={'C': -1, 'H': -2, 'O': -2},
    ),
    "01434": PsimodInfo(
        id="01434",
        name="4-hydroxy-L-glutamic acid",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01435": PsimodInfo(
        id="01435",
        name="2-(cystein-S-ylcarbonyl)-3-methyl-4-(glutam-5-yloxy)methylindole",
        formula="C11H7NO",
        monoisotopic_mass=169.052764,
        average_mass=169.18,
        dict_composition={'C': 11, 'H': 7, 'N': 1, 'O': 1},
    ),
    "01436": PsimodInfo(
        id="01436",
        name="cyclo[(prolylserin)-O-yl] cysteinate (Cys)",
        formula="C8H10N2O2",
        monoisotopic_mass=166.074228,
        average_mass=166.18,
        dict_composition={'C': 8, 'H': 10, 'N': 2, 'O': 2},
    ),
    "01437": PsimodInfo(
        id="01437",
        name="cyclo[(prolylserin)-O-yl] cysteinate (Cys-Pro-Ser cross-link)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01438": PsimodInfo(
        id="01438",
        name="S-[2-(pyridin-2-yl)ethyl]-L-cysteine",
        formula="C7H7N",
        monoisotopic_mass=105.057849,
        average_mass=105.14,
        dict_composition={'C': 7, 'H': 7, 'N': 1},
    ),
    "01442": PsimodInfo(
        id="01442",
        name="3-(O4'-L-tyrosyl)-L-valine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01443": PsimodInfo(
        id="01443",
        name="tetrakis-L-glutamato bis-L-N1'-histidino lipid carboxylato manganese iron oxide",
        formula="C14FeH23MnO3",
        monoisotopic_mass=350.038251,
        average_mass=350.12,
        dict_composition={'C': 14, 'Fe': 1, 'H': 23, 'Mn': 1, 'O': 3},
    ),
    "01444": PsimodInfo(
        id="01444",
        name="L-3,3-dihydroxyoalanine (Cys)",
        formula="O2S-1",
        monoisotopic_mass=0.017758,
        average_mass=-0.06,
        dict_composition={'O': 2, 'S': -1},
    ),
    "01445": PsimodInfo(
        id="01445",
        name="L-3,3-dihydroxyoalanine (Ser)",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01446": PsimodInfo(
        id="01446",
        name="N-(dihydroxymethyl)-L-methionine (fMet)",
        formula="H2O",
        monoisotopic_mass=18.010565,
        average_mass=18.02,
        dict_composition={'H': 2, 'O': 1},
    ),
    "01447": PsimodInfo(
        id="01447",
        name="N-(dihydroxymethyl)-L-methionine (Met)",
        formula="CH2O2",
        monoisotopic_mass=46.005479,
        average_mass=46.03,
        dict_composition={'C': 1, 'H': 2, 'O': 2},
    ),
    "01449": PsimodInfo(
        id="01449",
        name="L-3,3-dihydroxyoalanine (Oxoalanine)",
        formula="H2O",
        monoisotopic_mass=18.010565,
        average_mass=18.02,
        dict_composition={'H': 2, 'O': 1},
    ),
    "01451": PsimodInfo(
        id="01451",
        name="O-phospho-L-serine arising from O-phosphopantetheine-L-serine after neutral loss of pantetheine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
    "01452": PsimodInfo(
        id="01452",
        name="O-phosphopantetheine-L-serine with neutral loss of pantetheine",
        formula="C-11H-20N-2O-3S-1",
        monoisotopic_mass=-260.119464,
        average_mass=-260.35,
        dict_composition={'C': -11, 'H': -20, 'N': -2, 'O': -3, 'S': -1},
    ),
    "01455": PsimodInfo(
        id="01455",
        name="O-phosphorylated residue",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
    "01456": PsimodInfo(
        id="01456",
        name="N-phosphorylated residue",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
    "01457": PsimodInfo(
        id="01457",
        name="L-cysteine (Ser)",
        formula="OS-1",
        monoisotopic_mass=-15.977156,
        average_mass=-16.06,
        dict_composition={'O': 1, 'S': -1},
    ),
    "01458": PsimodInfo(
        id="01458",
        name="alpha-amino acetylated residue",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
    "01459": PsimodInfo(
        id="01459",
        name="4x(2)H labeled alpha-dimethylamino N-terminal residue",
        formula="C2[2H4]",
        monoisotopic_mass=32.056407,
        average_mass=32.06,
        dict_composition={'C': 2, '2H': 4},
    ),
    "01464": PsimodInfo(
        id="01464",
        name="protonated L-methionine (L-methioninium) residue",
        formula="H",
        monoisotopic_mass=1.007276,
        average_mass=1.01,
        dict_composition={'H': 1},
    ),
    "01465": PsimodInfo(
        id="01465",
        name="N,N,N-trimethyl-L-methionine (from L-methioninium)",
        formula="C3H6",
        monoisotopic_mass=42.046402,
        average_mass=42.08,
        dict_composition={'C': 3, 'H': 6},
    ),
    "01466": PsimodInfo(
        id="01466",
        name="menadione quinone derivative - site C",
        formula="C11H6O2",
        monoisotopic_mass=170.036779,
        average_mass=170.17,
        dict_composition={'C': 11, 'H': 6, 'O': 2},
    ),
    "01467": PsimodInfo(
        id="01467",
        name="menadione quinone derivative - site K",
        formula="C11H6O2",
        monoisotopic_mass=170.036779,
        average_mass=170.17,
        dict_composition={'C': 11, 'H': 6, 'O': 2},
    ),
    "01468": PsimodInfo(
        id="01468",
        name="L-selenocysteinyl molybdenum bis(molybdopterin guanine dinucleotide) (Cys)",
        formula="C40H47MoN20O26P4S3Se",
        monoisotopic_mass=1620.930226,
        average_mass=1618.93,
        dict_composition={'C': 40, 'H': 47, 'Mo': 1, 'N': 20, 'O': 26, 'P': 4, 'S': 3, 'Se': 1},
    ),
    "01469": PsimodInfo(
        id="01469",
        name="L-selenocysteinyl tungsten bis(molybdopterin guanine dinucleotide) (Cys)",
        formula="C40H47N20O26P4S4SeW",
        monoisotopic_mass=1738.94782,
        average_mass=1738.88,
        dict_composition={'C': 40, 'H': 47, 'N': 20, 'O': 26, 'P': 4, 'S': 4, 'Se': 1, 'W': 1},
    ),
    "01470": PsimodInfo(
        id="01470",
        name="(E)-dehydrobutyrine (Thr)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01471": PsimodInfo(
        id="01471",
        name="(Z)-dehydrobutyrine (Thr)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01474": PsimodInfo(
        id="01474",
        name="O-[S-(carboxymethyl)phosphopantetheine]-L-serine",
        formula="C13H23N2O8PS",
        monoisotopic_mass=398.091273,
        average_mass=398.37,
        dict_composition={'C': 13, 'H': 23, 'N': 2, 'O': 8, 'P': 1, 'S': 1},
    ),
    "01475": PsimodInfo(
        id="01475",
        name="O-[S-(carboxamidomethyl)phosphopantetheine]-L-serine",
        formula="C13H24N3O7PS",
        monoisotopic_mass=397.107258,
        average_mass=397.38,
        dict_composition={'C': 13, 'H': 24, 'N': 3, 'O': 7, 'P': 1, 'S': 1},
    ),
    "01476": PsimodInfo(
        id="01476",
        name="2'-fluoro-L-phenylalanine",
        formula="FH-1",
        monoisotopic_mass=17.990578,
        average_mass=17.99,
        dict_composition={'F': 1, 'H': -1},
    ),
    "01477": PsimodInfo(
        id="01477",
        name="3'-fluoro-L-phenylalanine",
        formula="FH-1",
        monoisotopic_mass=17.990578,
        average_mass=17.99,
        dict_composition={'F': 1, 'H': -1},
    ),
    "01478": PsimodInfo(
        id="01478",
        name="4'-fluoro-L-phenylalanine",
        formula="FH-1",
        monoisotopic_mass=17.990578,
        average_mass=17.99,
        dict_composition={'F': 1, 'H': -1},
    ),
    "01479": PsimodInfo(
        id="01479",
        name="4'-fluoro-L-tryptophan",
        formula="FH-1",
        monoisotopic_mass=17.990578,
        average_mass=17.99,
        dict_composition={'F': 1, 'H': -1},
    ),
    "01480": PsimodInfo(
        id="01480",
        name="5'-fluoro-L-tryptophan",
        formula="FH-1",
        monoisotopic_mass=17.990578,
        average_mass=17.99,
        dict_composition={'F': 1, 'H': -1},
    ),
    "01481": PsimodInfo(
        id="01481",
        name="6'-fluoro-L-tryptophan",
        formula="FH-1",
        monoisotopic_mass=17.990578,
        average_mass=17.99,
        dict_composition={'F': 1, 'H': -1},
    ),
    "01483": PsimodInfo(
        id="01483",
        name="O-formylated residue",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
    "01484": PsimodInfo(
        id="01484",
        name="N6-(L-isoglutamyl)-L-lysine (Glu)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01485": PsimodInfo(
        id="01485",
        name="iTRAQ4plex-114 reporter+balance reagent acylated residue",
        formula="[12C5][13C2]H12N2[18O]",
        monoisotopic_mass=144.105919,
        average_mass=144.11,
        dict_composition={'12C': 5, '13C': 2, 'H': 12, 'N': 2, '18O': 1},
    ),
    "01486": PsimodInfo(
        id="01486",
        name="iTRAQ4plex-114 reporter+balance reagent acylated N-terminal",
        formula="[12C5][13C2]H12N2[18O]",
        monoisotopic_mass=144.105919,
        average_mass=144.11,
        dict_composition={'12C': 5, '13C': 2, 'H': 12, 'N': 2, '18O': 1},
    ),
    "01487": PsimodInfo(
        id="01487",
        name="iTRAQ4plex-114 reporter+balance reagent N6-acylated lysine",
        formula="[12C5][13C2]H12N2[18O]",
        monoisotopic_mass=144.105919,
        average_mass=144.11,
        dict_composition={'12C': 5, '13C': 2, 'H': 12, 'N': 2, '18O': 1},
    ),
    "01488": PsimodInfo(
        id="01488",
        name="iTRAQ4plex-114 reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C5][13C2]H12N2[18O]",
        monoisotopic_mass=144.105919,
        average_mass=144.11,
        dict_composition={'12C': 5, '13C': 2, 'H': 12, 'N': 2, '18O': 1},
    ),
    "01489": PsimodInfo(
        id="01489",
        name="iTRAQ4plex-114 reporter+balance reagent N'-acylated histidine",
        formula="[12C5][13C2]H12N2[18O]",
        monoisotopic_mass=144.105919,
        average_mass=144.11,
        dict_composition={'12C': 5, '13C': 2, 'H': 12, 'N': 2, '18O': 1},
    ),
    "01490": PsimodInfo(
        id="01490",
        name="iTRAQ4plex-114 reporter+balance reagent O3-acylated serine",
        formula="[12C5][13C2]H12N2[18O]",
        monoisotopic_mass=144.105919,
        average_mass=144.11,
        dict_composition={'12C': 5, '13C': 2, 'H': 12, 'N': 2, '18O': 1},
    ),
    "01491": PsimodInfo(
        id="01491",
        name="iTRAQ4plex-114 reporter+balance reagent O3-acylated threonine",
        formula="[12C5][13C2]H12N2[18O]",
        monoisotopic_mass=144.105919,
        average_mass=144.11,
        dict_composition={'12C': 5, '13C': 2, 'H': 12, 'N': 2, '18O': 1},
    ),
    "01492": PsimodInfo(
        id="01492",
        name="iTRAQ4plex-115 reporter+balance reagent acylated residue",
        formula="[12C6][13C]H12[14N][15N][18O]",
        monoisotopic_mass=144.099599,
        average_mass=144.1,
        dict_composition={'12C': 6, '13C': 1, 'H': 12, '14N': 1, '15N': 1, '18O': 1},
    ),
    "01493": PsimodInfo(
        id="01493",
        name="iTRAQ4plex-115 reporter+balance reagent acylated N-terminal",
        formula="[12C6][13C]H12[14N][15N][18O]",
        monoisotopic_mass=144.099599,
        average_mass=144.1,
        dict_composition={'12C': 6, '13C': 1, 'H': 12, '14N': 1, '15N': 1, '18O': 1},
    ),
    "01494": PsimodInfo(
        id="01494",
        name="iTRAQ4plex-115 reporter+balance reagent N6-acylated lysine",
        formula="[12C6][13C]H12[14N][15N][18O]",
        monoisotopic_mass=144.099599,
        average_mass=144.1,
        dict_composition={'12C': 6, '13C': 1, 'H': 12, '14N': 1, '15N': 1, '18O': 1},
    ),
    "01495": PsimodInfo(
        id="01495",
        name="iTRAQ4plex-115 reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C6][13C]H12[14N][15N][18O]",
        monoisotopic_mass=144.099599,
        average_mass=144.1,
        dict_composition={'12C': 6, '13C': 1, 'H': 12, '14N': 1, '15N': 1, '18O': 1},
    ),
    "01496": PsimodInfo(
        id="01496",
        name="iTRAQ4plex-115 reporter+balance reagent N'-acylated histidine",
        formula="[12C6][13C]H12[14N][15N][18O]",
        monoisotopic_mass=144.099599,
        average_mass=144.1,
        dict_composition={'12C': 6, '13C': 1, 'H': 12, '14N': 1, '15N': 1, '18O': 1},
    ),
    "01497": PsimodInfo(
        id="01497",
        name="iTRAQ4plex-115 reporter+balance reagent O3-acylated serine",
        formula="[12C6][13C]H12[14N][15N][18O]",
        monoisotopic_mass=144.099599,
        average_mass=144.1,
        dict_composition={'12C': 6, '13C': 1, 'H': 12, '14N': 1, '15N': 1, '18O': 1},
    ),
    "01498": PsimodInfo(
        id="01498",
        name="iTRAQ4plex-115 reporter+balance reagent O3-acylated threonine",
        formula="[12C6][13C]H12[14N][15N][18O]",
        monoisotopic_mass=144.099599,
        average_mass=144.1,
        dict_composition={'12C': 6, '13C': 1, 'H': 12, '14N': 1, '15N': 1, '18O': 1},
    ),
    "01499": PsimodInfo(
        id="01499",
        name="iTRAQ4plex-116 reporter+balance reagent acylated residue",
        formula="[12C4][13C3]H12[14N][15N][16O]",
        monoisotopic_mass=144.102062,
        average_mass=144.1,
        dict_composition={'12C': 4, '13C': 3, 'H': 12, '14N': 1, '15N': 1, '16O': 1},
    ),
    "01500": PsimodInfo(
        id="01500",
        name="iTRAQ4plex-116 reporter+balance reagent acylated N-terminal",
        formula="[12C4][13C3]H12[14N][15N][16O]",
        monoisotopic_mass=144.102062,
        average_mass=144.1,
        dict_composition={'12C': 4, '13C': 3, 'H': 12, '14N': 1, '15N': 1, '16O': 1},
    ),
    "01501": PsimodInfo(
        id="01501",
        name="iTRAQ4plex-116 reporter+balance reagent N6-acylated lysine",
        formula="[12C4][13C3]H12[14N][15N][16O]",
        monoisotopic_mass=144.102062,
        average_mass=144.1,
        dict_composition={'12C': 4, '13C': 3, 'H': 12, '14N': 1, '15N': 1, '16O': 1},
    ),
    "01502": PsimodInfo(
        id="01502",
        name="iTRAQ4plex-116 reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C4][13C3]H12[14N][15N][16O]",
        monoisotopic_mass=144.102062,
        average_mass=144.1,
        dict_composition={'12C': 4, '13C': 3, 'H': 12, '14N': 1, '15N': 1, '16O': 1},
    ),
    "01503": PsimodInfo(
        id="01503",
        name="iTRAQ4plex-116 reporter+balance reagent N'-acylated histidine",
        formula="[12C4][13C3]H12[14N][15N][16O]",
        monoisotopic_mass=144.102062,
        average_mass=144.1,
        dict_composition={'12C': 4, '13C': 3, 'H': 12, '14N': 1, '15N': 1, '16O': 1},
    ),
    "01504": PsimodInfo(
        id="01504",
        name="iTRAQ4plex-116 reporter+balance reagent O3-acylated serine",
        formula="[12C4][13C3]H12[14N][15N][16O]",
        monoisotopic_mass=144.102062,
        average_mass=144.1,
        dict_composition={'12C': 4, '13C': 3, 'H': 12, '14N': 1, '15N': 1, '16O': 1},
    ),
    "01505": PsimodInfo(
        id="01505",
        name="iTRAQ4plex-116 reporter+balance reagent O3-acylated threonine",
        formula="[12C4][13C3]H12[14N][15N][16O]",
        monoisotopic_mass=144.102062,
        average_mass=144.1,
        dict_composition={'12C': 4, '13C': 3, 'H': 12, '14N': 1, '15N': 1, '16O': 1},
    ),
    "01506": PsimodInfo(
        id="01506",
        name="iTRAQ4plex-117, mTRAQ heavy, reporter+balance reagent acylated residue",
        formula="[12C4][13C3]H12[14N][15N][16O]",
        monoisotopic_mass=144.102062,
        average_mass=144.1,
        dict_composition={'12C': 4, '13C': 3, 'H': 12, '14N': 1, '15N': 1, '16O': 1},
    ),
    "01507": PsimodInfo(
        id="01507",
        name="iTRAQ4plex-117, mTRAQ heavy, reporter+balance reagent acylated N-terminal",
        formula="[12C4][13C3]H12[14N][15N][16O]",
        monoisotopic_mass=144.102062,
        average_mass=144.1,
        dict_composition={'12C': 4, '13C': 3, 'H': 12, '14N': 1, '15N': 1, '16O': 1},
    ),
    "01508": PsimodInfo(
        id="01508",
        name="iTRAQ4plex-117, mTRAQ heavy, reporter+balance reagent N6-acylated lysine",
        formula="[12C4][13C3]H12[14N][15N][16O]",
        monoisotopic_mass=144.102062,
        average_mass=144.1,
        dict_composition={'12C': 4, '13C': 3, 'H': 12, '14N': 1, '15N': 1, '16O': 1},
    ),
    "01509": PsimodInfo(
        id="01509",
        name="iTRAQ4plex-117, mTRAQ heavy, reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C4][13C3]H12[14N][15N][16O]",
        monoisotopic_mass=144.102062,
        average_mass=144.1,
        dict_composition={'12C': 4, '13C': 3, 'H': 12, '14N': 1, '15N': 1, '16O': 1},
    ),
    "01510": PsimodInfo(
        id="01510",
        name="iTRAQ4plex-117 reporter+balance reagent N'-acylated histidine",
        formula="[12C4][13C3]H12[14N][15N][16O]",
        monoisotopic_mass=144.102062,
        average_mass=144.1,
        dict_composition={'12C': 4, '13C': 3, 'H': 12, '14N': 1, '15N': 1, '16O': 1},
    ),
    "01511": PsimodInfo(
        id="01511",
        name="iTRAQ4plex-117 reporter+balance reagent O3-acylated serine",
        formula="[12C4][13C3]H12[14N][15N][16O]",
        monoisotopic_mass=144.102062,
        average_mass=144.1,
        dict_composition={'12C': 4, '13C': 3, 'H': 12, '14N': 1, '15N': 1, '16O': 1},
    ),
    "01512": PsimodInfo(
        id="01512",
        name="iTRAQ4plex-117 reporter+balance reagent O3-acylated threonine",
        formula="[12C4][13C3]H12[14N][15N][16O]",
        monoisotopic_mass=144.102062,
        average_mass=144.1,
        dict_composition={'12C': 4, '13C': 3, 'H': 12, '14N': 1, '15N': 1, '16O': 1},
    ),
    "01528": PsimodInfo(
        id="01528",
        name="iTRAQ8plex-113 reporter+balance reagent acylated residue",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01529": PsimodInfo(
        id="01529",
        name="iTRAQ8plex-113 reporter+balance reagent acylated N-terminal",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01530": PsimodInfo(
        id="01530",
        name="iTRAQ8plex-113 reporter+balance reagent N6-acylated lysine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01531": PsimodInfo(
        id="01531",
        name="iTRAQ8plex-113 reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01532": PsimodInfo(
        id="01532",
        name="iTRAQ8plex-113 reporter+balance reagent N'-acylated histidine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01533": PsimodInfo(
        id="01533",
        name="iTRAQ8plex-113 reporter+balance reagent O3-acylated serine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01534": PsimodInfo(
        id="01534",
        name="iTRAQ8plex-113 reporter+balance reagent O3-acylated threonine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01535": PsimodInfo(
        id="01535",
        name="iTRAQ8plex-114 reporter+balance reagent acylated residue",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01536": PsimodInfo(
        id="01536",
        name="iTRAQ8plex-114 reporter+balance reagent acylated N-terminal",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01537": PsimodInfo(
        id="01537",
        name="iTRAQ8plex-114 reporter+balance reagent N6-acylated lysine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01538": PsimodInfo(
        id="01538",
        name="iTRAQ8plex-114 reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01539": PsimodInfo(
        id="01539",
        name="iTRAQ8plex-114 reporter+balance reagent N'-acylated histidine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01540": PsimodInfo(
        id="01540",
        name="iTRAQ8plex-114 reporter+balance reagent O3-acylated serine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01541": PsimodInfo(
        id="01541",
        name="iTRAQ8plex-114 reporter+balance reagent O3-acylated threonine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01542": PsimodInfo(
        id="01542",
        name="iTRAQ8plex-115 reporter+balance reagent acylated residue",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01543": PsimodInfo(
        id="01543",
        name="iTRAQ8plex-115 reporter+balance reagent acylated N-terminal",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01544": PsimodInfo(
        id="01544",
        name="iTRAQ8plex-115 reporter+balance reagent N6-acylated lysine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01545": PsimodInfo(
        id="01545",
        name="iTRAQ8plex-115 reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01546": PsimodInfo(
        id="01546",
        name="iTRAQ8plex-115 reporter+balance reagent N'-derivatized histidine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01547": PsimodInfo(
        id="01547",
        name="iTRAQ8plex-115 reporter+balance reagent O3-acylated serine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01548": PsimodInfo(
        id="01548",
        name="iTRAQ8plex-115 reporter+balance reagent O3-acylated threonine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01549": PsimodInfo(
        id="01549",
        name="iTRAQ8plex-116 reporter+balance reagent acylated residue",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01550": PsimodInfo(
        id="01550",
        name="iTRAQ8plex-116 reporter+balance reagent acylated N-terminal",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01551": PsimodInfo(
        id="01551",
        name="iTRAQ8plex-116 reporter+balance reagent N6-acylated lysine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01552": PsimodInfo(
        id="01552",
        name="iTRAQ8plex-116 reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01553": PsimodInfo(
        id="01553",
        name="iTRAQ8plex-116 reporter+balance reagent N'-acylated histidine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01554": PsimodInfo(
        id="01554",
        name="iTRAQ8plex-116 reporter+balance reagent O3-acylated serine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01555": PsimodInfo(
        id="01555",
        name="iTRAQ8plex-116 reporter+balance reagent O3-acylated threonine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01556": PsimodInfo(
        id="01556",
        name="iTRAQ8plex-117 reporter+balance reagent acylated residue",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01557": PsimodInfo(
        id="01557",
        name="iTRAQ8plex-117 reporter+balance reagent acylated N-terminal",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01558": PsimodInfo(
        id="01558",
        name="iTRAQ8plex-117 reporter+balance reagent N6-acylated lysine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01559": PsimodInfo(
        id="01559",
        name="iTRAQ8plex-117 reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01560": PsimodInfo(
        id="01560",
        name="iTRAQ8plex-117 reporter+balance reagent N'-acylated histidine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01561": PsimodInfo(
        id="01561",
        name="iTRAQ8plex-117 reporter+balance reagent O3-acylated serine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01562": PsimodInfo(
        id="01562",
        name="iTRAQ8plex-117 reporter+balance reagent O3-acylated threonine",
        formula="[12C7][13C7]H24[14N3][15N][16O3]",
        monoisotopic_mass=304.205359,
        average_mass=304.21,
        dict_composition={'12C': 7, '13C': 7, 'H': 24, '14N': 3, '15N': 1, '16O': 3},
    ),
    "01563": PsimodInfo(
        id="01563",
        name="iTRAQ8plex-118 reporter+balance reagent acylated residue",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01564": PsimodInfo(
        id="01564",
        name="iTRAQ8plex-118 reporter+balance reagent acylated N-terminal",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01565": PsimodInfo(
        id="01565",
        name="iTRAQ8plex-118 reporter+balance reagent N6-acylated lysine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01566": PsimodInfo(
        id="01566",
        name="iTRAQ8plex-118 reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01567": PsimodInfo(
        id="01567",
        name="iTRAQ8plex-118 reporter+balance reagent N'-acylated histidine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01568": PsimodInfo(
        id="01568",
        name="iTRAQ8plex-118 reporter+balance reagent O3-acylated serine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01569": PsimodInfo(
        id="01569",
        name="iTRAQ8plex-118 reporter+balance reagent O3-acylated threonine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01570": PsimodInfo(
        id="01570",
        name="iTRAQ8plex-119 reporter+balance reagent acylated residue",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01571": PsimodInfo(
        id="01571",
        name="iTRAQ8plex-119 reporter+balance reagent acylated N-terminal",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01572": PsimodInfo(
        id="01572",
        name="iTRAQ8plex-119 reporter+balance reagent N6-acylated lysine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01573": PsimodInfo(
        id="01573",
        name="iTRAQ8plex-119 reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01574": PsimodInfo(
        id="01574",
        name="iTRAQ8plex-119 reporter+balance reagent N'-acylated histidine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01575": PsimodInfo(
        id="01575",
        name="iTRAQ8plex-119 reporter+balance reagent O3-acylated serine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01576": PsimodInfo(
        id="01576",
        name="iTRAQ8plex-119 reporter+balance reagent O3-acylated threonine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01577": PsimodInfo(
        id="01577",
        name="iTRAQ8plex-121 reporter+balance reagent acylated residue",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01578": PsimodInfo(
        id="01578",
        name="iTRAQ8plex-121 reporter+balance reagent acylated N-terminal",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01579": PsimodInfo(
        id="01579",
        name="iTRAQ8plex-121 reporter+balance reagent N6-acylated lysine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01580": PsimodInfo(
        id="01580",
        name="iTRAQ8plex-121 reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01581": PsimodInfo(
        id="01581",
        name="iTRAQ8plex-121 reporter+balance reagent N'-acylated histidine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01582": PsimodInfo(
        id="01582",
        name="iTRAQ8plex-121 reporter+balance reagent O3-acylated serine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01583": PsimodInfo(
        id="01583",
        name="iTRAQ8plex-121 reporter+balance reagent O3-acylated threonine",
        formula="[12C8][13C6]H24[14N2][15N2][16O3]",
        monoisotopic_mass=304.199039,
        average_mass=304.2,
        dict_composition={'12C': 8, '13C': 6, 'H': 24, '14N': 2, '15N': 2, '16O': 3},
    ),
    "01585": PsimodInfo(
        id="01585",
        name="O-glycyl-L-serine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01586": PsimodInfo(
        id="01586",
        name="O-glycyl-L-threonine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01587": PsimodInfo(
        id="01587",
        name="O-(2-aminoethylphosphoryl)-L-serine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
    "01588": PsimodInfo(
        id="01588",
        name="O-cholinephosphoryl-L-serine",
        formula="C5H13NO3P",
        monoisotopic_mass=166.062756,
        average_mass=166.14,
        dict_composition={'C': 5, 'H': 13, 'N': 1, 'O': 3, 'P': 1},
    ),
    "01589": PsimodInfo(
        id="01589",
        name="O-(2,4-diacetamido-2,4-dideoxyglucosyl)-L-serine",
        formula="C10H16N2O5",
        monoisotopic_mass=244.105922,
        average_mass=244.25,
        dict_composition={'C': 10, 'H': 16, 'N': 2, 'O': 5},
    ),
    "01590": PsimodInfo(
        id="01590",
        name="3'-farnesyl-2',3'-dihydro-2',N2-cyclo-L-tryptophan",
        formula="C15H24",
        monoisotopic_mass=204.187801,
        average_mass=204.36,
        dict_composition={'C': 15, 'H': 24},
    ),
    "01602": PsimodInfo(
        id="01602",
        name="S-(L-lysyl)-L-methionine sulfilimine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01603": PsimodInfo(
        id="01603",
        name="2x(15)N labeled L-lysine",
        formula="[14N-2][15N2]",
        monoisotopic_mass=1.99407,
        average_mass=1.99,
        dict_composition={'14N': -2, '15N': 2},
    ),
    "01604": PsimodInfo(
        id="01604",
        name="4x(15)N labeled L-arginine",
        formula="[14N-4][15N4]",
        monoisotopic_mass=3.98814,
        average_mass=3.99,
        dict_composition={'14N': -4, '15N': 4},
    ),
    "01605": PsimodInfo(
        id="01605",
        name="5-glutamyl 2-aminoadipic acid",
        formula="C6H9NO3",
        monoisotopic_mass=143.058243,
        average_mass=143.14,
        dict_composition={'C': 6, 'H': 9, 'N': 1, 'O': 3},
    ),
    "01606": PsimodInfo(
        id="01606",
        name="5-glutamyl 2-aminoadipic 6-phosphoric anhydride",
        formula="C6H10NO6P",
        monoisotopic_mass=223.024574,
        average_mass=223.12,
        dict_composition={'C': 6, 'H': 10, 'N': 1, 'O': 6, 'P': 1},
    ),
    "01607": PsimodInfo(
        id="01607",
        name="5-glutamyl allysine",
        formula="C6H9NO2",
        monoisotopic_mass=127.063329,
        average_mass=127.14,
        dict_composition={'C': 6, 'H': 9, 'N': 1, 'O': 2},
    ),
    "01608": PsimodInfo(
        id="01608",
        name="N2-(L-isoglutamyl)-L-lysine",
        formula="C6H12N2O",
        monoisotopic_mass=128.094963,
        average_mass=128.18,
        dict_composition={'C': 6, 'H': 12, 'N': 2, 'O': 1},
    ),
    "01609": PsimodInfo(
        id="01609",
        name="7'-hydroxy-2'-alpha-mannosyl-L-tryptophan",
        formula="C6H10O6",
        monoisotopic_mass=178.047738,
        average_mass=178.14,
        dict_composition={'C': 6, 'H': 10, 'O': 6},
    ),
    "01610": PsimodInfo(
        id="01610",
        name="L-threonine methyl ester",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "01611": PsimodInfo(
        id="01611",
        name="6-(S-L-cysteinyl)-8alpha-(-3'-L-histidino)-FMN",
        formula="C17H17N4O9P",
        monoisotopic_mass=452.073315,
        average_mass=452.32,
        dict_composition={'C': 17, 'H': 17, 'N': 4, 'O': 9, 'P': 1},
    ),
    "01612": PsimodInfo(
        id="01612",
        name="3'-iodo-L-tyrosine",
        formula="H-1I",
        monoisotopic_mass=125.896648,
        average_mass=125.9,
        dict_composition={'H': -1, 'I': 1},
    ),
    "01613": PsimodInfo(
        id="01613",
        name="3',5'-diiodo-L-tyrosine",
        formula="H-2I2",
        monoisotopic_mass=251.793295,
        average_mass=251.79,
        dict_composition={'H': -2, 'I': 2},
    ),
    "01614": PsimodInfo(
        id="01614",
        name="glycyl phospho-5'-adenosine",
        formula="C10H12N5O6P",
        monoisotopic_mass=329.05252,
        average_mass=329.21,
        dict_composition={'C': 10, 'H': 12, 'N': 5, 'O': 6, 'P': 1},
    ),
    "01615": PsimodInfo(
        id="01615",
        name="glycyl cysteine dithioester",
        formula="H-2O-1S",
        monoisotopic_mass=13.961506,
        average_mass=14.05,
        dict_composition={'H': -2, 'O': -1, 'S': 1},
    ),
    "01616": PsimodInfo(
        id="01616",
        name="trithiocystine",
        formula="H-2S3",
        monoisotopic_mass=93.900563,
        average_mass=94.16,
        dict_composition={'H': -2, 'S': 3},
    ),
    "01617": PsimodInfo(
        id="01617",
        name="O-(6-phosphomannosyl)-L-threonine",
        formula="C6H11O8P",
        monoisotopic_mass=242.019154,
        average_mass=242.12,
        dict_composition={'C': 6, 'H': 11, 'O': 8, 'P': 1},
    ),
    "01618": PsimodInfo(
        id="01618",
        name="L-alanyl-L-isoaspartyl cyclopeptide",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "01622": PsimodInfo(
        id="01622",
        name="monohydroxylated tryptophan",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01623": PsimodInfo(
        id="01623",
        name="1-thioglycine (C-terminal)",
        formula="O-1S",
        monoisotopic_mass=15.977156,
        average_mass=16.06,
        dict_composition={'O': -1, 'S': 1},
    ),
    "01624": PsimodInfo(
        id="01624",
        name="(2-aminosuccinimidyl)acetic acid (Asn)",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "01625": PsimodInfo(
        id="01625",
        name="1-thioglycine",
        formula="O-1S",
        monoisotopic_mass=15.977156,
        average_mass=16.06,
        dict_composition={'O': -1, 'S': 1},
    ),
    "01626": PsimodInfo(
        id="01626",
        name="L-cystine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01631": PsimodInfo(
        id="01631",
        name="L-alanine removal",
        formula="C-3H-5N-1O-1",
        monoisotopic_mass=-71.037114,
        average_mass=-71.08,
        dict_composition={'C': -3, 'H': -5, 'N': -1, 'O': -1},
    ),
    "01632": PsimodInfo(
        id="01632",
        name="L-arginine removal",
        formula="C-6H-12N-4O-1",
        monoisotopic_mass=-156.101111,
        average_mass=-156.19,
        dict_composition={'C': -6, 'H': -12, 'N': -4, 'O': -1},
    ),
    "01633": PsimodInfo(
        id="01633",
        name="L-asparagine removal",
        formula="C-4H-6N-2O-2",
        monoisotopic_mass=-114.042927,
        average_mass=-114.1,
        dict_composition={'C': -4, 'H': -6, 'N': -2, 'O': -2},
    ),
    "01634": PsimodInfo(
        id="01634",
        name="L-aspartic acid removal",
        formula="C-4H-5N-1O-3",
        monoisotopic_mass=-115.026943,
        average_mass=-115.09,
        dict_composition={'C': -4, 'H': -5, 'N': -1, 'O': -3},
    ),
    "01635": PsimodInfo(
        id="01635",
        name="L-cysteine removal",
        formula="C-3H-5N-1O-1S-1",
        monoisotopic_mass=-103.009185,
        average_mass=-103.14,
        dict_composition={'C': -3, 'H': -5, 'N': -1, 'O': -1, 'S': -1},
    ),
    "01636": PsimodInfo(
        id="01636",
        name="L-glutamic acid removal",
        formula="C-5H-7N-1O-3",
        monoisotopic_mass=-129.042593,
        average_mass=-129.12,
        dict_composition={'C': -5, 'H': -7, 'N': -1, 'O': -3},
    ),
    "01637": PsimodInfo(
        id="01637",
        name="L-glutamine removal",
        formula="C-5H-8N-2O-2",
        monoisotopic_mass=-128.058578,
        average_mass=-128.13,
        dict_composition={'C': -5, 'H': -8, 'N': -2, 'O': -2},
    ),
    "01638": PsimodInfo(
        id="01638",
        name="glycine removal",
        formula="C-2H-3N-1O-1",
        monoisotopic_mass=-57.021464,
        average_mass=-57.05,
        dict_composition={'C': -2, 'H': -3, 'N': -1, 'O': -1},
    ),
    "01639": PsimodInfo(
        id="01639",
        name="L-histidine removal",
        formula="C-6H-7N-3O-1",
        monoisotopic_mass=-137.058912,
        average_mass=-137.14,
        dict_composition={'C': -6, 'H': -7, 'N': -3, 'O': -1},
    ),
    "01640": PsimodInfo(
        id="01640",
        name="L-isoleucine removal",
        formula="C-6H-11N-1O-1",
        monoisotopic_mass=-113.084064,
        average_mass=-113.16,
        dict_composition={'C': -6, 'H': -11, 'N': -1, 'O': -1},
    ),
    "01641": PsimodInfo(
        id="01641",
        name="L-leucine removal",
        formula="C-6H-11N-1O-1",
        monoisotopic_mass=-113.084064,
        average_mass=-113.16,
        dict_composition={'C': -6, 'H': -11, 'N': -1, 'O': -1},
    ),
    "01642": PsimodInfo(
        id="01642",
        name="L-lysine removal",
        formula="C-6H-12N-2O-1",
        monoisotopic_mass=-128.094963,
        average_mass=-128.18,
        dict_composition={'C': -6, 'H': -12, 'N': -2, 'O': -1},
    ),
    "01643": PsimodInfo(
        id="01643",
        name="L-methionine removal",
        formula="C-5H-9N-1O-1S-1",
        monoisotopic_mass=-131.040485,
        average_mass=-131.19,
        dict_composition={'C': -5, 'H': -9, 'N': -1, 'O': -1, 'S': -1},
    ),
    "01644": PsimodInfo(
        id="01644",
        name="L-phenylalanine removal",
        formula="C-9H-9N-1O-1",
        monoisotopic_mass=-147.068414,
        average_mass=-147.18,
        dict_composition={'C': -9, 'H': -9, 'N': -1, 'O': -1},
    ),
    "01645": PsimodInfo(
        id="01645",
        name="L-proline removal",
        formula="C-5H-7N-1O-1",
        monoisotopic_mass=-97.052764,
        average_mass=-97.12,
        dict_composition={'C': -5, 'H': -7, 'N': -1, 'O': -1},
    ),
    "01646": PsimodInfo(
        id="01646",
        name="L-serine removal",
        formula="C-3H-5N-1O-2",
        monoisotopic_mass=-87.032028,
        average_mass=-87.08,
        dict_composition={'C': -3, 'H': -5, 'N': -1, 'O': -2},
    ),
    "01647": PsimodInfo(
        id="01647",
        name="L-threonine removal",
        formula="C-4H-7N-1O-2",
        monoisotopic_mass=-101.047678,
        average_mass=-101.1,
        dict_composition={'C': -4, 'H': -7, 'N': -1, 'O': -2},
    ),
    "01648": PsimodInfo(
        id="01648",
        name="L-tryptophan removal",
        formula="C-11H-10N-2O-1",
        monoisotopic_mass=-186.079313,
        average_mass=-186.21,
        dict_composition={'C': -11, 'H': -10, 'N': -2, 'O': -1},
    ),
    "01649": PsimodInfo(
        id="01649",
        name="L-tyrosine removal",
        formula="C-9H-9N-1O-2",
        monoisotopic_mass=-163.063329,
        average_mass=-163.18,
        dict_composition={'C': -9, 'H': -9, 'N': -1, 'O': -2},
    ),
    "01650": PsimodInfo(
        id="01650",
        name="L-valine removal",
        formula="C-5H-9N-1O-1",
        monoisotopic_mass=-99.068414,
        average_mass=-99.13,
        dict_composition={'C': -5, 'H': -9, 'N': -1, 'O': -1},
    ),
    "01653": PsimodInfo(
        id="01653",
        name="dansyl chloride derivatized residue",
        formula="C12H11NO2S",
        monoisotopic_mass=233.05105,
        average_mass=233.29,
        dict_composition={'C': 12, 'H': 11, 'N': 1, 'O': 2, 'S': 1},
    ),
    "01654": PsimodInfo(
        id="01654",
        name="N6-Dansyl derivatized lysine",
        formula="C12H11NO2S",
        monoisotopic_mass=233.05105,
        average_mass=233.29,
        dict_composition={'C': 12, 'H': 11, 'N': 1, 'O': 2, 'S': 1},
    ),
    "01655": PsimodInfo(
        id="01655",
        name="alpha-amino-Dansyl derivatized residue",
        formula="C12H11NO2S",
        monoisotopic_mass=233.05105,
        average_mass=233.29,
        dict_composition={'C': 12, 'H': 11, 'N': 1, 'O': 2, 'S': 1},
    ),
    "01656": PsimodInfo(
        id="01656",
        name="Dabsyl chloride derivatized residue",
        formula="C14H13N3O2S",
        monoisotopic_mass=287.072848,
        average_mass=287.34,
        dict_composition={'C': 14, 'H': 13, 'N': 3, 'O': 2, 'S': 1},
    ),
    "01657": PsimodInfo(
        id="01657",
        name="N6-Dabsyl derivatized lysine",
        formula="C14H13N3O2S",
        monoisotopic_mass=287.072848,
        average_mass=287.34,
        dict_composition={'C': 14, 'H': 13, 'N': 3, 'O': 2, 'S': 1},
    ),
    "01658": PsimodInfo(
        id="01658",
        name="alpha-amino-Dabsyl derivatized residue",
        formula="C14H13N3O2S",
        monoisotopic_mass=287.072848,
        average_mass=287.34,
        dict_composition={'C': 14, 'H': 13, 'N': 3, 'O': 2, 'S': 1},
    ),
    "01659": PsimodInfo(
        id="01659",
        name="Uniblue A derivatized residue",
        formula="C22H16N2O7S2",
        monoisotopic_mass=484.039893,
        average_mass=484.5,
        dict_composition={'C': 22, 'H': 16, 'N': 2, 'O': 7, 'S': 2},
    ),
    "01660": PsimodInfo(
        id="01660",
        name="Uniblue A derivatized cysteine",
        formula="C22H16N2O7S2",
        monoisotopic_mass=484.039893,
        average_mass=484.5,
        dict_composition={'C': 22, 'H': 16, 'N': 2, 'O': 7, 'S': 2},
    ),
    "01661": PsimodInfo(
        id="01661",
        name="pyruvic acid (Tyr)",
        formula="C-6H-7N-1",
        monoisotopic_mass=-93.057849,
        average_mass=-93.13,
        dict_composition={'C': -6, 'H': -7, 'N': -1},
    ),
    "01662": PsimodInfo(
        id="01662",
        name="N5-(ADP-ribosyl)-L-glutamine",
        formula="C15H21N5O13P2",
        monoisotopic_mass=541.061109,
        average_mass=541.3,
        dict_composition={'C': 15, 'H': 21, 'N': 5, 'O': 13, 'P': 2},
    ),
    "01663": PsimodInfo(
        id="01663",
        name="O-(ADP-ribosyl)-L-threonine",
        formula="C15H21N5O13P2",
        monoisotopic_mass=541.061109,
        average_mass=541.3,
        dict_composition={'C': 15, 'H': 21, 'N': 5, 'O': 13, 'P': 2},
    ),
    "01664": PsimodInfo(
        id="01664",
        name="7'-hydroxy-L-tryptophan",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01666": PsimodInfo(
        id="01666",
        name="epicocconone derivatized residue",
        formula="C23H22O7",
        monoisotopic_mass=410.136553,
        average_mass=410.42,
        dict_composition={'C': 23, 'H': 22, 'O': 7},
    ),
    "01667": PsimodInfo(
        id="01667",
        name="N6-epicoccononyl lysine adduct",
        formula="C23H22O7",
        monoisotopic_mass=410.136553,
        average_mass=410.42,
        dict_composition={'C': 23, 'H': 22, 'O': 7},
    ),
    "01668": PsimodInfo(
        id="01668",
        name="O4-(8alpha-FAD)-L-aspartate",
        formula="C27H31N9O15P2",
        monoisotopic_mass=783.141485,
        average_mass=783.54,
        dict_composition={'C': 27, 'H': 31, 'N': 9, 'O': 15, 'P': 2},
    ),
    "01669": PsimodInfo(
        id="01669",
        name="trimethyl-L-arginine",
        formula="C3H6",
        monoisotopic_mass=42.04695,
        average_mass=42.08,
        dict_composition={'C': 3, 'H': 6},
    ),
    "01670": PsimodInfo(
        id="01670",
        name="N6-chloro-L-lysine",
        formula="ClH-1",
        monoisotopic_mass=33.961028,
        average_mass=34.44,
        dict_composition={'Cl': 1, 'H': -1},
    ),
    "01671": PsimodInfo(
        id="01671",
        name="O-(L-isoaspartyl)-L-threonine (active site intermediate)",
        formula="C4H5NO3",
        monoisotopic_mass=115.026943,
        average_mass=115.09,
        dict_composition={'C': 4, 'H': 5, 'N': 1, 'O': 3},
    ),
    "01673": PsimodInfo(
        id="01673",
        name="N-acetylaminohexosylated residue",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "01674": PsimodInfo(
        id="01674",
        name="N4-(N-acetylamino)hexosyl-L-asparagine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "01675": PsimodInfo(
        id="01675",
        name="O-(N-acetylamino)hexosyl-L-serine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "01676": PsimodInfo(
        id="01676",
        name="O-(N-acetylamino)hexosyl-L-threonine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "01677": PsimodInfo(
        id="01677",
        name="O4-(N-acetylamino)hexosyl-L-hydroxyproline",
        formula="C8H13NO6",
        monoisotopic_mass=219.074287,
        average_mass=219.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 6},
    ),
    "01678": PsimodInfo(
        id="01678",
        name="N6-carbamoyl-L-lysine",
        formula="CHNO",
        monoisotopic_mass=43.005814,
        average_mass=43.02,
        dict_composition={'C': 1, 'H': 1, 'N': 1, 'O': 1},
    ),
    "01679": PsimodInfo(
        id="01679",
        name="alpha-aminocarbamoylated residue",
        formula="CHNO",
        monoisotopic_mass=43.005814,
        average_mass=43.02,
        dict_composition={'C': 1, 'H': 1, 'N': 1, 'O': 1},
    ),
    "01680": PsimodInfo(
        id="01680",
        name="alpha-amino monomethylated residue",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "01681": PsimodInfo(
        id="01681",
        name="monomethylated L-aspartic acid",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "01682": PsimodInfo(
        id="01682",
        name="monomethylated L-cysteine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "01683": PsimodInfo(
        id="01683",
        name="monomethylated L-lysine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "01684": PsimodInfo(
        id="01684",
        name="palmitoylated-L-cysteine",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
    "01685": PsimodInfo(
        id="01685",
        name="alpha-amino palmitoylated residue",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
    "01686": PsimodInfo(
        id="01686",
        name="alpha-amino dimethylated residue",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
    "01687": PsimodInfo(
        id="01687",
        name="alpha-amino trimethylated residue",
        formula="C3H6",
        monoisotopic_mass=42.046402,
        average_mass=42.08,
        dict_composition={'C': 3, 'H': 6},
    ),
    "01688": PsimodInfo(
        id="01688",
        name="3-hydroxy-L-asparagine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01689": PsimodInfo(
        id="01689",
        name="alpha-carboxyl methylated residue",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "01690": PsimodInfo(
        id="01690",
        name="N-[(12R)-12-hydroxymyristoyl]-L-cysteine",
        formula="C14H26O2",
        monoisotopic_mass=226.19328,
        average_mass=226.36,
        dict_composition={'C': 14, 'H': 26, 'O': 2},
    ),
    "01691": PsimodInfo(
        id="01691",
        name="N-(12-ketomyristoyl)-L-cysteine",
        formula="C14H24O2",
        monoisotopic_mass=224.17763,
        average_mass=224.34,
        dict_composition={'C': 14, 'H': 24, 'O': 2},
    ),
    "01692": PsimodInfo(
        id="01692",
        name="glutamyl semialdehyde (Glu)",
        formula="O-1",
        monoisotopic_mass=-15.994915,
        average_mass=-16.0,
        dict_composition={'O': -1},
    ),
    "01693": PsimodInfo(
        id="01693",
        name="alpha-amino pyridylacetylated residue",
        formula="C7H5NO",
        monoisotopic_mass=119.037114,
        average_mass=119.12,
        dict_composition={'C': 7, 'H': 5, 'N': 1, 'O': 1},
    ),
    "01694": PsimodInfo(
        id="01694",
        name="S-(coelenterazin-3a-yl)-L-cysteine",
        formula="C26H19N3O3",
        monoisotopic_mass=421.142641,
        average_mass=421.46,
        dict_composition={'C': 26, 'H': 19, 'N': 3, 'O': 3},
    ),
    "01695": PsimodInfo(
        id="01695",
        name="alpha-amino 3-(carboxamidomethylthio)propanoylated residue",
        formula="C5H7NO2S",
        monoisotopic_mass=145.019749,
        average_mass=145.18,
        dict_composition={'C': 5, 'H': 7, 'N': 1, 'O': 2, 'S': 1},
    ),
    "01697": PsimodInfo(
        id="01697",
        name="alpha-amino 4-(2-aminoethyl)benzenesulfonylated residue",
        formula="C8H9NO2S",
        monoisotopic_mass=183.0354,
        average_mass=183.23,
        dict_composition={'C': 8, 'H': 9, 'N': 1, 'O': 2, 'S': 1},
    ),
    "01698": PsimodInfo(
        id="01698",
        name="alpha-amino trimethylated protonated-residue",
        formula="C3H7",
        monoisotopic_mass=43.054227,
        average_mass=43.09,
        dict_composition={'C': 3, 'H': 7},
    ),
    "01699": PsimodInfo(
        id="01699",
        name="protonated residue",
        formula="H",
        monoisotopic_mass=1.007276,
        average_mass=1.01,
        dict_composition={'H': 1},
    ),
    "01700": PsimodInfo(
        id="01700",
        name="alpha-amino protonated residue",
        formula="H",
        monoisotopic_mass=1.007276,
        average_mass=1.01,
        dict_composition={'H': 1},
    ),
    "01701": PsimodInfo(
        id="01701",
        name="deprotonated residue",
        formula="H-1",
        monoisotopic_mass=-1.007276,
        average_mass=-1.01,
        dict_composition={'H': -1},
    ),
    "01702": PsimodInfo(
        id="01702",
        name="alpha-carboxyl deprotonated residue",
        formula="H-1",
        monoisotopic_mass=-1.007276,
        average_mass=-1.01,
        dict_composition={'H': -1},
    ),
    "01704": PsimodInfo(
        id="01704",
        name="dehydrobutyrine (Met)",
        formula="C-1H-4S-1",
        monoisotopic_mass=-48.003371,
        average_mass=-48.1,
        dict_composition={'C': -1, 'H': -4, 'S': -1},
    ),
    "01715": PsimodInfo(
        id="01715",
        name="TMT6plex reporter+balance reagent acylated residue",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01720": PsimodInfo(
        id="01720",
        name="TMT6plex-126 reporter+balance reagent acylated residue",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01721": PsimodInfo(
        id="01721",
        name="TMT6plex-126 reporter+balance reagent acylated N-terminal",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01722": PsimodInfo(
        id="01722",
        name="TMT6plex-126 reporter+balance reagent N6-acylated lysine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01723": PsimodInfo(
        id="01723",
        name="TMT6plex-126 reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01724": PsimodInfo(
        id="01724",
        name="TMT6plex-126 reporter+balance reagent N'-acylated histidine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01725": PsimodInfo(
        id="01725",
        name="TMT6plex-126 reporter+balance reagent O3-acylated serine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01726": PsimodInfo(
        id="01726",
        name="TMT6plex-126 reporter+balance reagent O3-acylated threonine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01728": PsimodInfo(
        id="01728",
        name="TMT6plex-127 reporter+balance reagent acylated residue",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01729": PsimodInfo(
        id="01729",
        name="TMT6plex-127 reporter+balance reagent acylated N-terminal",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01730": PsimodInfo(
        id="01730",
        name="TMT6plex-127 reporter+balance reagent N6-acylated lysine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01731": PsimodInfo(
        id="01731",
        name="TMT6plex-127 reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01732": PsimodInfo(
        id="01732",
        name="TMT6plex-127 reporter+balance reagent N'-acylated histidine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01733": PsimodInfo(
        id="01733",
        name="TMT6plex-127 reporter+balance reagent O3-acylated serine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01734": PsimodInfo(
        id="01734",
        name="TMT6plex-127 reporter+balance reagent O3-acylated threonine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01736": PsimodInfo(
        id="01736",
        name="TMT6plex-128 reporter+balance reagent acylated residue",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01737": PsimodInfo(
        id="01737",
        name="TMT6plex-128 reporter+balance reagent acylated N-terminal",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01738": PsimodInfo(
        id="01738",
        name="TMT6plex-128 reporter+balance reagent N6-acylated lysine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01739": PsimodInfo(
        id="01739",
        name="TMT6plex-128 reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01740": PsimodInfo(
        id="01740",
        name="TMT6plex-128 reporter+balance reagent N'-acylated histidine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01741": PsimodInfo(
        id="01741",
        name="TMT6plex-128 reporter+balance reagent O3-acylated serine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01742": PsimodInfo(
        id="01742",
        name="TMT6plex-128 reporter+balance reagent O3-acylated threonine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01744": PsimodInfo(
        id="01744",
        name="TMT6plex-129 reporter+balance reagent acylated residue",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01745": PsimodInfo(
        id="01745",
        name="TMT6plex-129 reporter+balance reagent acylated N-terminal",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01746": PsimodInfo(
        id="01746",
        name="TMT6plex-129 reporter+balance reagent N6-acylated lysine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01747": PsimodInfo(
        id="01747",
        name="TMT6plex-129 reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01748": PsimodInfo(
        id="01748",
        name="TMT6plex-129 reporter+balance reagent N'-acylated histidine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01749": PsimodInfo(
        id="01749",
        name="TMT6plex-129 reporter+balance reagent O3-acylated serine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01750": PsimodInfo(
        id="01750",
        name="TMT6plex-129 reporter+balance reagent O3-acylated threonine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01752": PsimodInfo(
        id="01752",
        name="TMT6plex-130 reporter+balance reagent acylated residue",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01753": PsimodInfo(
        id="01753",
        name="TMT6plex-130 reporter+balance reagent acylated N-terminal",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01754": PsimodInfo(
        id="01754",
        name="TMT6plex-130 reporter+balance reagent N6-acylated lysine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01755": PsimodInfo(
        id="01755",
        name="TMT6plex-130 reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01756": PsimodInfo(
        id="01756",
        name="TMT6plex-130 reporter+balance reagent N'-acylated histidine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01757": PsimodInfo(
        id="01757",
        name="TMT6plex-130 reporter+balance reagent O3-acylated serine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01758": PsimodInfo(
        id="01758",
        name="TMT6plex-130 reporter+balance reagent O3-acylated threonine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01760": PsimodInfo(
        id="01760",
        name="TMT6plex-131 reporter+balance reagent acylated residue",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01761": PsimodInfo(
        id="01761",
        name="TMT6plex-131 reporter+balance reagent acylated N-terminal",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01762": PsimodInfo(
        id="01762",
        name="TMT6plex-131 reporter+balance reagent N6-acylated lysine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01763": PsimodInfo(
        id="01763",
        name="TMT6plex-131 reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01764": PsimodInfo(
        id="01764",
        name="TMT6plex-131 reporter+balance reagent N'-acylated histidine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01765": PsimodInfo(
        id="01765",
        name="TMT6plex-131 reporter+balance reagent O3-acylated serine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01766": PsimodInfo(
        id="01766",
        name="TMT6plex-131 reporter+balance reagent O3-acylated threonine",
        formula="[12C8][13C4]H20[14N][15N]O2",
        monoisotopic_mass=229.162932,
        average_mass=229.16,
        dict_composition={'12C': 8, '13C': 4, 'H': 20, '14N': 1, '15N': 1, 'O': 2},
    ),
    "01768": PsimodInfo(
        id="01768",
        name="O-palmitoleylated residue",
        formula="C16H28O",
        monoisotopic_mass=236.214016,
        average_mass=236.4,
        dict_composition={'C': 16, 'H': 28, 'O': 1},
    ),
    "01769": PsimodInfo(
        id="01769",
        name="O-palmitoleyl-L-threonine",
        formula="C16H28O",
        monoisotopic_mass=236.214016,
        average_mass=236.4,
        dict_composition={'C': 16, 'H': 28, 'O': 1},
    ),
    "01770": PsimodInfo(
        id="01770",
        name="O-palmitoyl-L-threonine amide",
        formula="C16H32NO",
        monoisotopic_mass=254.24839,
        average_mass=254.44,
        dict_composition={'C': 16, 'H': 32, 'N': 1, 'O': 1},
    ),
    "01773": PsimodInfo(
        id="01773",
        name="N6,N6,N6-trimethyl-L-lysine with neutral loss of trimethylamine",
        formula="C-3H-9N-1",
        monoisotopic_mass=-59.074048,
        average_mass=-59.11,
        dict_composition={'C': -3, 'H': -9, 'N': -1},
    ),
    "01774": PsimodInfo(
        id="01774",
        name="N6-octanoyl-L-lysine",
        formula="C8H14O",
        monoisotopic_mass=126.104465,
        average_mass=126.2,
        dict_composition={'C': 8, 'H': 14, 'O': 1},
    ),
    "01775": PsimodInfo(
        id="01775",
        name="5-glutamyl serotonin",
        formula="C10H9NO",
        monoisotopic_mass=159.068414,
        average_mass=159.19,
        dict_composition={'C': 10, 'H': 9, 'N': 1, 'O': 1},
    ),
    "01776": PsimodInfo(
        id="01776",
        name="S-methylthiocarbonylaminoethylcysteine (Cys)",
        formula="C4H7NOS",
        monoisotopic_mass=117.024835,
        average_mass=117.17,
        dict_composition={'C': 4, 'H': 7, 'N': 1, 'O': 1, 'S': 1},
    ),
    "01777": PsimodInfo(
        id="01777",
        name="S-(glycyl)-L-cysteine (Gly)",
        formula="C3H5NOS",
        monoisotopic_mass=103.009185,
        average_mass=103.14,
        dict_composition={'C': 3, 'H': 5, 'N': 1, 'O': 1, 'S': 1},
    ),
    "01778": PsimodInfo(
        id="01778",
        name="N-(glycyl)-L-cysteine",
        formula="C3H5NOS",
        monoisotopic_mass=103.009185,
        average_mass=103.14,
        dict_composition={'C': 3, 'H': 5, 'N': 1, 'O': 1, 'S': 1},
    ),
    "01779": PsimodInfo(
        id="01779",
        name="N6-(L-lysyl)-L-lysine",
        formula="C6H12N2O",
        monoisotopic_mass=128.094963,
        average_mass=128.18,
        dict_composition={'C': 6, 'H': 12, 'N': 2, 'O': 1},
    ),
    "01780": PsimodInfo(
        id="01780",
        name="N6-(beta-lysyl)-L-5-hydroxylysine",
        formula="C6H12N2O2",
        monoisotopic_mass=144.089878,
        average_mass=144.17,
        dict_composition={'C': 6, 'H': 12, 'N': 2, 'O': 2},
    ),
    "01781": PsimodInfo(
        id="01781",
        name="N6-butanoyl-L-lysine",
        formula="C4H6O",
        monoisotopic_mass=70.041865,
        average_mass=70.09,
        dict_composition={'C': 4, 'H': 6, 'O': 1},
    ),
    "01782": PsimodInfo(
        id="01782",
        name="N-methyl-L-serine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "01783": PsimodInfo(
        id="01783",
        name="N,N-dimethyl-L-serine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
    "01784": PsimodInfo(
        id="01784",
        name="N,N,N-trimethyl-L-serine",
        formula="C3H7",
        monoisotopic_mass=43.054227,
        average_mass=43.09,
        dict_composition={'C': 3, 'H': 7},
    ),
    "01785": PsimodInfo(
        id="01785",
        name="O-(L-isoglutamyl)-L-threonine (active site intermediate)",
        formula="C5H7NO3",
        monoisotopic_mass=129.042593,
        average_mass=129.12,
        dict_composition={'C': 5, 'H': 7, 'N': 1, 'O': 3},
    ),
    "01786": PsimodInfo(
        id="01786",
        name="3'-nitro-L-tyrosine",
        formula="H-1NO2",
        monoisotopic_mass=44.985078,
        average_mass=45.0,
        dict_composition={'H': -1, 'N': 1, 'O': 2},
    ),
    "01787": PsimodInfo(
        id="01787",
        name="5'-(L-tyros-5'-yl)amino-L-tyrosine",
        formula="H-1N",
        monoisotopic_mass=12.995249,
        average_mass=13.0,
        dict_composition={'H': -1, 'N': 1},
    ),
    "01788": PsimodInfo(
        id="01788",
        name="histidine immonium ion",
        formula="C-1HO-1",
        monoisotopic_mass=-26.987638,
        average_mass=-27.0,
        dict_composition={'C': -1, 'H': 1, 'O': -1},
    ),
    "01789": PsimodInfo(
        id="01789",
        name="phenylalanine immonium ion",
        formula="C-1HO-1",
        monoisotopic_mass=-26.987638,
        average_mass=-27.0,
        dict_composition={'C': -1, 'H': 1, 'O': -1},
    ),
    "01790": PsimodInfo(
        id="01790",
        name="tyrosine immonium ion",
        formula="C-1HO-1",
        monoisotopic_mass=-26.987638,
        average_mass=-27.0,
        dict_composition={'C': -1, 'H': 1, 'O': -1},
    ),
    "01791": PsimodInfo(
        id="01791",
        name="phosphohistidine immonium ion",
        formula="C-1HO-1",
        monoisotopic_mass=-26.987638,
        average_mass=-27.0,
        dict_composition={'C': -1, 'H': 1, 'O': -1},
    ),
    "01792": PsimodInfo(
        id="01792",
        name="phosphotyrosine immonium ion",
        formula="C-1HO-1",
        monoisotopic_mass=-26.987638,
        average_mass=-27.0,
        dict_composition={'C': -1, 'H': 1, 'O': -1},
    ),
    "01793": PsimodInfo(
        id="01793",
        name="S-carboxamidomethyl-L-cysteine sulfoxide",
        formula="C2H3NO2",
        monoisotopic_mass=73.016378,
        average_mass=73.05,
        dict_composition={'C': 2, 'H': 3, 'N': 1, 'O': 2},
    ),
    "01794": PsimodInfo(
        id="01794",
        name="1x(13)C,3x(2)H labeled monomethylated residue",
        formula="[13C][1H-1][2H3]",
        monoisotopic_mass=18.037835,
        average_mass=18.04,
        dict_composition={'13C': 1, '1H': -1, '2H': 3},
    ),
    "01795": PsimodInfo(
        id="01795",
        name="1x(13)C,3x(2)H C(6)-labeled L-methionine",
        formula="[12C-1][13C][1H-3][2H3]",
        monoisotopic_mass=4.022185,
        average_mass=4.02,
        dict_composition={'12C': -1, '13C': 1, '1H': -3, '2H': 3},
    ),
    "01796": PsimodInfo(
        id="01796",
        name="1x(13)C,3x(2)H C(6)-labeled L-methionine sulfoxide",
        formula="[12C-1][13C][1H-3][2H3]O",
        monoisotopic_mass=20.0171,
        average_mass=20.02,
        dict_composition={'12C': -1, '13C': 1, '1H': -3, '2H': 3, 'O': 1},
    ),
    "01797": PsimodInfo(
        id="01797",
        name="1'-phosphohistidine immonium ion",
        formula="C-1HO-1",
        monoisotopic_mass=-26.987638,
        average_mass=-27.0,
        dict_composition={'C': -1, 'H': 1, 'O': -1},
    ),
    "01798": PsimodInfo(
        id="01798",
        name="3'-phosphohistidine immonium ion",
        formula="C-1HO-1",
        monoisotopic_mass=-26.987638,
        average_mass=-27.0,
        dict_composition={'C': -1, 'H': 1, 'O': -1},
    ),
    "01801": PsimodInfo(
        id="01801",
        name="protonated L-serine (L-serinium) residue",
        formula="H",
        monoisotopic_mass=1.007276,
        average_mass=1.01,
        dict_composition={'H': 1},
    ),
    "01802": PsimodInfo(
        id="01802",
        name="N,N,N-trimethyl-L-serine (from L-serinium)",
        formula="C3H6",
        monoisotopic_mass=42.046402,
        average_mass=42.08,
        dict_composition={'C': 3, 'H': 6},
    ),
    "01805": PsimodInfo(
        id="01805",
        name="N-(L-isoaspartyl)-glycine (Asp)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01806": PsimodInfo(
        id="01806",
        name="N,N-dimethyl-L-leucine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
    "01807": PsimodInfo(
        id="01807",
        name="N-formyl-L-glutamic acid",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
    "01809": PsimodInfo(
        id="01809",
        name="5x(13)C,1x(15)N labeled residue",
        formula="[12C-5][13C5][14N-1][15N]",
        monoisotopic_mass=6.013809,
        average_mass=6.01,
        dict_composition={'12C': -5, '13C': 5, '14N': -1, '15N': 1},
    ),
    "01810": PsimodInfo(
        id="01810",
        name="5x(13)C,1x(15)N labeled L-proline",
        formula="[12C-5][13C5][14N-1][15N]",
        monoisotopic_mass=6.013809,
        average_mass=6.01,
        dict_composition={'12C': -5, '13C': 5, '14N': -1, '15N': 1},
    ),
    "01811": PsimodInfo(
        id="01811",
        name="5x(13)C,1x(15)N labeled L-methionine",
        formula="[12C-5][13C5][14N-1][15N]",
        monoisotopic_mass=6.013809,
        average_mass=6.01,
        dict_composition={'12C': -5, '13C': 5, '14N': -1, '15N': 1},
    ),
    "01812": PsimodInfo(
        id="01812",
        name="5x(13)C,1x(15)N labeled L-methionine sulfoxide",
        formula="[12C-5][13C5][14N-1][15N]",
        monoisotopic_mass=6.013809,
        average_mass=6.01,
        dict_composition={'12C': -5, '13C': 5, '14N': -1, '15N': 1},
    ),
    "01813": PsimodInfo(
        id="01813",
        name="morpholine-2-acetylated residue",
        formula="C6H9NO2",
        monoisotopic_mass=127.063329,
        average_mass=127.14,
        dict_composition={'C': 6, 'H': 9, 'N': 1, 'O': 2},
    ),
    "01814": PsimodInfo(
        id="01814",
        name="L-cysteine 3-hydroxy-2,5-pyridinedicarboxylic acid",
        formula="H-8N-1O-2",
        monoisotopic_mass=-54.055504,
        average_mass=-54.07,
        dict_composition={'H': -8, 'N': -1, 'O': -2},
    ),
    "01815": PsimodInfo(
        id="01815",
        name="L-glutamate thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "01816": PsimodInfo(
        id="01816",
        name="2'-hydroxy-L-tryptophan",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01817": PsimodInfo(
        id="01817",
        name="2'-oxo-L-tryptophan",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01818": PsimodInfo(
        id="01818",
        name="1'-(L-tryptophan-3'-yl)-L-tryptophan",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01819": PsimodInfo(
        id="01819",
        name="N6-succinyl-L-lysine",
        formula="C4H4O3",
        monoisotopic_mass=100.016044,
        average_mass=100.07,
        dict_composition={'C': 4, 'H': 4, 'O': 3},
    ),
    "01822": PsimodInfo(
        id="01822",
        name="cysTMT6plex-zero reporter+balance reagent cysteine disulfide",
        formula="[12C14]H25[14N3]O2S",
        monoisotopic_mass=299.166748,
        average_mass=299.17,
        dict_composition={'12C': 14, 'H': 25, '14N': 3, 'O': 2, 'S': 1},
    ),
    "01823": PsimodInfo(
        id="01823",
        name="cysTMT6plex-126 reporter+balance reagent cysteine disulfide",
        formula="[12C10][13C4]H25[14N2][15N]O2S",
        monoisotopic_mass=304.177202,
        average_mass=304.18,
        dict_composition={'12C': 10, '13C': 4, 'H': 25, '14N': 2, '15N': 1, 'O': 2, 'S': 1},
    ),
    "01824": PsimodInfo(
        id="01824",
        name="cysTMT6plex-127 reporter+balance reagent cysteine disulfide",
        formula="[12C10][13C4]H25[14N2][15N]O2S",
        monoisotopic_mass=304.177202,
        average_mass=304.18,
        dict_composition={'12C': 10, '13C': 4, 'H': 25, '14N': 2, '15N': 1, 'O': 2, 'S': 1},
    ),
    "01825": PsimodInfo(
        id="01825",
        name="cysTMT6plex-128 reporter+balance reagent cysteine disulfide",
        formula="[12C10][13C4]H25[14N2][15N]O2S",
        monoisotopic_mass=304.177202,
        average_mass=304.18,
        dict_composition={'12C': 10, '13C': 4, 'H': 25, '14N': 2, '15N': 1, 'O': 2, 'S': 1},
    ),
    "01826": PsimodInfo(
        id="01826",
        name="cysTMT6plex-129 reporter+balance reagent cysteine disulfide",
        formula="[12C10][13C4]H25[14N2][15N]O2S",
        monoisotopic_mass=304.177202,
        average_mass=304.18,
        dict_composition={'12C': 10, '13C': 4, 'H': 25, '14N': 2, '15N': 1, 'O': 2, 'S': 1},
    ),
    "01827": PsimodInfo(
        id="01827",
        name="cysTMT6plex-130 reporter+balance reagent cysteine disulfide",
        formula="[12C10][13C4]H25[14N2][15N]O2S",
        monoisotopic_mass=304.177202,
        average_mass=304.18,
        dict_composition={'12C': 10, '13C': 4, 'H': 25, '14N': 2, '15N': 1, 'O': 2, 'S': 1},
    ),
    "01828": PsimodInfo(
        id="01828",
        name="cysTMT6plex-131 reporter+balance reagent cysteine disulfide",
        formula="[12C10][13C4]H25[14N2][15N]O2S",
        monoisotopic_mass=304.177202,
        average_mass=304.18,
        dict_composition={'12C': 10, '13C': 4, 'H': 25, '14N': 2, '15N': 1, 'O': 2, 'S': 1},
    ),
    "01829": PsimodInfo(
        id="01829",
        name="S-carboxymethyl-L-cysteine sulfoxide",
        formula="C2H2O2",
        monoisotopic_mass=58.005479,
        average_mass=58.04,
        dict_composition={'C': 2, 'H': 2, 'O': 2},
    ),
    "01830": PsimodInfo(
        id="01830",
        name="S-carboxymethyl-L-cysteine sulfone",
        formula="C2H2O3",
        monoisotopic_mass=74.000394,
        average_mass=74.03,
        dict_composition={'C': 2, 'H': 2, 'O': 3},
    ),
    "01831": PsimodInfo(
        id="01831",
        name="S-carboxamidomethyl-L-cysteine sulfone",
        formula="C2H3NO3",
        monoisotopic_mass=89.011293,
        average_mass=89.05,
        dict_composition={'C': 2, 'H': 3, 'N': 1, 'O': 3},
    ),
    "01832": PsimodInfo(
        id="01832",
        name="5x(13)C-labeled residue",
        formula="[12C-5][13C5]",
        monoisotopic_mass=5.016774,
        average_mass=5.02,
        dict_composition={'12C': -5, '13C': 5},
    ),
    "01833": PsimodInfo(
        id="01833",
        name="5x(13)C-labeled L-methionine",
        formula="[12C-5][13C5]",
        monoisotopic_mass=5.016774,
        average_mass=5.02,
        dict_composition={'12C': -5, '13C': 5},
    ),
    "01834": PsimodInfo(
        id="01834",
        name="5x(13)C-labeled L-methionine sulfoxide",
        formula="[12C-5][13C5]",
        monoisotopic_mass=5.016774,
        average_mass=5.02,
        dict_composition={'12C': -5, '13C': 5},
    ),
    "01835": PsimodInfo(
        id="01835",
        name="5x(13)C-labeled L-methionine sulfone",
        formula="[12C-5][13C5]",
        monoisotopic_mass=5.016774,
        average_mass=5.02,
        dict_composition={'12C': -5, '13C': 5},
    ),
    "01836": PsimodInfo(
        id="01836",
        name="N6-[([1-(6-nitro-2H-1,3-benzodioxol-5-yl)ethoxy]carbonyl]lysine",
        formula="C10H7NO6",
        monoisotopic_mass=237.027337,
        average_mass=237.17,
        dict_composition={'C': 10, 'H': 7, 'N': 1, 'O': 6},
    ),
    "01837": PsimodInfo(
        id="01837",
        name="L-lanthionine (Cys-Cys)",
        formula="H-2S-1",
        monoisotopic_mass=-33.987721,
        average_mass=-34.08,
        dict_composition={'H': -2, 'S': -1},
    ),
    "01838": PsimodInfo(
        id="01838",
        name="L-lysinoalanine (Lys)",
        formula="C3H5NO2",
        monoisotopic_mass=87.032028,
        average_mass=87.08,
        dict_composition={'C': 3, 'H': 5, 'N': 1, 'O': 2},
    ),
    "01839": PsimodInfo(
        id="01839",
        name="L-lanthionine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01840": PsimodInfo(
        id="01840",
        name="L-allo-isoleucine",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "01841": PsimodInfo(
        id="01841",
        name="lanthionine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01842": PsimodInfo(
        id="01842",
        name="S-(2-aminovinyl)-L-cysteine",
        formula="C-1H-4O-2S-1",
        monoisotopic_mass=-79.9932,
        average_mass=-80.1,
        dict_composition={'C': -1, 'H': -4, 'O': -2, 'S': -1},
    ),
    "01843": PsimodInfo(
        id="01843",
        name="5'-chloro-L-tryptophan",
        formula="ClH-1",
        monoisotopic_mass=33.961028,
        average_mass=34.44,
        dict_composition={'Cl': 1, 'H': -1},
    ),
    "01844": PsimodInfo(
        id="01844",
        name="2-(3-methylbutanoyl)-5-hydroxyoxazole-4-carbothionic acid",
        formula="H-7N-1O",
        monoisotopic_mass=-5.062935,
        average_mass=-5.06,
        dict_composition={'H': -7, 'N': -1, 'O': 1},
    ),
    "01845": PsimodInfo(
        id="01845",
        name="L-proline 5-hydroxyoxazole-4-carbothionic acid",
        formula="H-4",
        monoisotopic_mass=-4.0313,
        average_mass=-4.03,
        dict_composition={'H': -4},
    ),
    "01846": PsimodInfo(
        id="01846",
        name="methanobactin OB3b copper complex",
        formula="CuH-10O2",
        monoisotopic_mass=84.841176,
        average_mass=85.46,
        dict_composition={'Cu': 1, 'H': -10, 'O': 2},
    ),
    "01847": PsimodInfo(
        id="01847",
        name="L-cysteine sulfinyl phosphate",
        formula="HO5P",
        monoisotopic_mass=111.95616,
        average_mass=111.98,
        dict_composition={'H': 1, 'O': 5, 'P': 1},
    ),
    "01848": PsimodInfo(
        id="01848",
        name="S-(spermidinoglutathion-S-yl)-L-cysteine",
        formula="C17H32N6O5S",
        monoisotopic_mass=432.215489,
        average_mass=432.54,
        dict_composition={'C': 17, 'H': 32, 'N': 6, 'O': 5, 'S': 1},
    ),
    "01849": PsimodInfo(
        id="01849",
        name="S-(2-aminovinyl)-D-cysteine (Cys-Cys)",
        formula="C-1H-4O-2S-1",
        monoisotopic_mass=-79.9932,
        average_mass=-80.1,
        dict_composition={'C': -1, 'H': -4, 'O': -2, 'S': -1},
    ),
    "01852": PsimodInfo(
        id="01852",
        name="L-lysinoalanine (Lys-Cys)",
        formula="H-2S-1",
        monoisotopic_mass=-33.987721,
        average_mass=-34.08,
        dict_composition={'H': -2, 'S': -1},
    ),
    "01857": PsimodInfo(
        id="01857",
        name="2-(L-cystein-S-yl)-methionine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01858": PsimodInfo(
        id="01858",
        name="S-(N-acetylamino)glucosyl-L-cysteine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "01859": PsimodInfo(
        id="01859",
        name="4-amino-3-isothiazolidinone-L-phenylalanine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01860": PsimodInfo(
        id="01860",
        name="L-cysteine bacillithiol disulfide",
        formula="C13H20N2O10S",
        monoisotopic_mass=396.083866,
        average_mass=396.37,
        dict_composition={'C': 13, 'H': 20, 'N': 2, 'O': 10, 'S': 1},
    ),
    "01864": PsimodInfo(
        id="01864",
        name="mTRAQ light reporter+balance reagent acylated residue",
        formula="[12C7]H12[14N2][16O]",
        monoisotopic_mass=140.094963,
        average_mass=140.09,
        dict_composition={'12C': 7, 'H': 12, '14N': 2, '16O': 1},
    ),
    "01865": PsimodInfo(
        id="01865",
        name="mTRAQ light reporter+balance reagent acylated N-terminal",
        formula="[12C7]H12[14N2][16O]",
        monoisotopic_mass=140.094963,
        average_mass=140.09,
        dict_composition={'12C': 7, 'H': 12, '14N': 2, '16O': 1},
    ),
    "01866": PsimodInfo(
        id="01866",
        name="mTRAQ light reporter+balance reagent N6-acylated lysine",
        formula="[12C7]H12[14N2][16O]",
        monoisotopic_mass=140.094963,
        average_mass=140.09,
        dict_composition={'12C': 7, 'H': 12, '14N': 2, '16O': 1},
    ),
    "01867": PsimodInfo(
        id="01867",
        name="mTRAQ light reporter+balance reagent O4'-acylated tyrosine",
        formula="[12C7]H12[14N2][16O]",
        monoisotopic_mass=140.094963,
        average_mass=140.09,
        dict_composition={'12C': 7, 'H': 12, '14N': 2, '16O': 1},
    ),
    "01871": PsimodInfo(
        id="01871",
        name="cyclized N-terminal S-carboxamidomethyl-L-cysteine",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "01872": PsimodInfo(
        id="01872",
        name="cyclized N-terminal S-carboxymethyl-L-cysteine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01873": PsimodInfo(
        id="01873",
        name="N-carboxy-L-alanine",
        formula="CO2",
        monoisotopic_mass=43.989829,
        average_mass=44.01,
        dict_composition={'C': 1, 'O': 2},
    ),
    "01874": PsimodInfo(
        id="01874",
        name="N-carboxy-L-valine",
        formula="CO2",
        monoisotopic_mass=43.989829,
        average_mass=44.01,
        dict_composition={'C': 1, 'O': 2},
    ),
    "01877": PsimodInfo(
        id="01877",
        name="2-(4-guanidinobutanoyl)-5-hydroxyimidazole-4-carbothionic acid",
        formula="H-6",
        monoisotopic_mass=-6.04695,
        average_mass=-6.05,
        dict_composition={'H': -6},
    ),
    "01878": PsimodInfo(
        id="01878",
        name="L-threonine 5-hydroxyoxazole-4-carbonthionic acid",
        formula="H-4",
        monoisotopic_mass=-4.0313,
        average_mass=-4.03,
        dict_composition={'H': -4},
    ),
    "01879": PsimodInfo(
        id="01879",
        name="methanobactin SB2 copper complex",
        formula="CuH-9NO",
        monoisotopic_mass=83.857161,
        average_mass=84.48,
        dict_composition={'Cu': 1, 'H': -9, 'N': 1, 'O': 1},
    ),
    "01880": PsimodInfo(
        id="01880",
        name="L-deoxyhypusine",
        formula="C4H9N",
        monoisotopic_mass=71.073499,
        average_mass=71.12,
        dict_composition={'C': 4, 'H': 9, 'N': 1},
    ),
    "01881": PsimodInfo(
        id="01881",
        name="3-(L-phenylalan-2'-yl)-L-valine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01885": PsimodInfo(
        id="01885",
        name="biotinylated residue",
        formula="C10H14N2O2S",
        monoisotopic_mass=226.077599,
        average_mass=226.29,
        dict_composition={'C': 10, 'H': 14, 'N': 2, 'O': 2, 'S': 1},
    ),
    "01887": PsimodInfo(
        id="01887",
        name="Uniblue A derivatized lysine",
        formula="C22H16N2O7S2",
        monoisotopic_mass=484.039893,
        average_mass=484.5,
        dict_composition={'C': 22, 'H': 16, 'N': 2, 'O': 7, 'S': 2},
    ),
    "01888": PsimodInfo(
        id="01888",
        name="didehydrogenated residue",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01889": PsimodInfo(
        id="01889",
        name="S-(2-succinyl)-L-cysteine",
        formula="C4H4O4",
        monoisotopic_mass=116.010959,
        average_mass=116.07,
        dict_composition={'C': 4, 'H': 4, 'O': 4},
    ),
    "01890": PsimodInfo(
        id="01890",
        name="N-[(L-histidin-1'-yl)methyl]-L-methionine (fMet)",
        formula="O-1",
        monoisotopic_mass=-15.994915,
        average_mass=-16.0,
        dict_composition={'O': -1},
    ),
    "01891": PsimodInfo(
        id="01891",
        name="N-[(L-histidin-1'-yl)methyl]-L-methionine (Met)",
        formula="C",
        monoisotopic_mass=12.0,
        average_mass=12.01,
        dict_composition={'C': 1},
    ),
    "01892": PsimodInfo(
        id="01892",
        name="N6-crotonyl-L-lysine",
        formula="C4H4O",
        monoisotopic_mass=68.026215,
        average_mass=68.07,
        dict_composition={'C': 4, 'H': 4, 'O': 1},
    ),
    "01893": PsimodInfo(
        id="01893",
        name="N6-malonyl-L-lysine",
        formula="C3H2O3",
        monoisotopic_mass=86.000394,
        average_mass=86.05,
        dict_composition={'C': 3, 'H': 2, 'O': 3},
    ),
    "01894": PsimodInfo(
        id="01894",
        name="propanoylated residue",
        formula="C3H4O",
        monoisotopic_mass=56.026215,
        average_mass=56.06,
        dict_composition={'C': 3, 'H': 4, 'O': 1},
    ),
    "01895": PsimodInfo(
        id="01895",
        name="alpha-amino 3x(12)C-labeled propanoylated residue",
        formula="[12C3]H4O",
        monoisotopic_mass=56.026215,
        average_mass=56.03,
        dict_composition={'12C': 3, 'H': 4, 'O': 1},
    ),
    "01896": PsimodInfo(
        id="01896",
        name="trifluoroacetic acid adduct",
        formula="C2F3HO2",
        monoisotopic_mass=113.992864,
        average_mass=114.02,
        dict_composition={'C': 2, 'F': 3, 'H': 1, 'O': 2},
    ),
    "01897": PsimodInfo(
        id="01897",
        name="5-hydroxy-3-methyl-L-proline (Ile)",
        formula="H-2O",
        monoisotopic_mass=13.979265,
        average_mass=13.98,
        dict_composition={'H': -2, 'O': 1},
    ),
    "01898": PsimodInfo(
        id="01898",
        name="N2,N2-dimethyl-L-arginine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
    "01899": PsimodInfo(
        id="01899",
        name="L-arginine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "01900": PsimodInfo(
        id="01900",
        name="L-cysteine 5-methyloxazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "01901": PsimodInfo(
        id="01901",
        name="L-threonine 5-methyloxazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "01902": PsimodInfo(
        id="01902",
        name="L-isoleucine oxazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "01903": PsimodInfo(
        id="01903",
        name="L-serine oxazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "01904": PsimodInfo(
        id="01904",
        name="L-serine 5-methyloxazoline-4-carboxylic acid",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01906": PsimodInfo(
        id="01906",
        name="dehydromethionine",
        formula="H-1",
        monoisotopic_mass=-1.008374,
        average_mass=-1.01,
        dict_composition={'H': -1},
    ),
    "01907": PsimodInfo(
        id="01907",
        name="dehydromethionine (from L-methioninium)",
        formula="H-2",
        monoisotopic_mass=-2.016199,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01908": PsimodInfo(
        id="01908",
        name="4-sulfophenyl isothiocyanate alpha-amino derivatized residue",
        formula="C7H5NO3S2",
        monoisotopic_mass=214.971085,
        average_mass=215.24,
        dict_composition={'C': 7, 'H': 5, 'N': 1, 'O': 3, 'S': 2},
    ),
    "01909": PsimodInfo(
        id="01909",
        name="6x(13)C labeled 4-sulfophenyl isothiocyanate alpha-amino derivatized residue",
        formula="[12C][13C6]H5NO3S2",
        monoisotopic_mass=220.991214,
        average_mass=220.99,
        dict_composition={'12C': 1, '13C': 6, 'H': 5, 'N': 1, 'O': 3, 'S': 2},
    ),
    "01910": PsimodInfo(
        id="01910",
        name="monofluorinated residue",
        formula="FH-1",
        monoisotopic_mass=17.990578,
        average_mass=17.99,
        dict_composition={'F': 1, 'H': -1},
    ),
    "01911": PsimodInfo(
        id="01911",
        name="monochlorinated residue",
        formula="ClH-1",
        monoisotopic_mass=33.961028,
        average_mass=34.44,
        dict_composition={'Cl': 1, 'H': -1},
    ),
    "01912": PsimodInfo(
        id="01912",
        name="monobrominated residue",
        formula="BrH-1",
        monoisotopic_mass=77.910512,
        average_mass=78.9,
        dict_composition={'Br': 1, 'H': -1},
    ),
    "01913": PsimodInfo(
        id="01913",
        name="monochlorinated L-tryptophan",
        formula="ClH-1",
        monoisotopic_mass=33.961028,
        average_mass=34.44,
        dict_composition={'Cl': 1, 'H': -1},
    ),
    "01914": PsimodInfo(
        id="01914",
        name="O5-galactosyl-L-hydroxylysine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "01915": PsimodInfo(
        id="01915",
        name="N-formyl-L-alanine",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
    "01916": PsimodInfo(
        id="01916",
        name="O4'-(N-acetylamino)galactosyl-L-tyrosine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "01917": PsimodInfo(
        id="01917",
        name="N6-(L-isoaspartyl)-L-lysine (Asp)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01918": PsimodInfo(
        id="01918",
        name="(2S,5S)-5-hydroxylysine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01919": PsimodInfo(
        id="01919",
        name="(2S,3S)-3-hydroxyaspartic acid",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01920": PsimodInfo(
        id="01920",
        name="3-hydroxy-L-histidine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01921": PsimodInfo(
        id="01921",
        name="D-aspartic acid (Asp)",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "01922": PsimodInfo(
        id="01922",
        name="3-methoxydehydroalanine",
        formula="C",
        monoisotopic_mass=12.0,
        average_mass=12.01,
        dict_composition={'C': 1},
    ),
    "01923": PsimodInfo(
        id="01923",
        name="N6-(L-aspartyl)-L-lysine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01924": PsimodInfo(
        id="01924",
        name="S-octanoyl-L-cysteine",
        formula="C8H14O",
        monoisotopic_mass=126.104465,
        average_mass=126.2,
        dict_composition={'C': 8, 'H': 14, 'O': 1},
    ),
    "01925": PsimodInfo(
        id="01925",
        name="(2S,5R)-5-hydroxylysine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01926": PsimodInfo(
        id="01926",
        name="3-hydroxy-L-aspartic acid",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01930": PsimodInfo(
        id="01930",
        name="D-aspartic acid (Asn)",
        formula="H-1N-1O",
        monoisotopic_mass=0.984016,
        average_mass=0.98,
        dict_composition={'H': -1, 'N': -1, 'O': 1},
    ),
    "01931": PsimodInfo(
        id="01931",
        name="N6-phospho-L-lysine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
    "01932": PsimodInfo(
        id="01932",
        name="L-lysinonorleucine",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "01933": PsimodInfo(
        id="01933",
        name="desmosine",
        formula="H-16N-3",
        monoisotopic_mass=-58.134971,
        average_mass=-58.15,
        dict_composition={'H': -16, 'N': -3},
    ),
    "01934": PsimodInfo(
        id="01934",
        name="isodesmosine",
        formula="H-16N-3",
        monoisotopic_mass=-58.134971,
        average_mass=-58.15,
        dict_composition={'H': -16, 'N': -3},
    ),
    "01935": PsimodInfo(
        id="01935",
        name="O-glucosyl-L-hydroxylysine",
        formula="C6H10O6",
        monoisotopic_mass=178.047738,
        average_mass=178.14,
        dict_composition={'C': 6, 'H': 10, 'O': 6},
    ),
    "01936": PsimodInfo(
        id="01936",
        name="N6-oleoyl-L-lysine",
        formula="C18H32O",
        monoisotopic_mass=264.245316,
        average_mass=264.45,
        dict_composition={'C': 18, 'H': 32, 'O': 1},
    ),
    "01937": PsimodInfo(
        id="01937",
        name="N-palmitoyl-L-methionine",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
    "01938": PsimodInfo(
        id="01938",
        name="2-(2-aminosuccinimidyl)-3-sulfanylpropanoic acid (Asn)",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "01939": PsimodInfo(
        id="01939",
        name="2-(2-aminosuccinimidyl)-3-sulfanylpropanoic acid (Asp)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01940": PsimodInfo(
        id="01940",
        name="2-(2-aminosuccinimidyl)pentanedioic acid (Asn)",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "01941": PsimodInfo(
        id="01941",
        name="2-(2-aminosuccinimidyl)pentanedioic acid (Asp)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01947": PsimodInfo(
        id="01947",
        name="O-(L-isoaspartyl)-L-threonine (cross-link)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01948": PsimodInfo(
        id="01948",
        name="labionin",
        formula="H-4O-2",
        monoisotopic_mass=-36.021129,
        average_mass=-36.03,
        dict_composition={'H': -4, 'O': -2},
    ),
    "01949": PsimodInfo(
        id="01949",
        name="coelenterazine",
        formula="C-1H-6O-2",
        monoisotopic_mass=-50.036779,
        average_mass=-50.06,
        dict_composition={'C': -1, 'H': -6, 'O': -2},
    ),
    "01950": PsimodInfo(
        id="01950",
        name="L-isoglutamyl histamine",
        formula="C5H6N2",
        monoisotopic_mass=94.053098,
        average_mass=94.12,
        dict_composition={'C': 5, 'H': 6, 'N': 2},
    ),
    "01951": PsimodInfo(
        id="01951",
        name="O-(L-isoglutamyl)-L-serine (Gln-Ser)",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "01952": PsimodInfo(
        id="01952",
        name="O-(L-isoglutamyl)-L-threonine (Gln-Thr)",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
    "01953": PsimodInfo(
        id="01953",
        name="tetrakis-L-cysteinyl tetrairon octanitrosyl",
        formula="Fe4H-4N8O8",
        monoisotopic_mass=459.692359,
        average_mass=459.4,
        dict_composition={'Fe': 4, 'H': -4, 'N': 8, 'O': 8},
    ),
    "01954": PsimodInfo(
        id="01954",
        name="dehydroalanine (Sec)",
        formula="H-2Se-1",
        monoisotopic_mass=-81.932171,
        average_mass=-80.99,
        dict_composition={'H': -2, 'Se': -1},
    ),
    "01955": PsimodInfo(
        id="01955",
        name="L-alaninato bis-L-aspartato tris-L-glutamato L-histidino calcium tetramanganese pentoxide",
        formula="CaH-6Mn4O5",
        monoisotopic_mass=333.642394,
        average_mass=333.78,
        dict_composition={'Ca': 1, 'H': -6, 'Mn': 4, 'O': 5},
    ),
    "01956": PsimodInfo(
        id="01956",
        name="(3R)-3-hydroxy-L-arginine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01957": PsimodInfo(
        id="01957",
        name="2-hydroxyproline",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "01958": PsimodInfo(
        id="01958",
        name="bis-L-cysteinyl bisglutathion-S-yl diiron disulfide",
        formula="C20Fe2H30N6O12S4",
        monoisotopic_mass=785.950329,
        average_mass=786.42,
        dict_composition={'C': 20, 'Fe': 2, 'H': 30, 'N': 6, 'O': 12, 'S': 4},
    ),
    "01959": PsimodInfo(
        id="01959",
        name="tris-L-cysteinyl L-glutamato tetrairon tetrasulfide",
        formula="Fe4H-4S4",
        monoisotopic_mass=347.596734,
        average_mass=347.59,
        dict_composition={'Fe': 4, 'H': -4, 'S': 4},
    ),
    "01960": PsimodInfo(
        id="01960",
        name="tris-L-cysteinyl L-glutamin-O6-yl tetrairon tetrasulfide",
        formula="Fe4H-4S4",
        monoisotopic_mass=347.596734,
        average_mass=347.59,
        dict_composition={'Fe': 4, 'H': -4, 'S': 4},
    ),
    "01962": PsimodInfo(
        id="01962",
        name="N4-(2,4-diacetamido-2,4,6-trideoxy-D-glucosyl)-L-asparagine",
        formula="C10H16N2O4",
        monoisotopic_mass=228.111007,
        average_mass=228.25,
        dict_composition={'C': 10, 'H': 16, 'N': 2, 'O': 4},
    ),
    "01963": PsimodInfo(
        id="01963",
        name="O-(2,4-diacetamido-2,4,6-trideoxy-D-glucosyl)-L-serine",
        formula="C10H16N2O4",
        monoisotopic_mass=228.111007,
        average_mass=228.25,
        dict_composition={'C': 10, 'H': 16, 'N': 2, 'O': 4},
    ),
    "01964": PsimodInfo(
        id="01964",
        name="O-(2-acetamido-4-glyceramido-2,4,6-trideoxy-D-glucosyl)-L-serine",
        formula="C11H18N2O6",
        monoisotopic_mass=274.116486,
        average_mass=274.27,
        dict_composition={'C': 11, 'H': 18, 'N': 2, 'O': 6},
    ),
    "01965": PsimodInfo(
        id="01965",
        name="2xC(13),3x(2)H labeled N6-acetyl-L-lysine",
        formula="[13C2][1H-1][2H3]O",
        monoisotopic_mass=47.036105,
        average_mass=47.04,
        dict_composition={'13C': 2, '1H': -1, '2H': 3, 'O': 1},
    ),
    "01967": PsimodInfo(
        id="01967",
        name="omega-N-(N-acetylamino)glucosyl-L-arginine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "01968": PsimodInfo(
        id="01968",
        name="(2R,3R,2'R)-3-methyllanthionine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01969": PsimodInfo(
        id="01969",
        name="S-(gamma-glutamyl-cysteinyl-glycyl)-cysteine",
        formula="C10H15N3O5S",
        monoisotopic_mass=289.073242,
        average_mass=289.31,
        dict_composition={'C': 10, 'H': 15, 'N': 3, 'O': 5, 'S': 1},
    ),
    "01970": PsimodInfo(
        id="01970",
        name="5-glutamyl glutamic acid",
        formula="C5H7NO3",
        monoisotopic_mass=129.042593,
        average_mass=129.12,
        dict_composition={'C': 5, 'H': 7, 'N': 1, 'O': 3},
    ),
    "01971": PsimodInfo(
        id="01971",
        name="5-glutamyl N2-ornithine",
        formula="C5H10N2O",
        monoisotopic_mass=114.079313,
        average_mass=114.15,
        dict_composition={'C': 5, 'H': 10, 'N': 2, 'O': 1},
    ),
    "01972": PsimodInfo(
        id="01972",
        name="5-glutamyl coenzyme A thioester",
        formula="C21H34N7O15P3S",
        monoisotopic_mass=749.104644,
        average_mass=749.52,
        dict_composition={'C': 21, 'H': 34, 'N': 7, 'O': 15, 'P': 3, 'S': 1},
    ),
    "01973": PsimodInfo(
        id="01973",
        name="N6-(3-phosphoglyceryl)-L-lysine",
        formula="C3H5O6P",
        monoisotopic_mass=167.982375,
        average_mass=168.04,
        dict_composition={'C': 3, 'H': 5, 'O': 6, 'P': 1},
    ),
    "01974": PsimodInfo(
        id="01974",
        name="S-methyl-L-methionine",
        formula="CH3",
        monoisotopic_mass=15.022927,
        average_mass=15.03,
        dict_composition={'C': 1, 'H': 3},
    ),
    "01981": PsimodInfo(
        id="01981",
        name="3-methyllanthionine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
    "01982": PsimodInfo(
        id="01982",
        name="N,N,N-trimethylglycine",
        formula="C3H7",
        monoisotopic_mass=43.054775,
        average_mass=43.09,
        dict_composition={'C': 3, 'H': 7},
    ),
    "01983": PsimodInfo(
        id="01983",
        name="N,N-dimethylglycine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
    "01984": PsimodInfo(
        id="01984",
        name="2-(L-cystein-S-yl)-L-alanine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01985": PsimodInfo(
        id="01985",
        name="2-(L-cystein-S-yl)-D-asparagine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01986": PsimodInfo(
        id="01986",
        name="2-(L-cystein-S-yl)-L-serine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01987": PsimodInfo(
        id="01987",
        name="2-(L-cystein-S-yl)-D-serine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01988": PsimodInfo(
        id="01988",
        name="2-(L-cystein-S-yl)-L-threonine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01989": PsimodInfo(
        id="01989",
        name="2-(L-cystein-S-yl)-D-tyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    "01990": PsimodInfo(
        id="01990",
        name="protonated glycine (glycinium) residue",
        formula="H",
        monoisotopic_mass=1.007276,
        average_mass=1.01,
        dict_composition={'H': 1},
    ),
    "01991": PsimodInfo(
        id="01991",
        name="N,N,N-trimethylglycine (from glycinium)",
        formula="C3H6",
        monoisotopic_mass=42.046402,
        average_mass=42.08,
        dict_composition={'C': 3, 'H': 6},
    ),
    "01994": PsimodInfo(
        id="01994",
        name="N1'-formyl-L-tryptophan",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
    "01995": PsimodInfo(
        id="01995",
        name="N2-formyl-L-tryptophan",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
    "01996": PsimodInfo(
        id="01996",
        name="butanoylated residue",
        formula="C4H6O",
        monoisotopic_mass=70.041865,
        average_mass=70.09,
        dict_composition={'C': 4, 'H': 6, 'O': 1},
    ),
    "01997": PsimodInfo(
        id="01997",
        name="N-butanoylated residue",
        formula="C4H6O",
        monoisotopic_mass=70.041865,
        average_mass=70.09,
        dict_composition={'C': 4, 'H': 6, 'O': 1},
    ),
    "01998": PsimodInfo(
        id="01998",
        name="alpha-amino butanoylated residue",
        formula="C4H6O",
        monoisotopic_mass=70.041865,
        average_mass=70.09,
        dict_composition={'C': 4, 'H': 6, 'O': 1},
    ),
    "01999": PsimodInfo(
        id="01999",
        name="N6-(11-cis)-retinylidene-L-lysine",
        formula="C20H26",
        monoisotopic_mass=266.203451,
        average_mass=266.43,
        dict_composition={'C': 20, 'H': 26},
    ),
    "02000": PsimodInfo(
        id="02000",
        name="N6-retinylidene-L-lysine (unspecified geometric isomer)",
        formula="C20H26",
        monoisotopic_mass=266.203451,
        average_mass=266.43,
        dict_composition={'C': 20, 'H': 26},
    ),
    "02001": PsimodInfo(
        id="02001",
        name="stearoylated residue",
        formula="C18H34O",
        monoisotopic_mass=266.260966,
        average_mass=266.47,
        dict_composition={'C': 18, 'H': 34, 'O': 1},
    ),
    "02002": PsimodInfo(
        id="02002",
        name="S-palmitoleylated residue",
        formula="C16H28O",
        monoisotopic_mass=236.214016,
        average_mass=236.4,
        dict_composition={'C': 16, 'H': 28, 'O': 1},
    ),
    "02006": PsimodInfo(
        id="02006",
        name="S-stearoylated residue",
        formula="C18H34O",
        monoisotopic_mass=266.260966,
        average_mass=266.47,
        dict_composition={'C': 18, 'H': 34, 'O': 1},
    ),
    "02007": PsimodInfo(
        id="02007",
        name="N6-palmitoleyl-L-lysine",
        formula="C16H28O",
        monoisotopic_mass=236.214016,
        average_mass=236.4,
        dict_composition={'C': 16, 'H': 28, 'O': 1},
    ),
    "02008": PsimodInfo(
        id="02008",
        name="N-palmitoleylated residue",
        formula="C16H28O",
        monoisotopic_mass=236.214016,
        average_mass=236.4,
        dict_composition={'C': 16, 'H': 28, 'O': 1},
    ),
    "02009": PsimodInfo(
        id="02009",
        name="N6-stearoyl-L-lysine",
        formula="C18H34O",
        monoisotopic_mass=266.260966,
        average_mass=266.47,
        dict_composition={'C': 18, 'H': 34, 'O': 1},
    ),
    "02010": PsimodInfo(
        id="02010",
        name="N-stearoylated residue",
        formula="C18H34O",
        monoisotopic_mass=266.260966,
        average_mass=266.47,
        dict_composition={'C': 18, 'H': 34, 'O': 1},
    ),
    "02011": PsimodInfo(
        id="02011",
        name="N-oleoylated residue",
        formula="C18H32O",
        monoisotopic_mass=264.245316,
        average_mass=264.45,
        dict_composition={'C': 18, 'H': 32, 'O': 1},
    ),
    "02012": PsimodInfo(
        id="02012",
        name="oleoylated residue",
        formula="C18H32O",
        monoisotopic_mass=264.245316,
        average_mass=264.45,
        dict_composition={'C': 18, 'H': 32, 'O': 1},
    ),
    "02013": PsimodInfo(
        id="02013",
        name="N6-linoloyl-L-lysine",
        formula="C18H30O",
        monoisotopic_mass=262.229666,
        average_mass=262.45,
        dict_composition={'C': 18, 'H': 30, 'O': 1},
    ),
    "02014": PsimodInfo(
        id="02014",
        name="N-linoloylated residue",
        formula="C18H30O",
        monoisotopic_mass=262.229666,
        average_mass=262.45,
        dict_composition={'C': 18, 'H': 30, 'O': 1},
    ),
    "02015": PsimodInfo(
        id="02015",
        name="linoloylated residue",
        formula="C18H30O",
        monoisotopic_mass=262.229666,
        average_mass=262.45,
        dict_composition={'C': 18, 'H': 30, 'O': 1},
    ),
    "02016": PsimodInfo(
        id="02016",
        name="N6-arachidonoyl-L-lysine",
        formula="C20H30O",
        monoisotopic_mass=286.229666,
        average_mass=286.49,
        dict_composition={'C': 20, 'H': 30, 'O': 1},
    ),
    "02017": PsimodInfo(
        id="02017",
        name="N-arachidonoylated residue",
        formula="C20H30O",
        monoisotopic_mass=286.229666,
        average_mass=286.49,
        dict_composition={'C': 20, 'H': 30, 'O': 1},
    ),
    "02018": PsimodInfo(
        id="02018",
        name="arachidonoylated residue",
        formula="C20H30O",
        monoisotopic_mass=286.229666,
        average_mass=286.49,
        dict_composition={'C': 20, 'H': 30, 'O': 1},
    ),
    "02019": PsimodInfo(
        id="02019",
        name="N6-timnodonoyl-L-lysine",
        formula="C20H28O",
        monoisotopic_mass=284.214016,
        average_mass=284.48,
        dict_composition={'C': 20, 'H': 28, 'O': 1},
    ),
    "02020": PsimodInfo(
        id="02020",
        name="N-timnodonoylated residue",
        formula="C20H28O",
        monoisotopic_mass=284.214016,
        average_mass=284.48,
        dict_composition={'C': 20, 'H': 28, 'O': 1},
    ),
    "02021": PsimodInfo(
        id="02021",
        name="timnodonoylated residue",
        formula="C20H28O",
        monoisotopic_mass=284.214016,
        average_mass=284.48,
        dict_composition={'C': 20, 'H': 28, 'O': 1},
    ),
    "02022": PsimodInfo(
        id="02022",
        name="N6-cervonoyl-L-lysine",
        formula="C22H30O",
        monoisotopic_mass=310.229666,
        average_mass=310.53,
        dict_composition={'C': 22, 'H': 30, 'O': 1},
    ),
    "02023": PsimodInfo(
        id="02023",
        name="N-cervonoylated residue",
        formula="C22H30O",
        monoisotopic_mass=310.229666,
        average_mass=310.53,
        dict_composition={'C': 22, 'H': 30, 'O': 1},
    ),
    "02024": PsimodInfo(
        id="02024",
        name="cervonoylated residue",
        formula="C22H30O",
        monoisotopic_mass=310.229666,
        average_mass=310.53,
        dict_composition={'C': 22, 'H': 30, 'O': 1},
    ),
    "02025": PsimodInfo(
        id="02025",
        name="5-glutaminyl glutamic acid",
        formula="C5H8N2O2",
        monoisotopic_mass=128.058576,
        average_mass=128.13,
        dict_composition={'C': 5, 'H': 8, 'N': 2, 'O': 2},
    ),
    "02026": PsimodInfo(
        id="02026",
        name="S-(cysteinyl-glycyl)-L-cysteine",
        formula="C5H8N2O3S",
        monoisotopic_mass=176.025563,
        average_mass=176.17,
        dict_composition={'C': 5, 'H': 8, 'N': 2, 'O': 3, 'S': 1},
    ),
    "02028": PsimodInfo(
        id="02028",
        name="iTRAQ4plex reporter+balance reagent acylated residue, average mass modification",
        formula=None,
        monoisotopic_mass=144.102411,
        average_mass=144.1,
        dict_composition=None,
    ),
    "02029": PsimodInfo(
        id="02029",
        name="cis-peptidyl-L-proline",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "02030": PsimodInfo(
        id="02030",
        name="trans-peptidyl-L-proline",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
    "02031": PsimodInfo(
        id="02031",
        name="dHex1Hex4HexNAc5 N4-glycosylated asparagine",
        formula="C70H115N5O49",
        monoisotopic_mass=1809.666065,
        average_mass=1810.68,
        dict_composition={'C': 70, 'H': 115, 'N': 5, 'O': 49},
    ),
    "02032": PsimodInfo(
        id="02032",
        name="dHex2Hex4HexNAc5 N4-glycosylated asparagine",
        formula="C76H125N5O53",
        monoisotopic_mass=1955.723974,
        average_mass=1956.82,
        dict_composition={'C': 76, 'H': 125, 'N': 5, 'O': 53},
    ),
    "02033": PsimodInfo(
        id="02033",
        name="dHex1Hex5HexNAc3 N4-glycosylated asparagine",
        formula="C60H99N3O44",
        monoisotopic_mass=1565.560143,
        average_mass=1566.43,
        dict_composition={'C': 60, 'H': 99, 'N': 3, 'O': 44},
    ),
    "02034": PsimodInfo(
        id="02034",
        name="dHex1Hex3HexNAc6 N4-glycosylated asparagine",
        formula="C72H118N6O49",
        monoisotopic_mass=1850.692614,
        average_mass=1851.73,
        dict_composition={'C': 72, 'H': 118, 'N': 6, 'O': 49},
    ),
    "02035": PsimodInfo(
        id="02035",
        name="dHex1Hex6HexNAc3 N4-glycosylated asparagine",
        formula="C66H109N3O49",
        monoisotopic_mass=1727.612967,
        average_mass=1728.57,
        dict_composition={'C': 66, 'H': 109, 'N': 3, 'O': 49},
    ),
    "02036": PsimodInfo(
        id="02036",
        name="Hex9HexNAc2 N4-glycosylated asparagine",
        formula="C70H116N2O55",
        monoisotopic_mass=1864.634156,
        average_mass=1865.66,
        dict_composition={'C': 70, 'H': 116, 'N': 2, 'O': 55},
    ),
    "02037": PsimodInfo(
        id="02037",
        name="Hex7HexNAc2 N4-glycosylated asparagine",
        formula="C58H96N2O45",
        monoisotopic_mass=1540.528509,
        average_mass=1541.38,
        dict_composition={'C': 58, 'H': 96, 'N': 2, 'O': 45},
    ),
    "02038": PsimodInfo(
        id="02038",
        name="monomethylated L-histidine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "02077": PsimodInfo(
        id="02077",
        name="nitrosylated residue",
        formula="H-1NO",
        monoisotopic_mass=28.990164,
        average_mass=29.0,
        dict_composition={'H': -1, 'N': 1, 'O': 1},
    ),
    "02079": PsimodInfo(
        id="02079",
        name="diacetylated residue",
        formula="C4H4O2",
        monoisotopic_mass=84.021129,
        average_mass=84.07,
        dict_composition={'C': 4, 'H': 4, 'O': 2},
    ),
    "02080": PsimodInfo(
        id="02080",
        name="diacetylated L-serine",
        formula="C4H4O2",
        monoisotopic_mass=84.021129,
        average_mass=84.07,
        dict_composition={'C': 4, 'H': 4, 'O': 2},
    ),
    "02081": PsimodInfo(
        id="02081",
        name="alpha-amino succinylated residue",
        formula="C4H4O3",
        monoisotopic_mass=100.016044,
        average_mass=100.07,
        dict_composition={'C': 4, 'H': 4, 'O': 3},
    ),
    "02082": PsimodInfo(
        id="02082",
        name="didehydrogenated and dehydrated residue",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
    "02083": PsimodInfo(
        id="02083",
        name="4alpha-FMN modified residue",
        formula="C17H21N4O9P",
        monoisotopic_mass=456.104615,
        average_mass=456.35,
        dict_composition={'C': 17, 'H': 21, 'N': 4, 'O': 9, 'P': 1},
    ),
    "02084": PsimodInfo(
        id="02084",
        name="6-FMN modified residue",
        formula="C17H19N4O9P",
        monoisotopic_mass=454.088965,
        average_mass=454.33,
        dict_composition={'C': 17, 'H': 19, 'N': 4, 'O': 9, 'P': 1},
    ),
    "02085": PsimodInfo(
        id="02085",
        name="8alpha-FMN modified residue",
        formula="C17H19N4O9P",
        monoisotopic_mass=454.088965,
        average_mass=454.33,
        dict_composition={'C': 17, 'H': 19, 'N': 4, 'O': 9, 'P': 1},
    ),
    "02089": PsimodInfo(
        id="02089",
        name="O-(phospho-5'-uridine)-L-serine",
        formula="C9H11N2O8P",
        monoisotopic_mass=306.025302,
        average_mass=306.17,
        dict_composition={'C': 9, 'H': 11, 'N': 2, 'O': 8, 'P': 1},
    ),
    "02090": PsimodInfo(
        id="02090",
        name="O-(phospho-5'-uridine)-L-threonine",
        formula="C9H11N2O8P",
        monoisotopic_mass=306.025302,
        average_mass=306.17,
        dict_composition={'C': 9, 'H': 11, 'N': 2, 'O': 8, 'P': 1},
    ),
    "02091": PsimodInfo(
        id="02091",
        name="O-(phospho-5'-adenosine)-L-serine",
        formula="C10H12N5O6P",
        monoisotopic_mass=329.05252,
        average_mass=329.21,
        dict_composition={'C': 10, 'H': 12, 'N': 5, 'O': 6, 'P': 1},
    ),
    "02092": PsimodInfo(
        id="02092",
        name="S-methylbutanedioic acid-L-cysteine",
        formula="C5H6O4",
        monoisotopic_mass=130.026609,
        average_mass=130.1,
        dict_composition={'C': 5, 'H': 6, 'O': 4},
    ),
    "02093": PsimodInfo(
        id="02093",
        name="N6-(2-hydroxyisobutanoyl)-L-lysine",
        formula="C4H6O2",
        monoisotopic_mass=86.036779,
        average_mass=86.09,
        dict_composition={'C': 4, 'H': 6, 'O': 2},
    ),
    "02094": PsimodInfo(
        id="02094",
        name="N6-((3R)-3-hydroxybutanoyl)-L-lysine",
        formula="C4H6O2",
        monoisotopic_mass=86.036779,
        average_mass=86.09,
        dict_composition={'C': 4, 'H': 6, 'O': 2},
    ),
    "02095": PsimodInfo(
        id="02095",
        name="N6-glutaryl-L-lysine",
        formula="C5H6O3",
        monoisotopic_mass=114.031694,
        average_mass=114.1,
        dict_composition={'C': 5, 'H': 6, 'O': 3},
    ),
    "02096": PsimodInfo(
        id="02096",
        name="N4-methyl-D-asparagine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
    "02106": PsimodInfo(
        id="02106",
        name="4-hydroxy-L-tryptophan",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "02107": PsimodInfo(
        id="02107",
        name="5-hydroxy-L-tryptophan",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "02108": PsimodInfo(
        id="02108",
        name="6-hydroxy-L-tryptophan",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "02109": PsimodInfo(
        id="02109",
        name="oxindolylalanine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "02110": PsimodInfo(
        id="02110",
        name="5-hydroxy-L-proline",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "02111": PsimodInfo(
        id="02111",
        name="(2S,4S)-5-hydroxyleucine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "02112": PsimodInfo(
        id="02112",
        name="4,5-Dihydroxytryptophan",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "02113": PsimodInfo(
        id="02113",
        name="5,6-Dihydroxytryptophan",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "02114": PsimodInfo(
        id="02114",
        name="5,7-Dihydroxytryptophan",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "02115": PsimodInfo(
        id="02115",
        name="Dioxindolylalanine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
    "02100": PsimodInfo(
        id="02100",
        name="N2-Formyl-L-asparagine",
        formula="H-1C-1N-1O2",
        monoisotopic_mass=4.97893,
        average_mass=4.97,
        dict_composition={'H': -1, 'C': -1, 'N': -1, 'O': 2},
    ),
    "02101": PsimodInfo(
        id="02101",
        name="2-Amino-4,5-dioxopentanoic acid",
        formula="H-2C-1N-2O2",
        monoisotopic_mass=-10.031969,
        average_mass=-10.04,
        dict_composition={'H': -2, 'C': -1, 'N': -2, 'O': 2},
    ),
    "02102": PsimodInfo(
        id="02102",
        name="2-hydroxy-L-phenylalanine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "02104": PsimodInfo(
        id="02104",
        name="4-hydroxy-L-phenylalanine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    "02105": PsimodInfo(
        id="02105",
        name="L-2,5-dihydroxyphenylalanine (Phe)",
        formula="O",
        monoisotopic_mass=31.989828,
        average_mass=32.0,
        dict_composition={'O': 1},
    ),
    "02116": PsimodInfo(
        id="02116",
        name="monohydroxylated phenylalanine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
    }

    PSI_NAME_TO_ID: dict[str, str] = {
        mod.name: mod.id
        for mod in PSI_MODIFICATIONS.values()
    }
except Exception as e:
    warnings.warn(
        f"Exception in psimod_data: {e}. Using empty dictionaries.",
        UserWarning,
        stacklevel=2
    )
    PSI_MODIFICATIONS: dict[str, PsimodInfo] = {}
    PSI_NAME_TO_ID: dict[str, str] = {}
