"""Auto-generated Unimod data"""
# DO NOT EDIT - generated by gen_unimod.py

from .dclass import UnimodInfo
import warnings

VERSION = "17:06:2025 11:31"


try:
    UNIMOD_MODIFICATIONS: dict[str, UnimodInfo] = {
    "1": UnimodInfo(
        id="1",
        name="Acetyl",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.0367,
        dict_composition={'H': 2, 'C': 2, 'O': 1},
    ),
    "2": UnimodInfo(
        id="2",
        name="Amidated",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.9848,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "3": UnimodInfo(
        id="3",
        name="Biotin",
        formula="C10H14N2O2S",
        monoisotopic_mass=226.077598,
        average_mass=226.2954,
        dict_composition={'H': 14, 'C': 10, 'N': 2, 'O': 2, 'S': 1},
    ),
    "4": UnimodInfo(
        id="4",
        name="Carbamidomethyl",
        formula="C2H3NO",
        monoisotopic_mass=57.021464,
        average_mass=57.0513,
        dict_composition={'H': 3, 'C': 2, 'N': 1, 'O': 1},
    ),
    "5": UnimodInfo(
        id="5",
        name="Carbamyl",
        formula="CHNO",
        monoisotopic_mass=43.005814,
        average_mass=43.0247,
        dict_composition={'H': 1, 'C': 1, 'N': 1, 'O': 1},
    ),
    "6": UnimodInfo(
        id="6",
        name="Carboxymethyl",
        formula="C2H2O2",
        monoisotopic_mass=58.005479,
        average_mass=58.0361,
        dict_composition={'H': 2, 'C': 2, 'O': 2},
    ),
    "7": UnimodInfo(
        id="7",
        name="Deamidated",
        formula="H-1N-1O",
        monoisotopic_mass=0.984016,
        average_mass=0.9848,
        dict_composition={'H': -1, 'N': -1, 'O': 1},
    ),
    "8": UnimodInfo(
        id="8",
        name="ICAT-G",
        formula="C22H38N4O6S",
        monoisotopic_mass=486.251206,
        average_mass=486.6253,
        dict_composition={'H': 38, 'C': 22, 'N': 4, 'O': 6, 'S': 1},
    ),
    "9": UnimodInfo(
        id="9",
        name="ICAT-G:2H(8)",
        formula="C22H30N4O6S",
        monoisotopic_mass=494.30142,
        average_mass=494.6746,
        dict_composition={'H': 30, 'C': 22, 'N': 4, 'O': 6, 'S': 1},
    ),
    "10": UnimodInfo(
        id="10",
        name="Met->Hse",
        formula="C-1H-2OS-1",
        monoisotopic_mass=-29.992806,
        average_mass=-30.0922,
        dict_composition={'H': -2, 'C': -1, 'O': 1, 'S': -1},
    ),
    "11": UnimodInfo(
        id="11",
        name="Met->Hsl",
        formula="C-1H-4S-1",
        monoisotopic_mass=-48.003371,
        average_mass=-48.1075,
        dict_composition={'H': -4, 'C': -1, 'S': -1},
    ),
    "12": UnimodInfo(
        id="12",
        name="ICAT-D:2H(8)",
        formula="C20H26N4O5S",
        monoisotopic_mass=450.275205,
        average_mass=450.6221,
        dict_composition={'H': 26, 'C': 20, 'N': 4, 'O': 5, 'S': 1},
    ),
    "13": UnimodInfo(
        id="13",
        name="ICAT-D",
        formula="C20H34N4O5S",
        monoisotopic_mass=442.224991,
        average_mass=442.5728,
        dict_composition={'H': 34, 'C': 20, 'N': 4, 'O': 5, 'S': 1},
    ),
    "17": UnimodInfo(
        id="17",
        name="NIPCAM",
        formula="C5H9NO",
        monoisotopic_mass=99.068414,
        average_mass=99.1311,
        dict_composition={'H': 9, 'C': 5, 'N': 1, 'O': 1},
    ),
    "20": UnimodInfo(
        id="20",
        name="PEO-Iodoacetyl-LC-Biotin",
        formula="C18H30N4O5S",
        monoisotopic_mass=414.193691,
        average_mass=414.5196,
        dict_composition={'H': 30, 'C': 18, 'N': 4, 'O': 5, 'S': 1},
    ),
    "21": UnimodInfo(
        id="21",
        name="Phospho",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.9799,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
    "23": UnimodInfo(
        id="23",
        name="Dehydrated",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.0153,
        dict_composition={'H': -2, 'O': -1},
    ),
    "24": UnimodInfo(
        id="24",
        name="Propionamide",
        formula="C3H5NO",
        monoisotopic_mass=71.037114,
        average_mass=71.0779,
        dict_composition={'H': 5, 'C': 3, 'N': 1, 'O': 1},
    ),
    "25": UnimodInfo(
        id="25",
        name="Pyridylacetyl",
        formula="C7H5NO",
        monoisotopic_mass=119.037114,
        average_mass=119.1207,
        dict_composition={'H': 5, 'C': 7, 'N': 1, 'O': 1},
    ),
    "26": UnimodInfo(
        id="26",
        name="Pyro-carbamidomethyl",
        formula="C2O",
        monoisotopic_mass=39.994915,
        average_mass=40.0208,
        dict_composition={'C': 2, 'O': 1},
    ),
    "27": UnimodInfo(
        id="27",
        name="Glu->pyro-Glu",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.0153,
        dict_composition={'H': -2, 'O': -1},
    ),
    "28": UnimodInfo(
        id="28",
        name="Gln->pyro-Glu",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.0305,
        dict_composition={'H': -3, 'N': -1},
    ),
    "29": UnimodInfo(
        id="29",
        name="SMA",
        formula="C6H9NO2",
        monoisotopic_mass=127.063329,
        average_mass=127.1412,
        dict_composition={'H': 9, 'C': 6, 'N': 1, 'O': 2},
    ),
    "30": UnimodInfo(
        id="30",
        name="Cation:Na",
        formula="H-1Na",
        monoisotopic_mass=21.981943,
        average_mass=21.9818,
        dict_composition={'H': -1, 'Na': 1},
    ),
    "31": UnimodInfo(
        id="31",
        name="Pyridylethyl",
        formula="C7H7N",
        monoisotopic_mass=105.057849,
        average_mass=105.1372,
        dict_composition={'H': 7, 'C': 7, 'N': 1},
    ),
    "34": UnimodInfo(
        id="34",
        name="Methyl",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.0266,
        dict_composition={'H': 2, 'C': 1},
    ),
    "35": UnimodInfo(
        id="35",
        name="Oxidation",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=15.9994,
        dict_composition={'O': 1},
    ),
    "36": UnimodInfo(
        id="36",
        name="Dimethyl",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.0532,
        dict_composition={'H': 4, 'C': 2},
    ),
    "37": UnimodInfo(
        id="37",
        name="Trimethyl",
        formula="C3H6",
        monoisotopic_mass=42.04695,
        average_mass=42.0797,
        dict_composition={'H': 6, 'C': 3},
    ),
    "39": UnimodInfo(
        id="39",
        name="Methylthio",
        formula="CH2S",
        monoisotopic_mass=45.987721,
        average_mass=46.0916,
        dict_composition={'H': 2, 'C': 1, 'S': 1},
    ),
    "40": UnimodInfo(
        id="40",
        name="Sulfo",
        formula="O3S",
        monoisotopic_mass=79.956815,
        average_mass=80.0632,
        dict_composition={'O': 3, 'S': 1},
    ),
    "41": UnimodInfo(
        id="41",
        name="Hex",
        formula="C6H10O5",
        monoisotopic_mass=162.052824,
        average_mass=162.1406,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
    "42": UnimodInfo(
        id="42",
        name="Lipoyl",
        formula="C8H12OS2",
        monoisotopic_mass=188.032956,
        average_mass=188.3103,
        dict_composition={'H': 12, 'C': 8, 'O': 1, 'S': 2},
    ),
    "43": UnimodInfo(
        id="43",
        name="HexNAc",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.1925,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
    "44": UnimodInfo(
        id="44",
        name="Farnesyl",
        formula="C15H24",
        monoisotopic_mass=204.187801,
        average_mass=204.3511,
        dict_composition={'H': 24, 'C': 15},
    ),
    "45": UnimodInfo(
        id="45",
        name="Myristoyl",
        formula="C14H26O",
        monoisotopic_mass=210.198366,
        average_mass=210.3556,
        dict_composition={'H': 26, 'C': 14, 'O': 1},
    ),
    "46": UnimodInfo(
        id="46",
        name="PyridoxalPhosphate",
        formula="C8H8NO5P",
        monoisotopic_mass=229.014009,
        average_mass=229.1266,
        dict_composition={'H': 8, 'C': 8, 'N': 1, 'O': 5, 'P': 1},
    ),
    "47": UnimodInfo(
        id="47",
        name="Palmitoyl",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.4088,
        dict_composition={'H': 30, 'C': 16, 'O': 1},
    ),
    "48": UnimodInfo(
        id="48",
        name="GeranylGeranyl",
        formula="C20H32",
        monoisotopic_mass=272.250401,
        average_mass=272.4681,
        dict_composition={'H': 32, 'C': 20},
    ),
    "49": UnimodInfo(
        id="49",
        name="Phosphopantetheine",
        formula="C11H21N2O6PS",
        monoisotopic_mass=340.085794,
        average_mass=340.333,
        dict_composition={'H': 21, 'C': 11, 'N': 2, 'O': 6, 'P': 1, 'S': 1},
    ),
    "50": UnimodInfo(
        id="50",
        name="FAD",
        formula="C27H31N9O15P2",
        monoisotopic_mass=783.141486,
        average_mass=783.5339,
        dict_composition={'H': 31, 'C': 27, 'N': 9, 'O': 15, 'P': 2},
    ),
    "51": UnimodInfo(
        id="51",
        name="Tripalmitate",
        formula="C51H96O5",
        monoisotopic_mass=788.725777,
        average_mass=789.3049,
        dict_composition={'H': 96, 'C': 51, 'O': 5},
    ),
    "52": UnimodInfo(
        id="52",
        name="Guanidinyl",
        formula="CH2N2",
        monoisotopic_mass=42.021798,
        average_mass=42.04,
        dict_composition={'H': 2, 'C': 1, 'N': 2},
    ),
    "53": UnimodInfo(
        id="53",
        name="HNE",
        formula="C9H16O2",
        monoisotopic_mass=156.11503,
        average_mass=156.2221,
        dict_composition={'H': 16, 'C': 9, 'O': 2},
    ),
    "54": UnimodInfo(
        id="54",
        name="Glucuronyl",
        formula="C6H8O6",
        monoisotopic_mass=176.032088,
        average_mass=176.1241,
        dict_composition={'C': 6, 'H': 8, 'O': 6},
    ),
    "55": UnimodInfo(
        id="55",
        name="Glutathione",
        formula="C10H15N3O6S",
        monoisotopic_mass=305.068156,
        average_mass=305.3076,
        dict_composition={'H': 15, 'C': 10, 'N': 3, 'O': 6, 'S': 1},
    ),
    "56": UnimodInfo(
        id="56",
        name="Acetyl:2H(3)",
        formula="C2H-1O",
        monoisotopic_mass=45.029395,
        average_mass=45.0552,
        dict_composition={'H': -1, 'C': 2, 'O': 1},
    ),
    "58": UnimodInfo(
        id="58",
        name="Propionyl",
        formula="C3H4O",
        monoisotopic_mass=56.026215,
        average_mass=56.0633,
        dict_composition={'H': 4, 'C': 3, 'O': 1},
    ),
    "59": UnimodInfo(
        id="59",
        name="Propionyl:13C(3)",
        formula="H4O",
        monoisotopic_mass=59.036279,
        average_mass=59.0412,
        dict_composition={'H': 4, 'C': 0, 'O': 1},
    ),
    "60": UnimodInfo(
        id="60",
        name="GIST-Quat",
        formula="C7H13NO",
        monoisotopic_mass=127.099714,
        average_mass=127.1842,
        dict_composition={'H': 13, 'C': 7, 'N': 1, 'O': 1},
    ),
    "61": UnimodInfo(
        id="61",
        name="GIST-Quat:2H(3)",
        formula="C7H10NO",
        monoisotopic_mass=130.118544,
        average_mass=130.2027,
        dict_composition={'H': 10, 'C': 7, 'N': 1, 'O': 1},
    ),
    "62": UnimodInfo(
        id="62",
        name="GIST-Quat:2H(6)",
        formula="C7H7NO",
        monoisotopic_mass=133.137375,
        average_mass=133.2212,
        dict_composition={'H': 7, 'C': 7, 'N': 1, 'O': 1},
    ),
    "63": UnimodInfo(
        id="63",
        name="GIST-Quat:2H(9)",
        formula="C7H4NO",
        monoisotopic_mass=136.156205,
        average_mass=136.2397,
        dict_composition={'H': 4, 'C': 7, 'N': 1, 'O': 1},
    ),
    "64": UnimodInfo(
        id="64",
        name="Succinyl",
        formula="C4H4O3",
        monoisotopic_mass=100.016044,
        average_mass=100.0728,
        dict_composition={'H': 4, 'C': 4, 'O': 3},
    ),
    "65": UnimodInfo(
        id="65",
        name="Succinyl:2H(4)",
        formula="C4O3",
        monoisotopic_mass=104.041151,
        average_mass=104.0974,
        dict_composition={'H': 0, 'C': 4, 'O': 3},
    ),
    "66": UnimodInfo(
        id="66",
        name="Succinyl:13C(4)",
        formula="H4O3",
        monoisotopic_mass=104.029463,
        average_mass=104.0434,
        dict_composition={'H': 4, 'C': 0, 'O': 3},
    ),
    "89": UnimodInfo(
        id="89",
        name="Iminobiotin",
        formula="C10H15N3OS",
        monoisotopic_mass=225.093583,
        average_mass=225.3106,
        dict_composition={'H': 15, 'C': 10, 'N': 3, 'O': 1, 'S': 1},
    ),
    "90": UnimodInfo(
        id="90",
        name="ESP",
        formula="C16H26N4O2S",
        monoisotopic_mass=338.177647,
        average_mass=338.4682,
        dict_composition={'H': 26, 'C': 16, 'N': 4, 'O': 2, 'S': 1},
    ),
    "91": UnimodInfo(
        id="91",
        name="ESP:2H(10)",
        formula="C16H16N4O2S",
        monoisotopic_mass=348.240414,
        average_mass=348.5299,
        dict_composition={'H': 16, 'C': 16, 'N': 4, 'O': 2, 'S': 1},
    ),
    "92": UnimodInfo(
        id="92",
        name="NHS-LC-Biotin",
        formula="C16H25N3O3S",
        monoisotopic_mass=339.161662,
        average_mass=339.453,
        dict_composition={'H': 25, 'C': 16, 'N': 3, 'O': 3, 'S': 1},
    ),
    "93": UnimodInfo(
        id="93",
        name="EDT-maleimide-PEO-biotin",
        formula="C25H39N5O6S3",
        monoisotopic_mass=601.206246,
        average_mass=601.8021,
        dict_composition={'H': 39, 'C': 25, 'N': 5, 'O': 6, 'S': 3},
    ),
    "94": UnimodInfo(
        id="94",
        name="IMID",
        formula="C3H4N2",
        monoisotopic_mass=68.037448,
        average_mass=68.0773,
        dict_composition={'H': 4, 'C': 3, 'N': 2},
    ),
    "95": UnimodInfo(
        id="95",
        name="IMID:2H(4)",
        formula="C3N2",
        monoisotopic_mass=72.062555,
        average_mass=72.1019,
        dict_composition={'H': 0, 'C': 3, 'N': 2},
    ),
    "97": UnimodInfo(
        id="97",
        name="Propionamide:2H(3)",
        formula="C3H2NO",
        monoisotopic_mass=74.055944,
        average_mass=74.0964,
        dict_composition={'H': 2, 'C': 3, 'N': 1, 'O': 1},
    ),
    "105": UnimodInfo(
        id="105",
        name="ICAT-C",
        formula="C10H17N3O3",
        monoisotopic_mass=227.126991,
        average_mass=227.2603,
        dict_composition={'H': 17, 'C': 10, 'N': 3, 'O': 3},
    ),
    "106": UnimodInfo(
        id="106",
        name="ICAT-C:13C(9)",
        formula="CH17N3O3",
        monoisotopic_mass=236.157185,
        average_mass=236.1942,
        dict_composition={'H': 17, 'C': 1, 'N': 3, 'O': 3},
    ),
    "107": UnimodInfo(
        id="107",
        name="FormylMet",
        formula="C6H9NO2S",
        monoisotopic_mass=159.035399,
        average_mass=159.2062,
        dict_composition={'H': 9, 'C': 6, 'N': 1, 'O': 2, 'S': 1},
    ),
    "108": UnimodInfo(
        id="108",
        name="Nethylmaleimide",
        formula="C6H7NO2",
        monoisotopic_mass=125.047679,
        average_mass=125.1253,
        dict_composition={'H': 7, 'C': 6, 'N': 1, 'O': 2},
    ),
    "112": UnimodInfo(
        id="112",
        name="OxLysBiotinRed",
        formula="C16H26N4O3S",
        monoisotopic_mass=354.172562,
        average_mass=354.4676,
        dict_composition={'H': 26, 'C': 16, 'N': 4, 'O': 3, 'S': 1},
    ),
    "113": UnimodInfo(
        id="113",
        name="OxLysBiotin",
        formula="C16H24N4O3S",
        monoisotopic_mass=352.156911,
        average_mass=352.4518,
        dict_composition={'H': 24, 'C': 16, 'N': 4, 'O': 3, 'S': 1},
    ),
    "114": UnimodInfo(
        id="114",
        name="OxProBiotinRed",
        formula="C16H29N5O3S",
        monoisotopic_mass=371.199111,
        average_mass=371.4982,
        dict_composition={'H': 29, 'C': 16, 'N': 5, 'O': 3, 'S': 1},
    ),
    "115": UnimodInfo(
        id="115",
        name="OxProBiotin",
        formula="C16H27N5O3S",
        monoisotopic_mass=369.183461,
        average_mass=369.4823,
        dict_composition={'H': 27, 'C': 16, 'N': 5, 'O': 3, 'S': 1},
    ),
    "116": UnimodInfo(
        id="116",
        name="OxArgBiotin",
        formula="C15H22N2O3S",
        monoisotopic_mass=310.135113,
        average_mass=310.4118,
        dict_composition={'H': 22, 'C': 15, 'N': 2, 'O': 3, 'S': 1},
    ),
    "117": UnimodInfo(
        id="117",
        name="OxArgBiotinRed",
        formula="C15H24N2O3S",
        monoisotopic_mass=312.150763,
        average_mass=312.4277,
        dict_composition={'H': 24, 'C': 15, 'N': 2, 'O': 3, 'S': 1},
    ),
    "118": UnimodInfo(
        id="118",
        name="EDT-iodoacetyl-PEO-biotin",
        formula="C20H34N4O4S3",
        monoisotopic_mass=490.174218,
        average_mass=490.7034,
        dict_composition={'H': 34, 'C': 20, 'N': 4, 'O': 4, 'S': 3},
    ),
    "119": UnimodInfo(
        id="119",
        name="IBTP",
        formula="C22H21P",
        monoisotopic_mass=316.138088,
        average_mass=316.3759,
        dict_composition={'H': 21, 'C': 22, 'P': 1},
    ),
    "121": UnimodInfo(
        id="121",
        name="GG",
        formula="C4H6N2O2",
        monoisotopic_mass=114.042927,
        average_mass=114.1026,
        dict_composition={'H': 6, 'C': 4, 'N': 2, 'O': 2},
    ),
    "122": UnimodInfo(
        id="122",
        name="Formyl",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.0101,
        dict_composition={'C': 1, 'O': 1},
    ),
    "123": UnimodInfo(
        id="123",
        name="ICAT-H",
        formula="C15H20ClNO6",
        monoisotopic_mass=345.097915,
        average_mass=345.7754,
        dict_composition={'H': 20, 'C': 15, 'N': 1, 'O': 6, 'Cl': 1},
    ),
    "124": UnimodInfo(
        id="124",
        name="ICAT-H:13C(6)",
        formula="C9H20ClNO6",
        monoisotopic_mass=351.118044,
        average_mass=351.7313,
        dict_composition={'H': 20, 'C': 9, 'N': 1, 'O': 6, 'Cl': 1},
    ),
    "126": UnimodInfo(
        id="126",
        name="Xlink:DTSSP[88]",
        formula="C3H4OS",
        monoisotopic_mass=87.998285,
        average_mass=88.1283,
        dict_composition={'H': 4, 'C': 3, 'O': 1, 'S': 1},
    ),
    "127": UnimodInfo(
        id="127",
        name="Fluoro",
        formula="H-1F",
        monoisotopic_mass=17.990578,
        average_mass=17.9905,
        dict_composition={'H': -1, 'F': 1},
    ),
    "128": UnimodInfo(
        id="128",
        name="Fluorescein",
        formula="C22H13NO6",
        monoisotopic_mass=387.074287,
        average_mass=387.3417,
        dict_composition={'H': 13, 'C': 22, 'N': 1, 'O': 6},
    ),
    "129": UnimodInfo(
        id="129",
        name="Iodo",
        formula="H-1I",
        monoisotopic_mass=125.896648,
        average_mass=125.8965,
        dict_composition={'H': -1, 'I': 1},
    ),
    "130": UnimodInfo(
        id="130",
        name="Diiodo",
        formula="H-2I2",
        monoisotopic_mass=251.793296,
        average_mass=251.7931,
        dict_composition={'H': -2, 'I': 2},
    ),
    "131": UnimodInfo(
        id="131",
        name="Triiodo",
        formula="H-3I3",
        monoisotopic_mass=377.689944,
        average_mass=377.6896,
        dict_composition={'H': -3, 'I': 3},
    ),
    "134": UnimodInfo(
        id="134",
        name="Myristoleyl",
        formula="C14H24O",
        monoisotopic_mass=208.182715,
        average_mass=208.3398,
        dict_composition={'H': 24, 'C': 14, 'O': 1},
    ),
    "135": UnimodInfo(
        id="135",
        name="Myristoyl+Delta:H(-4)",
        formula="C14H22O",
        monoisotopic_mass=206.167065,
        average_mass=206.3239,
        dict_composition={'H': 22, 'C': 14, 'O': 1},
    ),
    "136": UnimodInfo(
        id="136",
        name="Benzoyl",
        formula="C7H4O",
        monoisotopic_mass=104.026215,
        average_mass=104.1061,
        dict_composition={'H': 4, 'C': 7, 'O': 1},
    ),
    "137": UnimodInfo(
        id="137",
        name="Hex(5)HexNAc(2)",
        formula="C46H76N2O35",
        monoisotopic_mass=1216.422863,
        average_mass=1217.088,
        dict_composition={'C': 46, 'H': 76, 'O': 35, 'N': 2},
    ),
    "139": UnimodInfo(
        id="139",
        name="Dansyl",
        formula="C12H11NO2S",
        monoisotopic_mass=233.051049,
        average_mass=233.2862,
        dict_composition={'H': 11, 'C': 12, 'N': 1, 'O': 2, 'S': 1},
    ),
    "140": UnimodInfo(
        id="140",
        name="a-type-ion",
        formula="C-1H-2O-2",
        monoisotopic_mass=-46.005479,
        average_mass=-46.0254,
        dict_composition={'H': -2, 'C': -1, 'O': -2},
    ),
    "141": UnimodInfo(
        id="141",
        name="Amidine",
        formula="C2H3N",
        monoisotopic_mass=41.026549,
        average_mass=41.0519,
        dict_composition={'H': 3, 'C': 2, 'N': 1},
    ),
    "142": UnimodInfo(
        id="142",
        name="HexNAc(1)dHex(1)",
        formula="C14H23NO9",
        monoisotopic_mass=349.137281,
        average_mass=349.3337,
        dict_composition={'C': 14, 'H': 23, 'O': 9, 'N': 1},
    ),
    "143": UnimodInfo(
        id="143",
        name="HexNAc(2)",
        formula="C16H26N2O10",
        monoisotopic_mass=406.158745,
        average_mass=406.385,
        dict_composition={'C': 16, 'H': 26, 'N': 2, 'O': 10},
    ),
    "144": UnimodInfo(
        id="144",
        name="Hex(3)",
        formula="C18H30O15",
        monoisotopic_mass=486.158471,
        average_mass=486.4218,
        dict_composition={'C': 18, 'H': 30, 'O': 15},
    ),
    "145": UnimodInfo(
        id="145",
        name="HexNAc(1)dHex(2)",
        formula="C20H33NO13",
        monoisotopic_mass=495.19519,
        average_mass=495.4749,
        dict_composition={'C': 20, 'H': 33, 'O': 13, 'N': 1},
    ),
    "146": UnimodInfo(
        id="146",
        name="Hex(1)HexNAc(1)dHex(1)",
        formula="C20H33NO14",
        monoisotopic_mass=511.190105,
        average_mass=511.4743,
        dict_composition={'C': 20, 'H': 33, 'O': 14, 'N': 1},
    ),
    "147": UnimodInfo(
        id="147",
        name="HexNAc(2)dHex(1)",
        formula="C22H36N2O14",
        monoisotopic_mass=552.216654,
        average_mass=552.5262,
        dict_composition={'C': 22, 'H': 36, 'O': 14, 'N': 2},
    ),
    "148": UnimodInfo(
        id="148",
        name="Hex(1)HexNAc(2)",
        formula="C22H36N2O15",
        monoisotopic_mass=568.211569,
        average_mass=568.5256,
        dict_composition={'C': 22, 'H': 36, 'O': 15, 'N': 2},
    ),
    "149": UnimodInfo(
        id="149",
        name="Hex(1)HexNAc(1)NeuAc(1)",
        formula="C25H40N2O18",
        monoisotopic_mass=656.227613,
        average_mass=656.5877,
        dict_composition={'C': 25, 'H': 40, 'O': 18, 'N': 2},
    ),
    "150": UnimodInfo(
        id="150",
        name="HexNAc(2)dHex(2)",
        formula="C28H46N2O18",
        monoisotopic_mass=698.274563,
        average_mass=698.6674,
        dict_composition={'C': 28, 'H': 46, 'O': 18, 'N': 2},
    ),
    "151": UnimodInfo(
        id="151",
        name="Hex(1)HexNAc(2)Pent(1)",
        formula="C27H44N2O19",
        monoisotopic_mass=700.253828,
        average_mass=700.6403,
        dict_composition={'C': 27, 'H': 44, 'O': 19, 'N': 2},
    ),
    "152": UnimodInfo(
        id="152",
        name="Hex(1)HexNAc(2)dHex(1)",
        formula="C28H46N2O19",
        monoisotopic_mass=714.269478,
        average_mass=714.6668,
        dict_composition={'C': 28, 'H': 46, 'O': 19, 'N': 2},
    ),
    "153": UnimodInfo(
        id="153",
        name="Hex(2)HexNAc(2)",
        formula="C28H46N2O20",
        monoisotopic_mass=730.264392,
        average_mass=730.6662,
        dict_composition={'C': 28, 'H': 46, 'O': 20, 'N': 2},
    ),
    "154": UnimodInfo(
        id="154",
        name="Hex(3)HexNAc(1)Pent(1)",
        formula="C31H51NO24",
        monoisotopic_mass=821.280102,
        average_mass=821.7289,
        dict_composition={'C': 31, 'H': 51, 'O': 24, 'N': 1},
    ),
    "155": UnimodInfo(
        id="155",
        name="Hex(1)HexNAc(2)dHex(1)Pent(1)",
        formula="C33H54N2O23",
        monoisotopic_mass=846.311736,
        average_mass=846.7815,
        dict_composition={'C': 33, 'H': 54, 'O': 23, 'N': 2},
    ),
    "156": UnimodInfo(
        id="156",
        name="Hex(1)HexNAc(2)dHex(2)",
        formula="C34H56N2O23",
        monoisotopic_mass=860.327386,
        average_mass=860.808,
        dict_composition={'C': 34, 'H': 56, 'O': 23, 'N': 2},
    ),
    "157": UnimodInfo(
        id="157",
        name="Hex(2)HexNAc(2)Pent(1)",
        formula="C33H54N2O24",
        monoisotopic_mass=862.306651,
        average_mass=862.7809,
        dict_composition={'C': 33, 'H': 54, 'O': 24, 'N': 2},
    ),
    "158": UnimodInfo(
        id="158",
        name="Hex(2)HexNAc(2)dHex(1)",
        formula="C34H56N2O24",
        monoisotopic_mass=876.322301,
        average_mass=876.8074,
        dict_composition={'C': 34, 'H': 56, 'O': 24, 'N': 2},
    ),
    "159": UnimodInfo(
        id="159",
        name="Hex(3)HexNAc(2)",
        formula="C34H56N2O25",
        monoisotopic_mass=892.317216,
        average_mass=892.8068,
        dict_composition={'C': 34, 'H': 56, 'O': 25, 'N': 2},
    ),
    "160": UnimodInfo(
        id="160",
        name="Hex(1)HexNAc(1)NeuAc(2)",
        formula="C36H57N3O26",
        monoisotopic_mass=947.323029,
        average_mass=947.8423,
        dict_composition={'C': 36, 'H': 57, 'O': 26, 'N': 3},
    ),
    "161": UnimodInfo(
        id="161",
        name="Hex(3)HexNAc(2)Phos(1)",
        formula="C34H57N2O28P",
        monoisotopic_mass=972.283547,
        average_mass=972.7867,
        dict_composition={'H': 57, 'O': 28, 'P': 1, 'C': 34, 'N': 2},
    ),
    "162": UnimodInfo(
        id="162",
        name="Delta:S(-1)Se(1)",
        formula="S-1Se",
        monoisotopic_mass=47.944449,
        average_mass=46.895,
        dict_composition={'S': -1, 'Se': 1},
    ),
    "170": UnimodInfo(
        id="170",
        name="Delta:H(-1)N(-1)18O(1)",
        formula="H-1N-1",
        monoisotopic_mass=2.988261,
        average_mass=2.9845,
        dict_composition={'H': -1, 'N': -1, 'O': 0},
    ),
    "171": UnimodInfo(
        id="171",
        name="NBS:13C(6)",
        formula="H3NO2S",
        monoisotopic_mass=159.008578,
        average_mass=159.1144,
        dict_composition={'H': 3, 'C': 0, 'N': 1, 'O': 2, 'S': 1},
    ),
    "172": UnimodInfo(
        id="172",
        name="NBS",
        formula="C6H3NO2S",
        monoisotopic_mass=152.988449,
        average_mass=153.1585,
        dict_composition={'H': 3, 'C': 6, 'N': 1, 'O': 2, 'S': 1},
    ),
    "176": UnimodInfo(
        id="176",
        name="BHT",
        formula="C15H22O",
        monoisotopic_mass=218.167065,
        average_mass=218.3346,
        dict_composition={'H': 22, 'C': 15, 'O': 1},
    ),
    "178": UnimodInfo(
        id="178",
        name="DAET",
        formula="C4H9NO-1S",
        monoisotopic_mass=87.050655,
        average_mass=87.1866,
        dict_composition={'H': 9, 'C': 4, 'N': 1, 'O': -1, 'S': 1},
    ),
    "184": UnimodInfo(
        id="184",
        name="Label:13C(9)",
        formula="C-9",
        monoisotopic_mass=9.030193,
        average_mass=8.9339,
        dict_composition={'C': -9},
    ),
    "185": UnimodInfo(
        id="185",
        name="Label:13C(9)+Phospho",
        formula="C-9HO3P",
        monoisotopic_mass=88.996524,
        average_mass=88.9138,
        dict_composition={'H': 1, 'C': -9, 'O': 3, 'P': 1},
    ),
    "186": UnimodInfo(
        id="186",
        name="HPG",
        formula="C8H4O2",
        monoisotopic_mass=132.021129,
        average_mass=132.1162,
        dict_composition={'H': 4, 'C': 8, 'O': 2},
    ),
    "187": UnimodInfo(
        id="187",
        name="2HPG",
        formula="C16H10O5",
        monoisotopic_mass=282.052824,
        average_mass=282.2476,
        dict_composition={'H': 10, 'C': 16, 'O': 5},
    ),
    "188": UnimodInfo(
        id="188",
        name="Label:13C(6)",
        formula="C-6",
        monoisotopic_mass=6.020129,
        average_mass=5.9559,
        dict_composition={'C': -6},
    ),
    "193": UnimodInfo(
        id="193",
        name="Label:18O(2)",
        formula="O-2",
        monoisotopic_mass=4.008491,
        average_mass=3.9995,
        dict_composition={'O': -2},
    ),
    "194": UnimodInfo(
        id="194",
        name="AccQTag",
        formula="C10H6N2O",
        monoisotopic_mass=170.048013,
        average_mass=170.1674,
        dict_composition={'H': 6, 'C': 10, 'N': 2, 'O': 1},
    ),
    "195": UnimodInfo(
        id="195",
        name="QAT",
        formula="C9H19N2O",
        monoisotopic_mass=171.149738,
        average_mass=171.26,
        dict_composition={'H': 19, 'C': 9, 'N': 2, 'O': 1},
    ),
    "196": UnimodInfo(
        id="196",
        name="QAT:2H(3)",
        formula="C9H16N2O",
        monoisotopic_mass=174.168569,
        average_mass=174.2784,
        dict_composition={'H': 16, 'C': 9, 'N': 2, 'O': 1},
    ),
    "197": UnimodInfo(
        id="197",
        name="EQAT",
        formula="C10H20N2O",
        monoisotopic_mass=184.157563,
        average_mass=184.2786,
        dict_composition={'H': 20, 'C': 10, 'N': 2, 'O': 1},
    ),
    "198": UnimodInfo(
        id="198",
        name="EQAT:2H(5)",
        formula="C10H15N2O",
        monoisotopic_mass=189.188947,
        average_mass=189.3094,
        dict_composition={'H': 15, 'C': 10, 'N': 2, 'O': 1},
    ),
    "199": UnimodInfo(
        id="199",
        name="Dimethyl:2H(4)",
        formula="C2",
        monoisotopic_mass=32.056407,
        average_mass=32.0778,
        dict_composition={'H': 0, 'C': 2},
    ),
    "200": UnimodInfo(
        id="200",
        name="Ethanedithiol",
        formula="C2H4O-1S2",
        monoisotopic_mass=75.980527,
        average_mass=76.1838,
        dict_composition={'H': 4, 'C': 2, 'O': -1, 'S': 2},
    ),
    "205": UnimodInfo(
        id="205",
        name="Delta:H(6)C(6)O(1)",
        formula="C6H6O",
        monoisotopic_mass=94.041865,
        average_mass=94.1112,
        dict_composition={'H': 6, 'C': 6, 'O': 1},
    ),
    "206": UnimodInfo(
        id="206",
        name="Delta:H(4)C(3)O(1)",
        formula="C3H4O",
        monoisotopic_mass=56.026215,
        average_mass=56.0633,
        dict_composition={'H': 4, 'C': 3, 'O': 1},
    ),
    "207": UnimodInfo(
        id="207",
        name="Delta:H(2)C(3)",
        formula="C3H2",
        monoisotopic_mass=38.01565,
        average_mass=38.048,
        dict_composition={'H': 2, 'C': 3},
    ),
    "208": UnimodInfo(
        id="208",
        name="Delta:H(4)C(6)",
        formula="C6H4",
        monoisotopic_mass=76.0313,
        average_mass=76.096,
        dict_composition={'H': 4, 'C': 6},
    ),
    "209": UnimodInfo(
        id="209",
        name="Delta:H(8)C(6)O(2)",
        formula="C6H8O2",
        monoisotopic_mass=112.05243,
        average_mass=112.1265,
        dict_composition={'H': 8, 'C': 6, 'O': 2},
    ),
    "211": UnimodInfo(
        id="211",
        name="NEIAA",
        formula="C4H7NO",
        monoisotopic_mass=85.052764,
        average_mass=85.1045,
        dict_composition={'H': 7, 'C': 4, 'N': 1, 'O': 1},
    ),
    "212": UnimodInfo(
        id="212",
        name="NEIAA:2H(5)",
        formula="C4H2NO",
        monoisotopic_mass=90.084148,
        average_mass=90.1353,
        dict_composition={'H': 2, 'C': 4, 'N': 1, 'O': 1},
    ),
    "213": UnimodInfo(
        id="213",
        name="ADP-Ribosyl",
        formula="C15H21N5O13P2",
        monoisotopic_mass=541.06111,
        average_mass=541.3005,
        dict_composition={'H': 21, 'C': 15, 'N': 5, 'O': 13, 'P': 2},
    ),
    "214": UnimodInfo(
        id="214",
        name="iTRAQ4plex",
        formula="C4H12NO",
        monoisotopic_mass=144.102063,
        average_mass=144.1544,
        dict_composition={'H': 12, 'C': 4, 'N': 1, 'O': 1},
    ),
    "243": UnimodInfo(
        id="243",
        name="IGBP",
        formula="C12H13BrN2O2",
        monoisotopic_mass=296.016039,
        average_mass=297.1478,
        dict_composition={'H': 13, 'C': 12, 'N': 2, 'O': 2, 'Br': 1},
    ),
    "253": UnimodInfo(
        id="253",
        name="Crotonaldehyde",
        formula="C4H6O",
        monoisotopic_mass=70.041865,
        average_mass=70.0898,
        dict_composition={'H': 6, 'C': 4, 'O': 1},
    ),
    "254": UnimodInfo(
        id="254",
        name="Delta:H(2)C(2)",
        formula="C2H2",
        monoisotopic_mass=26.01565,
        average_mass=26.0373,
        dict_composition={'H': 2, 'C': 2},
    ),
    "255": UnimodInfo(
        id="255",
        name="Delta:H(4)C(2)",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.0532,
        dict_composition={'H': 4, 'C': 2},
    ),
    "256": UnimodInfo(
        id="256",
        name="Delta:H(4)C(3)",
        formula="C3H4",
        monoisotopic_mass=40.0313,
        average_mass=40.0639,
        dict_composition={'H': 4, 'C': 3},
    ),
    "258": UnimodInfo(
        id="258",
        name="Label:18O(1)",
        formula="O-1",
        monoisotopic_mass=2.004246,
        average_mass=1.9998,
        dict_composition={'O': -1},
    ),
    "259": UnimodInfo(
        id="259",
        name="Label:13C(6)15N(2)",
        formula="C-6N-2",
        monoisotopic_mass=8.014199,
        average_mass=7.9427,
        dict_composition={'C': -6, 'N': -2},
    ),
    "260": UnimodInfo(
        id="260",
        name="Thiophospho",
        formula="HO2PS",
        monoisotopic_mass=95.943487,
        average_mass=96.0455,
        dict_composition={'H': 1, 'O': 2, 'P': 1, 'S': 1},
    ),
    "261": UnimodInfo(
        id="261",
        name="SPITC",
        formula="C7H5NO3S2",
        monoisotopic_mass=214.971084,
        average_mass=215.2495,
        dict_composition={'H': 5, 'C': 7, 'N': 1, 'O': 3, 'S': 2},
    ),
    "262": UnimodInfo(
        id="262",
        name="Label:2H(3)",
        formula="H-3",
        monoisotopic_mass=3.01883,
        average_mass=3.0185,
        dict_composition={'H': -3},
    ),
    "264": UnimodInfo(
        id="264",
        name="PET",
        formula="C7H7NO-1S",
        monoisotopic_mass=121.035005,
        average_mass=121.2028,
        dict_composition={'H': 7, 'C': 7, 'N': 1, 'O': -1, 'S': 1},
    ),
    "267": UnimodInfo(
        id="267",
        name="Label:13C(6)15N(4)",
        formula="C-6N-4",
        monoisotopic_mass=10.008269,
        average_mass=9.9296,
        dict_composition={'C': -6, 'N': -4},
    ),
    "268": UnimodInfo(
        id="268",
        name="Label:13C(5)15N(1)",
        formula="C-5N-1",
        monoisotopic_mass=6.013809,
        average_mass=5.9567,
        dict_composition={'C': -5, 'N': -1},
    ),
    "269": UnimodInfo(
        id="269",
        name="Label:13C(9)15N(1)",
        formula="C-9N-1",
        monoisotopic_mass=10.027228,
        average_mass=9.9273,
        dict_composition={'C': -9, 'N': -1},
    ),
    "270": UnimodInfo(
        id="270",
        name="Cytopiloyne",
        formula="C19H22O7",
        monoisotopic_mass=362.136553,
        average_mass=362.3738,
        dict_composition={'H': 22, 'C': 19, 'O': 7},
    ),
    "271": UnimodInfo(
        id="271",
        name="Cytopiloyne+water",
        formula="C19H24O8",
        monoisotopic_mass=380.147118,
        average_mass=380.3891,
        dict_composition={'H': 24, 'C': 19, 'O': 8},
    ),
    "272": UnimodInfo(
        id="272",
        name="CAF",
        formula="C3H4O4S",
        monoisotopic_mass=135.983029,
        average_mass=136.1265,
        dict_composition={'H': 4, 'C': 3, 'O': 4, 'S': 1},
    ),
    "275": UnimodInfo(
        id="275",
        name="Nitrosyl",
        formula="H-1NO",
        monoisotopic_mass=28.990164,
        average_mass=28.9982,
        dict_composition={'H': -1, 'N': 1, 'O': 1},
    ),
    "276": UnimodInfo(
        id="276",
        name="AEBS",
        formula="C8H9NO2S",
        monoisotopic_mass=183.035399,
        average_mass=183.2276,
        dict_composition={'H': 9, 'C': 8, 'N': 1, 'O': 2, 'S': 1},
    ),
    "278": UnimodInfo(
        id="278",
        name="Ethanolyl",
        formula="C2H4O",
        monoisotopic_mass=44.026215,
        average_mass=44.0526,
        dict_composition={'H': 4, 'C': 2, 'O': 1},
    ),
    "280": UnimodInfo(
        id="280",
        name="Ethyl",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.0532,
        dict_composition={'H': 4, 'C': 2},
    ),
    "281": UnimodInfo(
        id="281",
        name="CoenzymeA",
        formula="C21H34N7O16P3S",
        monoisotopic_mass=765.09956,
        average_mass=765.5182,
        dict_composition={'H': 34, 'C': 21, 'N': 7, 'O': 16, 'P': 3, 'S': 1},
    ),
    "284": UnimodInfo(
        id="284",
        name="Methyl:2H(2)",
        formula="C",
        monoisotopic_mass=16.028204,
        average_mass=16.0389,
        dict_composition={'H': 0, 'C': 1},
    ),
    "285": UnimodInfo(
        id="285",
        name="SulfanilicAcid",
        formula="C6H5NO2S",
        monoisotopic_mass=155.004099,
        average_mass=155.1744,
        dict_composition={'H': 5, 'C': 6, 'N': 1, 'O': 2, 'S': 1},
    ),
    "286": UnimodInfo(
        id="286",
        name="SulfanilicAcid:13C(6)",
        formula="H5NO2S",
        monoisotopic_mass=161.024228,
        average_mass=161.1303,
        dict_composition={'H': 5, 'C': 0, 'N': 1, 'O': 2, 'S': 1},
    ),
    "288": UnimodInfo(
        id="288",
        name="Trp->Oxolactone",
        formula="H-2O",
        monoisotopic_mass=13.979265,
        average_mass=13.9835,
        dict_composition={'H': -2, 'O': 1},
    ),
    "289": UnimodInfo(
        id="289",
        name="Biotin-PEO-Amine",
        formula="C16H28N4O3S",
        monoisotopic_mass=356.188212,
        average_mass=356.4835,
        dict_composition={'H': 28, 'C': 16, 'N': 4, 'O': 3, 'S': 1},
    ),
    "290": UnimodInfo(
        id="290",
        name="Biotin-HPDP",
        formula="C19H32N4O3S2",
        monoisotopic_mass=428.191582,
        average_mass=428.6124,
        dict_composition={'H': 32, 'C': 19, 'N': 4, 'O': 3, 'S': 2},
    ),
    "291": UnimodInfo(
        id="291",
        name="Delta:Hg(1)",
        formula="Hg",
        monoisotopic_mass=201.970617,
        average_mass=200.59,
        dict_composition={'Hg': 1},
    ),
    "292": UnimodInfo(
        id="292",
        name="IodoU-AMP",
        formula="C9H11N2O9P",
        monoisotopic_mass=322.020217,
        average_mass=322.1654,
        dict_composition={'H': 11, 'C': 9, 'N': 2, 'O': 9, 'P': 1},
    ),
    "293": UnimodInfo(
        id="293",
        name="CAMthiopropanoyl",
        formula="C5H7NO2S",
        monoisotopic_mass=145.019749,
        average_mass=145.1796,
        dict_composition={'H': 7, 'C': 5, 'N': 1, 'O': 2, 'S': 1},
    ),
    "294": UnimodInfo(
        id="294",
        name="IED-Biotin",
        formula="C14H22N4O3S",
        monoisotopic_mass=326.141261,
        average_mass=326.4145,
        dict_composition={'H': 22, 'C': 14, 'N': 4, 'O': 3, 'S': 1},
    ),
    "295": UnimodInfo(
        id="295",
        name="dHex",
        formula="C6H10O4",
        monoisotopic_mass=146.057909,
        average_mass=146.1412,
        dict_composition={'C': 6, 'H': 10, 'O': 4},
    ),
    "298": UnimodInfo(
        id="298",
        name="Methyl:2H(3)",
        formula="CH-1",
        monoisotopic_mass=17.03448,
        average_mass=17.0451,
        dict_composition={'H': -1, 'C': 1},
    ),
    "299": UnimodInfo(
        id="299",
        name="Carboxy",
        formula="CO2",
        monoisotopic_mass=43.989829,
        average_mass=44.0095,
        dict_composition={'C': 1, 'O': 2},
    ),
    "301": UnimodInfo(
        id="301",
        name="Bromobimane",
        formula="C10H10N2O2",
        monoisotopic_mass=190.074228,
        average_mass=190.1986,
        dict_composition={'H': 10, 'C': 10, 'N': 2, 'O': 2},
    ),
    "302": UnimodInfo(
        id="302",
        name="Menadione",
        formula="C11H6O2",
        monoisotopic_mass=170.036779,
        average_mass=170.1641,
        dict_composition={'H': 6, 'C': 11, 'O': 2},
    ),
    "303": UnimodInfo(
        id="303",
        name="DeStreak",
        formula="C2H4OS",
        monoisotopic_mass=75.998285,
        average_mass=76.1176,
        dict_composition={'H': 4, 'C': 2, 'O': 1, 'S': 1},
    ),
    "305": UnimodInfo(
        id="305",
        name="dHex(1)Hex(3)HexNAc(4)",
        formula="C56H92N4O39",
        monoisotopic_mass=1444.53387,
        average_mass=1445.3331,
        dict_composition={'C': 56, 'H': 92, 'O': 39, 'N': 4},
    ),
    "307": UnimodInfo(
        id="307",
        name="dHex(1)Hex(4)HexNAc(4)",
        formula="C62H102N4O44",
        monoisotopic_mass=1606.586693,
        average_mass=1607.4737,
        dict_composition={'C': 62, 'H': 102, 'O': 44, 'N': 4},
    ),
    "308": UnimodInfo(
        id="308",
        name="dHex(1)Hex(5)HexNAc(4)",
        formula="C68H112N4O49",
        monoisotopic_mass=1768.639517,
        average_mass=1769.6143,
        dict_composition={'C': 68, 'H': 112, 'O': 49, 'N': 4},
    ),
    "309": UnimodInfo(
        id="309",
        name="Hex(3)HexNAc(4)",
        formula="C50H82N4O35",
        monoisotopic_mass=1298.475961,
        average_mass=1299.1919,
        dict_composition={'C': 50, 'H': 82, 'O': 35, 'N': 4},
    ),
    "310": UnimodInfo(
        id="310",
        name="Hex(4)HexNAc(4)",
        formula="C56H92N4O40",
        monoisotopic_mass=1460.528784,
        average_mass=1461.3325,
        dict_composition={'C': 56, 'H': 92, 'O': 40, 'N': 4},
    ),
    "311": UnimodInfo(
        id="311",
        name="Hex(5)HexNAc(4)",
        formula="C62H102N4O45",
        monoisotopic_mass=1622.581608,
        average_mass=1623.4731,
        dict_composition={'C': 62, 'H': 102, 'O': 45, 'N': 4},
    ),
    "312": UnimodInfo(
        id="312",
        name="Cysteinyl",
        formula="C3H5NO2S",
        monoisotopic_mass=119.004099,
        average_mass=119.1423,
        dict_composition={'H': 5, 'C': 3, 'N': 1, 'O': 2, 'S': 1},
    ),
    "313": UnimodInfo(
        id="313",
        name="Lys-loss",
        formula="C-6H-12N-2O-1",
        monoisotopic_mass=-128.094963,
        average_mass=-128.1723,
        dict_composition={'H': -12, 'C': -6, 'N': -2, 'O': -1},
    ),
    "314": UnimodInfo(
        id="314",
        name="Nmethylmaleimide",
        formula="C5H5NO2",
        monoisotopic_mass=111.032028,
        average_mass=111.0987,
        dict_composition={'H': 5, 'C': 5, 'N': 1, 'O': 2},
    ),
    "316": UnimodInfo(
        id="316",
        name="DimethylpyrroleAdduct",
        formula="C6H6",
        monoisotopic_mass=78.04695,
        average_mass=78.1118,
        dict_composition={'H': 6, 'C': 6},
    ),
    "318": UnimodInfo(
        id="318",
        name="Delta:H(2)C(5)",
        formula="C5H2",
        monoisotopic_mass=62.01565,
        average_mass=62.0694,
        dict_composition={'H': 2, 'C': 5},
    ),
    "319": UnimodInfo(
        id="319",
        name="Delta:H(2)C(3)O(1)",
        formula="C3H2O",
        monoisotopic_mass=54.010565,
        average_mass=54.0474,
        dict_composition={'H': 2, 'C': 3, 'O': 1},
    ),
    "320": UnimodInfo(
        id="320",
        name="Nethylmaleimide+water",
        formula="C6H9NO3",
        monoisotopic_mass=143.058243,
        average_mass=143.1406,
        dict_composition={'H': 9, 'C': 6, 'N': 1, 'O': 3},
    ),
    "323": UnimodInfo(
        id="323",
        name="Xlink:B10621",
        formula="C31H30IN4O6S",
        monoisotopic_mass=713.093079,
        average_mass=713.5626,
        dict_composition={'H': 30, 'C': 31, 'N': 4, 'O': 6, 'S': 1, 'I': 1},
    ),
    "324": UnimodInfo(
        id="324",
        name="Xlink:DTBP[87]",
        formula="C3H5NS",
        monoisotopic_mass=87.01427,
        average_mass=87.1435,
        dict_composition={'H': 5, 'C': 3, 'N': 1, 'S': 1},
    ),
    "325": UnimodInfo(
        id="325",
        name="FP-Biotin",
        formula="C27H49N4O5PS",
        monoisotopic_mass=572.316129,
        average_mass=572.7405,
        dict_composition={'H': 49, 'C': 27, 'N': 4, 'O': 5, 'P': 1, 'S': 1},
    ),
    "327": UnimodInfo(
        id="327",
        name="Delta:H(4)C(2)O(-1)S(1)",
        formula="C2H4O-1S",
        monoisotopic_mass=44.008456,
        average_mass=44.1188,
        dict_composition={'H': 4, 'C': 2, 'O': -1, 'S': 1},
    ),
    "329": UnimodInfo(
        id="329",
        name="Methyl:2H(3)13C(1)",
        formula="H-1",
        monoisotopic_mass=18.037835,
        average_mass=18.0377,
        dict_composition={'H': -1, 'C': 0},
    ),
    "330": UnimodInfo(
        id="330",
        name="Dimethyl:2H(6)13C(2)",
        formula="H-2",
        monoisotopic_mass=36.07567,
        average_mass=36.0754,
        dict_composition={'H': -2, 'C': 0},
    ),
    "332": UnimodInfo(
        id="332",
        name="Thiophos-S-S-biotin",
        formula="C19H34N4O5PS3",
        monoisotopic_mass=525.142894,
        average_mass=525.6658,
        dict_composition={'H': 34, 'C': 19, 'N': 4, 'O': 5, 'P': 1, 'S': 3},
    ),
    "333": UnimodInfo(
        id="333",
        name="Can-FP-biotin",
        formula="C19H34N3O5PS",
        monoisotopic_mass=447.195679,
        average_mass=447.5291,
        dict_composition={'H': 34, 'C': 19, 'N': 3, 'O': 5, 'P': 1, 'S': 1},
    ),
    "335": UnimodInfo(
        id="335",
        name="HNE+Delta:H(2)",
        formula="C9H18O2",
        monoisotopic_mass=158.13068,
        average_mass=158.238,
        dict_composition={'H': 18, 'C': 9, 'O': 2},
    ),
    "337": UnimodInfo(
        id="337",
        name="Methylamine",
        formula="CH3NO-1",
        monoisotopic_mass=13.031634,
        average_mass=13.0418,
        dict_composition={'H': 3, 'C': 1, 'N': 1, 'O': -1},
    ),
    "340": UnimodInfo(
        id="340",
        name="Bromo",
        formula="H-1Br",
        monoisotopic_mass=77.910511,
        average_mass=78.8961,
        dict_composition={'H': -1, 'Br': 1},
    ),
    "342": UnimodInfo(
        id="342",
        name="Amino",
        formula="HN",
        monoisotopic_mass=15.010899,
        average_mass=15.0146,
        dict_composition={'H': 1, 'N': 1},
    ),
    "343": UnimodInfo(
        id="343",
        name="Argbiotinhydrazide",
        formula="C9H13NO2S",
        monoisotopic_mass=199.066699,
        average_mass=199.27,
        dict_composition={'H': 13, 'C': 9, 'N': 1, 'O': 2, 'S': 1},
    ),
    "344": UnimodInfo(
        id="344",
        name="Arg->GluSA",
        formula="C-1H-5N-3O",
        monoisotopic_mass=-43.053433,
        average_mass=-43.0711,
        dict_composition={'H': -5, 'C': -1, 'N': -3, 'O': 1},
    ),
    "345": UnimodInfo(
        id="345",
        name="Trioxidation",
        formula="O3",
        monoisotopic_mass=47.984744,
        average_mass=47.9982,
        dict_composition={'O': 3},
    ),
    "348": UnimodInfo(
        id="348",
        name="His->Asn",
        formula="C-2H-1N-1O",
        monoisotopic_mass=-23.015984,
        average_mass=-23.0366,
        dict_composition={'H': -1, 'C': -2, 'N': -1, 'O': 1},
    ),
    "349": UnimodInfo(
        id="349",
        name="His->Asp",
        formula="C-2H-2N-2O2",
        monoisotopic_mass=-22.031969,
        average_mass=-22.0519,
        dict_composition={'H': -2, 'C': -2, 'N': -2, 'O': 2},
    ),
    "350": UnimodInfo(
        id="350",
        name="Trp->Hydroxykynurenin",
        formula="C-1O2",
        monoisotopic_mass=19.989829,
        average_mass=19.9881,
        dict_composition={'C': -1, 'O': 2},
    ),
    "351": UnimodInfo(
        id="351",
        name="Trp->Kynurenin",
        formula="C-1O",
        monoisotopic_mass=3.994915,
        average_mass=3.9887,
        dict_composition={'C': -1, 'O': 1},
    ),
    "352": UnimodInfo(
        id="352",
        name="Lys->Allysine",
        formula="H-3N-1O",
        monoisotopic_mass=-1.031634,
        average_mass=-1.0311,
        dict_composition={'H': -3, 'N': -1, 'O': 1},
    ),
    "353": UnimodInfo(
        id="353",
        name="Lysbiotinhydrazide",
        formula="C10H15N3O2S",
        monoisotopic_mass=241.088497,
        average_mass=241.31,
        dict_composition={'H': 15, 'C': 10, 'N': 3, 'O': 2, 'S': 1},
    ),
    "354": UnimodInfo(
        id="354",
        name="Nitro",
        formula="H-1NO2",
        monoisotopic_mass=44.985078,
        average_mass=44.9976,
        dict_composition={'H': -1, 'N': 1, 'O': 2},
    ),
    "357": UnimodInfo(
        id="357",
        name="probiotinhydrazide",
        formula="C10H18N4O2S",
        monoisotopic_mass=258.115047,
        average_mass=258.3405,
        dict_composition={'H': 18, 'C': 10, 'N': 4, 'O': 2, 'S': 1},
    ),
    "359": UnimodInfo(
        id="359",
        name="Pro->pyro-Glu",
        formula="H-2O",
        monoisotopic_mass=13.979265,
        average_mass=13.9835,
        dict_composition={'H': -2, 'O': 1},
    ),
    "360": UnimodInfo(
        id="360",
        name="Pro->Pyrrolidinone",
        formula="C-1H-2O-1",
        monoisotopic_mass=-30.010565,
        average_mass=-30.026,
        dict_composition={'H': -2, 'C': -1, 'O': -1},
    ),
    "361": UnimodInfo(
        id="361",
        name="Thrbiotinhydrazide",
        formula="C10H16N4OS",
        monoisotopic_mass=240.104482,
        average_mass=240.3252,
        dict_composition={'H': 16, 'C': 10, 'N': 4, 'O': 1, 'S': 1},
    ),
    "362": UnimodInfo(
        id="362",
        name="Diisopropylphosphate",
        formula="C6H13O3P",
        monoisotopic_mass=164.060231,
        average_mass=164.1394,
        dict_composition={'H': 13, 'C': 6, 'O': 3, 'P': 1},
    ),
    "363": UnimodInfo(
        id="363",
        name="Isopropylphospho",
        formula="C3H7O3P",
        monoisotopic_mass=122.013281,
        average_mass=122.0596,
        dict_composition={'H': 7, 'C': 3, 'O': 3, 'P': 1},
    ),
    "364": UnimodInfo(
        id="364",
        name="ICPL:13C(6)",
        formula="H3NO",
        monoisotopic_mass=111.041593,
        average_mass=111.05,
        dict_composition={'H': 3, 'C': 0, 'N': 1, 'O': 1},
    ),
    "365": UnimodInfo(
        id="365",
        name="ICPL",
        formula="C6H3NO",
        monoisotopic_mass=105.021464,
        average_mass=105.0941,
        dict_composition={'H': 3, 'C': 6, 'N': 1, 'O': 1},
    ),
    "366": UnimodInfo(
        id="366",
        name="Deamidated:18O(1)",
        formula="H-1N-1",
        monoisotopic_mass=2.988261,
        average_mass=2.9845,
        dict_composition={'H': -1, 'N': -1, 'O': 0},
    ),
    "368": UnimodInfo(
        id="368",
        name="Cys->Dha",
        formula="H-2S-1",
        monoisotopic_mass=-33.987721,
        average_mass=-34.0809,
        dict_composition={'H': -2, 'S': -1},
    ),
    "369": UnimodInfo(
        id="369",
        name="Pro->Pyrrolidone",
        formula="C-1O-1",
        monoisotopic_mass=-27.994915,
        average_mass=-28.0101,
        dict_composition={'C': -1, 'O': -1},
    ),
    "371": UnimodInfo(
        id="371",
        name="HMVK",
        formula="C4H6O2",
        monoisotopic_mass=86.036779,
        average_mass=86.0892,
        dict_composition={'H': 6, 'C': 4, 'O': 2},
    ),
    "372": UnimodInfo(
        id="372",
        name="Arg->Orn",
        formula="C-1H-2N-2",
        monoisotopic_mass=-42.021798,
        average_mass=-42.04,
        dict_composition={'H': -2, 'C': -1, 'N': -2},
    ),
    "374": UnimodInfo(
        id="374",
        name="Dehydro",
        formula="H-1",
        monoisotopic_mass=-1.007825,
        average_mass=-1.0079,
        dict_composition={'H': -1},
    ),
    "375": UnimodInfo(
        id="375",
        name="Diphthamide",
        formula="C7H14N2O",
        monoisotopic_mass=142.110613,
        average_mass=142.1989,
        dict_composition={'H': 14, 'C': 7, 'N': 2, 'O': 1},
    ),
    "376": UnimodInfo(
        id="376",
        name="Hydroxyfarnesyl",
        formula="C15H24O",
        monoisotopic_mass=220.182715,
        average_mass=220.3505,
        dict_composition={'H': 24, 'C': 15, 'O': 1},
    ),
    "377": UnimodInfo(
        id="377",
        name="Diacylglycerol",
        formula="C37H68O4",
        monoisotopic_mass=576.511761,
        average_mass=576.9334,
        dict_composition={'H': 68, 'C': 37, 'O': 4},
    ),
    "378": UnimodInfo(
        id="378",
        name="Carboxyethyl",
        formula="C3H4O2",
        monoisotopic_mass=72.021129,
        average_mass=72.0627,
        dict_composition={'H': 4, 'C': 3, 'O': 2},
    ),
    "379": UnimodInfo(
        id="379",
        name="Hypusine",
        formula="C4H9NO",
        monoisotopic_mass=87.068414,
        average_mass=87.1204,
        dict_composition={'H': 9, 'C': 4, 'N': 1, 'O': 1},
    ),
    "380": UnimodInfo(
        id="380",
        name="Retinylidene",
        formula="C20H26",
        monoisotopic_mass=266.203451,
        average_mass=266.4204,
        dict_composition={'H': 26, 'C': 20},
    ),
    "381": UnimodInfo(
        id="381",
        name="Lys->AminoadipicAcid",
        formula="H-3N-1O2",
        monoisotopic_mass=14.96328,
        average_mass=14.9683,
        dict_composition={'H': -3, 'N': -1, 'O': 2},
    ),
    "382": UnimodInfo(
        id="382",
        name="Cys->PyruvicAcid",
        formula="H-3N-1OS-1",
        monoisotopic_mass=-33.003705,
        average_mass=-33.0961,
        dict_composition={'H': -3, 'N': -1, 'O': 1, 'S': -1},
    ),
    "385": UnimodInfo(
        id="385",
        name="Ammonia-loss",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.0305,
        dict_composition={'H': -3, 'N': -1},
    ),
    "387": UnimodInfo(
        id="387",
        name="Phycocyanobilin",
        formula="C33H38N4O6",
        monoisotopic_mass=586.279135,
        average_mass=586.678,
        dict_composition={'H': 38, 'C': 33, 'N': 4, 'O': 6},
    ),
    "388": UnimodInfo(
        id="388",
        name="Phycoerythrobilin",
        formula="C33H40N4O6",
        monoisotopic_mass=588.294785,
        average_mass=588.6939,
        dict_composition={'H': 40, 'C': 33, 'N': 4, 'O': 6},
    ),
    "389": UnimodInfo(
        id="389",
        name="Phytochromobilin",
        formula="C33H36N4O6",
        monoisotopic_mass=584.263485,
        average_mass=584.6621,
        dict_composition={'H': 36, 'C': 33, 'N': 4, 'O': 6},
    ),
    "390": UnimodInfo(
        id="390",
        name="Heme",
        formula="C34H32FeN4O4",
        monoisotopic_mass=616.177295,
        average_mass=616.4873,
        dict_composition={'H': 32, 'C': 34, 'N': 4, 'O': 4, 'Fe': 1},
    ),
    "391": UnimodInfo(
        id="391",
        name="Molybdopterin",
        formula="C10H11MoN5O8PS2",
        monoisotopic_mass=521.884073,
        average_mass=520.2668,
        dict_composition={'H': 11, 'C': 10, 'N': 5, 'O': 8, 'P': 1, 'S': 2, 'Mo': 1},
    ),
    "392": UnimodInfo(
        id="392",
        name="Quinone",
        formula="H-2O2",
        monoisotopic_mass=29.974179,
        average_mass=29.9829,
        dict_composition={'H': -2, 'O': 2},
    ),
    "393": UnimodInfo(
        id="393",
        name="Glucosylgalactosyl",
        formula="C12H20O11",
        monoisotopic_mass=340.100562,
        average_mass=340.2806,
        dict_composition={'O': 11, 'C': 12, 'H': 20},
    ),
    "394": UnimodInfo(
        id="394",
        name="GPIanchor",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.0477,
        dict_composition={'H': 6, 'C': 2, 'N': 1, 'O': 3, 'P': 1},
    ),
    "395": UnimodInfo(
        id="395",
        name="PhosphoribosyldephosphoCoA",
        formula="C26H42N7O19P3S",
        monoisotopic_mass=881.146904,
        average_mass=881.6335,
        dict_composition={'H': 42, 'C': 26, 'N': 7, 'O': 19, 'P': 3, 'S': 1},
    ),
    "396": UnimodInfo(
        id="396",
        name="GlycerylPE",
        formula="C5H12NO5P",
        monoisotopic_mass=197.04531,
        average_mass=197.1262,
        dict_composition={'H': 12, 'C': 5, 'N': 1, 'O': 5, 'P': 1},
    ),
    "397": UnimodInfo(
        id="397",
        name="Triiodothyronine",
        formula="C6HI3O",
        monoisotopic_mass=469.716159,
        average_mass=469.785,
        dict_composition={'H': 1, 'C': 6, 'O': 1, 'I': 3},
    ),
    "398": UnimodInfo(
        id="398",
        name="Thyroxine",
        formula="C6I4O",
        monoisotopic_mass=595.612807,
        average_mass=595.6815,
        dict_composition={'C': 6, 'O': 1, 'I': 4},
    ),
    "400": UnimodInfo(
        id="400",
        name="Tyr->Dha",
        formula="C-6H-6O-1",
        monoisotopic_mass=-94.041865,
        average_mass=-94.1112,
        dict_composition={'H': -6, 'C': -6, 'O': -1},
    ),
    "401": UnimodInfo(
        id="401",
        name="Didehydro",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.0159,
        dict_composition={'H': -2},
    ),
    "402": UnimodInfo(
        id="402",
        name="Cys->Oxoalanine",
        formula="H-2OS-1",
        monoisotopic_mass=-17.992806,
        average_mass=-18.0815,
        dict_composition={'H': -2, 'O': 1, 'S': -1},
    ),
    "403": UnimodInfo(
        id="403",
        name="Ser->LacticAcid",
        formula="H-1N-1",
        monoisotopic_mass=-15.010899,
        average_mass=-15.0146,
        dict_composition={'H': -1, 'N': -1},
    ),
    "405": UnimodInfo(
        id="405",
        name="Phosphoadenosine",
        formula="C10H12N5O6P",
        monoisotopic_mass=329.05252,
        average_mass=329.2059,
        dict_composition={'H': 12, 'C': 10, 'N': 5, 'O': 6, 'P': 1},
    ),
    "407": UnimodInfo(
        id="407",
        name="Hydroxycinnamyl",
        formula="C9H6O2",
        monoisotopic_mass=146.036779,
        average_mass=146.1427,
        dict_composition={'H': 6, 'C': 9, 'O': 2},
    ),
    "408": UnimodInfo(
        id="408",
        name="Glycosyl",
        formula="C5H8O5",
        monoisotopic_mass=148.037173,
        average_mass=148.114,
        dict_composition={'H': 8, 'C': 5, 'O': 5},
    ),
    "409": UnimodInfo(
        id="409",
        name="FMNH",
        formula="C17H19N4O9P",
        monoisotopic_mass=454.088965,
        average_mass=454.3279,
        dict_composition={'H': 19, 'C': 17, 'N': 4, 'O': 9, 'P': 1},
    ),
    "410": UnimodInfo(
        id="410",
        name="Archaeol",
        formula="C43H86O2",
        monoisotopic_mass=634.662782,
        average_mass=635.1417,
        dict_composition={'H': 86, 'C': 43, 'O': 2},
    ),
    "411": UnimodInfo(
        id="411",
        name="Phenylisocyanate",
        formula="C7H5NO",
        monoisotopic_mass=119.037114,
        average_mass=119.1207,
        dict_composition={'H': 5, 'C': 7, 'N': 1, 'O': 1},
    ),
    "412": UnimodInfo(
        id="412",
        name="Phenylisocyanate:2H(5)",
        formula="C7NO",
        monoisotopic_mass=124.068498,
        average_mass=124.1515,
        dict_composition={'H': 0, 'C': 7, 'N': 1, 'O': 1},
    ),
    "413": UnimodInfo(
        id="413",
        name="Phosphoguanosine",
        formula="C10H12N5O7P",
        monoisotopic_mass=345.047435,
        average_mass=345.2053,
        dict_composition={'H': 12, 'C': 10, 'N': 5, 'O': 7, 'P': 1},
    ),
    "414": UnimodInfo(
        id="414",
        name="Hydroxymethyl",
        formula="CH2O",
        monoisotopic_mass=30.010565,
        average_mass=30.026,
        dict_composition={'H': 2, 'C': 1, 'O': 1},
    ),
    "415": UnimodInfo(
        id="415",
        name="MolybdopterinGD+Delta:S(-1)Se(1)",
        formula="C40H47MoN20O26P4S3Se",
        monoisotopic_mass=1620.930224,
        average_mass=1618.9096,
        dict_composition={'H': 47, 'C': 40, 'N': 20, 'O': 26, 'P': 4, 'S': 3, 'Se': 1, 'Mo': 1},
    ),
    "416": UnimodInfo(
        id="416",
        name="Dipyrrolylmethanemethyl",
        formula="C20H22N2O8",
        monoisotopic_mass=418.137616,
        average_mass=418.3973,
        dict_composition={'H': 22, 'C': 20, 'N': 2, 'O': 8},
    ),
    "417": UnimodInfo(
        id="417",
        name="PhosphoUridine",
        formula="C9H11N2O8P",
        monoisotopic_mass=306.025302,
        average_mass=306.166,
        dict_composition={'H': 11, 'C': 9, 'N': 2, 'O': 8, 'P': 1},
    ),
    "419": UnimodInfo(
        id="419",
        name="Glycerophospho",
        formula="C3H7O5P",
        monoisotopic_mass=154.00311,
        average_mass=154.0584,
        dict_composition={'H': 7, 'C': 3, 'O': 5, 'P': 1},
    ),
    "420": UnimodInfo(
        id="420",
        name="Carboxy->Thiocarboxy",
        formula="O-1S",
        monoisotopic_mass=15.977156,
        average_mass=16.0656,
        dict_composition={'O': -1, 'S': 1},
    ),
    "421": UnimodInfo(
        id="421",
        name="Sulfide",
        formula="S",
        monoisotopic_mass=31.972071,
        average_mass=32.065,
        dict_composition={'S': 1},
    ),
    "422": UnimodInfo(
        id="422",
        name="PyruvicAcidIminyl",
        formula="C3H2O2",
        monoisotopic_mass=70.005479,
        average_mass=70.0468,
        dict_composition={'H': 2, 'C': 3, 'O': 2},
    ),
    "423": UnimodInfo(
        id="423",
        name="Delta:Se(1)",
        formula="Se",
        monoisotopic_mass=79.91652,
        average_mass=78.96,
        dict_composition={'Se': 1},
    ),
    "424": UnimodInfo(
        id="424",
        name="MolybdopterinGD",
        formula="C40H47MoN20O26P4S4",
        monoisotopic_mass=1572.985775,
        average_mass=1572.0146,
        dict_composition={'H': 47, 'C': 40, 'N': 20, 'O': 26, 'P': 4, 'S': 4, 'Mo': 1},
    ),
    "425": UnimodInfo(
        id="425",
        name="Dioxidation",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=31.9988,
        dict_composition={'O': 2},
    ),
    "426": UnimodInfo(
        id="426",
        name="Octanoyl",
        formula="C8H14O",
        monoisotopic_mass=126.104465,
        average_mass=126.1962,
        dict_composition={'H': 14, 'C': 8, 'O': 1},
    ),
    "428": UnimodInfo(
        id="428",
        name="PhosphoHexNAc",
        formula="C8H14NO8P",
        monoisotopic_mass=283.045704,
        average_mass=283.1724,
        dict_composition={'H': 14, 'O': 8, 'P': 1, 'C': 8, 'N': 1},
    ),
    "429": UnimodInfo(
        id="429",
        name="PhosphoHex",
        formula="C6H11O8P",
        monoisotopic_mass=242.019154,
        average_mass=242.1205,
        dict_composition={'H': 11, 'O': 8, 'P': 1, 'C': 6},
    ),
    "431": UnimodInfo(
        id="431",
        name="Palmitoleyl",
        formula="C16H28O",
        monoisotopic_mass=236.214016,
        average_mass=236.3929,
        dict_composition={'H': 28, 'C': 16, 'O': 1},
    ),
    "432": UnimodInfo(
        id="432",
        name="Cholesterol",
        formula="C27H44",
        monoisotopic_mass=368.344302,
        average_mass=368.6383,
        dict_composition={'H': 44, 'C': 27},
    ),
    "433": UnimodInfo(
        id="433",
        name="Didehydroretinylidene",
        formula="C20H24",
        monoisotopic_mass=264.187801,
        average_mass=264.4046,
        dict_composition={'H': 24, 'C': 20},
    ),
    "434": UnimodInfo(
        id="434",
        name="CHDH",
        formula="C17H26O4",
        monoisotopic_mass=294.183109,
        average_mass=294.3859,
        dict_composition={'H': 26, 'C': 17, 'O': 4},
    ),
    "435": UnimodInfo(
        id="435",
        name="Methylpyrroline",
        formula="C6H7NO",
        monoisotopic_mass=109.052764,
        average_mass=109.1259,
        dict_composition={'H': 7, 'C': 6, 'N': 1, 'O': 1},
    ),
    "436": UnimodInfo(
        id="436",
        name="Hydroxyheme",
        formula="C34H30FeN4O4",
        monoisotopic_mass=614.161645,
        average_mass=614.4714,
        dict_composition={'H': 30, 'C': 34, 'N': 4, 'O': 4, 'Fe': 1},
    ),
    "437": UnimodInfo(
        id="437",
        name="MicrocinC7",
        formula="C13H19N6O6P",
        monoisotopic_mass=386.110369,
        average_mass=386.3003,
        dict_composition={'H': 19, 'C': 13, 'N': 6, 'O': 6, 'P': 1},
    ),
    "438": UnimodInfo(
        id="438",
        name="Cyano",
        formula="CH-1N",
        monoisotopic_mass=24.995249,
        average_mass=25.0095,
        dict_composition={'H': -1, 'C': 1, 'N': 1},
    ),
    "439": UnimodInfo(
        id="439",
        name="Diironsubcluster",
        formula="C5H-1Fe2N2O5S2",
        monoisotopic_mass=342.786916,
        average_mass=342.876,
        dict_composition={'H': -1, 'C': 5, 'N': 2, 'O': 5, 'S': 2, 'Fe': 2},
    ),
    "440": UnimodInfo(
        id="440",
        name="Amidino",
        formula="CH2N2",
        monoisotopic_mass=42.021798,
        average_mass=42.04,
        dict_composition={'H': 2, 'C': 1, 'N': 2},
    ),
    "442": UnimodInfo(
        id="442",
        name="FMN",
        formula="C17H19N4O8P",
        monoisotopic_mass=438.094051,
        average_mass=438.3285,
        dict_composition={'H': 19, 'C': 17, 'N': 4, 'O': 8, 'P': 1},
    ),
    "443": UnimodInfo(
        id="443",
        name="FMNC",
        formula="C17H21N4O9P",
        monoisotopic_mass=456.104615,
        average_mass=456.3438,
        dict_composition={'H': 21, 'C': 17, 'N': 4, 'O': 9, 'P': 1},
    ),
    "444": UnimodInfo(
        id="444",
        name="CuSMo",
        formula="C19H24CuMoN8O15P2S3",
        monoisotopic_mass=922.834855,
        average_mass=922.067,
        dict_composition={'H': 24, 'C': 19, 'N': 8, 'O': 15, 'P': 2, 'S': 3, 'Cu': 1, 'Mo': 1},
    ),
    "445": UnimodInfo(
        id="445",
        name="Hydroxytrimethyl",
        formula="C3H7O",
        monoisotopic_mass=59.04969,
        average_mass=59.0871,
        dict_composition={'H': 7, 'C': 3, 'O': 1},
    ),
    "447": UnimodInfo(
        id="447",
        name="Deoxy",
        formula="O-1",
        monoisotopic_mass=-15.994915,
        average_mass=-15.9994,
        dict_composition={'O': -1},
    ),
    "448": UnimodInfo(
        id="448",
        name="Microcin",
        formula="C36H37N3O20",
        monoisotopic_mass=831.197041,
        average_mass=831.6871,
        dict_composition={'H': 37, 'C': 36, 'N': 3, 'O': 20},
    ),
    "449": UnimodInfo(
        id="449",
        name="Decanoyl",
        formula="C10H18O",
        monoisotopic_mass=154.135765,
        average_mass=154.2493,
        dict_composition={'H': 18, 'C': 10, 'O': 1},
    ),
    "450": UnimodInfo(
        id="450",
        name="Glu",
        formula="C5H7NO3",
        monoisotopic_mass=129.042593,
        average_mass=129.114,
        dict_composition={'H': 7, 'C': 5, 'N': 1, 'O': 3},
    ),
    "451": UnimodInfo(
        id="451",
        name="GluGlu",
        formula="C10H14N2O6",
        monoisotopic_mass=258.085186,
        average_mass=258.228,
        dict_composition={'H': 14, 'C': 10, 'N': 2, 'O': 6},
    ),
    "452": UnimodInfo(
        id="452",
        name="GluGluGlu",
        formula="C15H21N3O9",
        monoisotopic_mass=387.127779,
        average_mass=387.3419,
        dict_composition={'H': 21, 'C': 15, 'N': 3, 'O': 9},
    ),
    "453": UnimodInfo(
        id="453",
        name="GluGluGluGlu",
        formula="C20H28N4O12",
        monoisotopic_mass=516.170373,
        average_mass=516.4559,
        dict_composition={'H': 28, 'C': 20, 'N': 4, 'O': 12},
    ),
    "454": UnimodInfo(
        id="454",
        name="HexN",
        formula="C6H11NO4",
        monoisotopic_mass=161.068808,
        average_mass=161.1558,
        dict_composition={'C': 6, 'H': 11, 'N': 1, 'O': 4},
    ),
    "455": UnimodInfo(
        id="455",
        name="Xlink:DMP[154]",
        formula="C8H14N2O",
        monoisotopic_mass=154.110613,
        average_mass=154.2096,
        dict_composition={'H': 14, 'C': 8, 'N': 2, 'O': 1},
    ),
    "457": UnimodInfo(
        id="457",
        name="NDA",
        formula="C13H5N",
        monoisotopic_mass=175.042199,
        average_mass=175.1855,
        dict_composition={'H': 5, 'C': 13, 'N': 1},
    ),
    "464": UnimodInfo(
        id="464",
        name="SPITC:13C(6)",
        formula="CH5NO3S2",
        monoisotopic_mass=220.991213,
        average_mass=221.2054,
        dict_composition={'H': 5, 'C': 1, 'N': 1, 'O': 3, 'S': 2},
    ),
    "472": UnimodInfo(
        id="472",
        name="AEC-MAEC",
        formula="C2H5NO-1S",
        monoisotopic_mass=59.019355,
        average_mass=59.1334,
        dict_composition={'H': 5, 'C': 2, 'N': 1, 'O': -1, 'S': 1},
    ),
    "476": UnimodInfo(
        id="476",
        name="TMAB",
        formula="C7H14NO",
        monoisotopic_mass=128.107539,
        average_mass=128.1922,
        dict_composition={'H': 14, 'C': 7, 'N': 1, 'O': 1},
    ),
    "477": UnimodInfo(
        id="477",
        name="TMAB:2H(9)",
        formula="C7H5NO",
        monoisotopic_mass=137.16403,
        average_mass=137.2476,
        dict_composition={'H': 5, 'C': 7, 'N': 1, 'O': 1},
    ),
    "478": UnimodInfo(
        id="478",
        name="FTC",
        formula="C21H15N3O5S",
        monoisotopic_mass=421.073241,
        average_mass=421.4259,
        dict_composition={'H': 15, 'C': 21, 'N': 3, 'O': 5, 'S': 1},
    ),
    "481": UnimodInfo(
        id="481",
        name="Label:2H(4)",
        formula="H-4",
        monoisotopic_mass=4.025107,
        average_mass=4.0246,
        dict_composition={'H': -4},
    ),
    "488": UnimodInfo(
        id="488",
        name="DHP",
        formula="C8H8N",
        monoisotopic_mass=118.065674,
        average_mass=118.1558,
        dict_composition={'H': 8, 'C': 8, 'N': 1},
    ),
    "490": UnimodInfo(
        id="490",
        name="Hep",
        formula="C7H12O6",
        monoisotopic_mass=192.063388,
        average_mass=192.1666,
        dict_composition={'C': 7, 'H': 12, 'O': 6},
    ),
    "493": UnimodInfo(
        id="493",
        name="BADGE",
        formula="C21H24O4",
        monoisotopic_mass=340.167459,
        average_mass=340.4129,
        dict_composition={'H': 24, 'C': 21, 'O': 4},
    ),
    "494": UnimodInfo(
        id="494",
        name="CyDye-Cy3",
        formula="C37H44N4O6S",
        monoisotopic_mass=672.298156,
        average_mass=672.8335,
        dict_composition={'H': 44, 'C': 37, 'N': 4, 'O': 6, 'S': 1},
    ),
    "495": UnimodInfo(
        id="495",
        name="CyDye-Cy5",
        formula="C38H44N4O6S",
        monoisotopic_mass=684.298156,
        average_mass=684.8442,
        dict_composition={'H': 44, 'C': 38, 'N': 4, 'O': 6, 'S': 1},
    ),
    "498": UnimodInfo(
        id="498",
        name="BHTOH",
        formula="C15H22O2",
        monoisotopic_mass=234.16198,
        average_mass=234.334,
        dict_composition={'H': 22, 'C': 15, 'O': 2},
    ),
    "499": UnimodInfo(
        id="499",
        name="IGBP:13C(2)",
        formula="C10H13BrN2O2",
        monoisotopic_mass=298.022748,
        average_mass=299.1331,
        dict_composition={'H': 13, 'C': 10, 'N': 2, 'O': 2, 'Br': 1},
    ),
    "500": UnimodInfo(
        id="500",
        name="Nmethylmaleimide+water",
        formula="C5H7NO3",
        monoisotopic_mass=129.042593,
        average_mass=129.114,
        dict_composition={'H': 7, 'C': 5, 'N': 1, 'O': 3},
    ),
    "501": UnimodInfo(
        id="501",
        name="PyMIC",
        formula="C7H6N2O",
        monoisotopic_mass=134.048013,
        average_mass=134.1353,
        dict_composition={'H': 6, 'C': 7, 'N': 2, 'O': 1},
    ),
    "503": UnimodInfo(
        id="503",
        name="LG-lactam-K",
        formula="C20H28O4",
        monoisotopic_mass=332.19876,
        average_mass=332.4339,
        dict_composition={'H': 28, 'C': 20, 'O': 4},
    ),
    "504": UnimodInfo(
        id="504",
        name="LG-Hlactam-K",
        formula="C20H28O5",
        monoisotopic_mass=348.193674,
        average_mass=348.4333,
        dict_composition={'H': 28, 'C': 20, 'O': 5},
    ),
    "505": UnimodInfo(
        id="505",
        name="LG-lactam-R",
        formula="C19H26N-2O4",
        monoisotopic_mass=290.176961,
        average_mass=290.3939,
        dict_composition={'H': 26, 'C': 19, 'N': -2, 'O': 4},
    ),
    "506": UnimodInfo(
        id="506",
        name="LG-Hlactam-R",
        formula="C19H26N-2O5",
        monoisotopic_mass=306.171876,
        average_mass=306.3933,
        dict_composition={'H': 26, 'C': 19, 'N': -2, 'O': 5},
    ),
    "510": UnimodInfo(
        id="510",
        name="Dimethyl:2H(4)13C(2)",
        formula=None,
        monoisotopic_mass=34.063117,
        average_mass=34.0631,
        dict_composition={'H': 0, 'C': 0},
    ),
    "512": UnimodInfo(
        id="512",
        name="Hex(2)",
        formula="C12H20O10",
        monoisotopic_mass=324.105647,
        average_mass=324.2812,
        dict_composition={'C': 12, 'H': 20, 'O': 10},
    ),
    "513": UnimodInfo(
        id="513",
        name="C8-QAT",
        formula="C14H29NO",
        monoisotopic_mass=227.224915,
        average_mass=227.3862,
        dict_composition={'H': 29, 'C': 14, 'N': 1, 'O': 1},
    ),
    "514": UnimodInfo(
        id="514",
        name="PropylNAGthiazoline",
        formula="C9H14NO4S",
        monoisotopic_mass=232.064354,
        average_mass=232.2768,
        dict_composition={'H': 14, 'C': 9, 'N': 1, 'O': 4, 'S': 1},
    ),
    "515": UnimodInfo(
        id="515",
        name="FNEM",
        formula="C24H13NO7",
        monoisotopic_mass=427.069202,
        average_mass=427.3625,
        dict_composition={'H': 13, 'C': 24, 'N': 1, 'O': 7},
    ),
    "518": UnimodInfo(
        id="518",
        name="Diethyl",
        formula="C4H8",
        monoisotopic_mass=56.0626,
        average_mass=56.1063,
        dict_composition={'H': 8, 'C': 4},
    ),
    "519": UnimodInfo(
        id="519",
        name="BisANS",
        formula="C32H22N2O6S2",
        monoisotopic_mass=594.091928,
        average_mass=594.6569,
        dict_composition={'H': 22, 'C': 32, 'N': 2, 'O': 6, 'S': 2},
    ),
    "520": UnimodInfo(
        id="520",
        name="Piperidine",
        formula="C5H8",
        monoisotopic_mass=68.0626,
        average_mass=68.117,
        dict_composition={'H': 8, 'C': 5},
    ),
    "522": UnimodInfo(
        id="522",
        name="Maleimide-PEO2-Biotin",
        formula="C23H35N5O7S",
        monoisotopic_mass=525.225719,
        average_mass=525.6183,
        dict_composition={'H': 35, 'C': 23, 'N': 5, 'O': 7, 'S': 1},
    ),
    "523": UnimodInfo(
        id="523",
        name="Sulfo-NHS-LC-LC-Biotin",
        formula="C22H36N4O4S",
        monoisotopic_mass=452.245726,
        average_mass=452.6106,
        dict_composition={'H': 36, 'C': 22, 'N': 4, 'O': 4, 'S': 1},
    ),
    "525": UnimodInfo(
        id="525",
        name="CLIP_TRAQ_2",
        formula="C6H12N2O",
        monoisotopic_mass=141.098318,
        average_mass=141.1756,
        dict_composition={'H': 12, 'C': 6, 'N': 2, 'O': 1},
    ),
    "526": UnimodInfo(
        id="526",
        name="Dethiomethyl",
        formula="C-1H-4S-1",
        monoisotopic_mass=-48.003371,
        average_mass=-48.1075,
        dict_composition={'H': -4, 'C': -1, 'S': -1},
    ),
    "528": UnimodInfo(
        id="528",
        name="Methyl+Deamidated",
        formula="CHN-1O",
        monoisotopic_mass=14.999666,
        average_mass=15.0113,
        dict_composition={'H': 1, 'C': 1, 'N': -1, 'O': 1},
    ),
    "529": UnimodInfo(
        id="529",
        name="Delta:H(5)C(2)",
        formula="C2H5",
        monoisotopic_mass=29.039125,
        average_mass=29.0611,
        dict_composition={'H': 5, 'C': 2},
    ),
    "530": UnimodInfo(
        id="530",
        name="Cation:K",
        formula="H-1K",
        monoisotopic_mass=37.955882,
        average_mass=38.0904,
        dict_composition={'H': -1, 'K': 1},
    ),
    "531": UnimodInfo(
        id="531",
        name="Cation:Cu[I]",
        formula="H-1Cu",
        monoisotopic_mass=61.921774,
        average_mass=62.5381,
        dict_composition={'H': -1, 'Cu': 1},
    ),
    "532": UnimodInfo(
        id="532",
        name="iTRAQ4plex114",
        formula="C5H12N2",
        monoisotopic_mass=144.105918,
        average_mass=144.168,
        dict_composition={'H': 12, 'C': 5, 'N': 2, 'O': 0},
    ),
    "533": UnimodInfo(
        id="533",
        name="iTRAQ4plex115",
        formula="C6H12N",
        monoisotopic_mass=144.099599,
        average_mass=144.1688,
        dict_composition={'H': 12, 'C': 6, 'N': 1, 'O': 0},
    ),
    "534": UnimodInfo(
        id="534",
        name="Dibromo",
        formula="H-2Br2",
        monoisotopic_mass=155.821022,
        average_mass=157.7921,
        dict_composition={'H': -2, 'Br': 2},
    ),
    "535": UnimodInfo(
        id="535",
        name="LRGG",
        formula="C16H29N7O4",
        monoisotopic_mass=383.228103,
        average_mass=383.446,
        dict_composition={'H': 29, 'C': 16, 'N': 7, 'O': 4},
    ),
    "536": UnimodInfo(
        id="536",
        name="CLIP_TRAQ_3",
        formula="C11H20N3O4",
        monoisotopic_mass=271.148736,
        average_mass=271.2976,
        dict_composition={'H': 20, 'C': 11, 'N': 3, 'O': 4},
    ),
    "537": UnimodInfo(
        id="537",
        name="CLIP_TRAQ_4",
        formula="C9H15N2O5",
        monoisotopic_mass=244.101452,
        average_mass=244.2292,
        dict_composition={'H': 15, 'C': 9, 'N': 2, 'O': 5},
    ),
    "538": UnimodInfo(
        id="538",
        name="Biotin:Cayman-10141",
        formula="C35H54N4O4S",
        monoisotopic_mass=626.386577,
        average_mass=626.8927,
        dict_composition={'H': 54, 'C': 35, 'N': 4, 'O': 4, 'S': 1},
    ),
    "539": UnimodInfo(
        id="539",
        name="Biotin:Cayman-10013",
        formula="C36H60N4O5S",
        monoisotopic_mass=660.428442,
        average_mass=660.9504,
        dict_composition={'H': 60, 'C': 36, 'N': 4, 'O': 5, 'S': 1},
    ),
    "540": UnimodInfo(
        id="540",
        name="Ala->Ser",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=15.9994,
        dict_composition={'O': 1},
    ),
    "541": UnimodInfo(
        id="541",
        name="Ala->Thr",
        formula="CH2O",
        monoisotopic_mass=30.010565,
        average_mass=30.026,
        dict_composition={'H': 2, 'C': 1, 'O': 1},
    ),
    "542": UnimodInfo(
        id="542",
        name="Ala->Asp",
        formula="CO2",
        monoisotopic_mass=43.989829,
        average_mass=44.0095,
        dict_composition={'C': 1, 'O': 2},
    ),
    "543": UnimodInfo(
        id="543",
        name="Ala->Pro",
        formula="C2H2",
        monoisotopic_mass=26.01565,
        average_mass=26.0373,
        dict_composition={'H': 2, 'C': 2},
    ),
    "544": UnimodInfo(
        id="544",
        name="Ala->Gly",
        formula="C-1H-2",
        monoisotopic_mass=-14.01565,
        average_mass=-14.0266,
        dict_composition={'H': -2, 'C': -1},
    ),
    "545": UnimodInfo(
        id="545",
        name="Ala->Glu",
        formula="C2H2O2",
        monoisotopic_mass=58.005479,
        average_mass=58.0361,
        dict_composition={'H': 2, 'C': 2, 'O': 2},
    ),
    "546": UnimodInfo(
        id="546",
        name="Ala->Val",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.0532,
        dict_composition={'H': 4, 'C': 2},
    ),
    "547": UnimodInfo(
        id="547",
        name="Cys->Phe",
        formula="C6H4S-1",
        monoisotopic_mass=44.059229,
        average_mass=44.031,
        dict_composition={'H': 4, 'C': 6, 'S': -1},
    ),
    "548": UnimodInfo(
        id="548",
        name="Cys->Ser",
        formula="OS-1",
        monoisotopic_mass=-15.977156,
        average_mass=-16.0656,
        dict_composition={'O': 1, 'S': -1},
    ),
    "549": UnimodInfo(
        id="549",
        name="Cys->Trp",
        formula="C8H5NS-1",
        monoisotopic_mass=83.070128,
        average_mass=83.067,
        dict_composition={'H': 5, 'C': 8, 'N': 1, 'S': -1},
    ),
    "550": UnimodInfo(
        id="550",
        name="Cys->Tyr",
        formula="C6H4OS-1",
        monoisotopic_mass=60.054144,
        average_mass=60.0304,
        dict_composition={'H': 4, 'C': 6, 'O': 1, 'S': -1},
    ),
    "551": UnimodInfo(
        id="551",
        name="Cys->Arg",
        formula="C3H7N3S-1",
        monoisotopic_mass=53.091927,
        average_mass=53.0428,
        dict_composition={'H': 7, 'C': 3, 'N': 3, 'S': -1},
    ),
    "552": UnimodInfo(
        id="552",
        name="Cys->Gly",
        formula="C-1H-2S-1",
        monoisotopic_mass=-45.987721,
        average_mass=-46.0916,
        dict_composition={'H': -2, 'C': -1, 'S': -1},
    ),
    "553": UnimodInfo(
        id="553",
        name="Asp->Ala",
        formula="C-1O-2",
        monoisotopic_mass=-43.989829,
        average_mass=-44.0095,
        dict_composition={'C': -1, 'O': -2},
    ),
    "554": UnimodInfo(
        id="554",
        name="Asp->His",
        formula="C2H2N2O-2",
        monoisotopic_mass=22.031969,
        average_mass=22.0519,
        dict_composition={'H': 2, 'C': 2, 'N': 2, 'O': -2},
    ),
    "555": UnimodInfo(
        id="555",
        name="Asp->Asn",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.9848,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "556": UnimodInfo(
        id="556",
        name="Asp->Gly",
        formula="C-2H-2O-2",
        monoisotopic_mass=-58.005479,
        average_mass=-58.0361,
        dict_composition={'H': -2, 'C': -2, 'O': -2},
    ),
    "557": UnimodInfo(
        id="557",
        name="Asp->Tyr",
        formula="C5H4O-1",
        monoisotopic_mass=48.036386,
        average_mass=48.0859,
        dict_composition={'H': 4, 'C': 5, 'O': -1},
    ),
    "558": UnimodInfo(
        id="558",
        name="Asp->Glu",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.0266,
        dict_composition={'H': 2, 'C': 1},
    ),
    "559": UnimodInfo(
        id="559",
        name="Asp->Val",
        formula="CH4O-2",
        monoisotopic_mass=-15.958529,
        average_mass=-15.9563,
        dict_composition={'H': 4, 'C': 1, 'O': -2},
    ),
    "560": UnimodInfo(
        id="560",
        name="Glu->Ala",
        formula="C-2H-2O-2",
        monoisotopic_mass=-58.005479,
        average_mass=-58.0361,
        dict_composition={'H': -2, 'C': -2, 'O': -2},
    ),
    "561": UnimodInfo(
        id="561",
        name="Glu->Gln",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.9848,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
    "562": UnimodInfo(
        id="562",
        name="Glu->Asp",
        formula="C-1H-2",
        monoisotopic_mass=-14.01565,
        average_mass=-14.0266,
        dict_composition={'H': -2, 'C': -1},
    ),
    "563": UnimodInfo(
        id="563",
        name="Glu->Lys",
        formula="CH5NO-2",
        monoisotopic_mass=-0.94763,
        average_mass=-0.9417,
        dict_composition={'H': 5, 'C': 1, 'N': 1, 'O': -2},
    ),
    "564": UnimodInfo(
        id="564",
        name="Glu->Gly",
        formula="C-3H-4O-2",
        monoisotopic_mass=-72.021129,
        average_mass=-72.0627,
        dict_composition={'H': -4, 'C': -3, 'O': -2},
    ),
    "565": UnimodInfo(
        id="565",
        name="Glu->Val",
        formula="H2O-2",
        monoisotopic_mass=-29.974179,
        average_mass=-29.9829,
        dict_composition={'H': 2, 'O': -2},
    ),
    "566": UnimodInfo(
        id="566",
        name="Phe->Ser",
        formula="C-6H-4O",
        monoisotopic_mass=-60.036386,
        average_mass=-60.0966,
        dict_composition={'H': -4, 'C': -6, 'O': 1},
    ),
    "567": UnimodInfo(
        id="567",
        name="Phe->Cys",
        formula="C-6H-4S",
        monoisotopic_mass=-44.059229,
        average_mass=-44.031,
        dict_composition={'H': -4, 'C': -6, 'S': 1},
    ),
    "568": UnimodInfo(
        id="568",
        name="Phe->Xle",
        formula="C-3H2",
        monoisotopic_mass=-33.98435,
        average_mass=-34.0162,
        dict_composition={'H': 2, 'C': -3},
    ),
    "569": UnimodInfo(
        id="569",
        name="Phe->Tyr",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=15.9994,
        dict_composition={'O': 1},
    ),
    "570": UnimodInfo(
        id="570",
        name="Phe->Val",
        formula="C-4",
        monoisotopic_mass=-48.0,
        average_mass=-48.0428,
        dict_composition={'C': -4},
    ),
    "571": UnimodInfo(
        id="571",
        name="Gly->Ala",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.0266,
        dict_composition={'H': 2, 'C': 1},
    ),
    "572": UnimodInfo(
        id="572",
        name="Gly->Ser",
        formula="CH2O",
        monoisotopic_mass=30.010565,
        average_mass=30.026,
        dict_composition={'H': 2, 'C': 1, 'O': 1},
    ),
    "573": UnimodInfo(
        id="573",
        name="Gly->Trp",
        formula="C9H7N",
        monoisotopic_mass=129.057849,
        average_mass=129.1586,
        dict_composition={'H': 7, 'C': 9, 'N': 1},
    ),
    "574": UnimodInfo(
        id="574",
        name="Gly->Glu",
        formula="C3H4O2",
        monoisotopic_mass=72.021129,
        average_mass=72.0627,
        dict_composition={'H': 4, 'C': 3, 'O': 2},
    ),
    "575": UnimodInfo(
        id="575",
        name="Gly->Val",
        formula="C3H6",
        monoisotopic_mass=42.04695,
        average_mass=42.0797,
        dict_composition={'H': 6, 'C': 3},
    ),
    "576": UnimodInfo(
        id="576",
        name="Gly->Asp",
        formula="C2H2O2",
        monoisotopic_mass=58.005479,
        average_mass=58.0361,
        dict_composition={'H': 2, 'C': 2, 'O': 2},
    ),
    "577": UnimodInfo(
        id="577",
        name="Gly->Cys",
        formula="CH2S",
        monoisotopic_mass=45.987721,
        average_mass=46.0916,
        dict_composition={'H': 2, 'C': 1, 'S': 1},
    ),
    "578": UnimodInfo(
        id="578",
        name="Gly->Arg",
        formula="C4H9N3",
        monoisotopic_mass=99.079647,
        average_mass=99.1344,
        dict_composition={'H': 9, 'C': 4, 'N': 3},
    ),
    "580": UnimodInfo(
        id="580",
        name="His->Pro",
        formula="C-1N-2",
        monoisotopic_mass=-40.006148,
        average_mass=-40.0241,
        dict_composition={'C': -1, 'N': -2},
    ),
    "581": UnimodInfo(
        id="581",
        name="His->Tyr",
        formula="C3H2N-2O",
        monoisotopic_mass=26.004417,
        average_mass=26.034,
        dict_composition={'H': 2, 'C': 3, 'N': -2, 'O': 1},
    ),
    "582": UnimodInfo(
        id="582",
        name="His->Gln",
        formula="C-1HN-1O",
        monoisotopic_mass=-9.000334,
        average_mass=-9.0101,
        dict_composition={'H': 1, 'C': -1, 'N': -1, 'O': 1},
    ),
    "584": UnimodInfo(
        id="584",
        name="His->Arg",
        formula="H5N",
        monoisotopic_mass=19.042199,
        average_mass=19.0464,
        dict_composition={'H': 5, 'N': 1},
    ),
    "585": UnimodInfo(
        id="585",
        name="His->Xle",
        formula="H4N-2",
        monoisotopic_mass=-23.974848,
        average_mass=-23.9816,
        dict_composition={'H': 4, 'N': -2},
    ),
    "588": UnimodInfo(
        id="588",
        name="Xle->Thr",
        formula="C-2H-4O",
        monoisotopic_mass=-12.036386,
        average_mass=-12.0538,
        dict_composition={'H': -4, 'C': -2, 'O': 1},
    ),
    "589": UnimodInfo(
        id="589",
        name="Xle->Asn",
        formula="C-2H-5NO",
        monoisotopic_mass=0.958863,
        average_mass=0.945,
        dict_composition={'H': -5, 'C': -2, 'N': 1, 'O': 1},
    ),
    "590": UnimodInfo(
        id="590",
        name="Xle->Lys",
        formula="HN",
        monoisotopic_mass=15.010899,
        average_mass=15.0146,
        dict_composition={'H': 1, 'N': 1},
    ),
    "594": UnimodInfo(
        id="594",
        name="Lys->Thr",
        formula="C-2H-5N-1O",
        monoisotopic_mass=-27.047285,
        average_mass=-27.0684,
        dict_composition={'H': -5, 'C': -2, 'N': -1, 'O': 1},
    ),
    "595": UnimodInfo(
        id="595",
        name="Lys->Asn",
        formula="C-2H-6O",
        monoisotopic_mass=-14.052036,
        average_mass=-14.0696,
        dict_composition={'H': -6, 'C': -2, 'O': 1},
    ),
    "596": UnimodInfo(
        id="596",
        name="Lys->Glu",
        formula="C-1H-5N-1O2",
        monoisotopic_mass=0.94763,
        average_mass=0.9417,
        dict_composition={'H': -5, 'C': -1, 'N': -1, 'O': 2},
    ),
    "597": UnimodInfo(
        id="597",
        name="Lys->Gln",
        formula="C-1H-4O",
        monoisotopic_mass=-0.036386,
        average_mass=-0.0431,
        dict_composition={'H': -4, 'C': -1, 'O': 1},
    ),
    "598": UnimodInfo(
        id="598",
        name="Lys->Met",
        formula="C-1H-3N-1S",
        monoisotopic_mass=2.945522,
        average_mass=3.0238,
        dict_composition={'H': -3, 'C': -1, 'N': -1, 'S': 1},
    ),
    "599": UnimodInfo(
        id="599",
        name="Lys->Arg",
        formula="N2",
        monoisotopic_mass=28.006148,
        average_mass=28.0134,
        dict_composition={'N': 2},
    ),
    "600": UnimodInfo(
        id="600",
        name="Lys->Xle",
        formula="H-1N-1",
        monoisotopic_mass=-15.010899,
        average_mass=-15.0146,
        dict_composition={'H': -1, 'N': -1},
    ),
    "601": UnimodInfo(
        id="601",
        name="Xle->Ser",
        formula="C-3H-6O",
        monoisotopic_mass=-26.052036,
        average_mass=-26.0803,
        dict_composition={'H': -6, 'C': -3, 'O': 1},
    ),
    "602": UnimodInfo(
        id="602",
        name="Xle->Phe",
        formula="C3H-2",
        monoisotopic_mass=33.98435,
        average_mass=34.0162,
        dict_composition={'H': -2, 'C': 3},
    ),
    "603": UnimodInfo(
        id="603",
        name="Xle->Trp",
        formula="C5H-1N",
        monoisotopic_mass=72.995249,
        average_mass=73.0523,
        dict_composition={'H': -1, 'C': 5, 'N': 1},
    ),
    "604": UnimodInfo(
        id="604",
        name="Xle->Pro",
        formula="C-1H-4",
        monoisotopic_mass=-16.0313,
        average_mass=-16.0425,
        dict_composition={'H': -4, 'C': -1},
    ),
    "605": UnimodInfo(
        id="605",
        name="Xle->Val",
        formula="C-1H-2",
        monoisotopic_mass=-14.01565,
        average_mass=-14.0266,
        dict_composition={'H': -2, 'C': -1},
    ),
    "606": UnimodInfo(
        id="606",
        name="Xle->His",
        formula="H-4N2",
        monoisotopic_mass=23.974848,
        average_mass=23.9816,
        dict_composition={'H': -4, 'N': 2},
    ),
    "607": UnimodInfo(
        id="607",
        name="Xle->Gln",
        formula="C-1H-3NO",
        monoisotopic_mass=14.974514,
        average_mass=14.9716,
        dict_composition={'H': -3, 'C': -1, 'N': 1, 'O': 1},
    ),
    "608": UnimodInfo(
        id="608",
        name="Xle->Met",
        formula="C-1H-2S",
        monoisotopic_mass=17.956421,
        average_mass=18.0384,
        dict_composition={'H': -2, 'C': -1, 'S': 1},
    ),
    "609": UnimodInfo(
        id="609",
        name="Xle->Arg",
        formula="HN3",
        monoisotopic_mass=43.017047,
        average_mass=43.028,
        dict_composition={'H': 1, 'N': 3},
    ),
    "610": UnimodInfo(
        id="610",
        name="Met->Thr",
        formula="C-1H-2OS-1",
        monoisotopic_mass=-29.992806,
        average_mass=-30.0922,
        dict_composition={'H': -2, 'C': -1, 'O': 1, 'S': -1},
    ),
    "611": UnimodInfo(
        id="611",
        name="Met->Arg",
        formula="CH3N3S-1",
        monoisotopic_mass=25.060626,
        average_mass=24.9896,
        dict_composition={'H': 3, 'C': 1, 'N': 3, 'S': -1},
    ),
    "613": UnimodInfo(
        id="613",
        name="Met->Lys",
        formula="CH3NS-1",
        monoisotopic_mass=-2.945522,
        average_mass=-3.0238,
        dict_composition={'H': 3, 'C': 1, 'N': 1, 'S': -1},
    ),
    "614": UnimodInfo(
        id="614",
        name="Met->Xle",
        formula="CH2S-1",
        monoisotopic_mass=-17.956421,
        average_mass=-18.0384,
        dict_composition={'H': 2, 'C': 1, 'S': -1},
    ),
    "615": UnimodInfo(
        id="615",
        name="Met->Val",
        formula="S-1",
        monoisotopic_mass=-31.972071,
        average_mass=-32.065,
        dict_composition={'S': -1},
    ),
    "616": UnimodInfo(
        id="616",
        name="Asn->Ser",
        formula="C-1H-1N-1",
        monoisotopic_mass=-27.010899,
        average_mass=-27.0253,
        dict_composition={'H': -1, 'C': -1, 'N': -1},
    ),
    "617": UnimodInfo(
        id="617",
        name="Asn->Thr",
        formula="HN-1",
        monoisotopic_mass=-12.995249,
        average_mass=-12.9988,
        dict_composition={'H': 1, 'N': -1},
    ),
    "618": UnimodInfo(
        id="618",
        name="Asn->Lys",
        formula="C2H6O-1",
        monoisotopic_mass=14.052036,
        average_mass=14.0696,
        dict_composition={'H': 6, 'C': 2, 'O': -1},
    ),
    "619": UnimodInfo(
        id="619",
        name="Asn->Tyr",
        formula="C5H3N-1",
        monoisotopic_mass=49.020401,
        average_mass=49.0706,
        dict_composition={'H': 3, 'C': 5, 'N': -1},
    ),
    "620": UnimodInfo(
        id="620",
        name="Asn->His",
        formula="C2HNO-1",
        monoisotopic_mass=23.015984,
        average_mass=23.0366,
        dict_composition={'H': 1, 'C': 2, 'N': 1, 'O': -1},
    ),
    "621": UnimodInfo(
        id="621",
        name="Asn->Asp",
        formula="H-1N-1O",
        monoisotopic_mass=0.984016,
        average_mass=0.9848,
        dict_composition={'H': -1, 'N': -1, 'O': 1},
    ),
    "622": UnimodInfo(
        id="622",
        name="Asn->Xle",
        formula="C2H5N-1O-1",
        monoisotopic_mass=-0.958863,
        average_mass=-0.945,
        dict_composition={'H': 5, 'C': 2, 'N': -1, 'O': -1},
    ),
    "623": UnimodInfo(
        id="623",
        name="Pro->Ser",
        formula="C-2H-2O",
        monoisotopic_mass=-10.020735,
        average_mass=-10.0379,
        dict_composition={'H': -2, 'C': -2, 'O': 1},
    ),
    "624": UnimodInfo(
        id="624",
        name="Pro->Ala",
        formula="C-2H-2",
        monoisotopic_mass=-26.01565,
        average_mass=-26.0373,
        dict_composition={'H': -2, 'C': -2},
    ),
    "625": UnimodInfo(
        id="625",
        name="Pro->His",
        formula="CN2",
        monoisotopic_mass=40.006148,
        average_mass=40.0241,
        dict_composition={'C': 1, 'N': 2},
    ),
    "626": UnimodInfo(
        id="626",
        name="Pro->Gln",
        formula="HNO",
        monoisotopic_mass=31.005814,
        average_mass=31.014,
        dict_composition={'H': 1, 'N': 1, 'O': 1},
    ),
    "627": UnimodInfo(
        id="627",
        name="Pro->Thr",
        formula="C-1O",
        monoisotopic_mass=3.994915,
        average_mass=3.9887,
        dict_composition={'C': -1, 'O': 1},
    ),
    "628": UnimodInfo(
        id="628",
        name="Pro->Arg",
        formula="CH5N3",
        monoisotopic_mass=59.048347,
        average_mass=59.0705,
        dict_composition={'H': 5, 'C': 1, 'N': 3},
    ),
    "629": UnimodInfo(
        id="629",
        name="Pro->Xle",
        formula="CH4",
        monoisotopic_mass=16.0313,
        average_mass=16.0425,
        dict_composition={'H': 4, 'C': 1},
    ),
    "630": UnimodInfo(
        id="630",
        name="Gln->Pro",
        formula="H-1N-1O-1",
        monoisotopic_mass=-31.005814,
        average_mass=-31.014,
        dict_composition={'H': -1, 'N': -1, 'O': -1},
    ),
    "631": UnimodInfo(
        id="631",
        name="Gln->Lys",
        formula="CH4O-1",
        monoisotopic_mass=0.036386,
        average_mass=0.0431,
        dict_composition={'H': 4, 'C': 1, 'O': -1},
    ),
    "632": UnimodInfo(
        id="632",
        name="Gln->Glu",
        formula="H-1N-1O",
        monoisotopic_mass=0.984016,
        average_mass=0.9848,
        dict_composition={'H': -1, 'N': -1, 'O': 1},
    ),
    "633": UnimodInfo(
        id="633",
        name="Gln->His",
        formula="CH-1NO-1",
        monoisotopic_mass=9.000334,
        average_mass=9.0101,
        dict_composition={'H': -1, 'C': 1, 'N': 1, 'O': -1},
    ),
    "634": UnimodInfo(
        id="634",
        name="Gln->Arg",
        formula="CH4N2O-1",
        monoisotopic_mass=28.042534,
        average_mass=28.0565,
        dict_composition={'H': 4, 'C': 1, 'N': 2, 'O': -1},
    ),
    "635": UnimodInfo(
        id="635",
        name="Gln->Xle",
        formula="CH3N-1O-1",
        monoisotopic_mass=-14.974514,
        average_mass=-14.9716,
        dict_composition={'H': 3, 'C': 1, 'N': -1, 'O': -1},
    ),
    "636": UnimodInfo(
        id="636",
        name="Arg->Ser",
        formula="C-3H-7N-3O",
        monoisotopic_mass=-69.069083,
        average_mass=-69.1084,
        dict_composition={'H': -7, 'C': -3, 'N': -3, 'O': 1},
    ),
    "637": UnimodInfo(
        id="637",
        name="Arg->Trp",
        formula="C5H-2N-2",
        monoisotopic_mass=29.978202,
        average_mass=30.0242,
        dict_composition={'H': -2, 'C': 5, 'N': -2},
    ),
    "638": UnimodInfo(
        id="638",
        name="Arg->Thr",
        formula="C-2H-5N-3O",
        monoisotopic_mass=-55.053433,
        average_mass=-55.0818,
        dict_composition={'H': -5, 'C': -2, 'N': -3, 'O': 1},
    ),
    "639": UnimodInfo(
        id="639",
        name="Arg->Pro",
        formula="C-1H-5N-3",
        monoisotopic_mass=-59.048347,
        average_mass=-59.0705,
        dict_composition={'H': -5, 'C': -1, 'N': -3},
    ),
    "640": UnimodInfo(
        id="640",
        name="Arg->Lys",
        formula="N-2",
        monoisotopic_mass=-28.006148,
        average_mass=-28.0134,
        dict_composition={'N': -2},
    ),
    "641": UnimodInfo(
        id="641",
        name="Arg->His",
        formula="H-5N-1",
        monoisotopic_mass=-19.042199,
        average_mass=-19.0464,
        dict_composition={'H': -5, 'N': -1},
    ),
    "642": UnimodInfo(
        id="642",
        name="Arg->Gln",
        formula="C-1H-4N-2O",
        monoisotopic_mass=-28.042534,
        average_mass=-28.0565,
        dict_composition={'H': -4, 'C': -1, 'N': -2, 'O': 1},
    ),
    "643": UnimodInfo(
        id="643",
        name="Arg->Met",
        formula="C-1H-3N-3S",
        monoisotopic_mass=-25.060626,
        average_mass=-24.9896,
        dict_composition={'H': -3, 'C': -1, 'N': -3, 'S': 1},
    ),
    "644": UnimodInfo(
        id="644",
        name="Arg->Cys",
        formula="C-3H-7N-3S",
        monoisotopic_mass=-53.091927,
        average_mass=-53.0428,
        dict_composition={'H': -7, 'C': -3, 'N': -3, 'S': 1},
    ),
    "645": UnimodInfo(
        id="645",
        name="Arg->Xle",
        formula="H-1N-3",
        monoisotopic_mass=-43.017047,
        average_mass=-43.028,
        dict_composition={'H': -1, 'N': -3},
    ),
    "646": UnimodInfo(
        id="646",
        name="Arg->Gly",
        formula="C-4H-9N-3",
        monoisotopic_mass=-99.079647,
        average_mass=-99.1344,
        dict_composition={'H': -9, 'C': -4, 'N': -3},
    ),
    "647": UnimodInfo(
        id="647",
        name="Ser->Phe",
        formula="C6H4O-1",
        monoisotopic_mass=60.036386,
        average_mass=60.0966,
        dict_composition={'H': 4, 'C': 6, 'O': -1},
    ),
    "648": UnimodInfo(
        id="648",
        name="Ser->Ala",
        formula="O-1",
        monoisotopic_mass=-15.994915,
        average_mass=-15.9994,
        dict_composition={'O': -1},
    ),
    "649": UnimodInfo(
        id="649",
        name="Ser->Trp",
        formula="C8H5NO-1",
        monoisotopic_mass=99.047285,
        average_mass=99.1326,
        dict_composition={'H': 5, 'C': 8, 'N': 1, 'O': -1},
    ),
    "650": UnimodInfo(
        id="650",
        name="Ser->Thr",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.0266,
        dict_composition={'H': 2, 'C': 1},
    ),
    "651": UnimodInfo(
        id="651",
        name="Ser->Asn",
        formula="CHN",
        monoisotopic_mass=27.010899,
        average_mass=27.0253,
        dict_composition={'H': 1, 'C': 1, 'N': 1},
    ),
    "652": UnimodInfo(
        id="652",
        name="Ser->Pro",
        formula="C2H2O-1",
        monoisotopic_mass=10.020735,
        average_mass=10.0379,
        dict_composition={'H': 2, 'C': 2, 'O': -1},
    ),
    "653": UnimodInfo(
        id="653",
        name="Ser->Tyr",
        formula="C6H4",
        monoisotopic_mass=76.0313,
        average_mass=76.096,
        dict_composition={'H': 4, 'C': 6},
    ),
    "654": UnimodInfo(
        id="654",
        name="Ser->Cys",
        formula="O-1S",
        monoisotopic_mass=15.977156,
        average_mass=16.0656,
        dict_composition={'O': -1, 'S': 1},
    ),
    "655": UnimodInfo(
        id="655",
        name="Ser->Arg",
        formula="C3H7N3O-1",
        monoisotopic_mass=69.069083,
        average_mass=69.1084,
        dict_composition={'H': 7, 'C': 3, 'N': 3, 'O': -1},
    ),
    "656": UnimodInfo(
        id="656",
        name="Ser->Xle",
        formula="C3H6O-1",
        monoisotopic_mass=26.052036,
        average_mass=26.0803,
        dict_composition={'H': 6, 'C': 3, 'O': -1},
    ),
    "657": UnimodInfo(
        id="657",
        name="Ser->Gly",
        formula="C-1H-2O-1",
        monoisotopic_mass=-30.010565,
        average_mass=-30.026,
        dict_composition={'H': -2, 'C': -1, 'O': -1},
    ),
    "658": UnimodInfo(
        id="658",
        name="Thr->Ser",
        formula="C-1H-2",
        monoisotopic_mass=-14.01565,
        average_mass=-14.0266,
        dict_composition={'H': -2, 'C': -1},
    ),
    "659": UnimodInfo(
        id="659",
        name="Thr->Ala",
        formula="C-1H-2O-1",
        monoisotopic_mass=-30.010565,
        average_mass=-30.026,
        dict_composition={'H': -2, 'C': -1, 'O': -1},
    ),
    "660": UnimodInfo(
        id="660",
        name="Thr->Asn",
        formula="H-1N",
        monoisotopic_mass=12.995249,
        average_mass=12.9988,
        dict_composition={'H': -1, 'N': 1},
    ),
    "661": UnimodInfo(
        id="661",
        name="Thr->Lys",
        formula="C2H5NO-1",
        monoisotopic_mass=27.047285,
        average_mass=27.0684,
        dict_composition={'H': 5, 'C': 2, 'N': 1, 'O': -1},
    ),
    "662": UnimodInfo(
        id="662",
        name="Thr->Pro",
        formula="CO-1",
        monoisotopic_mass=-3.994915,
        average_mass=-3.9887,
        dict_composition={'C': 1, 'O': -1},
    ),
    "663": UnimodInfo(
        id="663",
        name="Thr->Met",
        formula="CH2O-1S",
        monoisotopic_mass=29.992806,
        average_mass=30.0922,
        dict_composition={'H': 2, 'C': 1, 'O': -1, 'S': 1},
    ),
    "664": UnimodInfo(
        id="664",
        name="Thr->Xle",
        formula="C2H4O-1",
        monoisotopic_mass=12.036386,
        average_mass=12.0538,
        dict_composition={'H': 4, 'C': 2, 'O': -1},
    ),
    "665": UnimodInfo(
        id="665",
        name="Thr->Arg",
        formula="C2H5N3O-1",
        monoisotopic_mass=55.053433,
        average_mass=55.0818,
        dict_composition={'H': 5, 'C': 2, 'N': 3, 'O': -1},
    ),
    "666": UnimodInfo(
        id="666",
        name="Val->Phe",
        formula="C4",
        monoisotopic_mass=48.0,
        average_mass=48.0428,
        dict_composition={'C': 4},
    ),
    "667": UnimodInfo(
        id="667",
        name="Val->Ala",
        formula="C-2H-4",
        monoisotopic_mass=-28.0313,
        average_mass=-28.0532,
        dict_composition={'H': -4, 'C': -2},
    ),
    "668": UnimodInfo(
        id="668",
        name="Val->Glu",
        formula="H-2O2",
        monoisotopic_mass=29.974179,
        average_mass=29.9829,
        dict_composition={'H': -2, 'O': 2},
    ),
    "669": UnimodInfo(
        id="669",
        name="Val->Met",
        formula="S",
        monoisotopic_mass=31.972071,
        average_mass=32.065,
        dict_composition={'S': 1},
    ),
    "670": UnimodInfo(
        id="670",
        name="Val->Asp",
        formula="C-1H-4O2",
        monoisotopic_mass=15.958529,
        average_mass=15.9563,
        dict_composition={'H': -4, 'C': -1, 'O': 2},
    ),
    "671": UnimodInfo(
        id="671",
        name="Val->Xle",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.0266,
        dict_composition={'H': 2, 'C': 1},
    ),
    "672": UnimodInfo(
        id="672",
        name="Val->Gly",
        formula="C-3H-6",
        monoisotopic_mass=-42.04695,
        average_mass=-42.0797,
        dict_composition={'H': -6, 'C': -3},
    ),
    "673": UnimodInfo(
        id="673",
        name="Trp->Ser",
        formula="C-8H-5N-1O",
        monoisotopic_mass=-99.047285,
        average_mass=-99.1326,
        dict_composition={'H': -5, 'C': -8, 'N': -1, 'O': 1},
    ),
    "674": UnimodInfo(
        id="674",
        name="Trp->Cys",
        formula="C-8H-5N-1S",
        monoisotopic_mass=-83.070128,
        average_mass=-83.067,
        dict_composition={'H': -5, 'C': -8, 'N': -1, 'S': 1},
    ),
    "675": UnimodInfo(
        id="675",
        name="Trp->Arg",
        formula="C-5H2N2",
        monoisotopic_mass=-29.978202,
        average_mass=-30.0242,
        dict_composition={'H': 2, 'C': -5, 'N': 2},
    ),
    "676": UnimodInfo(
        id="676",
        name="Trp->Gly",
        formula="C-9H-7N-1",
        monoisotopic_mass=-129.057849,
        average_mass=-129.1586,
        dict_composition={'H': -7, 'C': -9, 'N': -1},
    ),
    "677": UnimodInfo(
        id="677",
        name="Trp->Xle",
        formula="C-5HN-1",
        monoisotopic_mass=-72.995249,
        average_mass=-73.0523,
        dict_composition={'H': 1, 'C': -5, 'N': -1},
    ),
    "678": UnimodInfo(
        id="678",
        name="Tyr->Phe",
        formula="O-1",
        monoisotopic_mass=-15.994915,
        average_mass=-15.9994,
        dict_composition={'O': -1},
    ),
    "679": UnimodInfo(
        id="679",
        name="Tyr->Ser",
        formula="C-6H-4",
        monoisotopic_mass=-76.0313,
        average_mass=-76.096,
        dict_composition={'H': -4, 'C': -6},
    ),
    "680": UnimodInfo(
        id="680",
        name="Tyr->Asn",
        formula="C-5H-3N",
        monoisotopic_mass=-49.020401,
        average_mass=-49.0706,
        dict_composition={'H': -3, 'C': -5, 'N': 1},
    ),
    "681": UnimodInfo(
        id="681",
        name="Tyr->His",
        formula="C-3H-2N2O-1",
        monoisotopic_mass=-26.004417,
        average_mass=-26.034,
        dict_composition={'H': -2, 'C': -3, 'N': 2, 'O': -1},
    ),
    "682": UnimodInfo(
        id="682",
        name="Tyr->Asp",
        formula="C-5H-4O",
        monoisotopic_mass=-48.036386,
        average_mass=-48.0859,
        dict_composition={'H': -4, 'C': -5, 'O': 1},
    ),
    "683": UnimodInfo(
        id="683",
        name="Tyr->Cys",
        formula="C-6H-4O-1S",
        monoisotopic_mass=-60.054144,
        average_mass=-60.0304,
        dict_composition={'H': -4, 'C': -6, 'O': -1, 'S': 1},
    ),
    "684": UnimodInfo(
        id="684",
        name="BDMAPP",
        formula="C11H12BrNO",
        monoisotopic_mass=253.010225,
        average_mass=254.1231,
        dict_composition={'H': 12, 'C': 11, 'N': 1, 'O': 1, 'Br': 1},
    ),
    "685": UnimodInfo(
        id="685",
        name="NA-LNO2",
        formula="C18H31NO4",
        monoisotopic_mass=325.225309,
        average_mass=325.443,
        dict_composition={'H': 31, 'C': 18, 'N': 1, 'O': 4},
    ),
    "686": UnimodInfo(
        id="686",
        name="NA-OA-NO2",
        formula="C18H33NO4",
        monoisotopic_mass=327.240959,
        average_mass=327.4589,
        dict_composition={'H': 33, 'C': 18, 'N': 1, 'O': 4},
    ),
    "687": UnimodInfo(
        id="687",
        name="ICPL:2H(4)",
        formula="C6H-1NO",
        monoisotopic_mass=109.046571,
        average_mass=109.1188,
        dict_composition={'H': -1, 'C': 6, 'N': 1, 'O': 1},
    ),
    "695": UnimodInfo(
        id="695",
        name="Label:13C(6)15N(1)",
        formula="C-6N-1",
        monoisotopic_mass=7.017164,
        average_mass=6.9493,
        dict_composition={'C': -6, 'N': -1},
    ),
    "696": UnimodInfo(
        id="696",
        name="Label:2H(9)13C(6)15N(2)",
        formula="C-6H-9N-2",
        monoisotopic_mass=17.07069,
        average_mass=16.9982,
        dict_composition={'H': -9, 'C': -6, 'N': -2},
    ),
    "697": UnimodInfo(
        id="697",
        name="NIC",
        formula="C6H3NO",
        monoisotopic_mass=105.021464,
        average_mass=105.0941,
        dict_composition={'H': 3, 'C': 6, 'N': 1, 'O': 1},
    ),
    "698": UnimodInfo(
        id="698",
        name="dNIC",
        formula="C6HNO",
        monoisotopic_mass=109.048119,
        average_mass=109.1205,
        dict_composition={'H': 1, 'C': 6, 'N': 1, 'O': 1},
    ),
    "720": UnimodInfo(
        id="720",
        name="HNE-Delta:H(2)O",
        formula="C9H14O",
        monoisotopic_mass=138.104465,
        average_mass=138.2069,
        dict_composition={'H': 14, 'C': 9, 'O': 1},
    ),
    "721": UnimodInfo(
        id="721",
        name="4-ONE",
        formula="C9H14O2",
        monoisotopic_mass=154.09938,
        average_mass=154.2063,
        dict_composition={'H': 14, 'C': 9, 'O': 2},
    ),
    "723": UnimodInfo(
        id="723",
        name="O-Dimethylphosphate",
        formula="C2H5O3P",
        monoisotopic_mass=107.997631,
        average_mass=108.0331,
        dict_composition={'H': 5, 'C': 2, 'O': 3, 'P': 1},
    ),
    "724": UnimodInfo(
        id="724",
        name="O-Methylphosphate",
        formula="CH3O3P",
        monoisotopic_mass=93.981981,
        average_mass=94.0065,
        dict_composition={'H': 3, 'C': 1, 'O': 3, 'P': 1},
    ),
    "725": UnimodInfo(
        id="725",
        name="Diethylphosphate",
        formula="C4H9O3P",
        monoisotopic_mass=136.028931,
        average_mass=136.0862,
        dict_composition={'H': 9, 'C': 4, 'O': 3, 'P': 1},
    ),
    "726": UnimodInfo(
        id="726",
        name="Ethylphosphate",
        formula="C2H5O3P",
        monoisotopic_mass=107.997631,
        average_mass=108.0331,
        dict_composition={'H': 5, 'C': 2, 'O': 3, 'P': 1},
    ),
    "727": UnimodInfo(
        id="727",
        name="O-pinacolylmethylphosphonate",
        formula="C7H15O2P",
        monoisotopic_mass=162.080967,
        average_mass=162.1666,
        dict_composition={'H': 15, 'C': 7, 'O': 2, 'P': 1},
    ),
    "728": UnimodInfo(
        id="728",
        name="Methylphosphonate",
        formula="CH3O2P",
        monoisotopic_mass=77.987066,
        average_mass=78.0071,
        dict_composition={'H': 3, 'C': 1, 'O': 2, 'P': 1},
    ),
    "729": UnimodInfo(
        id="729",
        name="O-Isopropylmethylphosphonate",
        formula="C4H9O2P",
        monoisotopic_mass=120.034017,
        average_mass=120.0868,
        dict_composition={'H': 9, 'C': 4, 'O': 2, 'P': 1},
    ),
    "730": UnimodInfo(
        id="730",
        name="iTRAQ8plex",
        formula="C7H24N3O3",
        monoisotopic_mass=304.20536,
        average_mass=304.3074,
        dict_composition={'H': 24, 'C': 7, 'N': 3, 'O': 3},
    ),
    "731": UnimodInfo(
        id="731",
        name="iTRAQ8plex:13C(6)15N(2)",
        formula="C8H24N2O3",
        monoisotopic_mass=304.19904,
        average_mass=304.3081,
        dict_composition={'H': 24, 'C': 8, 'N': 2, 'O': 3},
    ),
    "734": UnimodInfo(
        id="734",
        name="Ethanolamine",
        formula="C2H5N",
        monoisotopic_mass=43.042199,
        average_mass=43.0678,
        dict_composition={'H': 5, 'C': 2, 'N': 1},
    ),
    "735": UnimodInfo(
        id="735",
        name="BEMAD_ST",
        formula="C4H8OS2",
        monoisotopic_mass=136.001656,
        average_mass=136.2357,
        dict_composition={'H': 8, 'C': 4, 'O': 1, 'S': 2},
    ),
    "736": UnimodInfo(
        id="736",
        name="BEMAD_C",
        formula="C4H8O2S",
        monoisotopic_mass=120.0245,
        average_mass=120.1701,
        dict_composition={'H': 8, 'C': 4, 'O': 2, 'S': 1},
    ),
    "737": UnimodInfo(
        id="737",
        name="TMT6plex",
        formula="C8H20NO2",
        monoisotopic_mass=229.162932,
        average_mass=229.2634,
        dict_composition={'H': 20, 'C': 8, 'N': 1, 'O': 2},
    ),
    "738": UnimodInfo(
        id="738",
        name="TMT2plex",
        formula="C11H20N2O2",
        monoisotopic_mass=225.155833,
        average_mass=225.2921,
        dict_composition={'H': 20, 'C': 11, 'N': 2, 'O': 2},
    ),
    "739": UnimodInfo(
        id="739",
        name="TMT",
        formula="C12H20N2O2",
        monoisotopic_mass=224.152478,
        average_mass=224.2994,
        dict_composition={'H': 20, 'C': 12, 'N': 2, 'O': 2},
    ),
    "740": UnimodInfo(
        id="740",
        name="ExacTagThiol",
        formula="C23H50N8O18",
        monoisotopic_mass=972.365219,
        average_mass=972.7268,
        dict_composition={'H': 50, 'C': 23, 'N': 8, 'O': 18},
    ),
    "741": UnimodInfo(
        id="741",
        name="ExacTagAmine",
        formula="C25H52N8O19S",
        monoisotopic_mass=1046.347854,
        average_mass=1046.8285,
        dict_composition={'H': 52, 'C': 25, 'N': 8, 'O': 19, 'S': 1},
    ),
    "743": UnimodInfo(
        id="743",
        name="4-ONE+Delta:H(-2)O(-1)",
        formula="C9H12O",
        monoisotopic_mass=136.088815,
        average_mass=136.191,
        dict_composition={'H': 12, 'C': 9, 'O': 1},
    ),
    "744": UnimodInfo(
        id="744",
        name="NO_SMX_SEMD",
        formula="C10H9N3O3S",
        monoisotopic_mass=251.036462,
        average_mass=251.2618,
        dict_composition={'H': 9, 'C': 10, 'N': 3, 'O': 3, 'S': 1},
    ),
    "746": UnimodInfo(
        id="746",
        name="NO_SMX_SIMD",
        formula="C10H9N3O4S",
        monoisotopic_mass=267.031377,
        average_mass=267.2612,
        dict_composition={'H': 9, 'C': 10, 'N': 3, 'O': 4, 'S': 1},
    ),
    "747": UnimodInfo(
        id="747",
        name="Malonyl",
        formula="C3H2O3",
        monoisotopic_mass=86.000394,
        average_mass=86.0462,
        dict_composition={'H': 2, 'C': 3, 'O': 3},
    ),
    "748": UnimodInfo(
        id="748",
        name="3sulfo",
        formula="C7H4O4S",
        monoisotopic_mass=183.983029,
        average_mass=184.1693,
        dict_composition={'H': 4, 'C': 7, 'O': 4, 'S': 1},
    ),
    "750": UnimodInfo(
        id="750",
        name="trifluoro",
        formula="H-3F3",
        monoisotopic_mass=53.971735,
        average_mass=53.9714,
        dict_composition={'H': -3, 'F': 3},
    ),
    "751": UnimodInfo(
        id="751",
        name="TNBS",
        formula="C6HN3O6",
        monoisotopic_mass=210.986535,
        average_mass=211.0886,
        dict_composition={'H': 1, 'C': 6, 'N': 3, 'O': 6},
    ),
    "762": UnimodInfo(
        id="762",
        name="IDEnT",
        formula="C9H7Cl2NO",
        monoisotopic_mass=214.990469,
        average_mass=216.064,
        dict_composition={'H': 7, 'C': 9, 'N': 1, 'O': 1, 'Cl': 2},
    ),
    "763": UnimodInfo(
        id="763",
        name="BEMAD_ST:2H(6)",
        formula="C4H2OS2",
        monoisotopic_mass=142.039317,
        average_mass=142.2727,
        dict_composition={'H': 2, 'C': 4, 'O': 1, 'S': 2},
    ),
    "764": UnimodInfo(
        id="764",
        name="BEMAD_C:2H(6)",
        formula="C4H2O2S",
        monoisotopic_mass=126.062161,
        average_mass=126.2071,
        dict_composition={'H': 2, 'C': 4, 'O': 2, 'S': 1},
    ),
    "765": UnimodInfo(
        id="765",
        name="Met-loss",
        formula="C-5H-9N-1O-1S-1",
        monoisotopic_mass=-131.040485,
        average_mass=-131.1961,
        dict_composition={'H': -9, 'C': -5, 'N': -1, 'O': -1, 'S': -1},
    ),
    "766": UnimodInfo(
        id="766",
        name="Met-loss+Acetyl",
        formula="C-3H-7N-1S-1",
        monoisotopic_mass=-89.02992,
        average_mass=-89.1594,
        dict_composition={'H': -7, 'C': -3, 'N': -1, 'S': -1},
    ),
    "767": UnimodInfo(
        id="767",
        name="Menadione-HQ",
        formula="C11H8O2",
        monoisotopic_mass=172.05243,
        average_mass=172.18,
        dict_composition={'H': 8, 'C': 11, 'O': 2},
    ),
    "768": UnimodInfo(
        id="768",
        name="Methyl+Acetyl:2H(3)",
        formula="C3HO",
        monoisotopic_mass=59.045045,
        average_mass=59.0817,
        dict_composition={'H': 1, 'C': 3, 'O': 1},
    ),
    "771": UnimodInfo(
        id="771",
        name="lapachenole",
        formula="C16H16O2",
        monoisotopic_mass=240.11503,
        average_mass=240.297,
        dict_composition={'H': 16, 'C': 16, 'O': 2},
    ),
    "772": UnimodInfo(
        id="772",
        name="Label:13C(5)",
        formula="C-5",
        monoisotopic_mass=5.016774,
        average_mass=4.9633,
        dict_composition={'C': -5},
    ),
    "773": UnimodInfo(
        id="773",
        name="maleimide",
        formula="C4H3NO2",
        monoisotopic_mass=97.016378,
        average_mass=97.0721,
        dict_composition={'H': 3, 'C': 4, 'N': 1, 'O': 2},
    ),
    "774": UnimodInfo(
        id="774",
        name="Biotin-phenacyl",
        formula="C29H38N8O6S",
        monoisotopic_mass=626.263502,
        average_mass=626.727,
        dict_composition={'H': 38, 'C': 29, 'N': 8, 'O': 6, 'S': 1},
    ),
    "775": UnimodInfo(
        id="775",
        name="Carboxymethyl:13C(2)",
        formula="H2O2",
        monoisotopic_mass=60.012189,
        average_mass=60.0214,
        dict_composition={'H': 2, 'C': 0, 'O': 2},
    ),
    "776": UnimodInfo(
        id="776",
        name="NEM:2H(5)",
        formula="C6H2NO2",
        monoisotopic_mass=130.079062,
        average_mass=130.1561,
        dict_composition={'H': 2, 'C': 6, 'N': 1, 'O': 2},
    ),
    "792": UnimodInfo(
        id="792",
        name="AEC-MAEC:2H(4)",
        formula="C2HNO-1S",
        monoisotopic_mass=63.044462,
        average_mass=63.158,
        dict_composition={'H': 1, 'C': 2, 'N': 1, 'O': -1, 'S': 1},
    ),
    "793": UnimodInfo(
        id="793",
        name="Hex(1)HexNAc(1)",
        formula="C14H23NO10",
        monoisotopic_mass=365.132196,
        average_mass=365.3331,
        dict_composition={'C': 14, 'H': 23, 'O': 10, 'N': 1},
    ),
    "799": UnimodInfo(
        id="799",
        name="Label:13C(6)+GG",
        formula="C-2H6N2O2",
        monoisotopic_mass=120.063056,
        average_mass=120.0586,
        dict_composition={'H': 6, 'C': -2, 'N': 2, 'O': 2},
    ),
    "800": UnimodInfo(
        id="800",
        name="Biotin:Thermo-21345",
        formula="C15H25N3O2S",
        monoisotopic_mass=311.166748,
        average_mass=311.4429,
        dict_composition={'H': 25, 'C': 15, 'N': 3, 'O': 2, 'S': 1},
    ),
    "801": UnimodInfo(
        id="801",
        name="Pentylamine",
        formula="C5H10",
        monoisotopic_mass=70.07825,
        average_mass=70.1329,
        dict_composition={'H': 10, 'C': 5},
    ),
    "811": UnimodInfo(
        id="811",
        name="Biotin:Thermo-21360",
        formula="C21H37N5O6S",
        monoisotopic_mass=487.246455,
        average_mass=487.6134,
        dict_composition={'H': 37, 'C': 21, 'N': 5, 'O': 6, 'S': 1},
    ),
    "821": UnimodInfo(
        id="821",
        name="Cy3b-maleimide",
        formula="C37H38N4O7S",
        monoisotopic_mass=682.24612,
        average_mass=682.7852,
        dict_composition={'H': 38, 'C': 37, 'N': 4, 'O': 7, 'S': 1},
    ),
    "822": UnimodInfo(
        id="822",
        name="Gly-loss+Amide",
        formula="C-2H-2O-2",
        monoisotopic_mass=-58.005479,
        average_mass=-58.0361,
        dict_composition={'H': -2, 'C': -2, 'O': -2},
    ),
    "824": UnimodInfo(
        id="824",
        name="Xlink:BMOE",
        formula="C10H8N2O4",
        monoisotopic_mass=220.048407,
        average_mass=220.1815,
        dict_composition={'H': 8, 'C': 10, 'N': 2, 'O': 4},
    ),
    "825": UnimodInfo(
        id="825",
        name="Xlink:DFDNB",
        formula="C6N2O4",
        monoisotopic_mass=163.985807,
        average_mass=164.0752,
        dict_composition={'C': 6, 'N': 2, 'O': 4},
    ),
    "827": UnimodInfo(
        id="827",
        name="TMPP-Ac",
        formula="C29H33O10P",
        monoisotopic_mass=572.181134,
        average_mass=572.5401,
        dict_composition={'H': 33, 'C': 29, 'O': 10, 'P': 1},
    ),
    "830": UnimodInfo(
        id="830",
        name="Dihydroxyimidazolidine",
        formula="C3H4O2",
        monoisotopic_mass=72.021129,
        average_mass=72.0627,
        dict_composition={'H': 4, 'C': 3, 'O': 2},
    ),
    "834": UnimodInfo(
        id="834",
        name="Label:2H(4)+Acetyl",
        formula="C2H-2O",
        monoisotopic_mass=46.035672,
        average_mass=46.0613,
        dict_composition={'H': -2, 'C': 2, 'O': 1},
    ),
    "835": UnimodInfo(
        id="835",
        name="Label:13C(6)+Acetyl",
        formula="C-4H2O",
        monoisotopic_mass=48.030694,
        average_mass=47.9926,
        dict_composition={'H': 2, 'C': -4, 'O': 1},
    ),
    "836": UnimodInfo(
        id="836",
        name="Label:13C(6)15N(2)+Acetyl",
        formula="C-4H2N-2O",
        monoisotopic_mass=50.024764,
        average_mass=49.9794,
        dict_composition={'H': 2, 'C': -4, 'N': -2, 'O': 1},
    ),
    "837": UnimodInfo(
        id="837",
        name="Arg->Npo",
        formula="C3H-1NO2",
        monoisotopic_mass=80.985078,
        average_mass=81.0297,
        dict_composition={'H': -1, 'C': 3, 'N': 1, 'O': 2},
    ),
    "846": UnimodInfo(
        id="846",
        name="EQIGG",
        formula="C20H32N6O8",
        monoisotopic_mass=484.228162,
        average_mass=484.5035,
        dict_composition={'H': 32, 'C': 20, 'N': 6, 'O': 8},
    ),
    "848": UnimodInfo(
        id="848",
        name="Arg2PG",
        formula="C16H10O4",
        monoisotopic_mass=266.057909,
        average_mass=266.2482,
        dict_composition={'H': 10, 'C': 16, 'O': 4},
    ),
    "849": UnimodInfo(
        id="849",
        name="cGMP",
        formula="C10H10N5O7P",
        monoisotopic_mass=343.031785,
        average_mass=343.1895,
        dict_composition={'H': 10, 'C': 10, 'N': 5, 'O': 7, 'P': 1},
    ),
    "851": UnimodInfo(
        id="851",
        name="cGMP+RMP-loss",
        formula="C5H4N5O",
        monoisotopic_mass=150.041585,
        average_mass=150.1182,
        dict_composition={'H': 4, 'C': 5, 'N': 5, 'O': 1},
    ),
    "853": UnimodInfo(
        id="853",
        name="Label:2H(4)+GG",
        formula="C4H2N2O2",
        monoisotopic_mass=118.068034,
        average_mass=118.1273,
        dict_composition={'H': 2, 'C': 4, 'N': 2, 'O': 2},
    ),
    "859": UnimodInfo(
        id="859",
        name="MG-H1",
        formula="C3H2O",
        monoisotopic_mass=54.010565,
        average_mass=54.0474,
        dict_composition={'H': 2, 'C': 3, 'O': 1},
    ),
    "860": UnimodInfo(
        id="860",
        name="G-H1",
        formula="C2O",
        monoisotopic_mass=39.994915,
        average_mass=40.0208,
        dict_composition={'C': 2, 'O': 1},
    ),
    "861": UnimodInfo(
        id="861",
        name="ZGB",
        formula="C37H53BF2N6O6S",
        monoisotopic_mass=758.380841,
        average_mass=758.7261,
        dict_composition={'H': 53, 'B': 1, 'C': 37, 'N': 6, 'O': 6, 'F': 2, 'S': 1},
    ),
    "862": UnimodInfo(
        id="862",
        name="Label:13C(1)2H(3)",
        formula="C-1H-3",
        monoisotopic_mass=4.022185,
        average_mass=4.0111,
        dict_composition={'H': -3, 'C': -1},
    ),
    "864": UnimodInfo(
        id="864",
        name="Label:13C(6)15N(2)+GG",
        formula="C-2H6O2",
        monoisotopic_mass=122.057126,
        average_mass=122.0454,
        dict_composition={'H': 6, 'C': -2, 'N': 0, 'O': 2},
    ),
    "866": UnimodInfo(
        id="866",
        name="ICPL:13C(6)2H(4)",
        formula="H-1NO",
        monoisotopic_mass=115.0667,
        average_mass=115.0747,
        dict_composition={'H': -1, 'C': 0, 'N': 1, 'O': 1},
    ),
    "876": UnimodInfo(
        id="876",
        name="QEQTGG",
        formula="C23H36N8O11",
        monoisotopic_mass=600.250354,
        average_mass=600.5789,
        dict_composition={'H': 36, 'C': 23, 'N': 8, 'O': 11},
    ),
    "877": UnimodInfo(
        id="877",
        name="QQQTGG",
        formula="C23H37N9O10",
        monoisotopic_mass=599.266339,
        average_mass=599.5942,
        dict_composition={'H': 37, 'C': 23, 'N': 9, 'O': 10},
    ),
    "884": UnimodInfo(
        id="884",
        name="Biotin:Thermo-21325",
        formula="C34H45N7O7S",
        monoisotopic_mass=695.310118,
        average_mass=695.8288,
        dict_composition={'H': 45, 'C': 34, 'N': 7, 'O': 7, 'S': 1},
    ),
    "885": UnimodInfo(
        id="885",
        name="Label:13C(1)2H(3)+Oxidation",
        formula="C-1H-3O",
        monoisotopic_mass=20.0171,
        average_mass=20.0105,
        dict_composition={'H': -3, 'C': -1, 'O': 1},
    ),
    "886": UnimodInfo(
        id="886",
        name="HydroxymethylOP",
        formula="C6H4O2",
        monoisotopic_mass=108.021129,
        average_mass=108.0948,
        dict_composition={'H': 4, 'C': 6, 'O': 2},
    ),
    "887": UnimodInfo(
        id="887",
        name="MDCC",
        formula="C20H21N3O5",
        monoisotopic_mass=383.148121,
        average_mass=383.3978,
        dict_composition={'H': 21, 'C': 20, 'N': 3, 'O': 5},
    ),
    "888": UnimodInfo(
        id="888",
        name="mTRAQ",
        formula="C7H12N2O",
        monoisotopic_mass=140.094963,
        average_mass=140.183,
        dict_composition={'H': 12, 'C': 7, 'N': 2, 'O': 1},
    ),
    "889": UnimodInfo(
        id="889",
        name="mTRAQ:13C(3)15N(1)",
        formula="C4H12NO",
        monoisotopic_mass=144.102063,
        average_mass=144.1544,
        dict_composition={'H': 12, 'C': 4, 'N': 1, 'O': 1},
    ),
    "890": UnimodInfo(
        id="890",
        name="DyLight-maleimide",
        formula="C39H48N4O15S4",
        monoisotopic_mass=940.1999,
        average_mass=941.0762,
        dict_composition={'H': 48, 'C': 39, 'N': 4, 'O': 15, 'S': 4},
    ),
    "891": UnimodInfo(
        id="891",
        name="Methyl-PEO12-Maleimide",
        formula="C32H58N2O15",
        monoisotopic_mass=710.383719,
        average_mass=710.8073,
        dict_composition={'H': 58, 'C': 32, 'N': 2, 'O': 15},
    ),
    "893": UnimodInfo(
        id="893",
        name="CarbamidomethylDTT",
        formula="C6H11NO3S2",
        monoisotopic_mass=209.018035,
        average_mass=209.2864,
        dict_composition={'H': 11, 'C': 6, 'N': 1, 'O': 3, 'S': 2},
    ),
    "894": UnimodInfo(
        id="894",
        name="CarboxymethylDTT",
        formula="C6H10O4S2",
        monoisotopic_mass=210.00205,
        average_mass=210.2712,
        dict_composition={'H': 10, 'C': 6, 'O': 4, 'S': 2},
    ),
    "895": UnimodInfo(
        id="895",
        name="Biotin-PEG-PRA",
        formula="C26H42N8O7",
        monoisotopic_mass=578.317646,
        average_mass=578.6611,
        dict_composition={'H': 42, 'C': 26, 'N': 8, 'O': 7},
    ),
    "896": UnimodInfo(
        id="896",
        name="Met->Aha",
        formula="C-1H-3N3S-1",
        monoisotopic_mass=-4.986324,
        average_mass=-5.0794,
        dict_composition={'H': -3, 'C': -1, 'N': 3, 'S': -1},
    ),
    "897": UnimodInfo(
        id="897",
        name="Label:15N(4)",
        formula="N-4",
        monoisotopic_mass=3.98814,
        average_mass=3.9736,
        dict_composition={'N': -4},
    ),
    "898": UnimodInfo(
        id="898",
        name="pyrophospho",
        formula="H2O6P2",
        monoisotopic_mass=159.932662,
        average_mass=159.9598,
        dict_composition={'H': 2, 'O': 6, 'P': 2},
    ),
    "899": UnimodInfo(
        id="899",
        name="Met->Hpg",
        formula="CH-2S-1",
        monoisotopic_mass=-21.987721,
        average_mass=-22.0702,
        dict_composition={'H': -2, 'C': 1, 'S': -1},
    ),
    "901": UnimodInfo(
        id="901",
        name="4AcAllylGal",
        formula="C17H24O9",
        monoisotopic_mass=372.142033,
        average_mass=372.3671,
        dict_composition={'H': 24, 'C': 17, 'O': 9},
    ),
    "902": UnimodInfo(
        id="902",
        name="DimethylArsino",
        formula="C2H5As",
        monoisotopic_mass=103.960719,
        average_mass=103.9827,
        dict_composition={'H': 5, 'C': 2, 'As': 1},
    ),
    "903": UnimodInfo(
        id="903",
        name="Lys->CamCys",
        formula="C-1H-4OS",
        monoisotopic_mass=31.935685,
        average_mass=32.0219,
        dict_composition={'H': -4, 'C': -1, 'O': 1, 'S': 1},
    ),
    "904": UnimodInfo(
        id="904",
        name="Phe->CamCys",
        formula="C-4H-1NOS",
        monoisotopic_mass=12.962234,
        average_mass=13.0204,
        dict_composition={'H': -1, 'C': -4, 'N': 1, 'O': 1, 'S': 1},
    ),
    "905": UnimodInfo(
        id="905",
        name="Leu->MetOx",
        formula="C-1H-2OS",
        monoisotopic_mass=33.951335,
        average_mass=34.0378,
        dict_composition={'H': -2, 'C': -1, 'O': 1, 'S': 1},
    ),
    "906": UnimodInfo(
        id="906",
        name="Lys->MetOx",
        formula="C-1H-3N-1OS",
        monoisotopic_mass=18.940436,
        average_mass=19.0232,
        dict_composition={'H': -3, 'C': -1, 'N': -1, 'O': 1, 'S': 1},
    ),
    "907": UnimodInfo(
        id="907",
        name="Galactosyl",
        formula="C6H10O6",
        monoisotopic_mass=178.047738,
        average_mass=178.14,
        dict_composition={'O': 6, 'C': 6, 'H': 10},
    ),
    "908": UnimodInfo(
        id="908",
        name="Xlink:SMCC[321]",
        formula="C17H27N3O3",
        monoisotopic_mass=321.205242,
        average_mass=321.4146,
        dict_composition={'H': 27, 'C': 17, 'N': 3, 'O': 3},
    ),
    "910": UnimodInfo(
        id="910",
        name="Bacillosamine",
        formula="C10H16N2O4",
        monoisotopic_mass=228.111007,
        average_mass=228.245,
        dict_composition={'H': 16, 'C': 10, 'N': 2, 'O': 4},
    ),
    "911": UnimodInfo(
        id="911",
        name="MTSL",
        formula="C9H14NOS",
        monoisotopic_mass=184.07961,
        average_mass=184.2786,
        dict_composition={'H': 14, 'C': 9, 'N': 1, 'O': 1, 'S': 1},
    ),
    "912": UnimodInfo(
        id="912",
        name="HNE-BAHAH",
        formula="C25H45N5O4S",
        monoisotopic_mass=511.319226,
        average_mass=511.7209,
        dict_composition={'H': 45, 'C': 25, 'N': 5, 'O': 4, 'S': 1},
    ),
    "914": UnimodInfo(
        id="914",
        name="Methylmalonylation",
        formula="C4H4O3",
        monoisotopic_mass=100.016044,
        average_mass=100.0728,
        dict_composition={'H': 4, 'C': 4, 'O': 3},
    ),
    "923": UnimodInfo(
        id="923",
        name="Label:13C(4)15N(2)+GG",
        formula="H6O2",
        monoisotopic_mass=120.050417,
        average_mass=120.0601,
        dict_composition={'H': 6, 'C': 0, 'N': 0, 'O': 2},
    ),
    "926": UnimodInfo(
        id="926",
        name="ethylamino",
        formula="C2H5NO-1",
        monoisotopic_mass=27.047285,
        average_mass=27.0684,
        dict_composition={'H': 5, 'C': 2, 'N': 1, 'O': -1},
    ),
    "928": UnimodInfo(
        id="928",
        name="MercaptoEthanol",
        formula="C2H4S",
        monoisotopic_mass=60.003371,
        average_mass=60.1182,
        dict_composition={'H': 4, 'C': 2, 'S': 1},
    ),
    "931": UnimodInfo(
        id="931",
        name="Ethyl+Deamidated",
        formula="C2H3N-1O",
        monoisotopic_mass=29.015316,
        average_mass=29.0379,
        dict_composition={'H': 3, 'C': 2, 'N': -1, 'O': 1},
    ),
    "932": UnimodInfo(
        id="932",
        name="VFQQQTGG",
        formula="C37H55N11O12",
        monoisotopic_mass=845.403166,
        average_mass=845.8991,
        dict_composition={'H': 55, 'C': 37, 'N': 11, 'O': 12},
    ),
    "933": UnimodInfo(
        id="933",
        name="VIEVYQEQTGG",
        formula="C53H81N13O19",
        monoisotopic_mass=1203.577168,
        average_mass=1204.2859,
        dict_composition={'H': 81, 'C': 53, 'N': 13, 'O': 19},
    ),
    "934": UnimodInfo(
        id="934",
        name="AMTzHexNAc2",
        formula="C19H30N6O10",
        monoisotopic_mass=502.202341,
        average_mass=502.4757,
        dict_composition={'H': 30, 'C': 19, 'N': 6, 'O': 10},
    ),
    "935": UnimodInfo(
        id="935",
        name="Atto495Maleimide",
        formula="C27H32N5O3",
        monoisotopic_mass=474.250515,
        average_mass=474.5747,
        dict_composition={'H': 32, 'C': 27, 'N': 5, 'O': 3},
    ),
    "936": UnimodInfo(
        id="936",
        name="Chlorination",
        formula="H-1Cl",
        monoisotopic_mass=33.961028,
        average_mass=34.4451,
        dict_composition={'H': -1, 'Cl': 1},
    ),
    "937": UnimodInfo(
        id="937",
        name="dichlorination",
        formula="H-2Cl2",
        monoisotopic_mass=67.922055,
        average_mass=68.8901,
        dict_composition={'H': -2, 'Cl': 2},
    ),
    "938": UnimodInfo(
        id="938",
        name="AROD",
        formula="C35H52N10O9S2",
        monoisotopic_mass=820.336015,
        average_mass=820.979,
        dict_composition={'H': 52, 'C': 35, 'N': 10, 'O': 9, 'S': 2},
    ),
    "939": UnimodInfo(
        id="939",
        name="Cys->methylaminoAla",
        formula="CH3NS-1",
        monoisotopic_mass=-2.945522,
        average_mass=-3.0238,
        dict_composition={'H': 3, 'C': 1, 'N': 1, 'S': -1},
    ),
    "940": UnimodInfo(
        id="940",
        name="Cys->ethylaminoAla",
        formula="C2H5NS-1",
        monoisotopic_mass=11.070128,
        average_mass=11.0028,
        dict_composition={'H': 5, 'C': 2, 'N': 1, 'S': -1},
    ),
    "941": UnimodInfo(
        id="941",
        name="DNPS",
        formula="C6H3N2O4S",
        monoisotopic_mass=198.981352,
        average_mass=199.164,
        dict_composition={'H': 3, 'C': 6, 'N': 2, 'O': 4, 'S': 1},
    ),
    "942": UnimodInfo(
        id="942",
        name="SulfoGMBS",
        formula="C22H26N4O5S",
        monoisotopic_mass=458.162391,
        average_mass=458.5306,
        dict_composition={'H': 26, 'C': 22, 'N': 4, 'O': 5, 'S': 1},
    ),
    "943": UnimodInfo(
        id="943",
        name="DimethylamineGMBS",
        formula="C13H21N3O3",
        monoisotopic_mass=267.158292,
        average_mass=267.3241,
        dict_composition={'H': 21, 'C': 13, 'N': 3, 'O': 3},
    ),
    "944": UnimodInfo(
        id="944",
        name="Label:15N(2)2H(9)",
        formula="H-9N-2",
        monoisotopic_mass=11.050561,
        average_mass=11.0423,
        dict_composition={'H': -9, 'N': -2},
    ),
    "946": UnimodInfo(
        id="946",
        name="LG-anhydrolactam",
        formula="C20H26O3",
        monoisotopic_mass=314.188195,
        average_mass=314.4186,
        dict_composition={'H': 26, 'C': 20, 'O': 3},
    ),
    "947": UnimodInfo(
        id="947",
        name="LG-pyrrole",
        formula="C20H28O3",
        monoisotopic_mass=316.203845,
        average_mass=316.4345,
        dict_composition={'H': 28, 'C': 20, 'O': 3},
    ),
    "948": UnimodInfo(
        id="948",
        name="LG-anhyropyrrole",
        formula="C20H26O2",
        monoisotopic_mass=298.19328,
        average_mass=298.4192,
        dict_composition={'H': 26, 'C': 20, 'O': 2},
    ),
    "949": UnimodInfo(
        id="949",
        name="3-deoxyglucosone",
        formula="C6H8O4",
        monoisotopic_mass=144.042259,
        average_mass=144.1253,
        dict_composition={'H': 8, 'C': 6, 'O': 4},
    ),
    "950": UnimodInfo(
        id="950",
        name="Cation:Li",
        formula="H-1Li",
        monoisotopic_mass=6.008178,
        average_mass=5.9331,
        dict_composition={'H': -1, 'Li': 1},
    ),
    "951": UnimodInfo(
        id="951",
        name="Cation:Ca[II]",
        formula="H-2Ca",
        monoisotopic_mass=37.946941,
        average_mass=38.0621,
        dict_composition={'H': -2, 'Ca': 1},
    ),
    "952": UnimodInfo(
        id="952",
        name="Cation:Fe[II]",
        formula="H-2Fe",
        monoisotopic_mass=53.919289,
        average_mass=53.8291,
        dict_composition={'H': -2, 'Fe': 1},
    ),
    "953": UnimodInfo(
        id="953",
        name="Cation:Ni[II]",
        formula="H-2Ni",
        monoisotopic_mass=55.919696,
        average_mass=56.6775,
        dict_composition={'H': -2, 'Ni': 1},
    ),
    "954": UnimodInfo(
        id="954",
        name="Cation:Zn[II]",
        formula="H-2Zn",
        monoisotopic_mass=61.913495,
        average_mass=63.3931,
        dict_composition={'H': -2, 'Zn': 1},
    ),
    "955": UnimodInfo(
        id="955",
        name="Cation:Ag",
        formula="H-1Ag",
        monoisotopic_mass=105.897267,
        average_mass=106.8603,
        dict_composition={'H': -1, 'Ag': 1},
    ),
    "956": UnimodInfo(
        id="956",
        name="Cation:Mg[II]",
        formula="H-2Mg",
        monoisotopic_mass=21.969392,
        average_mass=22.2891,
        dict_composition={'H': -2, 'Mg': 1},
    ),
    "957": UnimodInfo(
        id="957",
        name="2-succinyl",
        formula="C4H4O4",
        monoisotopic_mass=116.010959,
        average_mass=116.0722,
        dict_composition={'H': 4, 'C': 4, 'O': 4},
    ),
    "958": UnimodInfo(
        id="958",
        name="Propargylamine",
        formula="C3H3NO-1",
        monoisotopic_mass=37.031634,
        average_mass=37.0632,
        dict_composition={'H': 3, 'C': 3, 'N': 1, 'O': -1},
    ),
    "959": UnimodInfo(
        id="959",
        name="Phosphopropargyl",
        formula="C3H4NO2P",
        monoisotopic_mass=116.997965,
        average_mass=117.0431,
        dict_composition={'H': 4, 'C': 3, 'N': 1, 'O': 2, 'P': 1},
    ),
    "960": UnimodInfo(
        id="960",
        name="SUMO2135",
        formula="C90H137N21O37S",
        monoisotopic_mass=2135.920496,
        average_mass=2137.2343,
        dict_composition={'H': 137, 'C': 90, 'N': 21, 'O': 37, 'S': 1},
    ),
    "961": UnimodInfo(
        id="961",
        name="SUMO3549",
        formula="C150H224N38O60S",
        monoisotopic_mass=3549.536568,
        average_mass=3551.6672,
        dict_composition={'H': 224, 'C': 150, 'N': 38, 'O': 60, 'S': 1},
    ),
    "967": UnimodInfo(
        id="967",
        name="thioacylPA",
        formula="C6H9NO2S",
        monoisotopic_mass=159.035399,
        average_mass=159.2062,
        dict_composition={'H': 9, 'C': 6, 'N': 1, 'O': 2, 'S': 1},
    ),
    "971": UnimodInfo(
        id="971",
        name="maleimide3",
        formula="C37H59N7O23",
        monoisotopic_mass=969.366232,
        average_mass=969.8975,
        dict_composition={'H': 59, 'C': 37, 'N': 7, 'O': 23},
    ),
    "972": UnimodInfo(
        id="972",
        name="maleimide5",
        formula="C49H79N7O33",
        monoisotopic_mass=1293.471879,
        average_mass=1294.1787,
        dict_composition={'H': 79, 'C': 49, 'N': 7, 'O': 33},
    ),
    "973": UnimodInfo(
        id="973",
        name="Puromycin",
        formula="C22H27N7O4",
        monoisotopic_mass=453.212452,
        average_mass=453.4943,
        dict_composition={'H': 27, 'C': 22, 'N': 7, 'O': 4},
    ),
    "977": UnimodInfo(
        id="977",
        name="Carbofuran",
        formula="C2H3NO",
        monoisotopic_mass=57.021464,
        average_mass=57.0513,
        dict_composition={'H': 3, 'C': 2, 'N': 1, 'O': 1},
    ),
    "978": UnimodInfo(
        id="978",
        name="BITC",
        formula="C8H7NS",
        monoisotopic_mass=149.02992,
        average_mass=149.2129,
        dict_composition={'H': 7, 'C': 8, 'N': 1, 'S': 1},
    ),
    "979": UnimodInfo(
        id="979",
        name="PEITC",
        formula="C9H9NS",
        monoisotopic_mass=163.04557,
        average_mass=163.2395,
        dict_composition={'H': 9, 'C': 9, 'N': 1, 'S': 1},
    ),
    "981": UnimodInfo(
        id="981",
        name="glucosone",
        formula="C6H8O5",
        monoisotopic_mass=160.037173,
        average_mass=160.1247,
        dict_composition={'H': 8, 'C': 6, 'O': 5},
    ),
    "984": UnimodInfo(
        id="984",
        name="cysTMT",
        formula="C14H25N3O2S",
        monoisotopic_mass=299.166748,
        average_mass=299.4322,
        dict_composition={'H': 25, 'C': 14, 'N': 3, 'O': 2, 'S': 1},
    ),
    "985": UnimodInfo(
        id="985",
        name="cysTMT6plex",
        formula="C10H25N2O2S",
        monoisotopic_mass=304.177202,
        average_mass=304.3962,
        dict_composition={'H': 25, 'C': 10, 'N': 2, 'O': 2, 'S': 1},
    ),
    "986": UnimodInfo(
        id="986",
        name="Label:13C(6)+Dimethyl",
        formula="C-4H4",
        monoisotopic_mass=34.051429,
        average_mass=34.0091,
        dict_composition={'H': 4, 'C': -4},
    ),
    "987": UnimodInfo(
        id="987",
        name="Label:13C(6)15N(2)+Dimethyl",
        formula="C-4H4N-2",
        monoisotopic_mass=36.045499,
        average_mass=35.9959,
        dict_composition={'H': 4, 'C': -4, 'N': -2},
    ),
    "989": UnimodInfo(
        id="989",
        name="Ammonium",
        formula="H3N",
        monoisotopic_mass=17.026549,
        average_mass=17.0305,
        dict_composition={'H': 3, 'N': 1},
    ),
    "991": UnimodInfo(
        id="991",
        name="ISD_z+2_ion",
        formula="H-1N-1",
        monoisotopic_mass=-15.010899,
        average_mass=-15.0146,
        dict_composition={'H': -1, 'N': -1},
    ),
    "993": UnimodInfo(
        id="993",
        name="Biotin:Sigma-B1267",
        formula="C20H27N5O5S",
        monoisotopic_mass=449.17329,
        average_mass=449.5239,
        dict_composition={'H': 27, 'C': 20, 'N': 5, 'O': 5, 'S': 1},
    ),
    "994": UnimodInfo(
        id="994",
        name="Label:15N(1)",
        formula="N-1",
        monoisotopic_mass=0.997035,
        average_mass=0.9934,
        dict_composition={'N': -1},
    ),
    "995": UnimodInfo(
        id="995",
        name="Label:15N(2)",
        formula="N-2",
        monoisotopic_mass=1.99407,
        average_mass=1.9868,
        dict_composition={'N': -2},
    ),
    "996": UnimodInfo(
        id="996",
        name="Label:15N(3)",
        formula="N-3",
        monoisotopic_mass=2.991105,
        average_mass=2.9802,
        dict_composition={'N': -3},
    ),
    "997": UnimodInfo(
        id="997",
        name="sulfo+amino",
        formula="HNO3S",
        monoisotopic_mass=94.967714,
        average_mass=95.0778,
        dict_composition={'H': 1, 'N': 1, 'O': 3, 'S': 1},
    ),
    "1000": UnimodInfo(
        id="1000",
        name="AHA-Alkyne",
        formula="C4H5N5OS-1",
        monoisotopic_mass=107.077339,
        average_mass=107.0504,
        dict_composition={'H': 5, 'C': 4, 'N': 5, 'O': 1, 'S': -1},
    ),
    "1001": UnimodInfo(
        id="1001",
        name="AHA-Alkyne-KDDDD",
        formula="C26H37N11O14S-1",
        monoisotopic_mass=695.280074,
        average_mass=695.5723,
        dict_composition={'H': 37, 'C': 26, 'N': 11, 'O': 14, 'S': -1},
    ),
    "1002": UnimodInfo(
        id="1002",
        name="EGCG1",
        formula="C22H16O11",
        monoisotopic_mass=456.069261,
        average_mass=456.3558,
        dict_composition={'H': 16, 'C': 22, 'O': 11},
    ),
    "1003": UnimodInfo(
        id="1003",
        name="EGCG2",
        formula="C15H11O6",
        monoisotopic_mass=287.055563,
        average_mass=287.2442,
        dict_composition={'H': 11, 'C': 15, 'O': 6},
    ),
    "1004": UnimodInfo(
        id="1004",
        name="Label:13C(6)15N(4)+Methyl",
        formula="C-5H2N-4",
        monoisotopic_mass=24.023919,
        average_mass=23.9561,
        dict_composition={'H': 2, 'C': -5, 'N': -4},
    ),
    "1005": UnimodInfo(
        id="1005",
        name="Label:13C(6)15N(4)+Dimethyl",
        formula="C-4H4N-4",
        monoisotopic_mass=38.039569,
        average_mass=37.9827,
        dict_composition={'H': 4, 'C': -4, 'N': -4},
    ),
    "1006": UnimodInfo(
        id="1006",
        name="Label:13C(6)15N(4)+Methyl:2H(3)13C(1)",
        formula="C-6H-1N-4",
        monoisotopic_mass=28.046104,
        average_mass=27.9673,
        dict_composition={'H': -1, 'C': -6, 'N': -4},
    ),
    "1007": UnimodInfo(
        id="1007",
        name="Label:13C(6)15N(4)+Dimethyl:2H(6)13C(2)",
        formula="C-6H-2N-4",
        monoisotopic_mass=46.083939,
        average_mass=46.005,
        dict_composition={'H': -2, 'C': -6, 'N': -4},
    ),
    "1008": UnimodInfo(
        id="1008",
        name="Cys->CamSec",
        formula="C2H3NOS-1Se",
        monoisotopic_mass=104.965913,
        average_mass=103.9463,
        dict_composition={'H': 3, 'C': 2, 'N': 1, 'O': 1, 'S': -1, 'Se': 1},
    ),
    "1009": UnimodInfo(
        id="1009",
        name="Thiazolidine",
        formula="C",
        monoisotopic_mass=12.0,
        average_mass=12.0107,
        dict_composition={'C': 1},
    ),
    "1010": UnimodInfo(
        id="1010",
        name="DEDGFLYMVYASQETFG",
        formula="C89H122N18O31S",
        monoisotopic_mass=1970.824411,
        average_mass=1972.088,
        dict_composition={'H': 122, 'C': 89, 'N': 18, 'O': 31, 'S': 1},
    ),
    "1012": UnimodInfo(
        id="1012",
        name="Biotin:Invitrogen-M1602",
        formula="C23H33N5O7S",
        monoisotopic_mass=523.210069,
        average_mass=523.6024,
        dict_composition={'H': 33, 'C': 23, 'N': 5, 'O': 7, 'S': 1},
    ),
    "1014": UnimodInfo(
        id="1014",
        name="glycidamide",
        formula="C3H5NO2",
        monoisotopic_mass=87.032028,
        average_mass=87.0773,
        dict_composition={'H': 5, 'C': 3, 'N': 1, 'O': 2},
    ),
    "1015": UnimodInfo(
        id="1015",
        name="Ahx2+Hsl",
        formula="C16H27N3O3",
        monoisotopic_mass=309.205242,
        average_mass=309.4039,
        dict_composition={'H': 27, 'C': 16, 'N': 3, 'O': 3},
    ),
    "1017": UnimodInfo(
        id="1017",
        name="DMPO",
        formula="C6H9NO",
        monoisotopic_mass=111.068414,
        average_mass=111.1418,
        dict_composition={'H': 9, 'C': 6, 'N': 1, 'O': 1},
    ),
    "1018": UnimodInfo(
        id="1018",
        name="ICDID",
        formula="C8H10O2",
        monoisotopic_mass=138.06808,
        average_mass=138.1638,
        dict_composition={'H': 10, 'C': 8, 'O': 2},
    ),
    "1019": UnimodInfo(
        id="1019",
        name="ICDID:2H(6)",
        formula="C8H4O2",
        monoisotopic_mass=144.10574,
        average_mass=144.2008,
        dict_composition={'H': 4, 'C': 8, 'O': 2},
    ),
    "1020": UnimodInfo(
        id="1020",
        name="Xlink:DSS[156]",
        formula="C8H12O3",
        monoisotopic_mass=156.078644,
        average_mass=156.1791,
        dict_composition={'H': 12, 'C': 8, 'O': 3},
    ),
    "1021": UnimodInfo(
        id="1021",
        name="Xlink:EGS[244]",
        formula="C10H12O7",
        monoisotopic_mass=244.058303,
        average_mass=244.1981,
        dict_composition={'H': 12, 'C': 10, 'O': 7},
    ),
    "1022": UnimodInfo(
        id="1022",
        name="Xlink:DST[132]",
        formula="C4H4O5",
        monoisotopic_mass=132.005873,
        average_mass=132.0716,
        dict_composition={'H': 4, 'C': 4, 'O': 5},
    ),
    "1023": UnimodInfo(
        id="1023",
        name="Xlink:DTSSP[192]",
        formula="C6H8O3S2",
        monoisotopic_mass=191.991486,
        average_mass=192.2559,
        dict_composition={'H': 8, 'C': 6, 'O': 3, 'S': 2},
    ),
    "1024": UnimodInfo(
        id="1024",
        name="Xlink:SMCC[237]",
        formula="C12H15NO4",
        monoisotopic_mass=237.100108,
        average_mass=237.2518,
        dict_composition={'H': 15, 'C': 12, 'N': 1, 'O': 4},
    ),
    "1027": UnimodInfo(
        id="1027",
        name="Xlink:DMP[140]",
        formula="C7H12N2O",
        monoisotopic_mass=140.094963,
        average_mass=140.183,
        dict_composition={'H': 12, 'C': 7, 'N': 2, 'O': 1},
    ),
    "1028": UnimodInfo(
        id="1028",
        name="Xlink:EGS[115]",
        formula="C4H5NO3",
        monoisotopic_mass=115.026943,
        average_mass=115.0874,
        dict_composition={'H': 5, 'C': 4, 'N': 1, 'O': 3},
    ),
    "1031": UnimodInfo(
        id="1031",
        name="Biotin:Thermo-88310",
        formula="C10H16N2O2",
        monoisotopic_mass=196.121178,
        average_mass=196.2462,
        dict_composition={'H': 16, 'C': 10, 'N': 2, 'O': 2},
    ),
    "1032": UnimodInfo(
        id="1032",
        name="2-nitrobenzyl",
        formula="C7H5NO2",
        monoisotopic_mass=135.032028,
        average_mass=135.1201,
        dict_composition={'H': 5, 'C': 7, 'N': 1, 'O': 2},
    ),
    "1033": UnimodInfo(
        id="1033",
        name="Cys->SecNEM",
        formula="C6H7NO2S-1Se",
        monoisotopic_mass=172.992127,
        average_mass=172.0203,
        dict_composition={'H': 7, 'C': 6, 'N': 1, 'O': 2, 'S': -1, 'Se': 1},
    ),
    "1034": UnimodInfo(
        id="1034",
        name="Cys->SecNEM:2H(5)",
        formula="C6H2NO2S-1Se",
        monoisotopic_mass=178.023511,
        average_mass=177.0511,
        dict_composition={'H': 2, 'C': 6, 'N': 1, 'O': 2, 'S': -1, 'Se': 1},
    ),
    "1035": UnimodInfo(
        id="1035",
        name="Thiadiazole",
        formula="C9H6N2S",
        monoisotopic_mass=174.025169,
        average_mass=174.2223,
        dict_composition={'H': 6, 'C': 9, 'N': 2, 'S': 1},
    ),
    "1036": UnimodInfo(
        id="1036",
        name="Withaferin",
        formula="C28H38O6",
        monoisotopic_mass=470.266839,
        average_mass=470.5977,
        dict_composition={'H': 38, 'C': 28, 'O': 6},
    ),
    "1037": UnimodInfo(
        id="1037",
        name="Biotin:Thermo-88317",
        formula="C22H42N3O4P",
        monoisotopic_mass=443.291294,
        average_mass=443.5603,
        dict_composition={'H': 42, 'C': 22, 'N': 3, 'O': 4, 'P': 1},
    ),
    "1038": UnimodInfo(
        id="1038",
        name="TAMRA-FP",
        formula="C37H46N3O6P",
        monoisotopic_mass=659.312423,
        average_mass=659.7514,
        dict_composition={'H': 46, 'C': 37, 'N': 3, 'O': 6, 'P': 1},
    ),
    "1039": UnimodInfo(
        id="1039",
        name="Biotin:Thermo-21901+H2O",
        formula="C23H37N5O8S",
        monoisotopic_mass=543.236284,
        average_mass=543.6336,
        dict_composition={'H': 37, 'C': 23, 'N': 5, 'O': 8, 'S': 1},
    ),
    "1041": UnimodInfo(
        id="1041",
        name="Deoxyhypusine",
        formula="C4H9N",
        monoisotopic_mass=71.073499,
        average_mass=71.121,
        dict_composition={'H': 9, 'C': 4, 'N': 1},
    ),
    "1042": UnimodInfo(
        id="1042",
        name="Acetyldeoxyhypusine",
        formula="C6H11NO",
        monoisotopic_mass=113.084064,
        average_mass=113.1576,
        dict_composition={'H': 11, 'C': 6, 'N': 1, 'O': 1},
    ),
    "1043": UnimodInfo(
        id="1043",
        name="Acetylhypusine",
        formula="C6H11NO2",
        monoisotopic_mass=129.078979,
        average_mass=129.157,
        dict_composition={'H': 11, 'C': 6, 'N': 1, 'O': 2},
    ),
    "1044": UnimodInfo(
        id="1044",
        name="Ala->Cys",
        formula="S",
        monoisotopic_mass=31.972071,
        average_mass=32.065,
        dict_composition={'S': 1},
    ),
    "1045": UnimodInfo(
        id="1045",
        name="Ala->Phe",
        formula="C6H4",
        monoisotopic_mass=76.0313,
        average_mass=76.096,
        dict_composition={'H': 4, 'C': 6},
    ),
    "1046": UnimodInfo(
        id="1046",
        name="Ala->His",
        formula="C3H2N2",
        monoisotopic_mass=66.021798,
        average_mass=66.0614,
        dict_composition={'H': 2, 'C': 3, 'N': 2},
    ),
    "1047": UnimodInfo(
        id="1047",
        name="Ala->Xle",
        formula="C3H6",
        monoisotopic_mass=42.04695,
        average_mass=42.0797,
        dict_composition={'H': 6, 'C': 3},
    ),
    "1048": UnimodInfo(
        id="1048",
        name="Ala->Lys",
        formula="C3H7N",
        monoisotopic_mass=57.057849,
        average_mass=57.0944,
        dict_composition={'H': 7, 'C': 3, 'N': 1},
    ),
    "1049": UnimodInfo(
        id="1049",
        name="Ala->Met",
        formula="C2H4S",
        monoisotopic_mass=60.003371,
        average_mass=60.1182,
        dict_composition={'H': 4, 'C': 2, 'S': 1},
    ),
    "1050": UnimodInfo(
        id="1050",
        name="Ala->Asn",
        formula="CHNO",
        monoisotopic_mass=43.005814,
        average_mass=43.0247,
        dict_composition={'H': 1, 'C': 1, 'N': 1, 'O': 1},
    ),
    "1051": UnimodInfo(
        id="1051",
        name="Ala->Gln",
        formula="C2H3NO",
        monoisotopic_mass=57.021464,
        average_mass=57.0513,
        dict_composition={'H': 3, 'C': 2, 'N': 1, 'O': 1},
    ),
    "1052": UnimodInfo(
        id="1052",
        name="Ala->Arg",
        formula="C3H7N3",
        monoisotopic_mass=85.063997,
        average_mass=85.1078,
        dict_composition={'H': 7, 'C': 3, 'N': 3},
    ),
    "1053": UnimodInfo(
        id="1053",
        name="Ala->Trp",
        formula="C8H5N",
        monoisotopic_mass=115.042199,
        average_mass=115.132,
        dict_composition={'H': 5, 'C': 8, 'N': 1},
    ),
    "1054": UnimodInfo(
        id="1054",
        name="Ala->Tyr",
        formula="C6H4O",
        monoisotopic_mass=92.026215,
        average_mass=92.0954,
        dict_composition={'H': 4, 'C': 6, 'O': 1},
    ),
    "1055": UnimodInfo(
        id="1055",
        name="Cys->Ala",
        formula="S-1",
        monoisotopic_mass=-31.972071,
        average_mass=-32.065,
        dict_composition={'S': -1},
    ),
    "1056": UnimodInfo(
        id="1056",
        name="Cys->Asp",
        formula="CO2S-1",
        monoisotopic_mass=12.017759,
        average_mass=11.9445,
        dict_composition={'C': 1, 'O': 2, 'S': -1},
    ),
    "1057": UnimodInfo(
        id="1057",
        name="Cys->Glu",
        formula="C2H2O2S-1",
        monoisotopic_mass=26.033409,
        average_mass=25.9711,
        dict_composition={'H': 2, 'C': 2, 'O': 2, 'S': -1},
    ),
    "1058": UnimodInfo(
        id="1058",
        name="Cys->His",
        formula="C3H2N2S-1",
        monoisotopic_mass=34.049727,
        average_mass=33.9964,
        dict_composition={'H': 2, 'C': 3, 'N': 2, 'S': -1},
    ),
    "1059": UnimodInfo(
        id="1059",
        name="Cys->Xle",
        formula="C3H6S-1",
        monoisotopic_mass=10.07488,
        average_mass=10.0147,
        dict_composition={'H': 6, 'C': 3, 'S': -1},
    ),
    "1060": UnimodInfo(
        id="1060",
        name="Cys->Lys",
        formula="C3H7NS-1",
        monoisotopic_mass=25.085779,
        average_mass=25.0294,
        dict_composition={'H': 7, 'C': 3, 'N': 1, 'S': -1},
    ),
    "1061": UnimodInfo(
        id="1061",
        name="Cys->Met",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.0532,
        dict_composition={'H': 4, 'C': 2},
    ),
    "1062": UnimodInfo(
        id="1062",
        name="Cys->Asn",
        formula="CHNOS-1",
        monoisotopic_mass=11.033743,
        average_mass=10.9597,
        dict_composition={'H': 1, 'C': 1, 'N': 1, 'O': 1, 'S': -1},
    ),
    "1063": UnimodInfo(
        id="1063",
        name="Cys->Pro",
        formula="C2H2S-1",
        monoisotopic_mass=-5.956421,
        average_mass=-6.0277,
        dict_composition={'H': 2, 'C': 2, 'S': -1},
    ),
    "1064": UnimodInfo(
        id="1064",
        name="Cys->Gln",
        formula="C2H3NOS-1",
        monoisotopic_mass=25.049393,
        average_mass=24.9863,
        dict_composition={'H': 3, 'C': 2, 'N': 1, 'O': 1, 'S': -1},
    ),
    "1065": UnimodInfo(
        id="1065",
        name="Cys->Thr",
        formula="CH2OS-1",
        monoisotopic_mass=-1.961506,
        average_mass=-2.039,
        dict_composition={'H': 2, 'C': 1, 'O': 1, 'S': -1},
    ),
    "1066": UnimodInfo(
        id="1066",
        name="Cys->Val",
        formula="C2H4S-1",
        monoisotopic_mass=-3.940771,
        average_mass=-4.0118,
        dict_composition={'H': 4, 'C': 2, 'S': -1},
    ),
    "1067": UnimodInfo(
        id="1067",
        name="Asp->Cys",
        formula="C-1O-2S",
        monoisotopic_mass=-12.017759,
        average_mass=-11.9445,
        dict_composition={'C': -1, 'O': -2, 'S': 1},
    ),
    "1068": UnimodInfo(
        id="1068",
        name="Asp->Phe",
        formula="C5H4O-2",
        monoisotopic_mass=32.041471,
        average_mass=32.0865,
        dict_composition={'H': 4, 'C': 5, 'O': -2},
    ),
    "1069": UnimodInfo(
        id="1069",
        name="Asp->Xle",
        formula="C2H6O-2",
        monoisotopic_mass=-1.942879,
        average_mass=-1.9298,
        dict_composition={'H': 6, 'C': 2, 'O': -2},
    ),
    "1070": UnimodInfo(
        id="1070",
        name="Asp->Lys",
        formula="C2H7NO-2",
        monoisotopic_mass=13.06802,
        average_mass=13.0849,
        dict_composition={'H': 7, 'C': 2, 'N': 1, 'O': -2},
    ),
    "1071": UnimodInfo(
        id="1071",
        name="Asp->Met",
        formula="CH4O-2S",
        monoisotopic_mass=16.013542,
        average_mass=16.1087,
        dict_composition={'H': 4, 'C': 1, 'O': -2, 'S': 1},
    ),
    "1072": UnimodInfo(
        id="1072",
        name="Asp->Pro",
        formula="CH2O-2",
        monoisotopic_mass=-17.974179,
        average_mass=-17.9722,
        dict_composition={'H': 2, 'C': 1, 'O': -2},
    ),
    "1073": UnimodInfo(
        id="1073",
        name="Asp->Gln",
        formula="CH3NO-1",
        monoisotopic_mass=13.031634,
        average_mass=13.0418,
        dict_composition={'H': 3, 'C': 1, 'N': 1, 'O': -1},
    ),
    "1074": UnimodInfo(
        id="1074",
        name="Asp->Arg",
        formula="C2H7N3O-2",
        monoisotopic_mass=41.074168,
        average_mass=41.0983,
        dict_composition={'H': 7, 'C': 2, 'N': 3, 'O': -2},
    ),
    "1075": UnimodInfo(
        id="1075",
        name="Asp->Ser",
        formula="C-1O-1",
        monoisotopic_mass=-27.994915,
        average_mass=-28.0101,
        dict_composition={'C': -1, 'O': -1},
    ),
    "1076": UnimodInfo(
        id="1076",
        name="Asp->Thr",
        formula="H2O-1",
        monoisotopic_mass=-13.979265,
        average_mass=-13.9835,
        dict_composition={'H': 2, 'O': -1},
    ),
    "1077": UnimodInfo(
        id="1077",
        name="Asp->Trp",
        formula="C7H5NO-2",
        monoisotopic_mass=71.05237,
        average_mass=71.1225,
        dict_composition={'H': 5, 'C': 7, 'N': 1, 'O': -2},
    ),
    "1078": UnimodInfo(
        id="1078",
        name="Glu->Cys",
        formula="C-2H-2O-2S",
        monoisotopic_mass=-26.033409,
        average_mass=-25.9711,
        dict_composition={'H': -2, 'C': -2, 'O': -2, 'S': 1},
    ),
    "1079": UnimodInfo(
        id="1079",
        name="Glu->Phe",
        formula="C4H2O-2",
        monoisotopic_mass=18.025821,
        average_mass=18.0599,
        dict_composition={'H': 2, 'C': 4, 'O': -2},
    ),
    "1080": UnimodInfo(
        id="1080",
        name="Glu->His",
        formula="CN2O-2",
        monoisotopic_mass=8.016319,
        average_mass=8.0253,
        dict_composition={'C': 1, 'N': 2, 'O': -2},
    ),
    "1081": UnimodInfo(
        id="1081",
        name="Glu->Xle",
        formula="CH4O-2",
        monoisotopic_mass=-15.958529,
        average_mass=-15.9563,
        dict_composition={'H': 4, 'C': 1, 'O': -2},
    ),
    "1082": UnimodInfo(
        id="1082",
        name="Glu->Met",
        formula="H2O-2S",
        monoisotopic_mass=1.997892,
        average_mass=2.0821,
        dict_composition={'H': 2, 'O': -2, 'S': 1},
    ),
    "1083": UnimodInfo(
        id="1083",
        name="Glu->Asn",
        formula="C-1H-1NO-1",
        monoisotopic_mass=-14.999666,
        average_mass=-15.0113,
        dict_composition={'H': -1, 'C': -1, 'N': 1, 'O': -1},
    ),
    "1084": UnimodInfo(
        id="1084",
        name="Glu->Pro",
        formula="O-2",
        monoisotopic_mass=-31.989829,
        average_mass=-31.9988,
        dict_composition={'O': -2},
    ),
    "1085": UnimodInfo(
        id="1085",
        name="Glu->Arg",
        formula="CH5N3O-2",
        monoisotopic_mass=27.058518,
        average_mass=27.0717,
        dict_composition={'H': 5, 'C': 1, 'N': 3, 'O': -2},
    ),
    "1086": UnimodInfo(
        id="1086",
        name="Glu->Ser",
        formula="C-2H-2O-1",
        monoisotopic_mass=-42.010565,
        average_mass=-42.0367,
        dict_composition={'H': -2, 'C': -2, 'O': -1},
    ),
    "1087": UnimodInfo(
        id="1087",
        name="Glu->Thr",
        formula="C-1O-1",
        monoisotopic_mass=-27.994915,
        average_mass=-28.0101,
        dict_composition={'C': -1, 'O': -1},
    ),
    "1088": UnimodInfo(
        id="1088",
        name="Glu->Trp",
        formula="C6H3NO-2",
        monoisotopic_mass=57.03672,
        average_mass=57.0959,
        dict_composition={'H': 3, 'C': 6, 'N': 1, 'O': -2},
    ),
    "1089": UnimodInfo(
        id="1089",
        name="Glu->Tyr",
        formula="C4H2O-1",
        monoisotopic_mass=34.020735,
        average_mass=34.0593,
        dict_composition={'H': 2, 'C': 4, 'O': -1},
    ),
    "1090": UnimodInfo(
        id="1090",
        name="Phe->Ala",
        formula="C-6H-4",
        monoisotopic_mass=-76.0313,
        average_mass=-76.096,
        dict_composition={'H': -4, 'C': -6},
    ),
    "1091": UnimodInfo(
        id="1091",
        name="Phe->Asp",
        formula="C-5H-4O2",
        monoisotopic_mass=-32.041471,
        average_mass=-32.0865,
        dict_composition={'H': -4, 'C': -5, 'O': 2},
    ),
    "1092": UnimodInfo(
        id="1092",
        name="Phe->Glu",
        formula="C-4H-2O2",
        monoisotopic_mass=-18.025821,
        average_mass=-18.0599,
        dict_composition={'H': -2, 'C': -4, 'O': 2},
    ),
    "1093": UnimodInfo(
        id="1093",
        name="Phe->Gly",
        formula="C-7H-6",
        monoisotopic_mass=-90.04695,
        average_mass=-90.1225,
        dict_composition={'H': -6, 'C': -7},
    ),
    "1094": UnimodInfo(
        id="1094",
        name="Phe->His",
        formula="C-3H-2N2",
        monoisotopic_mass=-10.009502,
        average_mass=-10.0346,
        dict_composition={'H': -2, 'C': -3, 'N': 2},
    ),
    "1095": UnimodInfo(
        id="1095",
        name="Phe->Lys",
        formula="C-3H3N",
        monoisotopic_mass=-18.973451,
        average_mass=-19.0016,
        dict_composition={'H': 3, 'C': -3, 'N': 1},
    ),
    "1096": UnimodInfo(
        id="1096",
        name="Phe->Met",
        formula="C-4S",
        monoisotopic_mass=-16.027929,
        average_mass=-15.9778,
        dict_composition={'C': -4, 'S': 1},
    ),
    "1097": UnimodInfo(
        id="1097",
        name="Phe->Asn",
        formula="C-5H-3NO",
        monoisotopic_mass=-33.025486,
        average_mass=-33.0712,
        dict_composition={'H': -3, 'C': -5, 'N': 1, 'O': 1},
    ),
    "1098": UnimodInfo(
        id="1098",
        name="Phe->Pro",
        formula="C-4H-2",
        monoisotopic_mass=-50.01565,
        average_mass=-50.0587,
        dict_composition={'H': -2, 'C': -4},
    ),
    "1099": UnimodInfo(
        id="1099",
        name="Phe->Gln",
        formula="C-4H-1NO",
        monoisotopic_mass=-19.009836,
        average_mass=-19.0446,
        dict_composition={'H': -1, 'C': -4, 'N': 1, 'O': 1},
    ),
    "1100": UnimodInfo(
        id="1100",
        name="Phe->Arg",
        formula="C-3H3N3",
        monoisotopic_mass=9.032697,
        average_mass=9.0118,
        dict_composition={'H': 3, 'C': -3, 'N': 3},
    ),
    "1101": UnimodInfo(
        id="1101",
        name="Phe->Thr",
        formula="C-5H-2O",
        monoisotopic_mass=-46.020735,
        average_mass=-46.07,
        dict_composition={'H': -2, 'C': -5, 'O': 1},
    ),
    "1102": UnimodInfo(
        id="1102",
        name="Phe->Trp",
        formula="C2HN",
        monoisotopic_mass=39.010899,
        average_mass=39.036,
        dict_composition={'H': 1, 'C': 2, 'N': 1},
    ),
    "1103": UnimodInfo(
        id="1103",
        name="Gly->Phe",
        formula="C7H6",
        monoisotopic_mass=90.04695,
        average_mass=90.1225,
        dict_composition={'H': 6, 'C': 7},
    ),
    "1104": UnimodInfo(
        id="1104",
        name="Gly->His",
        formula="C4H4N2",
        monoisotopic_mass=80.037448,
        average_mass=80.088,
        dict_composition={'H': 4, 'C': 4, 'N': 2},
    ),
    "1105": UnimodInfo(
        id="1105",
        name="Gly->Xle",
        formula="C4H8",
        monoisotopic_mass=56.0626,
        average_mass=56.1063,
        dict_composition={'H': 8, 'C': 4},
    ),
    "1106": UnimodInfo(
        id="1106",
        name="Gly->Lys",
        formula="C4H9N",
        monoisotopic_mass=71.073499,
        average_mass=71.121,
        dict_composition={'H': 9, 'C': 4, 'N': 1},
    ),
    "1107": UnimodInfo(
        id="1107",
        name="Gly->Met",
        formula="C3H6S",
        monoisotopic_mass=74.019021,
        average_mass=74.1447,
        dict_composition={'H': 6, 'C': 3, 'S': 1},
    ),
    "1108": UnimodInfo(
        id="1108",
        name="Gly->Asn",
        formula="C2H3NO",
        monoisotopic_mass=57.021464,
        average_mass=57.0513,
        dict_composition={'H': 3, 'C': 2, 'N': 1, 'O': 1},
    ),
    "1109": UnimodInfo(
        id="1109",
        name="Gly->Pro",
        formula="C3H4",
        monoisotopic_mass=40.0313,
        average_mass=40.0639,
        dict_composition={'H': 4, 'C': 3},
    ),
    "1110": UnimodInfo(
        id="1110",
        name="Gly->Gln",
        formula="C3H5NO",
        monoisotopic_mass=71.037114,
        average_mass=71.0779,
        dict_composition={'H': 5, 'C': 3, 'N': 1, 'O': 1},
    ),
    "1111": UnimodInfo(
        id="1111",
        name="Gly->Thr",
        formula="C2H4O",
        monoisotopic_mass=44.026215,
        average_mass=44.0526,
        dict_composition={'H': 4, 'C': 2, 'O': 1},
    ),
    "1112": UnimodInfo(
        id="1112",
        name="Gly->Tyr",
        formula="C7H6O",
        monoisotopic_mass=106.041865,
        average_mass=106.1219,
        dict_composition={'H': 6, 'C': 7, 'O': 1},
    ),
    "1113": UnimodInfo(
        id="1113",
        name="His->Ala",
        formula="C-3H-2N-2",
        monoisotopic_mass=-66.021798,
        average_mass=-66.0614,
        dict_composition={'H': -2, 'C': -3, 'N': -2},
    ),
    "1114": UnimodInfo(
        id="1114",
        name="His->Cys",
        formula="C-3H-2N-2S",
        monoisotopic_mass=-34.049727,
        average_mass=-33.9964,
        dict_composition={'H': -2, 'C': -3, 'N': -2, 'S': 1},
    ),
    "1115": UnimodInfo(
        id="1115",
        name="His->Glu",
        formula="C-1N-2O2",
        monoisotopic_mass=-8.016319,
        average_mass=-8.0253,
        dict_composition={'C': -1, 'N': -2, 'O': 2},
    ),
    "1116": UnimodInfo(
        id="1116",
        name="His->Phe",
        formula="C3H2N-2",
        monoisotopic_mass=10.009502,
        average_mass=10.0346,
        dict_composition={'H': 2, 'C': 3, 'N': -2},
    ),
    "1117": UnimodInfo(
        id="1117",
        name="His->Gly",
        formula="C-4H-4N-2",
        monoisotopic_mass=-80.037448,
        average_mass=-80.088,
        dict_composition={'H': -4, 'C': -4, 'N': -2},
    ),
    "1119": UnimodInfo(
        id="1119",
        name="His->Lys",
        formula="H5N-1",
        monoisotopic_mass=-8.963949,
        average_mass=-8.967,
        dict_composition={'H': 5, 'N': -1},
    ),
    "1120": UnimodInfo(
        id="1120",
        name="His->Met",
        formula="C-1H2N-2S",
        monoisotopic_mass=-6.018427,
        average_mass=-5.9432,
        dict_composition={'H': 2, 'C': -1, 'N': -2, 'S': 1},
    ),
    "1121": UnimodInfo(
        id="1121",
        name="His->Ser",
        formula="C-3H-2N-2O",
        monoisotopic_mass=-50.026883,
        average_mass=-50.062,
        dict_composition={'H': -2, 'C': -3, 'N': -2, 'O': 1},
    ),
    "1122": UnimodInfo(
        id="1122",
        name="His->Thr",
        formula="C-2N-2O",
        monoisotopic_mass=-36.011233,
        average_mass=-36.0354,
        dict_composition={'C': -2, 'N': -2, 'O': 1},
    ),
    "1123": UnimodInfo(
        id="1123",
        name="His->Val",
        formula="C-1H2N-2",
        monoisotopic_mass=-37.990498,
        average_mass=-38.0082,
        dict_composition={'H': 2, 'C': -1, 'N': -2},
    ),
    "1124": UnimodInfo(
        id="1124",
        name="His->Trp",
        formula="C5H3N-1",
        monoisotopic_mass=49.020401,
        average_mass=49.0706,
        dict_composition={'H': 3, 'C': 5, 'N': -1},
    ),
    "1125": UnimodInfo(
        id="1125",
        name="Xle->Ala",
        formula="C-3H-6",
        monoisotopic_mass=-42.04695,
        average_mass=-42.0797,
        dict_composition={'H': -6, 'C': -3},
    ),
    "1126": UnimodInfo(
        id="1126",
        name="Xle->Cys",
        formula="C-3H-6S",
        monoisotopic_mass=-10.07488,
        average_mass=-10.0147,
        dict_composition={'H': -6, 'C': -3, 'S': 1},
    ),
    "1127": UnimodInfo(
        id="1127",
        name="Xle->Asp",
        formula="C-2H-6O2",
        monoisotopic_mass=1.942879,
        average_mass=1.9298,
        dict_composition={'H': -6, 'C': -2, 'O': 2},
    ),
    "1128": UnimodInfo(
        id="1128",
        name="Xle->Glu",
        formula="C-1H-4O2",
        monoisotopic_mass=15.958529,
        average_mass=15.9563,
        dict_composition={'H': -4, 'C': -1, 'O': 2},
    ),
    "1129": UnimodInfo(
        id="1129",
        name="Xle->Gly",
        formula="C-4H-8",
        monoisotopic_mass=-56.0626,
        average_mass=-56.1063,
        dict_composition={'H': -8, 'C': -4},
    ),
    "1130": UnimodInfo(
        id="1130",
        name="Xle->Tyr",
        formula="C3H-2O",
        monoisotopic_mass=49.979265,
        average_mass=50.0156,
        dict_composition={'H': -2, 'C': 3, 'O': 1},
    ),
    "1131": UnimodInfo(
        id="1131",
        name="Lys->Ala",
        formula="C-3H-7N-1",
        monoisotopic_mass=-57.057849,
        average_mass=-57.0944,
        dict_composition={'H': -7, 'C': -3, 'N': -1},
    ),
    "1132": UnimodInfo(
        id="1132",
        name="Lys->Cys",
        formula="C-3H-7N-1S",
        monoisotopic_mass=-25.085779,
        average_mass=-25.0294,
        dict_composition={'H': -7, 'C': -3, 'N': -1, 'S': 1},
    ),
    "1133": UnimodInfo(
        id="1133",
        name="Lys->Asp",
        formula="C-2H-7N-1O2",
        monoisotopic_mass=-13.06802,
        average_mass=-13.0849,
        dict_composition={'H': -7, 'C': -2, 'N': -1, 'O': 2},
    ),
    "1134": UnimodInfo(
        id="1134",
        name="Lys->Phe",
        formula="C3H-3N-1",
        monoisotopic_mass=18.973451,
        average_mass=19.0016,
        dict_composition={'H': -3, 'C': 3, 'N': -1},
    ),
    "1135": UnimodInfo(
        id="1135",
        name="Lys->Gly",
        formula="C-4H-9N-1",
        monoisotopic_mass=-71.073499,
        average_mass=-71.121,
        dict_composition={'H': -9, 'C': -4, 'N': -1},
    ),
    "1136": UnimodInfo(
        id="1136",
        name="Lys->His",
        formula="H-5N",
        monoisotopic_mass=8.963949,
        average_mass=8.967,
        dict_composition={'H': -5, 'N': 1},
    ),
    "1137": UnimodInfo(
        id="1137",
        name="Lys->Pro",
        formula="C-1H-5N-1",
        monoisotopic_mass=-31.042199,
        average_mass=-31.0571,
        dict_composition={'H': -5, 'C': -1, 'N': -1},
    ),
    "1138": UnimodInfo(
        id="1138",
        name="Lys->Ser",
        formula="C-3H-7N-1O",
        monoisotopic_mass=-41.062935,
        average_mass=-41.095,
        dict_composition={'H': -7, 'C': -3, 'N': -1, 'O': 1},
    ),
    "1139": UnimodInfo(
        id="1139",
        name="Lys->Val",
        formula="C-1H-3N-1",
        monoisotopic_mass=-29.026549,
        average_mass=-29.0412,
        dict_composition={'H': -3, 'C': -1, 'N': -1},
    ),
    "1140": UnimodInfo(
        id="1140",
        name="Lys->Trp",
        formula="C5H-2",
        monoisotopic_mass=57.98435,
        average_mass=58.0376,
        dict_composition={'H': -2, 'C': 5},
    ),
    "1141": UnimodInfo(
        id="1141",
        name="Lys->Tyr",
        formula="C3H-3N-1O",
        monoisotopic_mass=34.968366,
        average_mass=35.001,
        dict_composition={'H': -3, 'C': 3, 'N': -1, 'O': 1},
    ),
    "1142": UnimodInfo(
        id="1142",
        name="Met->Ala",
        formula="C-2H-4S-1",
        monoisotopic_mass=-60.003371,
        average_mass=-60.1182,
        dict_composition={'H': -4, 'C': -2, 'S': -1},
    ),
    "1143": UnimodInfo(
        id="1143",
        name="Met->Cys",
        formula="C-2H-4",
        monoisotopic_mass=-28.0313,
        average_mass=-28.0532,
        dict_composition={'H': -4, 'C': -2},
    ),
    "1144": UnimodInfo(
        id="1144",
        name="Met->Asp",
        formula="C-1H-4O2S-1",
        monoisotopic_mass=-16.013542,
        average_mass=-16.1087,
        dict_composition={'H': -4, 'C': -1, 'O': 2, 'S': -1},
    ),
    "1145": UnimodInfo(
        id="1145",
        name="Met->Glu",
        formula="H-2O2S-1",
        monoisotopic_mass=-1.997892,
        average_mass=-2.0821,
        dict_composition={'H': -2, 'O': 2, 'S': -1},
    ),
    "1146": UnimodInfo(
        id="1146",
        name="Met->Phe",
        formula="C4S-1",
        monoisotopic_mass=16.027929,
        average_mass=15.9778,
        dict_composition={'C': 4, 'S': -1},
    ),
    "1147": UnimodInfo(
        id="1147",
        name="Met->Gly",
        formula="C-3H-6S-1",
        monoisotopic_mass=-74.019021,
        average_mass=-74.1447,
        dict_composition={'H': -6, 'C': -3, 'S': -1},
    ),
    "1148": UnimodInfo(
        id="1148",
        name="Met->His",
        formula="CH-2N2S-1",
        monoisotopic_mass=6.018427,
        average_mass=5.9432,
        dict_composition={'H': -2, 'C': 1, 'N': 2, 'S': -1},
    ),
    "1149": UnimodInfo(
        id="1149",
        name="Met->Asn",
        formula="C-1H-3NOS-1",
        monoisotopic_mass=-16.997557,
        average_mass=-17.0934,
        dict_composition={'H': -3, 'C': -1, 'N': 1, 'O': 1, 'S': -1},
    ),
    "1150": UnimodInfo(
        id="1150",
        name="Met->Pro",
        formula="H-2S-1",
        monoisotopic_mass=-33.987721,
        average_mass=-34.0809,
        dict_composition={'H': -2, 'S': -1},
    ),
    "1151": UnimodInfo(
        id="1151",
        name="Met->Gln",
        formula="H-1NOS-1",
        monoisotopic_mass=-2.981907,
        average_mass=-3.0668,
        dict_composition={'H': -1, 'N': 1, 'O': 1, 'S': -1},
    ),
    "1152": UnimodInfo(
        id="1152",
        name="Met->Ser",
        formula="C-2H-4OS-1",
        monoisotopic_mass=-44.008456,
        average_mass=-44.1188,
        dict_composition={'H': -4, 'C': -2, 'O': 1, 'S': -1},
    ),
    "1153": UnimodInfo(
        id="1153",
        name="Met->Trp",
        formula="C6HNS-1",
        monoisotopic_mass=55.038828,
        average_mass=55.0138,
        dict_composition={'H': 1, 'C': 6, 'N': 1, 'S': -1},
    ),
    "1154": UnimodInfo(
        id="1154",
        name="Met->Tyr",
        formula="C4OS-1",
        monoisotopic_mass=32.022844,
        average_mass=31.9772,
        dict_composition={'C': 4, 'O': 1, 'S': -1},
    ),
    "1155": UnimodInfo(
        id="1155",
        name="Asn->Ala",
        formula="C-1H-1N-1O-1",
        monoisotopic_mass=-43.005814,
        average_mass=-43.0247,
        dict_composition={'H': -1, 'C': -1, 'N': -1, 'O': -1},
    ),
    "1156": UnimodInfo(
        id="1156",
        name="Asn->Cys",
        formula="C-1H-1N-1O-1S",
        monoisotopic_mass=-11.033743,
        average_mass=-10.9597,
        dict_composition={'H': -1, 'C': -1, 'N': -1, 'O': -1, 'S': 1},
    ),
    "1157": UnimodInfo(
        id="1157",
        name="Asn->Glu",
        formula="CHN-1O",
        monoisotopic_mass=14.999666,
        average_mass=15.0113,
        dict_composition={'H': 1, 'C': 1, 'N': -1, 'O': 1},
    ),
    "1158": UnimodInfo(
        id="1158",
        name="Asn->Phe",
        formula="C5H3N-1O-1",
        monoisotopic_mass=33.025486,
        average_mass=33.0712,
        dict_composition={'H': 3, 'C': 5, 'N': -1, 'O': -1},
    ),
    "1159": UnimodInfo(
        id="1159",
        name="Asn->Gly",
        formula="C-2H-3N-1O-1",
        monoisotopic_mass=-57.021464,
        average_mass=-57.0513,
        dict_composition={'H': -3, 'C': -2, 'N': -1, 'O': -1},
    ),
    "1160": UnimodInfo(
        id="1160",
        name="Asn->Met",
        formula="CH3N-1O-1S",
        monoisotopic_mass=16.997557,
        average_mass=17.0934,
        dict_composition={'H': 3, 'C': 1, 'N': -1, 'O': -1, 'S': 1},
    ),
    "1161": UnimodInfo(
        id="1161",
        name="Asn->Pro",
        formula="CHN-1O-1",
        monoisotopic_mass=-16.990164,
        average_mass=-16.9875,
        dict_composition={'H': 1, 'C': 1, 'N': -1, 'O': -1},
    ),
    "1162": UnimodInfo(
        id="1162",
        name="Asn->Gln",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.0266,
        dict_composition={'H': 2, 'C': 1},
    ),
    "1163": UnimodInfo(
        id="1163",
        name="Asn->Arg",
        formula="C2H6N2O-1",
        monoisotopic_mass=42.058184,
        average_mass=42.083,
        dict_composition={'H': 6, 'C': 2, 'N': 2, 'O': -1},
    ),
    "1164": UnimodInfo(
        id="1164",
        name="Asn->Val",
        formula="CH3N-1O-1",
        monoisotopic_mass=-14.974514,
        average_mass=-14.9716,
        dict_composition={'H': 3, 'C': 1, 'N': -1, 'O': -1},
    ),
    "1165": UnimodInfo(
        id="1165",
        name="Asn->Trp",
        formula="C7H4O-1",
        monoisotopic_mass=72.036386,
        average_mass=72.1073,
        dict_composition={'H': 4, 'C': 7, 'O': -1},
    ),
    "1166": UnimodInfo(
        id="1166",
        name="Pro->Cys",
        formula="C-2H-2S",
        monoisotopic_mass=5.956421,
        average_mass=6.0277,
        dict_composition={'H': -2, 'C': -2, 'S': 1},
    ),
    "1167": UnimodInfo(
        id="1167",
        name="Pro->Asp",
        formula="C-1H-2O2",
        monoisotopic_mass=17.974179,
        average_mass=17.9722,
        dict_composition={'H': -2, 'C': -1, 'O': 2},
    ),
    "1168": UnimodInfo(
        id="1168",
        name="Pro->Glu",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=31.9988,
        dict_composition={'O': 2},
    ),
    "1169": UnimodInfo(
        id="1169",
        name="Pro->Phe",
        formula="C4H2",
        monoisotopic_mass=50.01565,
        average_mass=50.0587,
        dict_composition={'H': 2, 'C': 4},
    ),
    "1170": UnimodInfo(
        id="1170",
        name="Pro->Gly",
        formula="C-3H-4",
        monoisotopic_mass=-40.0313,
        average_mass=-40.0639,
        dict_composition={'H': -4, 'C': -3},
    ),
    "1171": UnimodInfo(
        id="1171",
        name="Pro->Lys",
        formula="CH5N",
        monoisotopic_mass=31.042199,
        average_mass=31.0571,
        dict_composition={'H': 5, 'C': 1, 'N': 1},
    ),
    "1172": UnimodInfo(
        id="1172",
        name="Pro->Met",
        formula="H2S",
        monoisotopic_mass=33.987721,
        average_mass=34.0809,
        dict_composition={'H': 2, 'S': 1},
    ),
    "1173": UnimodInfo(
        id="1173",
        name="Pro->Asn",
        formula="C-1H-1NO",
        monoisotopic_mass=16.990164,
        average_mass=16.9875,
        dict_composition={'H': -1, 'C': -1, 'N': 1, 'O': 1},
    ),
    "1174": UnimodInfo(
        id="1174",
        name="Pro->Val",
        formula="H2",
        monoisotopic_mass=2.01565,
        average_mass=2.0159,
        dict_composition={'H': 2},
    ),
    "1175": UnimodInfo(
        id="1175",
        name="Pro->Trp",
        formula="C6H3N",
        monoisotopic_mass=89.026549,
        average_mass=89.0947,
        dict_composition={'H': 3, 'C': 6, 'N': 1},
    ),
    "1176": UnimodInfo(
        id="1176",
        name="Pro->Tyr",
        formula="C4H2O",
        monoisotopic_mass=66.010565,
        average_mass=66.0581,
        dict_composition={'H': 2, 'C': 4, 'O': 1},
    ),
    "1177": UnimodInfo(
        id="1177",
        name="Gln->Ala",
        formula="C-2H-3N-1O-1",
        monoisotopic_mass=-57.021464,
        average_mass=-57.0513,
        dict_composition={'H': -3, 'C': -2, 'N': -1, 'O': -1},
    ),
    "1178": UnimodInfo(
        id="1178",
        name="Gln->Cys",
        formula="C-2H-3N-1O-1S",
        monoisotopic_mass=-25.049393,
        average_mass=-24.9863,
        dict_composition={'H': -3, 'C': -2, 'N': -1, 'O': -1, 'S': 1},
    ),
    "1179": UnimodInfo(
        id="1179",
        name="Gln->Asp",
        formula="C-1H-3N-1O",
        monoisotopic_mass=-13.031634,
        average_mass=-13.0418,
        dict_composition={'H': -3, 'C': -1, 'N': -1, 'O': 1},
    ),
    "1180": UnimodInfo(
        id="1180",
        name="Gln->Phe",
        formula="C4HN-1O-1",
        monoisotopic_mass=19.009836,
        average_mass=19.0446,
        dict_composition={'H': 1, 'C': 4, 'N': -1, 'O': -1},
    ),
    "1181": UnimodInfo(
        id="1181",
        name="Gln->Gly",
        formula="C-3H-5N-1O-1",
        monoisotopic_mass=-71.037114,
        average_mass=-71.0779,
        dict_composition={'H': -5, 'C': -3, 'N': -1, 'O': -1},
    ),
    "1182": UnimodInfo(
        id="1182",
        name="Gln->Met",
        formula="HN-1O-1S",
        monoisotopic_mass=2.981907,
        average_mass=3.0668,
        dict_composition={'H': 1, 'N': -1, 'O': -1, 'S': 1},
    ),
    "1183": UnimodInfo(
        id="1183",
        name="Gln->Asn",
        formula="C-1H-2",
        monoisotopic_mass=-14.01565,
        average_mass=-14.0266,
        dict_composition={'H': -2, 'C': -1},
    ),
    "1184": UnimodInfo(
        id="1184",
        name="Gln->Ser",
        formula="C-2H-3N-1",
        monoisotopic_mass=-41.026549,
        average_mass=-41.0519,
        dict_composition={'H': -3, 'C': -2, 'N': -1},
    ),
    "1185": UnimodInfo(
        id="1185",
        name="Gln->Thr",
        formula="C-1H-1N-1",
        monoisotopic_mass=-27.010899,
        average_mass=-27.0253,
        dict_composition={'H': -1, 'C': -1, 'N': -1},
    ),
    "1186": UnimodInfo(
        id="1186",
        name="Gln->Val",
        formula="HN-1O-1",
        monoisotopic_mass=-28.990164,
        average_mass=-28.9982,
        dict_composition={'H': 1, 'N': -1, 'O': -1},
    ),
    "1187": UnimodInfo(
        id="1187",
        name="Gln->Trp",
        formula="C6H2O-1",
        monoisotopic_mass=58.020735,
        average_mass=58.0807,
        dict_composition={'H': 2, 'C': 6, 'O': -1},
    ),
    "1188": UnimodInfo(
        id="1188",
        name="Gln->Tyr",
        formula="C4HN-1",
        monoisotopic_mass=35.004751,
        average_mass=35.044,
        dict_composition={'H': 1, 'C': 4, 'N': -1},
    ),
    "1189": UnimodInfo(
        id="1189",
        name="Arg->Ala",
        formula="C-3H-7N-3",
        monoisotopic_mass=-85.063997,
        average_mass=-85.1078,
        dict_composition={'H': -7, 'C': -3, 'N': -3},
    ),
    "1190": UnimodInfo(
        id="1190",
        name="Arg->Asp",
        formula="C-2H-7N-3O2",
        monoisotopic_mass=-41.074168,
        average_mass=-41.0983,
        dict_composition={'H': -7, 'C': -2, 'N': -3, 'O': 2},
    ),
    "1191": UnimodInfo(
        id="1191",
        name="Arg->Glu",
        formula="C-1H-5N-3O2",
        monoisotopic_mass=-27.058518,
        average_mass=-27.0717,
        dict_composition={'H': -5, 'C': -1, 'N': -3, 'O': 2},
    ),
    "1192": UnimodInfo(
        id="1192",
        name="Arg->Asn",
        formula="C-2H-6N-2O",
        monoisotopic_mass=-42.058184,
        average_mass=-42.083,
        dict_composition={'H': -6, 'C': -2, 'N': -2, 'O': 1},
    ),
    "1193": UnimodInfo(
        id="1193",
        name="Arg->Val",
        formula="C-1H-3N-3",
        monoisotopic_mass=-57.032697,
        average_mass=-57.0546,
        dict_composition={'H': -3, 'C': -1, 'N': -3},
    ),
    "1194": UnimodInfo(
        id="1194",
        name="Arg->Tyr",
        formula="C3H-3N-3O",
        monoisotopic_mass=6.962218,
        average_mass=6.9876,
        dict_composition={'H': -3, 'C': 3, 'N': -3, 'O': 1},
    ),
    "1195": UnimodInfo(
        id="1195",
        name="Arg->Phe",
        formula="C3H-3N-3",
        monoisotopic_mass=-9.032697,
        average_mass=-9.0118,
        dict_composition={'H': -3, 'C': 3, 'N': -3},
    ),
    "1196": UnimodInfo(
        id="1196",
        name="Ser->Asp",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.0101,
        dict_composition={'C': 1, 'O': 1},
    ),
    "1197": UnimodInfo(
        id="1197",
        name="Ser->Glu",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.0367,
        dict_composition={'H': 2, 'C': 2, 'O': 1},
    ),
    "1198": UnimodInfo(
        id="1198",
        name="Ser->His",
        formula="C3H2N2O-1",
        monoisotopic_mass=50.026883,
        average_mass=50.062,
        dict_composition={'H': 2, 'C': 3, 'N': 2, 'O': -1},
    ),
    "1199": UnimodInfo(
        id="1199",
        name="Ser->Lys",
        formula="C3H7NO-1",
        monoisotopic_mass=41.062935,
        average_mass=41.095,
        dict_composition={'H': 7, 'C': 3, 'N': 1, 'O': -1},
    ),
    "1200": UnimodInfo(
        id="1200",
        name="Ser->Met",
        formula="C2H4O-1S",
        monoisotopic_mass=44.008456,
        average_mass=44.1188,
        dict_composition={'H': 4, 'C': 2, 'O': -1, 'S': 1},
    ),
    "1201": UnimodInfo(
        id="1201",
        name="Ser->Gln",
        formula="C2H3N",
        monoisotopic_mass=41.026549,
        average_mass=41.0519,
        dict_composition={'H': 3, 'C': 2, 'N': 1},
    ),
    "1202": UnimodInfo(
        id="1202",
        name="Ser->Val",
        formula="C2H4O-1",
        monoisotopic_mass=12.036386,
        average_mass=12.0538,
        dict_composition={'H': 4, 'C': 2, 'O': -1},
    ),
    "1203": UnimodInfo(
        id="1203",
        name="Thr->Cys",
        formula="C-1H-2O-1S",
        monoisotopic_mass=1.961506,
        average_mass=2.039,
        dict_composition={'H': -2, 'C': -1, 'O': -1, 'S': 1},
    ),
    "1204": UnimodInfo(
        id="1204",
        name="Thr->Asp",
        formula="H-2O",
        monoisotopic_mass=13.979265,
        average_mass=13.9835,
        dict_composition={'H': -2, 'O': 1},
    ),
    "1205": UnimodInfo(
        id="1205",
        name="Thr->Glu",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.0101,
        dict_composition={'C': 1, 'O': 1},
    ),
    "1206": UnimodInfo(
        id="1206",
        name="Thr->Phe",
        formula="C5H2O-1",
        monoisotopic_mass=46.020735,
        average_mass=46.07,
        dict_composition={'H': 2, 'C': 5, 'O': -1},
    ),
    "1207": UnimodInfo(
        id="1207",
        name="Thr->Gly",
        formula="C-2H-4O-1",
        monoisotopic_mass=-44.026215,
        average_mass=-44.0526,
        dict_composition={'H': -4, 'C': -2, 'O': -1},
    ),
    "1208": UnimodInfo(
        id="1208",
        name="Thr->His",
        formula="C2N2O-1",
        monoisotopic_mass=36.011233,
        average_mass=36.0354,
        dict_composition={'C': 2, 'N': 2, 'O': -1},
    ),
    "1209": UnimodInfo(
        id="1209",
        name="Thr->Gln",
        formula="CHN",
        monoisotopic_mass=27.010899,
        average_mass=27.0253,
        dict_composition={'H': 1, 'C': 1, 'N': 1},
    ),
    "1210": UnimodInfo(
        id="1210",
        name="Thr->Val",
        formula="CH2O-1",
        monoisotopic_mass=-1.979265,
        average_mass=-1.9728,
        dict_composition={'H': 2, 'C': 1, 'O': -1},
    ),
    "1211": UnimodInfo(
        id="1211",
        name="Thr->Trp",
        formula="C7H3NO-1",
        monoisotopic_mass=85.031634,
        average_mass=85.106,
        dict_composition={'H': 3, 'C': 7, 'N': 1, 'O': -1},
    ),
    "1212": UnimodInfo(
        id="1212",
        name="Thr->Tyr",
        formula="C5H2",
        monoisotopic_mass=62.01565,
        average_mass=62.0694,
        dict_composition={'H': 2, 'C': 5},
    ),
    "1213": UnimodInfo(
        id="1213",
        name="Val->Cys",
        formula="C-2H-4S",
        monoisotopic_mass=3.940771,
        average_mass=4.0118,
        dict_composition={'H': -4, 'C': -2, 'S': 1},
    ),
    "1214": UnimodInfo(
        id="1214",
        name="Val->His",
        formula="CH-2N2",
        monoisotopic_mass=37.990498,
        average_mass=38.0082,
        dict_composition={'H': -2, 'C': 1, 'N': 2},
    ),
    "1215": UnimodInfo(
        id="1215",
        name="Val->Lys",
        formula="CH3N",
        monoisotopic_mass=29.026549,
        average_mass=29.0412,
        dict_composition={'H': 3, 'C': 1, 'N': 1},
    ),
    "1216": UnimodInfo(
        id="1216",
        name="Val->Asn",
        formula="C-1H-3NO",
        monoisotopic_mass=14.974514,
        average_mass=14.9716,
        dict_composition={'H': -3, 'C': -1, 'N': 1, 'O': 1},
    ),
    "1217": UnimodInfo(
        id="1217",
        name="Val->Pro",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.0159,
        dict_composition={'H': -2},
    ),
    "1218": UnimodInfo(
        id="1218",
        name="Val->Gln",
        formula="H-1NO",
        monoisotopic_mass=28.990164,
        average_mass=28.9982,
        dict_composition={'H': -1, 'N': 1, 'O': 1},
    ),
    "1219": UnimodInfo(
        id="1219",
        name="Val->Arg",
        formula="CH3N3",
        monoisotopic_mass=57.032697,
        average_mass=57.0546,
        dict_composition={'H': 3, 'C': 1, 'N': 3},
    ),
    "1220": UnimodInfo(
        id="1220",
        name="Val->Ser",
        formula="C-2H-4O",
        monoisotopic_mass=-12.036386,
        average_mass=-12.0538,
        dict_composition={'H': -4, 'C': -2, 'O': 1},
    ),
    "1221": UnimodInfo(
        id="1221",
        name="Val->Thr",
        formula="C-1H-2O",
        monoisotopic_mass=1.979265,
        average_mass=1.9728,
        dict_composition={'H': -2, 'C': -1, 'O': 1},
    ),
    "1222": UnimodInfo(
        id="1222",
        name="Val->Trp",
        formula="C6HN",
        monoisotopic_mass=87.010899,
        average_mass=87.0788,
        dict_composition={'H': 1, 'C': 6, 'N': 1},
    ),
    "1223": UnimodInfo(
        id="1223",
        name="Val->Tyr",
        formula="C4O",
        monoisotopic_mass=63.994915,
        average_mass=64.0422,
        dict_composition={'C': 4, 'O': 1},
    ),
    "1224": UnimodInfo(
        id="1224",
        name="Trp->Ala",
        formula="C-8H-5N-1",
        monoisotopic_mass=-115.042199,
        average_mass=-115.132,
        dict_composition={'H': -5, 'C': -8, 'N': -1},
    ),
    "1225": UnimodInfo(
        id="1225",
        name="Trp->Asp",
        formula="C-7H-5N-1O2",
        monoisotopic_mass=-71.05237,
        average_mass=-71.1225,
        dict_composition={'H': -5, 'C': -7, 'N': -1, 'O': 2},
    ),
    "1226": UnimodInfo(
        id="1226",
        name="Trp->Glu",
        formula="C-6H-3N-1O2",
        monoisotopic_mass=-57.03672,
        average_mass=-57.0959,
        dict_composition={'H': -3, 'C': -6, 'N': -1, 'O': 2},
    ),
    "1227": UnimodInfo(
        id="1227",
        name="Trp->Phe",
        formula="C-2H-1N-1",
        monoisotopic_mass=-39.010899,
        average_mass=-39.036,
        dict_composition={'H': -1, 'C': -2, 'N': -1},
    ),
    "1228": UnimodInfo(
        id="1228",
        name="Trp->His",
        formula="C-5H-3N",
        monoisotopic_mass=-49.020401,
        average_mass=-49.0706,
        dict_composition={'H': -3, 'C': -5, 'N': 1},
    ),
    "1229": UnimodInfo(
        id="1229",
        name="Trp->Lys",
        formula="C-5H2",
        monoisotopic_mass=-57.98435,
        average_mass=-58.0376,
        dict_composition={'H': 2, 'C': -5},
    ),
    "1230": UnimodInfo(
        id="1230",
        name="Trp->Met",
        formula="C-6H-1N-1S",
        monoisotopic_mass=-55.038828,
        average_mass=-55.0138,
        dict_composition={'H': -1, 'C': -6, 'N': -1, 'S': 1},
    ),
    "1231": UnimodInfo(
        id="1231",
        name="Trp->Asn",
        formula="C-7H-4O",
        monoisotopic_mass=-72.036386,
        average_mass=-72.1073,
        dict_composition={'H': -4, 'C': -7, 'O': 1},
    ),
    "1232": UnimodInfo(
        id="1232",
        name="Trp->Pro",
        formula="C-6H-3N-1",
        monoisotopic_mass=-89.026549,
        average_mass=-89.0947,
        dict_composition={'H': -3, 'C': -6, 'N': -1},
    ),
    "1233": UnimodInfo(
        id="1233",
        name="Trp->Gln",
        formula="C-6H-2O",
        monoisotopic_mass=-58.020735,
        average_mass=-58.0807,
        dict_composition={'H': -2, 'C': -6, 'O': 1},
    ),
    "1234": UnimodInfo(
        id="1234",
        name="Trp->Thr",
        formula="C-7H-3N-1O",
        monoisotopic_mass=-85.031634,
        average_mass=-85.106,
        dict_composition={'H': -3, 'C': -7, 'N': -1, 'O': 1},
    ),
    "1235": UnimodInfo(
        id="1235",
        name="Trp->Val",
        formula="C-6H-1N-1",
        monoisotopic_mass=-87.010899,
        average_mass=-87.0788,
        dict_composition={'H': -1, 'C': -6, 'N': -1},
    ),
    "1236": UnimodInfo(
        id="1236",
        name="Trp->Tyr",
        formula="C-2H-1N-1O",
        monoisotopic_mass=-23.015984,
        average_mass=-23.0366,
        dict_composition={'H': -1, 'C': -2, 'N': -1, 'O': 1},
    ),
    "1237": UnimodInfo(
        id="1237",
        name="Tyr->Ala",
        formula="C-6H-4O-1",
        monoisotopic_mass=-92.026215,
        average_mass=-92.0954,
        dict_composition={'H': -4, 'C': -6, 'O': -1},
    ),
    "1238": UnimodInfo(
        id="1238",
        name="Tyr->Glu",
        formula="C-4H-2O",
        monoisotopic_mass=-34.020735,
        average_mass=-34.0593,
        dict_composition={'H': -2, 'C': -4, 'O': 1},
    ),
    "1239": UnimodInfo(
        id="1239",
        name="Tyr->Gly",
        formula="C-7H-6O-1",
        monoisotopic_mass=-106.041865,
        average_mass=-106.1219,
        dict_composition={'H': -6, 'C': -7, 'O': -1},
    ),
    "1240": UnimodInfo(
        id="1240",
        name="Tyr->Lys",
        formula="C-3H3NO-1",
        monoisotopic_mass=-34.968366,
        average_mass=-35.001,
        dict_composition={'H': 3, 'C': -3, 'N': 1, 'O': -1},
    ),
    "1241": UnimodInfo(
        id="1241",
        name="Tyr->Met",
        formula="C-4O-1S",
        monoisotopic_mass=-32.022844,
        average_mass=-31.9772,
        dict_composition={'C': -4, 'O': -1, 'S': 1},
    ),
    "1242": UnimodInfo(
        id="1242",
        name="Tyr->Pro",
        formula="C-4H-2O-1",
        monoisotopic_mass=-66.010565,
        average_mass=-66.0581,
        dict_composition={'H': -2, 'C': -4, 'O': -1},
    ),
    "1243": UnimodInfo(
        id="1243",
        name="Tyr->Gln",
        formula="C-4H-1N",
        monoisotopic_mass=-35.004751,
        average_mass=-35.044,
        dict_composition={'H': -1, 'C': -4, 'N': 1},
    ),
    "1244": UnimodInfo(
        id="1244",
        name="Tyr->Arg",
        formula="C-3H3N3O-1",
        monoisotopic_mass=-6.962218,
        average_mass=-6.9876,
        dict_composition={'H': 3, 'C': -3, 'N': 3, 'O': -1},
    ),
    "1245": UnimodInfo(
        id="1245",
        name="Tyr->Thr",
        formula="C-5H-2",
        monoisotopic_mass=-62.01565,
        average_mass=-62.0694,
        dict_composition={'H': -2, 'C': -5},
    ),
    "1246": UnimodInfo(
        id="1246",
        name="Tyr->Val",
        formula="C-4O-1",
        monoisotopic_mass=-63.994915,
        average_mass=-64.0422,
        dict_composition={'C': -4, 'O': -1},
    ),
    "1247": UnimodInfo(
        id="1247",
        name="Tyr->Trp",
        formula="C2HNO-1",
        monoisotopic_mass=23.015984,
        average_mass=23.0366,
        dict_composition={'H': 1, 'C': 2, 'N': 1, 'O': -1},
    ),
    "1248": UnimodInfo(
        id="1248",
        name="Tyr->Xle",
        formula="C-3H2O-1",
        monoisotopic_mass=-49.979265,
        average_mass=-50.0156,
        dict_composition={'H': 2, 'C': -3, 'O': -1},
    ),
    "1249": UnimodInfo(
        id="1249",
        name="AHA-SS",
        formula="C7H9N5O2",
        monoisotopic_mass=195.075625,
        average_mass=195.1787,
        dict_composition={'H': 9, 'C': 7, 'N': 5, 'O': 2},
    ),
    "1250": UnimodInfo(
        id="1250",
        name="AHA-SS_CAM",
        formula="C9H12N6O3",
        monoisotopic_mass=252.097088,
        average_mass=252.23,
        dict_composition={'H': 12, 'C': 9, 'N': 6, 'O': 3},
    ),
    "1251": UnimodInfo(
        id="1251",
        name="Biotin:Thermo-33033",
        formula="C25H36N6O4S2",
        monoisotopic_mass=548.223945,
        average_mass=548.7211,
        dict_composition={'H': 36, 'C': 25, 'N': 6, 'O': 4, 'S': 2},
    ),
    "1252": UnimodInfo(
        id="1252",
        name="Biotin:Thermo-33033-H",
        formula="C25H34N6O4S2",
        monoisotopic_mass=546.208295,
        average_mass=546.7053,
        dict_composition={'H': 34, 'C': 25, 'N': 6, 'O': 4, 'S': 2},
    ),
    "1253": UnimodInfo(
        id="1253",
        name="2-monomethylsuccinyl",
        formula="C5H6O4",
        monoisotopic_mass=130.026609,
        average_mass=130.0987,
        dict_composition={'H': 6, 'C': 5, 'O': 4},
    ),
    "1254": UnimodInfo(
        id="1254",
        name="Saligenin",
        formula="C7H6O",
        monoisotopic_mass=106.041865,
        average_mass=106.1219,
        dict_composition={'H': 6, 'C': 7, 'O': 1},
    ),
    "1255": UnimodInfo(
        id="1255",
        name="Cresylphosphate",
        formula="C7H7O3P",
        monoisotopic_mass=170.013281,
        average_mass=170.1024,
        dict_composition={'H': 7, 'C': 7, 'O': 3, 'P': 1},
    ),
    "1256": UnimodInfo(
        id="1256",
        name="CresylSaligeninPhosphate",
        formula="C14H13O4P",
        monoisotopic_mass=276.055146,
        average_mass=276.2244,
        dict_composition={'H': 13, 'C': 14, 'O': 4, 'P': 1},
    ),
    "1257": UnimodInfo(
        id="1257",
        name="Ub-Br2",
        formula="C4H8N2O",
        monoisotopic_mass=100.063663,
        average_mass=100.1191,
        dict_composition={'H': 8, 'C': 4, 'N': 2, 'O': 1},
    ),
    "1258": UnimodInfo(
        id="1258",
        name="Ub-VME",
        formula="C7H12N2O3",
        monoisotopic_mass=172.084792,
        average_mass=172.1818,
        dict_composition={'H': 12, 'C': 7, 'N': 2, 'O': 3},
    ),
    "1261": UnimodInfo(
        id="1261",
        name="Ub-fluorescein",
        formula="C31H29N6O7",
        monoisotopic_mass=597.209772,
        average_mass=597.598,
        dict_composition={'H': 29, 'C': 31, 'N': 6, 'O': 7},
    ),
    "1262": UnimodInfo(
        id="1262",
        name="2-dimethylsuccinyl",
        formula="C6H8O4",
        monoisotopic_mass=144.042259,
        average_mass=144.1253,
        dict_composition={'H': 8, 'C': 6, 'O': 4},
    ),
    "1263": UnimodInfo(
        id="1263",
        name="Gly",
        formula="C2H3NO",
        monoisotopic_mass=57.021464,
        average_mass=57.0513,
        dict_composition={'H': 3, 'C': 2, 'N': 1, 'O': 1},
    ),
    "1264": UnimodInfo(
        id="1264",
        name="pupylation",
        formula="C9H13N3O5",
        monoisotopic_mass=243.085521,
        average_mass=243.2166,
        dict_composition={'H': 13, 'C': 9, 'N': 3, 'O': 5},
    ),
    "1266": UnimodInfo(
        id="1266",
        name="Label:13C(4)",
        formula="C-4",
        monoisotopic_mass=4.013419,
        average_mass=3.9706,
        dict_composition={'C': -4},
    ),
    "1267": UnimodInfo(
        id="1267",
        name="Label:13C(4)+Oxidation",
        formula="C-4O",
        monoisotopic_mass=20.008334,
        average_mass=19.97,
        dict_composition={'C': -4, 'O': 1},
    ),
    "1270": UnimodInfo(
        id="1270",
        name="HCysThiolactone",
        formula="C4H7NOS",
        monoisotopic_mass=117.024835,
        average_mass=117.1695,
        dict_composition={'H': 7, 'C': 4, 'N': 1, 'O': 1, 'S': 1},
    ),
    "1271": UnimodInfo(
        id="1271",
        name="HCysteinyl",
        formula="C4H7NO2S",
        monoisotopic_mass=133.019749,
        average_mass=133.1689,
        dict_composition={'H': 7, 'C': 4, 'N': 1, 'O': 2, 'S': 1},
    ),
    "1276": UnimodInfo(
        id="1276",
        name="UgiJoullie",
        formula="C47H60N23O10",
        monoisotopic_mass=1106.48935,
        average_mass=1107.1274,
        dict_composition={'H': 60, 'C': 47, 'N': 23, 'O': 10},
    ),
    "1277": UnimodInfo(
        id="1277",
        name="Dipyridyl",
        formula="C13H11N3O",
        monoisotopic_mass=225.090212,
        average_mass=225.2459,
        dict_composition={'H': 11, 'C': 13, 'N': 3, 'O': 1},
    ),
    "1278": UnimodInfo(
        id="1278",
        name="Furan",
        formula="C4H2O",
        monoisotopic_mass=66.010565,
        average_mass=66.0581,
        dict_composition={'H': 2, 'C': 4, 'O': 1},
    ),
    "1279": UnimodInfo(
        id="1279",
        name="Difuran",
        formula="C8H4O2",
        monoisotopic_mass=132.021129,
        average_mass=132.1162,
        dict_composition={'H': 4, 'C': 8, 'O': 2},
    ),
    "1281": UnimodInfo(
        id="1281",
        name="BMP-piperidinol",
        formula="C18H17NO",
        monoisotopic_mass=263.131014,
        average_mass=263.3337,
        dict_composition={'H': 17, 'C': 18, 'N': 1, 'O': 1},
    ),
    "1282": UnimodInfo(
        id="1282",
        name="UgiJoullieProGly",
        formula="C7H10N2O2",
        monoisotopic_mass=154.074228,
        average_mass=154.1665,
        dict_composition={'H': 10, 'C': 7, 'N': 2, 'O': 2},
    ),
    "1283": UnimodInfo(
        id="1283",
        name="UgiJoullieProGlyProGly",
        formula="C14H20N4O4",
        monoisotopic_mass=308.148455,
        average_mass=308.333,
        dict_composition={'H': 20, 'C': 14, 'N': 4, 'O': 4},
    ),
    "1286": UnimodInfo(
        id="1286",
        name="IMEHex(2)NeuAc(1)",
        formula="C25H40N2O18S",
        monoisotopic_mass=688.199683,
        average_mass=688.6527,
        dict_composition={'H': 40, 'C': 25, 'N': 2, 'S': 1, 'O': 18},
    ),
    "1287": UnimodInfo(
        id="1287",
        name="Arg-loss",
        formula="C-6H-12N-4O-1",
        monoisotopic_mass=-156.101111,
        average_mass=-156.1857,
        dict_composition={'H': -12, 'C': -6, 'N': -4, 'O': -1},
    ),
    "1288": UnimodInfo(
        id="1288",
        name="Arg",
        formula="C6H12N4O",
        monoisotopic_mass=156.101111,
        average_mass=156.1857,
        dict_composition={'H': 12, 'C': 6, 'N': 4, 'O': 1},
    ),
    "1289": UnimodInfo(
        id="1289",
        name="Butyryl",
        formula="C4H6O",
        monoisotopic_mass=70.041865,
        average_mass=70.0898,
        dict_composition={'H': 6, 'C': 4, 'O': 1},
    ),
    "1290": UnimodInfo(
        id="1290",
        name="Dicarbamidomethyl",
        formula="C4H6N2O2",
        monoisotopic_mass=114.042927,
        average_mass=114.1026,
        dict_composition={'H': 6, 'C': 4, 'N': 2, 'O': 2},
    ),
    "1291": UnimodInfo(
        id="1291",
        name="Dimethyl:2H(6)",
        formula="C2H-2",
        monoisotopic_mass=34.068961,
        average_mass=34.0901,
        dict_composition={'H': -2, 'C': 2},
    ),
    "1292": UnimodInfo(
        id="1292",
        name="GGQ",
        formula="C9H14N4O4",
        monoisotopic_mass=242.101505,
        average_mass=242.2319,
        dict_composition={'H': 14, 'C': 9, 'N': 4, 'O': 4},
    ),
    "1293": UnimodInfo(
        id="1293",
        name="QTGG",
        formula="C13H21N5O6",
        monoisotopic_mass=343.149184,
        average_mass=343.3357,
        dict_composition={'H': 21, 'C': 13, 'N': 5, 'O': 6},
    ),
    "1296": UnimodInfo(
        id="1296",
        name="Label:13C(3)",
        formula="C-3",
        monoisotopic_mass=3.010064,
        average_mass=2.978,
        dict_composition={'C': -3},
    ),
    "1297": UnimodInfo(
        id="1297",
        name="Label:13C(3)15N(1)",
        formula="C-3N-1",
        monoisotopic_mass=4.007099,
        average_mass=3.9714,
        dict_composition={'C': -3, 'N': -1},
    ),
    "1298": UnimodInfo(
        id="1298",
        name="Label:13C(4)15N(1)",
        formula="C-4N-1",
        monoisotopic_mass=5.010454,
        average_mass=4.964,
        dict_composition={'C': -4, 'N': -1},
    ),
    "1299": UnimodInfo(
        id="1299",
        name="Label:2H(10)",
        formula="H-10",
        monoisotopic_mass=10.062767,
        average_mass=10.0616,
        dict_composition={'H': -10},
    ),
    "1300": UnimodInfo(
        id="1300",
        name="Label:2H(4)13C(1)",
        formula="C-1H-4",
        monoisotopic_mass=5.028462,
        average_mass=5.0173,
        dict_composition={'H': -4, 'C': -1},
    ),
    "1301": UnimodInfo(
        id="1301",
        name="Lys",
        formula="C6H12N2O",
        monoisotopic_mass=128.094963,
        average_mass=128.1723,
        dict_composition={'H': 12, 'C': 6, 'N': 2, 'O': 1},
    ),
    "1302": UnimodInfo(
        id="1302",
        name="mTRAQ:13C(6)15N(2)",
        formula="CH12O",
        monoisotopic_mass=148.109162,
        average_mass=148.1257,
        dict_composition={'H': 12, 'C': 1, 'N': 0, 'O': 1},
    ),
    "1303": UnimodInfo(
        id="1303",
        name="NeuAc",
        formula="C11H17NO8",
        monoisotopic_mass=291.095417,
        average_mass=291.2546,
        dict_composition={'C': 11, 'H': 17, 'N': 1, 'O': 8},
    ),
    "1304": UnimodInfo(
        id="1304",
        name="NeuGc",
        formula="C11H17NO9",
        monoisotopic_mass=307.090331,
        average_mass=307.254,
        dict_composition={'C': 11, 'H': 17, 'N': 1, 'O': 9},
    ),
    "1305": UnimodInfo(
        id="1305",
        name="Propyl",
        formula="C3H6",
        monoisotopic_mass=42.04695,
        average_mass=42.0797,
        dict_composition={'H': 6, 'C': 3},
    ),
    "1306": UnimodInfo(
        id="1306",
        name="Propyl:2H(6)",
        formula="C3",
        monoisotopic_mass=48.084611,
        average_mass=48.1167,
        dict_composition={'H': 0, 'C': 3},
    ),
    "1310": UnimodInfo(
        id="1310",
        name="Propiophenone",
        formula="C9H8O",
        monoisotopic_mass=132.057515,
        average_mass=132.1592,
        dict_composition={'H': 8, 'C': 9, 'O': 1},
    ),
    "1312": UnimodInfo(
        id="1312",
        name="Delta:H(6)C(3)O(1)",
        formula="C3H6O",
        monoisotopic_mass=58.041865,
        average_mass=58.0791,
        dict_composition={'H': 6, 'C': 3, 'O': 1},
    ),
    "1313": UnimodInfo(
        id="1313",
        name="Delta:H(8)C(6)O(1)",
        formula="C6H8O",
        monoisotopic_mass=96.057515,
        average_mass=96.1271,
        dict_composition={'H': 8, 'C': 6, 'O': 1},
    ),
    "1314": UnimodInfo(
        id="1314",
        name="biotinAcrolein298",
        formula="C13H22N4O2S",
        monoisotopic_mass=298.146347,
        average_mass=298.4044,
        dict_composition={'H': 22, 'C': 13, 'N': 4, 'O': 2, 'S': 1},
    ),
    "1315": UnimodInfo(
        id="1315",
        name="MM-diphenylpentanone",
        formula="C18H19NO",
        monoisotopic_mass=265.146664,
        average_mass=265.3496,
        dict_composition={'H': 19, 'C': 18, 'N': 1, 'O': 1},
    ),
    "1317": UnimodInfo(
        id="1317",
        name="EHD-diphenylpentanone",
        formula="C18H18O2",
        monoisotopic_mass=266.13068,
        average_mass=266.3343,
        dict_composition={'H': 18, 'C': 18, 'O': 2},
    ),
    "1320": UnimodInfo(
        id="1320",
        name="Biotin:Thermo-21901+2H2O",
        formula="C23H39N5O9S",
        monoisotopic_mass=561.246849,
        average_mass=561.6489,
        dict_composition={'H': 39, 'C': 23, 'N': 5, 'O': 9, 'S': 1},
    ),
    "1321": UnimodInfo(
        id="1321",
        name="DiLeu4plex115",
        formula="C7H15",
        monoisotopic_mass=145.12,
        average_mass=145.1966,
        dict_composition={'H': 15, 'C': 7, 'N': 0, 'O': 0},
    ),
    "1322": UnimodInfo(
        id="1322",
        name="DiLeu4plex",
        formula="C8H13N",
        monoisotopic_mass=145.132163,
        average_mass=145.2229,
        dict_composition={'H': 13, 'C': 8, 'N': 1, 'O': 0},
    ),
    "1323": UnimodInfo(
        id="1323",
        name="DiLeu4plex117",
        formula="C7H13O",
        monoisotopic_mass=145.128307,
        average_mass=145.2092,
        dict_composition={'H': 13, 'C': 7, 'N': 0, 'O': 1},
    ),
    "1324": UnimodInfo(
        id="1324",
        name="DiLeu4plex118",
        formula="C8H11NO",
        monoisotopic_mass=145.140471,
        average_mass=145.2354,
        dict_composition={'H': 11, 'C': 8, 'N': 1, 'O': 1},
    ),
    "1326": UnimodInfo(
        id="1326",
        name="NEMsulfur",
        formula="C6H7NO2S",
        monoisotopic_mass=157.019749,
        average_mass=157.1903,
        dict_composition={'H': 7, 'C': 6, 'N': 1, 'O': 2, 'S': 1},
    ),
    "1327": UnimodInfo(
        id="1327",
        name="SulfurDioxide",
        formula="O2S",
        monoisotopic_mass=63.9619,
        average_mass=64.0638,
        dict_composition={'O': 2, 'S': 1},
    ),
    "1328": UnimodInfo(
        id="1328",
        name="NEMsulfurWater",
        formula="C6H9NO3S",
        monoisotopic_mass=175.030314,
        average_mass=175.2056,
        dict_composition={'H': 9, 'C': 6, 'N': 1, 'O': 3, 'S': 1},
    ),
    "1330": UnimodInfo(
        id="1330",
        name="bisANS-sulfonates",
        formula="C32H22N2",
        monoisotopic_mass=434.178299,
        average_mass=434.5305,
        dict_composition={'H': 22, 'C': 32, 'N': 2},
    ),
    "1331": UnimodInfo(
        id="1331",
        name="DNCB_hapten",
        formula="C6H2N2O4",
        monoisotopic_mass=166.001457,
        average_mass=166.0911,
        dict_composition={'H': 2, 'C': 6, 'N': 2, 'O': 4},
    ),
    "1340": UnimodInfo(
        id="1340",
        name="Biotin:Thermo-21911",
        formula="C41H71N5O16S",
        monoisotopic_mass=921.461652,
        average_mass=922.0913,
        dict_composition={'H': 71, 'C': 41, 'N': 5, 'O': 16, 'S': 1},
    ),
    "1341": UnimodInfo(
        id="1341",
        name="iodoTMT",
        formula="C16H28N4O3",
        monoisotopic_mass=324.216141,
        average_mass=324.4185,
        dict_composition={'H': 28, 'C': 16, 'N': 4, 'O': 3},
    ),
    "1342": UnimodInfo(
        id="1342",
        name="iodoTMT6plex",
        formula="C12H28N3O3",
        monoisotopic_mass=329.226595,
        average_mass=329.3825,
        dict_composition={'H': 28, 'C': 12, 'N': 3, 'O': 3},
    ),
    "1344": UnimodInfo(
        id="1344",
        name="Phosphogluconoylation",
        formula="C6H11O9P",
        monoisotopic_mass=258.014069,
        average_mass=258.1199,
        dict_composition={'H': 11, 'C': 6, 'O': 9, 'P': 1},
    ),
    "1345": UnimodInfo(
        id="1345",
        name="PS_Hapten",
        formula="C7H4O2",
        monoisotopic_mass=120.021129,
        average_mass=120.1055,
        dict_composition={'H': 4, 'C': 7, 'O': 2},
    ),
    "1348": UnimodInfo(
        id="1348",
        name="Cy3-maleimide",
        formula="C37H45N4O9S2",
        monoisotopic_mass=753.262796,
        average_mass=753.9046,
        dict_composition={'H': 45, 'C': 37, 'N': 4, 'O': 9, 'S': 2},
    ),
    "1349": UnimodInfo(
        id="1349",
        name="benzylguanidine",
        formula="C8H8N2",
        monoisotopic_mass=132.068748,
        average_mass=132.1625,
        dict_composition={'H': 8, 'C': 8, 'N': 2},
    ),
    "1350": UnimodInfo(
        id="1350",
        name="CarboxymethylDMAP",
        formula="C9H10N2O",
        monoisotopic_mass=162.079313,
        average_mass=162.1885,
        dict_composition={'H': 10, 'C': 9, 'N': 2, 'O': 1},
    ),
    "1355": UnimodInfo(
        id="1355",
        name="azole",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.0312,
        dict_composition={'H': -4, 'O': -1},
    ),
    "1356": UnimodInfo(
        id="1356",
        name="phosphoRibosyl",
        formula="C5H9O7P",
        monoisotopic_mass=212.00859,
        average_mass=212.0945,
        dict_composition={'H': 9, 'C': 5, 'O': 7, 'P': 1},
    ),
    "1358": UnimodInfo(
        id="1358",
        name="NEM:2H(5)+H2O",
        formula="C6H4NO3",
        monoisotopic_mass=148.089627,
        average_mass=148.1714,
        dict_composition={'H': 4, 'C': 6, 'N': 1, 'O': 3},
    ),
    "1363": UnimodInfo(
        id="1363",
        name="Crotonyl",
        formula="C4H4O",
        monoisotopic_mass=68.026215,
        average_mass=68.074,
        dict_composition={'H': 4, 'C': 4, 'O': 1},
    ),
    "1364": UnimodInfo(
        id="1364",
        name="O-Et-N-diMePhospho",
        formula="C4H10NO2P",
        monoisotopic_mass=135.044916,
        average_mass=135.1015,
        dict_composition={'H': 10, 'C': 4, 'N': 1, 'O': 2, 'P': 1},
    ),
    "1365": UnimodInfo(
        id="1365",
        name="N-dimethylphosphate",
        formula="C2H6NO2P",
        monoisotopic_mass=107.013615,
        average_mass=107.0483,
        dict_composition={'H': 6, 'C': 2, 'N': 1, 'O': 2, 'P': 1},
    ),
    "1367": UnimodInfo(
        id="1367",
        name="dHex(1)Hex(1)",
        formula="C12H20O9",
        monoisotopic_mass=308.110732,
        average_mass=308.2818,
        dict_composition={'C': 12, 'H': 20, 'O': 9},
    ),
    "1368": UnimodInfo(
        id="1368",
        name="Methyl:2H(3)+Acetyl:2H(3)",
        formula="C3H-2O",
        monoisotopic_mass=62.063875,
        average_mass=62.1002,
        dict_composition={'H': -2, 'C': 3, 'O': 1},
    ),
    "1370": UnimodInfo(
        id="1370",
        name="Label:2H(3)+Oxidation",
        formula="H-3O",
        monoisotopic_mass=19.013745,
        average_mass=19.0179,
        dict_composition={'H': -3, 'O': 1},
    ),
    "1371": UnimodInfo(
        id="1371",
        name="Trimethyl:2H(9)",
        formula="C3H-3",
        monoisotopic_mass=51.103441,
        average_mass=51.1352,
        dict_composition={'H': -3, 'C': 3},
    ),
    "1372": UnimodInfo(
        id="1372",
        name="Acetyl:13C(2)",
        formula="H2O",
        monoisotopic_mass=44.017274,
        average_mass=44.022,
        dict_composition={'H': 2, 'C': 0, 'O': 1},
    ),
    "1375": UnimodInfo(
        id="1375",
        name="dHex(1)Hex(2)",
        formula="C18H30O14",
        monoisotopic_mass=470.163556,
        average_mass=470.4224,
        dict_composition={'C': 18, 'H': 30, 'O': 14},
    ),
    "1376": UnimodInfo(
        id="1376",
        name="dHex(1)Hex(3)",
        formula="C24H40O19",
        monoisotopic_mass=632.216379,
        average_mass=632.563,
        dict_composition={'C': 24, 'H': 40, 'O': 19},
    ),
    "1377": UnimodInfo(
        id="1377",
        name="dHex(1)Hex(4)",
        formula="C30H50O24",
        monoisotopic_mass=794.269203,
        average_mass=794.7036,
        dict_composition={'C': 30, 'H': 50, 'O': 24},
    ),
    "1378": UnimodInfo(
        id="1378",
        name="dHex(1)Hex(5)",
        formula="C36H60O29",
        monoisotopic_mass=956.322026,
        average_mass=956.8442,
        dict_composition={'C': 36, 'H': 60, 'O': 29},
    ),
    "1379": UnimodInfo(
        id="1379",
        name="dHex(1)Hex(6)",
        formula="C42H70O34",
        monoisotopic_mass=1118.37485,
        average_mass=1118.9848,
        dict_composition={'C': 42, 'H': 70, 'O': 34},
    ),
    "1380": UnimodInfo(
        id="1380",
        name="methylsulfonylethyl",
        formula="C3H6O2S",
        monoisotopic_mass=106.00885,
        average_mass=106.1435,
        dict_composition={'H': 6, 'C': 3, 'O': 2, 'S': 1},
    ),
    "1381": UnimodInfo(
        id="1381",
        name="ethylsulfonylethyl",
        formula="C4H8O2S",
        monoisotopic_mass=120.0245,
        average_mass=120.1701,
        dict_composition={'H': 8, 'C': 4, 'O': 2, 'S': 1},
    ),
    "1382": UnimodInfo(
        id="1382",
        name="phenylsulfonylethyl",
        formula="C8H8O2S",
        monoisotopic_mass=168.0245,
        average_mass=168.2129,
        dict_composition={'H': 8, 'C': 8, 'O': 2, 'S': 1},
    ),
    "1383": UnimodInfo(
        id="1383",
        name="PyridoxalPhosphateH2",
        formula="C8H10NO5P",
        monoisotopic_mass=231.02966,
        average_mass=231.1425,
        dict_composition={'H': 10, 'C': 8, 'N': 1, 'O': 5, 'P': 1},
    ),
    "1384": UnimodInfo(
        id="1384",
        name="Homocysteic_acid",
        formula="C-1H-2O3",
        monoisotopic_mass=33.969094,
        average_mass=33.9716,
        dict_composition={'H': -2, 'C': -1, 'O': 3},
    ),
    "1385": UnimodInfo(
        id="1385",
        name="Hydroxamic_acid",
        formula="HN",
        monoisotopic_mass=15.010899,
        average_mass=15.0146,
        dict_composition={'H': 1, 'N': 1},
    ),
    "1387": UnimodInfo(
        id="1387",
        name="3-phosphoglyceryl",
        formula="C3H5O6P",
        monoisotopic_mass=167.982375,
        average_mass=168.042,
        dict_composition={'H': 5, 'C': 3, 'O': 6, 'P': 1},
    ),
    "1388": UnimodInfo(
        id="1388",
        name="HN2_mustard",
        formula="C5H11NO",
        monoisotopic_mass=101.084064,
        average_mass=101.1469,
        dict_composition={'H': 11, 'C': 5, 'N': 1, 'O': 1},
    ),
    "1389": UnimodInfo(
        id="1389",
        name="HN3_mustard",
        formula="C6H13NO2",
        monoisotopic_mass=131.094629,
        average_mass=131.1729,
        dict_composition={'H': 13, 'C': 6, 'N': 1, 'O': 2},
    ),
    "1390": UnimodInfo(
        id="1390",
        name="Oxidation+NEM",
        formula="C6H7NO3",
        monoisotopic_mass=141.042593,
        average_mass=141.1247,
        dict_composition={'H': 7, 'C': 6, 'N': 1, 'O': 3},
    ),
    "1391": UnimodInfo(
        id="1391",
        name="NHS-fluorescein",
        formula="C27H21NO7",
        monoisotopic_mass=471.131802,
        average_mass=471.4581,
        dict_composition={'H': 21, 'C': 27, 'N': 1, 'O': 7},
    ),
    "1392": UnimodInfo(
        id="1392",
        name="DiART6plex",
        formula="C7H20NO2",
        monoisotopic_mass=217.162932,
        average_mass=217.2527,
        dict_composition={'H': 20, 'C': 7, 'N': 1, 'O': 2},
    ),
    "1393": UnimodInfo(
        id="1393",
        name="DiART6plex115",
        formula="C8H20O2",
        monoisotopic_mass=217.156612,
        average_mass=217.2535,
        dict_composition={'H': 20, 'C': 8, 'N': 0, 'O': 2},
    ),
    "1394": UnimodInfo(
        id="1394",
        name="DiART6plex116/119",
        formula="C9H18NO2",
        monoisotopic_mass=217.168776,
        average_mass=217.2797,
        dict_composition={'H': 18, 'C': 9, 'N': 1, 'O': 2},
    ),
    "1395": UnimodInfo(
        id="1395",
        name="DiART6plex117",
        formula="C10H18O2",
        monoisotopic_mass=217.162456,
        average_mass=217.2805,
        dict_composition={'H': 18, 'C': 10, 'N': 0, 'O': 2},
    ),
    "1396": UnimodInfo(
        id="1396",
        name="DiART6plex118",
        formula="C8H18N2O2",
        monoisotopic_mass=217.175096,
        average_mass=217.279,
        dict_composition={'H': 18, 'C': 8, 'N': 2, 'O': 2},
    ),
    "1397": UnimodInfo(
        id="1397",
        name="Iodoacetanilide",
        formula="C8H7NO",
        monoisotopic_mass=133.052764,
        average_mass=133.1473,
        dict_composition={'H': 7, 'C': 8, 'N': 1, 'O': 1},
    ),
    "1398": UnimodInfo(
        id="1398",
        name="Iodoacetanilide:13C(6)",
        formula="C2H7NO",
        monoisotopic_mass=139.072893,
        average_mass=139.1032,
        dict_composition={'H': 7, 'C': 2, 'N': 1, 'O': 1},
    ),
    "1399": UnimodInfo(
        id="1399",
        name="Dap-DSP",
        formula="C13H20N2O6S2",
        monoisotopic_mass=364.076278,
        average_mass=364.4377,
        dict_composition={'H': 20, 'C': 13, 'N': 2, 'O': 6, 'S': 2},
    ),
    "1400": UnimodInfo(
        id="1400",
        name="MurNAc",
        formula="C11H17NO7",
        monoisotopic_mass=275.100502,
        average_mass=275.2552,
        dict_composition={'O': 7, 'C': 11, 'H': 17, 'N': 1},
    ),
    "1402": UnimodInfo(
        id="1402",
        name="Label:2H(7)15N(4)",
        formula="H-7N-4",
        monoisotopic_mass=11.032077,
        average_mass=11.0168,
        dict_composition={'H': -7, 'N': -4},
    ),
    "1403": UnimodInfo(
        id="1403",
        name="Label:2H(6)15N(1)",
        formula="H-6N-1",
        monoisotopic_mass=7.034695,
        average_mass=7.0304,
        dict_composition={'H': -6, 'N': -1},
    ),
    "1405": UnimodInfo(
        id="1405",
        name="EEEDVIEVYQEQTGG",
        formula="C72H107N17O31",
        monoisotopic_mass=1705.73189,
        average_mass=1706.7153,
        dict_composition={'H': 107, 'C': 72, 'N': 17, 'O': 31},
    ),
    "1406": UnimodInfo(
        id="1406",
        name="EDEDTIDVFQQQTGG",
        formula="C69H102N18O30",
        monoisotopic_mass=1662.700924,
        average_mass=1663.6508,
        dict_composition={'H': 102, 'C': 69, 'N': 18, 'O': 30},
    ),
    "1408": UnimodInfo(
        id="1408",
        name="Hex(5)HexNAc(4)NeuAc(2)",
        formula="C84H136N6O61",
        monoisotopic_mass=2204.772441,
        average_mass=2205.9822,
        dict_composition={'C': 84, 'H': 136, 'O': 61, 'N': 6},
    ),
    "1409": UnimodInfo(
        id="1409",
        name="Hex(5)HexNAc(4)NeuAc(1)",
        formula="C73H119N5O53",
        monoisotopic_mass=1913.677025,
        average_mass=1914.7277,
        dict_composition={'C': 73, 'H': 119, 'O': 53, 'N': 5},
    ),
    "1410": UnimodInfo(
        id="1410",
        name="dHex(1)Hex(5)HexNAc(4)NeuAc(1)",
        formula="C79H129N5O57",
        monoisotopic_mass=2059.734933,
        average_mass=2060.8689,
        dict_composition={'C': 79, 'H': 129, 'O': 57, 'N': 5},
    ),
    "1411": UnimodInfo(
        id="1411",
        name="dHex(1)Hex(5)HexNAc(4)NeuAc(2)",
        formula="C90H146N6O65",
        monoisotopic_mass=2350.83035,
        average_mass=2352.1234,
        dict_composition={'C': 90, 'H': 146, 'O': 65, 'N': 6},
    ),
    "1412": UnimodInfo(
        id="1412",
        name="s-GlcNAc",
        formula="C8H13NO8S",
        monoisotopic_mass=283.036187,
        average_mass=283.2557,
        dict_composition={'O': 8, 'S': 1, 'C': 8, 'H': 13, 'N': 1},
    ),
    "1413": UnimodInfo(
        id="1413",
        name="PhosphoHex(2)",
        formula="C12H21O13P",
        monoisotopic_mass=404.071978,
        average_mass=404.2611,
        dict_composition={'H': 21, 'O': 13, 'P': 1, 'C': 12},
    ),
    "1414": UnimodInfo(
        id="1414",
        name="Trimethyl:13C(3)2H(9)",
        formula="H-3",
        monoisotopic_mass=54.113505,
        average_mass=54.1132,
        dict_composition={'H': -3, 'C': 0},
    ),
    "1419": UnimodInfo(
        id="1419",
        name="15N-oxobutanoic",
        formula="H-3",
        monoisotopic_mass=-18.023584,
        average_mass=-18.0239,
        dict_composition={'H': -3, 'N': 0},
    ),
    "1420": UnimodInfo(
        id="1420",
        name="spermine",
        formula="C10H23N3",
        monoisotopic_mass=185.189198,
        average_mass=185.3097,
        dict_composition={'H': 23, 'C': 10, 'N': 3},
    ),
    "1421": UnimodInfo(
        id="1421",
        name="spermidine",
        formula="C7H16N2",
        monoisotopic_mass=128.131349,
        average_mass=128.2153,
        dict_composition={'H': 16, 'C': 7, 'N': 2},
    ),
    "1423": UnimodInfo(
        id="1423",
        name="Biotin:Thermo-21330",
        formula="C21H35N3O7S",
        monoisotopic_mass=473.219571,
        average_mass=473.5835,
        dict_composition={'H': 35, 'C': 21, 'N': 3, 'O': 7, 'S': 1},
    ),
    "1425": UnimodInfo(
        id="1425",
        name="Pentose",
        formula="C5H8O4",
        monoisotopic_mass=132.042259,
        average_mass=132.1146,
        dict_composition={'C': 5, 'H': 8, 'O': 4},
    ),
    "1426": UnimodInfo(
        id="1426",
        name="Hex(1)Pent(1)",
        formula="C11H18O9",
        monoisotopic_mass=294.095082,
        average_mass=294.2552,
        dict_composition={'C': 11, 'H': 18, 'O': 9},
    ),
    "1427": UnimodInfo(
        id="1427",
        name="Hex(1)HexA(1)",
        formula="C12H18O11",
        monoisotopic_mass=338.084912,
        average_mass=338.2647,
        dict_composition={'C': 12, 'H': 18, 'O': 11},
    ),
    "1428": UnimodInfo(
        id="1428",
        name="Hex(1)Pent(2)",
        formula="C16H26O13",
        monoisotopic_mass=426.137341,
        average_mass=426.3698,
        dict_composition={'C': 16, 'H': 26, 'O': 13},
    ),
    "1429": UnimodInfo(
        id="1429",
        name="Hex(1)HexNAc(1)Phos(1)",
        formula="C14H24NO13P",
        monoisotopic_mass=445.098527,
        average_mass=445.313,
        dict_composition={'H': 24, 'O': 13, 'P': 1, 'C': 14, 'N': 1},
    ),
    "1430": UnimodInfo(
        id="1430",
        name="Hex(1)HexNAc(1)Sulf(1)",
        formula="C14H23NO13S",
        monoisotopic_mass=445.089011,
        average_mass=445.3963,
        dict_composition={'O': 13, 'S': 1, 'C': 14, 'H': 23, 'N': 1},
    ),
    "1431": UnimodInfo(
        id="1431",
        name="Hex(1)NeuAc(1)",
        formula="C17H27NO13",
        monoisotopic_mass=453.14824,
        average_mass=453.3952,
        dict_composition={'C': 17, 'H': 27, 'O': 13, 'N': 1},
    ),
    "1432": UnimodInfo(
        id="1432",
        name="Hex(1)NeuGc(1)",
        formula="C17H27NO14",
        monoisotopic_mass=469.143155,
        average_mass=469.3946,
        dict_composition={'C': 17, 'H': 27, 'O': 14, 'N': 1},
    ),
    "1433": UnimodInfo(
        id="1433",
        name="HexNAc(3)",
        formula="C24H39N3O15",
        monoisotopic_mass=609.238118,
        average_mass=609.5776,
        dict_composition={'C': 24, 'H': 39, 'N': 3, 'O': 15},
    ),
    "1434": UnimodInfo(
        id="1434",
        name="HexNAc(1)NeuAc(1)",
        formula="C19H30N2O13",
        monoisotopic_mass=494.174789,
        average_mass=494.4471,
        dict_composition={'C': 19, 'H': 30, 'N': 2, 'O': 13},
    ),
    "1435": UnimodInfo(
        id="1435",
        name="HexNAc(1)NeuGc(1)",
        formula="C19H30N2O14",
        monoisotopic_mass=510.169704,
        average_mass=510.4465,
        dict_composition={'C': 19, 'H': 30, 'N': 2, 'O': 14},
    ),
    "1436": UnimodInfo(
        id="1436",
        name="Hex(1)HexNAc(1)dHex(1)Me(1)",
        formula="C21H35NO14",
        monoisotopic_mass=525.205755,
        average_mass=525.5009,
        dict_composition={'C': 21, 'H': 35, 'O': 14, 'N': 1},
    ),
    "1437": UnimodInfo(
        id="1437",
        name="Hex(1)HexNAc(1)dHex(1)Me(2)",
        formula="C22H37NO14",
        monoisotopic_mass=539.221405,
        average_mass=539.5275,
        dict_composition={'C': 22, 'H': 37, 'O': 14, 'N': 1},
    ),
    "1438": UnimodInfo(
        id="1438",
        name="Hex(2)HexNAc(1)",
        formula="C20H33NO15",
        monoisotopic_mass=527.18502,
        average_mass=527.4737,
        dict_composition={'C': 20, 'H': 33, 'O': 15, 'N': 1},
    ),
    "1439": UnimodInfo(
        id="1439",
        name="Hex(1)HexA(1)HexNAc(1)",
        formula="C20H31NO16",
        monoisotopic_mass=541.164284,
        average_mass=541.4572,
        dict_composition={'C': 20, 'H': 31, 'O': 16, 'N': 1},
    ),
    "1440": UnimodInfo(
        id="1440",
        name="Hex(2)HexNAc(1)Me(1)",
        formula="C21H35NO15",
        monoisotopic_mass=541.20067,
        average_mass=541.5003,
        dict_composition={'C': 21, 'H': 35, 'O': 15, 'N': 1},
    ),
    "1441": UnimodInfo(
        id="1441",
        name="Hex(1)Pent(3)",
        formula="C21H34O17",
        monoisotopic_mass=558.1796,
        average_mass=558.4845,
        dict_composition={'C': 21, 'H': 34, 'O': 17},
    ),
    "1442": UnimodInfo(
        id="1442",
        name="Hex(1)NeuAc(1)Pent(1)",
        formula="C22H35NO17",
        monoisotopic_mass=585.190499,
        average_mass=585.5098,
        dict_composition={'C': 22, 'H': 35, 'O': 17, 'N': 1},
    ),
    "1443": UnimodInfo(
        id="1443",
        name="Hex(2)HexNAc(1)Sulf(1)",
        formula="C20H33NO18S",
        monoisotopic_mass=607.141834,
        average_mass=607.5369,
        dict_composition={'O': 18, 'S': 1, 'C': 20, 'H': 33, 'N': 1},
    ),
    "1444": UnimodInfo(
        id="1444",
        name="Hex(2)NeuAc(1)",
        formula="C23H37NO18",
        monoisotopic_mass=615.201064,
        average_mass=615.5358,
        dict_composition={'C': 23, 'H': 37, 'O': 18, 'N': 1},
    ),
    "1445": UnimodInfo(
        id="1445",
        name="dHex(2)Hex(2)",
        formula="C24H40O18",
        monoisotopic_mass=616.221465,
        average_mass=616.5636,
        dict_composition={'C': 24, 'H': 40, 'O': 18},
    ),
    "1446": UnimodInfo(
        id="1446",
        name="dHex(1)Hex(2)HexA(1)",
        formula="C24H38O20",
        monoisotopic_mass=646.195644,
        average_mass=646.5465,
        dict_composition={'C': 24, 'H': 38, 'O': 20},
    ),
    "1447": UnimodInfo(
        id="1447",
        name="Hex(1)HexNAc(2)Sulf(1)",
        formula="C22H36N2O18S",
        monoisotopic_mass=648.168383,
        average_mass=648.5888,
        dict_composition={'O': 18, 'S': 1, 'C': 22, 'H': 36, 'N': 2},
    ),
    "1448": UnimodInfo(
        id="1448",
        name="Hex(4)",
        formula="C24H40O20",
        monoisotopic_mass=648.211294,
        average_mass=648.5624,
        dict_composition={'C': 24, 'H': 40, 'O': 20},
    ),
    "1449": UnimodInfo(
        id="1449",
        name="dHex(1)Hex(2)HexNAc(2)Pent(1)",
        formula="C39H64N2O28",
        monoisotopic_mass=1008.36456,
        average_mass=1008.9221,
        dict_composition={'C': 39, 'H': 64, 'O': 28, 'N': 2},
    ),
    "1450": UnimodInfo(
        id="1450",
        name="Hex(2)HexNAc(2)NeuAc(1)",
        formula="C39H63N3O28",
        monoisotopic_mass=1021.359809,
        average_mass=1021.9208,
        dict_composition={'C': 39, 'H': 63, 'O': 28, 'N': 3},
    ),
    "1451": UnimodInfo(
        id="1451",
        name="Hex(3)HexNAc(2)Pent(1)",
        formula="C39H64N2O29",
        monoisotopic_mass=1024.359475,
        average_mass=1024.9215,
        dict_composition={'C': 39, 'H': 64, 'O': 29, 'N': 2},
    ),
    "1452": UnimodInfo(
        id="1452",
        name="Hex(4)HexNAc(2)",
        formula="C40H66N2O30",
        monoisotopic_mass=1054.370039,
        average_mass=1054.9474,
        dict_composition={'C': 40, 'H': 66, 'O': 30, 'N': 2},
    ),
    "1453": UnimodInfo(
        id="1453",
        name="dHex(1)Hex(4)HexNAc(1)Pent(1)",
        formula="C43H71NO33",
        monoisotopic_mass=1129.390834,
        average_mass=1130.0107,
        dict_composition={'C': 43, 'H': 71, 'O': 33, 'N': 1},
    ),
    "1454": UnimodInfo(
        id="1454",
        name="dHex(1)Hex(3)HexNAc(2)Pent(1)",
        formula="C45H74N2O33",
        monoisotopic_mass=1170.417383,
        average_mass=1171.0627,
        dict_composition={'C': 45, 'H': 74, 'O': 33, 'N': 2},
    ),
    "1455": UnimodInfo(
        id="1455",
        name="Hex(3)HexNAc(2)NeuAc(1)",
        formula="C45H73N3O33",
        monoisotopic_mass=1183.412632,
        average_mass=1184.0614,
        dict_composition={'C': 45, 'H': 73, 'O': 33, 'N': 3},
    ),
    "1456": UnimodInfo(
        id="1456",
        name="Hex(4)HexNAc(2)Pent(1)",
        formula="C45H74N2O34",
        monoisotopic_mass=1186.412298,
        average_mass=1187.0621,
        dict_composition={'C': 45, 'H': 74, 'O': 34, 'N': 2},
    ),
    "1457": UnimodInfo(
        id="1457",
        name="Hex(3)HexNAc(3)Pent(1)",
        formula="C47H77N3O34",
        monoisotopic_mass=1227.438847,
        average_mass=1228.114,
        dict_composition={'C': 47, 'H': 77, 'O': 34, 'N': 3},
    ),
    "1458": UnimodInfo(
        id="1458",
        name="Hex(5)HexNAc(2)Phos(1)",
        formula="C46H77N2O38P",
        monoisotopic_mass=1296.389194,
        average_mass=1297.0679,
        dict_composition={'H': 77, 'O': 38, 'P': 1, 'C': 46, 'N': 2},
    ),
    "1459": UnimodInfo(
        id="1459",
        name="dHex(1)Hex(4)HexNAc(2)Pent(1)",
        formula="C51H84N2O38",
        monoisotopic_mass=1332.470207,
        average_mass=1333.2033,
        dict_composition={'C': 51, 'H': 84, 'O': 38, 'N': 2},
    ),
    "1460": UnimodInfo(
        id="1460",
        name="Hex(7)HexNAc(1)",
        formula="C50H83NO40",
        monoisotopic_mass=1337.449137,
        average_mass=1338.1767,
        dict_composition={'C': 50, 'H': 83, 'O': 40, 'N': 1},
    ),
    "1461": UnimodInfo(
        id="1461",
        name="Hex(4)HexNAc(2)NeuAc(1)",
        formula="C51H83N3O38",
        monoisotopic_mass=1345.465456,
        average_mass=1346.202,
        dict_composition={'C': 51, 'H': 83, 'O': 38, 'N': 3},
    ),
    "1462": UnimodInfo(
        id="1462",
        name="dHex(1)Hex(5)HexNAc(2)",
        formula="C52H86N2O39",
        monoisotopic_mass=1362.480772,
        average_mass=1363.2292,
        dict_composition={'C': 52, 'H': 86, 'O': 39, 'N': 2},
    ),
    "1463": UnimodInfo(
        id="1463",
        name="dHex(1)Hex(3)HexNAc(3)Pent(1)",
        formula="C53H87N3O38",
        monoisotopic_mass=1373.496756,
        average_mass=1374.2552,
        dict_composition={'C': 53, 'H': 87, 'O': 38, 'N': 3},
    ),
    "1464": UnimodInfo(
        id="1464",
        name="Hex(3)HexNAc(4)Sulf(1)",
        formula="C50H82N4O38S",
        monoisotopic_mass=1378.432776,
        average_mass=1379.2551,
        dict_composition={'O': 38, 'S': 1, 'C': 50, 'H': 82, 'N': 4},
    ),
    "1465": UnimodInfo(
        id="1465",
        name="Hex(6)HexNAc(2)",
        formula="C52H86N2O40",
        monoisotopic_mass=1378.475686,
        average_mass=1379.2286,
        dict_composition={'C': 52, 'H': 86, 'O': 40, 'N': 2},
    ),
    "1466": UnimodInfo(
        id="1466",
        name="Hex(4)HexNAc(3)Pent(1)",
        formula="C53H87N3O39",
        monoisotopic_mass=1389.491671,
        average_mass=1390.2546,
        dict_composition={'C': 53, 'H': 87, 'O': 39, 'N': 3},
    ),
    "1467": UnimodInfo(
        id="1467",
        name="dHex(1)Hex(4)HexNAc(3)",
        formula="C54H89N3O39",
        monoisotopic_mass=1403.507321,
        average_mass=1404.2812,
        dict_composition={'C': 54, 'H': 89, 'O': 39, 'N': 3},
    ),
    "1468": UnimodInfo(
        id="1468",
        name="Hex(5)HexNAc(3)",
        formula="C54H89N3O40",
        monoisotopic_mass=1419.502235,
        average_mass=1420.2806,
        dict_composition={'C': 54, 'H': 89, 'O': 40, 'N': 3},
    ),
    "1469": UnimodInfo(
        id="1469",
        name="Hex(3)HexNAc(4)Pent(1)",
        formula="C55H90N4O39",
        monoisotopic_mass=1430.51822,
        average_mass=1431.3065,
        dict_composition={'C': 55, 'H': 90, 'O': 39, 'N': 4},
    ),
    "1470": UnimodInfo(
        id="1470",
        name="Hex(6)HexNAc(2)Phos(1)",
        formula="C52H87N2O43P",
        monoisotopic_mass=1458.442017,
        average_mass=1459.2085,
        dict_composition={'H': 87, 'O': 43, 'P': 1, 'C': 52, 'N': 2},
    ),
    "1471": UnimodInfo(
        id="1471",
        name="dHex(1)Hex(4)HexNAc(3)Sulf(1)",
        formula="C54H89N3O42S",
        monoisotopic_mass=1483.464135,
        average_mass=1484.3444,
        dict_composition={'O': 42, 'S': 1, 'C': 54, 'H': 89, 'N': 3},
    ),
    "1472": UnimodInfo(
        id="1472",
        name="dHex(1)Hex(5)HexNAc(2)Pent(1)",
        formula="C57H94N2O43",
        monoisotopic_mass=1494.52303,
        average_mass=1495.3439,
        dict_composition={'C': 57, 'H': 94, 'O': 43, 'N': 2},
    ),
    "1473": UnimodInfo(
        id="1473",
        name="Hex(8)HexNAc(1)",
        formula="C56H93NO45",
        monoisotopic_mass=1499.501961,
        average_mass=1500.3173,
        dict_composition={'C': 56, 'H': 93, 'O': 45, 'N': 1},
    ),
    "1474": UnimodInfo(
        id="1474",
        name="dHex(1)Hex(3)HexNAc(3)Pent(2)",
        formula="C58H95N3O42",
        monoisotopic_mass=1505.539015,
        average_mass=1506.3698,
        dict_composition={'C': 58, 'H': 95, 'O': 42, 'N': 3},
    ),
    "1475": UnimodInfo(
        id="1475",
        name="dHex(2)Hex(3)HexNAc(3)Pent(1)",
        formula="C59H97N3O42",
        monoisotopic_mass=1519.554665,
        average_mass=1520.3964,
        dict_composition={'C': 59, 'H': 97, 'O': 42, 'N': 3},
    ),
    "1476": UnimodInfo(
        id="1476",
        name="dHex(1)Hex(3)HexNAc(4)Sulf(1)",
        formula="C56H92N4O42S",
        monoisotopic_mass=1524.490684,
        average_mass=1525.3963,
        dict_composition={'O': 42, 'S': 1, 'C': 56, 'H': 92, 'N': 4},
    ),
    "1477": UnimodInfo(
        id="1477",
        name="dHex(1)Hex(6)HexNAc(2)",
        formula="C58H96N2O44",
        monoisotopic_mass=1524.533595,
        average_mass=1525.3698,
        dict_composition={'C': 58, 'H': 96, 'O': 44, 'N': 2},
    ),
    "1478": UnimodInfo(
        id="1478",
        name="dHex(1)Hex(4)HexNAc(3)Pent(1)",
        formula="C59H97N3O43",
        monoisotopic_mass=1535.549579,
        average_mass=1536.3958,
        dict_composition={'C': 59, 'H': 97, 'O': 43, 'N': 3},
    ),
    "1479": UnimodInfo(
        id="1479",
        name="Hex(4)HexNAc(4)Sulf(1)",
        formula="C56H92N4O43S",
        monoisotopic_mass=1540.485599,
        average_mass=1541.3957,
        dict_composition={'O': 43, 'S': 1, 'C': 56, 'H': 92, 'N': 4},
    ),
    "1480": UnimodInfo(
        id="1480",
        name="Hex(7)HexNAc(2)",
        formula="C58H96N2O45",
        monoisotopic_mass=1540.52851,
        average_mass=1541.3692,
        dict_composition={'C': 58, 'H': 96, 'O': 45, 'N': 2},
    ),
    "1481": UnimodInfo(
        id="1481",
        name="dHex(2)Hex(4)HexNAc(3)",
        formula="C60H99N3O43",
        monoisotopic_mass=1549.56523,
        average_mass=1550.4224,
        dict_composition={'C': 60, 'H': 99, 'O': 43, 'N': 3},
    ),
    "1482": UnimodInfo(
        id="1482",
        name="Hex(5)HexNAc(3)Pent(1)",
        formula="C59H97N3O44",
        monoisotopic_mass=1551.544494,
        average_mass=1552.3952,
        dict_composition={'C': 59, 'H': 97, 'O': 44, 'N': 3},
    ),
    "1483": UnimodInfo(
        id="1483",
        name="Hex(4)HexNAc(3)NeuGc(1)",
        formula="C59H96N4O44",
        monoisotopic_mass=1564.539743,
        average_mass=1565.3939,
        dict_composition={'C': 59, 'H': 96, 'O': 44, 'N': 4},
    ),
    "1484": UnimodInfo(
        id="1484",
        name="dHex(1)Hex(5)HexNAc(3)",
        formula="C60H99N3O44",
        monoisotopic_mass=1565.560144,
        average_mass=1566.4218,
        dict_composition={'C': 60, 'H': 99, 'O': 44, 'N': 3},
    ),
    "1485": UnimodInfo(
        id="1485",
        name="dHex(1)Hex(3)HexNAc(4)Pent(1)",
        formula="C61H100N4O43",
        monoisotopic_mass=1576.576129,
        average_mass=1577.4477,
        dict_composition={'C': 61, 'H': 100, 'O': 43, 'N': 4},
    ),
    "1486": UnimodInfo(
        id="1486",
        name="Hex(3)HexNAc(5)Sulf(1)",
        formula="C58H95N5O43S",
        monoisotopic_mass=1581.512148,
        average_mass=1582.4476,
        dict_composition={'O': 43, 'S': 1, 'C': 58, 'H': 95, 'N': 5},
    ),
    "1487": UnimodInfo(
        id="1487",
        name="Hex(6)HexNAc(3)",
        formula="C60H99N3O45",
        monoisotopic_mass=1581.555059,
        average_mass=1582.4212,
        dict_composition={'C': 60, 'H': 99, 'O': 45, 'N': 3},
    ),
    "1488": UnimodInfo(
        id="1488",
        name="Hex(3)HexNAc(4)NeuAc(1)",
        formula="C61H99N5O43",
        monoisotopic_mass=1589.571378,
        average_mass=1590.4465,
        dict_composition={'C': 61, 'H': 99, 'O': 43, 'N': 5},
    ),
    "1489": UnimodInfo(
        id="1489",
        name="Hex(4)HexNAc(4)Pent(1)",
        formula="C61H100N4O44",
        monoisotopic_mass=1592.571043,
        average_mass=1593.4471,
        dict_composition={'C': 61, 'H': 100, 'O': 44, 'N': 4},
    ),
    "1490": UnimodInfo(
        id="1490",
        name="Hex(7)HexNAc(2)Phos(1)",
        formula="C58H97N2O48P",
        monoisotopic_mass=1620.494841,
        average_mass=1621.3491,
        dict_composition={'H': 97, 'O': 48, 'P': 1, 'C': 58, 'N': 2},
    ),
    "1491": UnimodInfo(
        id="1491",
        name="Hex(4)HexNAc(4)Me(2)Pent(1)",
        formula="C63H104N4O44",
        monoisotopic_mass=1620.602343,
        average_mass=1621.5003,
        dict_composition={'C': 63, 'H': 104, 'O': 44, 'N': 4},
    ),
    "1492": UnimodInfo(
        id="1492",
        name="dHex(1)Hex(3)HexNAc(3)Pent(3)",
        formula="C63H103N3O46",
        monoisotopic_mass=1637.581274,
        average_mass=1638.4844,
        dict_composition={'C': 63, 'H': 103, 'O': 46, 'N': 3},
    ),
    "1493": UnimodInfo(
        id="1493",
        name="dHex(1)Hex(5)HexNAc(3)Sulf(1)",
        formula="C60H99N3O47S",
        monoisotopic_mass=1645.516959,
        average_mass=1646.485,
        dict_composition={'O': 47, 'S': 1, 'C': 60, 'H': 99, 'N': 3},
    ),
    "1494": UnimodInfo(
        id="1494",
        name="dHex(2)Hex(3)HexNAc(3)Pent(2)",
        formula="C64H105N3O46",
        monoisotopic_mass=1651.596924,
        average_mass=1652.511,
        dict_composition={'C': 64, 'H': 105, 'O': 46, 'N': 3},
    ),
    "1495": UnimodInfo(
        id="1495",
        name="Hex(6)HexNAc(3)Phos(1)",
        formula="C60H100N3O48P",
        monoisotopic_mass=1661.52139,
        average_mass=1662.4011,
        dict_composition={'H': 100, 'O': 48, 'P': 1, 'C': 60, 'N': 3},
    ),
    "1496": UnimodInfo(
        id="1496",
        name="Hex(4)HexNAc(5)",
        formula="C64H105N5O45",
        monoisotopic_mass=1663.608157,
        average_mass=1664.525,
        dict_composition={'C': 64, 'H': 105, 'O': 45, 'N': 5},
    ),
    "1497": UnimodInfo(
        id="1497",
        name="dHex(3)Hex(3)HexNAc(3)Pent(1)",
        formula="C65H107N3O46",
        monoisotopic_mass=1665.612574,
        average_mass=1666.5376,
        dict_composition={'C': 65, 'H': 107, 'O': 46, 'N': 3},
    ),
    "1498": UnimodInfo(
        id="1498",
        name="dHex(2)Hex(4)HexNAc(3)Pent(1)",
        formula="C65H107N3O47",
        monoisotopic_mass=1681.607488,
        average_mass=1682.537,
        dict_composition={'C': 65, 'H': 107, 'O': 47, 'N': 3},
    ),
    "1499": UnimodInfo(
        id="1499",
        name="dHex(1)Hex(4)HexNAc(4)Sulf(1)",
        formula="C62H102N4O47S",
        monoisotopic_mass=1686.543508,
        average_mass=1687.5369,
        dict_composition={'O': 47, 'S': 1, 'C': 62, 'H': 102, 'N': 4},
    ),
    "1500": UnimodInfo(
        id="1500",
        name="dHex(1)Hex(7)HexNAc(2)",
        formula="C64H106N2O49",
        monoisotopic_mass=1686.586419,
        average_mass=1687.5104,
        dict_composition={'C': 64, 'H': 106, 'O': 49, 'N': 2},
    ),
    "1501": UnimodInfo(
        id="1501",
        name="dHex(1)Hex(4)HexNAc(3)NeuAc(1)",
        formula="C65H106N4O47",
        monoisotopic_mass=1694.602737,
        average_mass=1695.5357,
        dict_composition={'C': 65, 'H': 106, 'O': 47, 'N': 4},
    ),
    "1502": UnimodInfo(
        id="1502",
        name="Hex(7)HexNAc(2)Phos(2)",
        formula="C58H98N2O51P2",
        monoisotopic_mass=1700.461172,
        average_mass=1701.329,
        dict_composition={'H': 98, 'O': 51, 'P': 2, 'C': 58, 'N': 2},
    ),
    "1503": UnimodInfo(
        id="1503",
        name="Hex(5)HexNAc(4)Sulf(1)",
        formula="C62H102N4O48S",
        monoisotopic_mass=1702.538423,
        average_mass=1703.5363,
        dict_composition={'O': 48, 'S': 1, 'C': 62, 'H': 102, 'N': 4},
    ),
    "1504": UnimodInfo(
        id="1504",
        name="Hex(8)HexNAc(2)",
        formula="C64H106N2O50",
        monoisotopic_mass=1702.581333,
        average_mass=1703.5098,
        dict_composition={'C': 64, 'H': 106, 'O': 50, 'N': 2},
    ),
    "1505": UnimodInfo(
        id="1505",
        name="dHex(1)Hex(3)HexNAc(4)Pent(2)",
        formula="C66H108N4O47",
        monoisotopic_mass=1708.618387,
        average_mass=1709.5623,
        dict_composition={'C': 66, 'H': 108, 'O': 47, 'N': 4},
    ),
    "1506": UnimodInfo(
        id="1506",
        name="dHex(1)Hex(4)HexNAc(3)NeuGc(1)",
        formula="C65H106N4O48",
        monoisotopic_mass=1710.597652,
        average_mass=1711.5351,
        dict_composition={'C': 65, 'H': 106, 'O': 48, 'N': 4},
    ),
    "1507": UnimodInfo(
        id="1507",
        name="dHex(2)Hex(3)HexNAc(4)Pent(1)",
        formula="C67H110N4O47",
        monoisotopic_mass=1722.634037,
        average_mass=1723.5889,
        dict_composition={'C': 67, 'H': 110, 'O': 47, 'N': 4},
    ),
    "1508": UnimodInfo(
        id="1508",
        name="dHex(1)Hex(3)HexNAc(5)Sulf(1)",
        formula="C64H105N5O47S",
        monoisotopic_mass=1727.570057,
        average_mass=1728.5888,
        dict_composition={'O': 47, 'S': 1, 'C': 64, 'H': 105, 'N': 5},
    ),
    "1509": UnimodInfo(
        id="1509",
        name="dHex(1)Hex(6)HexNAc(3)",
        formula="C66H109N3O49",
        monoisotopic_mass=1727.612968,
        average_mass=1728.5624,
        dict_composition={'C': 66, 'H': 109, 'O': 49, 'N': 3},
    ),
    "1510": UnimodInfo(
        id="1510",
        name="dHex(1)Hex(3)HexNAc(4)NeuAc(1)",
        formula="C67H109N5O47",
        monoisotopic_mass=1735.629286,
        average_mass=1736.5877,
        dict_composition={'C': 67, 'H': 109, 'O': 47, 'N': 5},
    ),
    "1511": UnimodInfo(
        id="1511",
        name="dHex(3)Hex(3)HexNAc(4)",
        formula="C68H112N4O47",
        monoisotopic_mass=1736.649688,
        average_mass=1737.6155,
        dict_composition={'C': 68, 'H': 112, 'O': 47, 'N': 4},
    ),
    "1512": UnimodInfo(
        id="1512",
        name="dHex(1)Hex(4)HexNAc(4)Pent(1)",
        formula="C67H110N4O48",
        monoisotopic_mass=1738.628952,
        average_mass=1739.5883,
        dict_composition={'C': 67, 'H': 110, 'O': 48, 'N': 4},
    ),
    "1513": UnimodInfo(
        id="1513",
        name="Hex(4)HexNAc(5)Sulf(1)",
        formula="C64H105N5O48S",
        monoisotopic_mass=1743.564972,
        average_mass=1744.5882,
        dict_composition={'O': 48, 'S': 1, 'C': 64, 'H': 105, 'N': 5},
    ),
    "1514": UnimodInfo(
        id="1514",
        name="Hex(7)HexNAc(3)",
        formula="C66H109N3O50",
        monoisotopic_mass=1743.607882,
        average_mass=1744.5618,
        dict_composition={'C': 66, 'H': 109, 'O': 50, 'N': 3},
    ),
    "1515": UnimodInfo(
        id="1515",
        name="dHex(1)Hex(4)HexNAc(3)NeuAc(1)Sulf(1)",
        formula="C65H106N4O50S",
        monoisotopic_mass=1774.559552,
        average_mass=1775.5989,
        dict_composition={'O': 50, 'S': 1, 'C': 65, 'H': 106, 'N': 4},
    ),
    "1516": UnimodInfo(
        id="1516",
        name="Hex(5)HexNAc(4)Me(2)Pent(1)",
        formula="C69H114N4O49",
        monoisotopic_mass=1782.655167,
        average_mass=1783.6409,
        dict_composition={'C': 69, 'H': 114, 'O': 49, 'N': 4},
    ),
    "1517": UnimodInfo(
        id="1517",
        name="Hex(3)HexNAc(6)Sulf(1)",
        formula="C66H108N6O48S",
        monoisotopic_mass=1784.591521,
        average_mass=1785.6401,
        dict_composition={'O': 48, 'S': 1, 'C': 66, 'H': 108, 'N': 6},
    ),
    "1518": UnimodInfo(
        id="1518",
        name="dHex(1)Hex(6)HexNAc(3)Sulf(1)",
        formula="C66H109N3O52S",
        monoisotopic_mass=1807.569782,
        average_mass=1808.6256,
        dict_composition={'O': 52, 'S': 1, 'C': 66, 'H': 109, 'N': 3},
    ),
    "1519": UnimodInfo(
        id="1519",
        name="dHex(1)Hex(4)HexNAc(5)",
        formula="C70H115N5O49",
        monoisotopic_mass=1809.666066,
        average_mass=1810.6662,
        dict_composition={'C': 70, 'H': 115, 'O': 49, 'N': 5},
    ),
    "1520": UnimodInfo(
        id="1520",
        name="dHex(1)Hex(5)HexA(1)HexNAc(3)Sulf(1)",
        formula="C66H107N3O53S",
        monoisotopic_mass=1821.549047,
        average_mass=1822.6091,
        dict_composition={'O': 53, 'S': 1, 'C': 66, 'H': 107, 'N': 3},
    ),
    "1521": UnimodInfo(
        id="1521",
        name="Hex(7)HexNAc(3)Phos(1)",
        formula="C66H110N3O53P",
        monoisotopic_mass=1823.574213,
        average_mass=1824.5417,
        dict_composition={'H': 110, 'O': 53, 'P': 1, 'C': 66, 'N': 3},
    ),
    "1522": UnimodInfo(
        id="1522",
        name="Hex(6)HexNAc(4)Me(3)",
        formula="C71H118N4O50",
        monoisotopic_mass=1826.681382,
        average_mass=1827.6934,
        dict_composition={'C': 71, 'H': 118, 'O': 50, 'N': 4},
    ),
    "1523": UnimodInfo(
        id="1523",
        name="dHex(2)Hex(4)HexNAc(4)Sulf(1)",
        formula="C68H112N4O51S",
        monoisotopic_mass=1832.601417,
        average_mass=1833.6781,
        dict_composition={'O': 51, 'S': 1, 'C': 68, 'H': 112, 'N': 4},
    ),
    "1524": UnimodInfo(
        id="1524",
        name="Hex(4)HexNAc(3)NeuAc(2)",
        formula="C70H113N5O51",
        monoisotopic_mass=1839.640245,
        average_mass=1840.6491,
        dict_composition={'C': 70, 'H': 113, 'O': 51, 'N': 5},
    ),
    "1525": UnimodInfo(
        id="1525",
        name="dHex(1)Hex(3)HexNAc(4)Pent(3)",
        formula="C71H116N4O51",
        monoisotopic_mass=1840.660646,
        average_mass=1841.6769,
        dict_composition={'C': 71, 'H': 116, 'O': 51, 'N': 4},
    ),
    "1526": UnimodInfo(
        id="1526",
        name="dHex(2)Hex(5)HexNAc(3)Pent(1)",
        formula="C71H117N3O52",
        monoisotopic_mass=1843.660312,
        average_mass=1844.6776,
        dict_composition={'C': 71, 'H': 117, 'O': 52, 'N': 3},
    ),
    "1527": UnimodInfo(
        id="1527",
        name="dHex(1)Hex(5)HexNAc(4)Sulf(1)",
        formula="C68H112N4O52S",
        monoisotopic_mass=1848.596331,
        average_mass=1849.6775,
        dict_composition={'O': 52, 'S': 1, 'C': 68, 'H': 112, 'N': 4},
    ),
    "1528": UnimodInfo(
        id="1528",
        name="dHex(2)Hex(3)HexNAc(4)Pent(2)",
        formula="C72H118N4O51",
        monoisotopic_mass=1854.676296,
        average_mass=1855.7035,
        dict_composition={'C': 72, 'H': 118, 'O': 51, 'N': 4},
    ),
    "1529": UnimodInfo(
        id="1529",
        name="dHex(1)Hex(5)HexNAc(3)NeuAc(1)",
        formula="C71H116N4O52",
        monoisotopic_mass=1856.655561,
        average_mass=1857.6763,
        dict_composition={'C': 71, 'H': 116, 'O': 52, 'N': 4},
    ),
    "1530": UnimodInfo(
        id="1530",
        name="Hex(3)HexNAc(6)Sulf(2)",
        formula="C66H108N6O51S2",
        monoisotopic_mass=1864.548335,
        average_mass=1865.7033,
        dict_composition={'O': 51, 'S': 2, 'C': 66, 'H': 108, 'N': 6},
    ),
    "1531": UnimodInfo(
        id="1531",
        name="Hex(9)HexNAc(2)",
        formula="C70H116N2O55",
        monoisotopic_mass=1864.634157,
        average_mass=1865.6504,
        dict_composition={'C': 70, 'H': 116, 'O': 55, 'N': 2},
    ),
    "1532": UnimodInfo(
        id="1532",
        name="Hex(4)HexNAc(6)",
        formula="C72H118N6O50",
        monoisotopic_mass=1866.68753,
        average_mass=1867.7175,
        dict_composition={'C': 72, 'H': 118, 'O': 50, 'N': 6},
    ),
    "1533": UnimodInfo(
        id="1533",
        name="dHex(3)Hex(3)HexNAc(4)Pent(1)",
        formula="C73H120N4O51",
        monoisotopic_mass=1868.691946,
        average_mass=1869.7301,
        dict_composition={'C': 73, 'H': 120, 'O': 51, 'N': 4},
    ),
    "1534": UnimodInfo(
        id="1534",
        name="dHex(1)Hex(5)HexNAc(3)NeuGc(1)",
        formula="C71H116N4O53",
        monoisotopic_mass=1872.650475,
        average_mass=1873.6757,
        dict_composition={'C': 71, 'H': 116, 'O': 53, 'N': 4},
    ),
    "1535": UnimodInfo(
        id="1535",
        name="dHex(2)Hex(4)HexNAc(4)Pent(1)",
        formula="C73H120N4O52",
        monoisotopic_mass=1884.686861,
        average_mass=1885.7295,
        dict_composition={'C': 73, 'H': 120, 'O': 52, 'N': 4},
    ),
    "1536": UnimodInfo(
        id="1536",
        name="dHex(1)Hex(4)HexNAc(5)Sulf(1)",
        formula="C70H115N5O52S",
        monoisotopic_mass=1889.62288,
        average_mass=1890.7294,
        dict_composition={'O': 52, 'S': 1, 'C': 70, 'H': 115, 'N': 5},
    ),
    "1537": UnimodInfo(
        id="1537",
        name="dHex(1)Hex(7)HexNAc(3)",
        formula="C72H119N3O54",
        monoisotopic_mass=1889.665791,
        average_mass=1890.703,
        dict_composition={'C': 72, 'H': 119, 'O': 54, 'N': 3},
    ),
    "1538": UnimodInfo(
        id="1538",
        name="dHex(1)Hex(5)HexNAc(4)Pent(1)",
        formula="C73H120N4O53",
        monoisotopic_mass=1900.681776,
        average_mass=1901.7289,
        dict_composition={'C': 73, 'H': 120, 'O': 53, 'N': 4},
    ),
    "1539": UnimodInfo(
        id="1539",
        name="dHex(1)Hex(5)HexA(1)HexNAc(3)Sulf(2)",
        formula="C66H107N3O56S2",
        monoisotopic_mass=1901.505861,
        average_mass=1902.6723,
        dict_composition={'O': 56, 'S': 2, 'C': 66, 'H': 107, 'N': 3},
    ),
    "1540": UnimodInfo(
        id="1540",
        name="Hex(3)HexNAc(7)",
        formula="C74H121N7O50",
        monoisotopic_mass=1907.714079,
        average_mass=1908.7694,
        dict_composition={'C': 74, 'H': 121, 'O': 50, 'N': 7},
    ),
    "1541": UnimodInfo(
        id="1541",
        name="dHex(2)Hex(5)HexNAc(4)",
        formula="C74H122N4O53",
        monoisotopic_mass=1914.697426,
        average_mass=1915.7555,
        dict_composition={'C': 74, 'H': 122, 'O': 53, 'N': 4},
    ),
    "1542": UnimodInfo(
        id="1542",
        name="dHex(2)Hex(4)HexNAc(3)NeuAc(1)Sulf(1)",
        formula="C71H116N4O54S",
        monoisotopic_mass=1920.617461,
        average_mass=1921.7401,
        dict_composition={'O': 54, 'S': 1, 'C': 71, 'H': 116, 'N': 4},
    ),
    "1543": UnimodInfo(
        id="1543",
        name="dHex(1)Hex(5)HexNAc(4)Sulf(2)",
        formula="C68H112N4O55S2",
        monoisotopic_mass=1928.553146,
        average_mass=1929.7407,
        dict_composition={'O': 55, 'S': 2, 'C': 68, 'H': 112, 'N': 4},
    ),
    "1544": UnimodInfo(
        id="1544",
        name="dHex(1)Hex(5)HexNAc(4)Me(2)Pent(1)",
        formula="C75H124N4O53",
        monoisotopic_mass=1928.713076,
        average_mass=1929.7821,
        dict_composition={'C': 75, 'H': 124, 'O': 53, 'N': 4},
    ),
    "1545": UnimodInfo(
        id="1545",
        name="Hex(5)HexNAc(4)NeuGc(1)",
        formula="C73H119N5O54",
        monoisotopic_mass=1929.671939,
        average_mass=1930.7271,
        dict_composition={'C': 73, 'H': 119, 'O': 54, 'N': 5},
    ),
    "1546": UnimodInfo(
        id="1546",
        name="dHex(1)Hex(3)HexNAc(6)Sulf(1)",
        formula="C72H118N6O52S",
        monoisotopic_mass=1930.64943,
        average_mass=1931.7813,
        dict_composition={'O': 52, 'S': 1, 'C': 72, 'H': 118, 'N': 6},
    ),
    "1547": UnimodInfo(
        id="1547",
        name="dHex(1)Hex(6)HexNAc(4)",
        formula="C74H122N4O54",
        monoisotopic_mass=1930.69234,
        average_mass=1931.7549,
        dict_composition={'C': 74, 'H': 122, 'O': 54, 'N': 4},
    ),
    "1548": UnimodInfo(
        id="1548",
        name="dHex(1)Hex(5)HexNAc(3)NeuAc(1)Sulf(1)",
        formula="C71H116N4O55S",
        monoisotopic_mass=1936.612375,
        average_mass=1937.7395,
        dict_composition={'O': 55, 'S': 1, 'C': 71, 'H': 116, 'N': 4},
    ),
    "1549": UnimodInfo(
        id="1549",
        name="Hex(7)HexNAc(4)",
        formula="C74H122N4O55",
        monoisotopic_mass=1946.687255,
        average_mass=1947.7543,
        dict_composition={'C': 74, 'H': 122, 'O': 55, 'N': 4},
    ),
    "1550": UnimodInfo(
        id="1550",
        name="dHex(1)Hex(5)HexNAc(3)NeuGc(1)Sulf(1)",
        formula="C71H116N4O56S",
        monoisotopic_mass=1952.60729,
        average_mass=1953.7389,
        dict_composition={'O': 56, 'S': 1, 'C': 71, 'H': 116, 'N': 4},
    ),
    "1551": UnimodInfo(
        id="1551",
        name="Hex(4)HexNAc(5)NeuAc(1)",
        formula="C75H122N6O53",
        monoisotopic_mass=1954.703574,
        average_mass=1955.7796,
        dict_composition={'C': 75, 'H': 122, 'O': 53, 'N': 6},
    ),
    "1552": UnimodInfo(
        id="1552",
        name="Hex(6)HexNAc(4)Me(3)Pent(1)",
        formula="C76H126N4O54",
        monoisotopic_mass=1958.72364,
        average_mass=1959.808,
        dict_composition={'C': 76, 'H': 126, 'O': 54, 'N': 4},
    ),
    "1553": UnimodInfo(
        id="1553",
        name="dHex(1)Hex(7)HexNAc(3)Sulf(1)",
        formula="C72H119N3O57S",
        monoisotopic_mass=1969.622606,
        average_mass=1970.7662,
        dict_composition={'O': 57, 'S': 1, 'C': 72, 'H': 119, 'N': 3},
    ),
    "1554": UnimodInfo(
        id="1554",
        name="dHex(1)Hex(7)HexNAc(3)Phos(1)",
        formula="C72H120N3O57P",
        monoisotopic_mass=1969.632122,
        average_mass=1970.6829,
        dict_composition={'H': 120, 'O': 57, 'P': 1, 'C': 72, 'N': 3},
    ),
    "1555": UnimodInfo(
        id="1555",
        name="dHex(1)Hex(5)HexNAc(5)",
        formula="C76H125N5O54",
        monoisotopic_mass=1971.718889,
        average_mass=1972.8068,
        dict_composition={'C': 76, 'H': 125, 'O': 54, 'N': 5},
    ),
    "1556": UnimodInfo(
        id="1556",
        name="dHex(1)Hex(4)HexNAc(4)NeuAc(1)Sulf(1)",
        formula="C73H119N5O55S",
        monoisotopic_mass=1977.638925,
        average_mass=1978.7915,
        dict_composition={'O': 55, 'S': 1, 'C': 73, 'H': 119, 'N': 5},
    ),
    "1557": UnimodInfo(
        id="1557",
        name="dHex(3)Hex(4)HexNAc(4)Sulf(1)",
        formula="C74H122N4O55S",
        monoisotopic_mass=1978.659326,
        average_mass=1979.8193,
        dict_composition={'O': 55, 'S': 1, 'C': 74, 'H': 122, 'N': 4},
    ),
    "1558": UnimodInfo(
        id="1558",
        name="Hex(3)HexNAc(7)Sulf(1)",
        formula="C74H121N7O53S",
        monoisotopic_mass=1987.670893,
        average_mass=1988.8326,
        dict_composition={'O': 53, 'S': 1, 'C': 74, 'H': 121, 'N': 7},
    ),
    "1559": UnimodInfo(
        id="1559",
        name="Hex(6)HexNAc(5)",
        formula="C76H125N5O55",
        monoisotopic_mass=1987.713804,
        average_mass=1988.8062,
        dict_composition={'C': 76, 'H': 125, 'O': 55, 'N': 5},
    ),
    "1560": UnimodInfo(
        id="1560",
        name="Hex(5)HexNAc(4)NeuAc(1)Sulf(1)",
        formula="C73H119N5O56S",
        monoisotopic_mass=1993.633839,
        average_mass=1994.7909,
        dict_composition={'O': 56, 'S': 1, 'C': 73, 'H': 119, 'N': 5},
    ),
    "1561": UnimodInfo(
        id="1561",
        name="Hex(3)HexNAc(6)NeuAc(1)",
        formula="C77H125N7O53",
        monoisotopic_mass=1995.730123,
        average_mass=1996.8315,
        dict_composition={'C': 77, 'H': 125, 'O': 53, 'N': 7},
    ),
    "1562": UnimodInfo(
        id="1562",
        name="dHex(2)Hex(3)HexNAc(6)",
        formula="C78H128N6O53",
        monoisotopic_mass=1996.750524,
        average_mass=1997.8593,
        dict_composition={'C': 78, 'H': 128, 'O': 53, 'N': 6},
    ),
    "1563": UnimodInfo(
        id="1563",
        name="Hex(1)HexNAc(1)NeuGc(1)",
        formula="C25H40N2O19",
        monoisotopic_mass=672.222527,
        average_mass=672.5871,
        dict_composition={'C': 25, 'H': 40, 'O': 19, 'N': 2},
    ),
    "1564": UnimodInfo(
        id="1564",
        name="dHex(1)Hex(2)HexNAc(1)",
        formula="C26H43NO19",
        monoisotopic_mass=673.242928,
        average_mass=673.6149,
        dict_composition={'C': 26, 'H': 43, 'O': 19, 'N': 1},
    ),
    "1565": UnimodInfo(
        id="1565",
        name="HexNAc(3)Sulf(1)",
        formula="C24H39N3O18S",
        monoisotopic_mass=689.194932,
        average_mass=689.6408,
        dict_composition={'O': 18, 'S': 1, 'C': 24, 'H': 39, 'N': 3},
    ),
    "1566": UnimodInfo(
        id="1566",
        name="Hex(3)HexNAc(1)",
        formula="C26H43NO20",
        monoisotopic_mass=689.237843,
        average_mass=689.6143,
        dict_composition={'C': 26, 'H': 43, 'O': 20, 'N': 1},
    ),
    "1567": UnimodInfo(
        id="1567",
        name="Hex(1)HexNAc(1)Kdn(1)Sulf(1)",
        formula="C23H37NO21S",
        monoisotopic_mass=695.157878,
        average_mass=695.599,
        dict_composition={'O': 21, 'S': 1, 'C': 23, 'H': 37, 'N': 1},
    ),
    "1568": UnimodInfo(
        id="1568",
        name="HexNAc(2)NeuAc(1)",
        formula="C27H43N3O18",
        monoisotopic_mass=697.254162,
        average_mass=697.6396,
        dict_composition={'C': 27, 'H': 43, 'N': 3, 'O': 18},
    ),
    "1570": UnimodInfo(
        id="1570",
        name="HexNAc(1)Kdn(2)",
        formula="C26H41NO21",
        monoisotopic_mass=703.217108,
        average_mass=703.5978,
        dict_composition={'C': 26, 'H': 41, 'N': 1, 'O': 21},
    ),
    "1571": UnimodInfo(
        id="1571",
        name="Hex(3)HexNAc(1)Me(1)",
        formula="C27H45NO20",
        monoisotopic_mass=703.253493,
        average_mass=703.6409,
        dict_composition={'C': 27, 'H': 45, 'O': 20, 'N': 1},
    ),
    "1572": UnimodInfo(
        id="1572",
        name="Hex(2)HexA(1)Pent(1)Sulf(1)",
        formula="C23H36O23S",
        monoisotopic_mass=712.136808,
        average_mass=712.5831,
        dict_composition={'O': 23, 'S': 1, 'C': 23, 'H': 36},
    ),
    "1573": UnimodInfo(
        id="1573",
        name="HexNAc(2)NeuGc(1)",
        formula="C27H43N3O19",
        monoisotopic_mass=713.249076,
        average_mass=713.639,
        dict_composition={'C': 27, 'H': 43, 'N': 3, 'O': 19},
    ),
    "1575": UnimodInfo(
        id="1575",
        name="Hex(4)Phos(1)",
        formula="C24H41O23P",
        monoisotopic_mass=728.177625,
        average_mass=728.5423,
        dict_composition={'H': 41, 'O': 23, 'P': 1, 'C': 24},
    ),
    "1577": UnimodInfo(
        id="1577",
        name="Hex(1)HexNAc(1)NeuAc(1)Sulf(1)",
        formula="C25H40N2O21S",
        monoisotopic_mass=736.184427,
        average_mass=736.6509,
        dict_composition={'O': 21, 'S': 1, 'C': 25, 'H': 40, 'N': 2},
    ),
    "1578": UnimodInfo(
        id="1578",
        name="Hex(1)HexA(1)HexNAc(2)",
        formula="C28H44N2O21",
        monoisotopic_mass=744.243657,
        average_mass=744.6498,
        dict_composition={'C': 28, 'H': 44, 'O': 21, 'N': 2},
    ),
    "1579": UnimodInfo(
        id="1579",
        name="dHex(1)Hex(2)HexNAc(1)Sulf(1)",
        formula="C26H43NO22S",
        monoisotopic_mass=753.199743,
        average_mass=753.6781,
        dict_composition={'O': 22, 'S': 1, 'C': 26, 'H': 43, 'N': 1},
    ),
    "1580": UnimodInfo(
        id="1580",
        name="dHex(1)HexNAc(3)",
        formula="C30H49N3O19",
        monoisotopic_mass=755.296027,
        average_mass=755.7188,
        dict_composition={'C': 30, 'H': 49, 'O': 19, 'N': 3},
    ),
    "1581": UnimodInfo(
        id="1581",
        name="dHex(1)Hex(1)HexNAc(1)Kdn(1)",
        formula="C29H47NO22",
        monoisotopic_mass=761.258973,
        average_mass=761.677,
        dict_composition={'C': 29, 'H': 47, 'O': 22, 'N': 1},
    ),
    "1582": UnimodInfo(
        id="1582",
        name="Hex(1)HexNAc(3)",
        formula="C30H49N3O20",
        monoisotopic_mass=771.290941,
        average_mass=771.7182,
        dict_composition={'C': 30, 'H': 49, 'O': 20, 'N': 3},
    ),
    "1583": UnimodInfo(
        id="1583",
        name="HexNAc(2)NeuAc(1)Sulf(1)",
        formula="C27H43N3O21S",
        monoisotopic_mass=777.210976,
        average_mass=777.7028,
        dict_composition={'O': 21, 'S': 1, 'C': 27, 'H': 43, 'N': 3},
    ),
    "1584": UnimodInfo(
        id="1584",
        name="dHex(2)Hex(3)",
        formula="C30H50O23",
        monoisotopic_mass=778.274288,
        average_mass=778.7042,
        dict_composition={'C': 30, 'H': 50, 'O': 23},
    ),
    "1585": UnimodInfo(
        id="1585",
        name="Hex(2)HexA(1)HexNAc(1)Sulf(1)",
        formula="C26H41NO24S",
        monoisotopic_mass=783.173922,
        average_mass=783.661,
        dict_composition={'O': 24, 'S': 1, 'C': 26, 'H': 41, 'N': 1},
    ),
    "1586": UnimodInfo(
        id="1586",
        name="dHex(2)Hex(2)HexA(1)",
        formula="C30H48O24",
        monoisotopic_mass=792.253553,
        average_mass=792.6877,
        dict_composition={'C': 30, 'H': 48, 'O': 24},
    ),
    "1587": UnimodInfo(
        id="1587",
        name="dHex(1)Hex(1)HexNAc(2)Sulf(1)",
        formula="C28H46N2O22S",
        monoisotopic_mass=794.226292,
        average_mass=794.73,
        dict_composition={'O': 22, 'S': 1, 'C': 28, 'H': 46, 'N': 2},
    ),
    "1588": UnimodInfo(
        id="1588",
        name="dHex(1)Hex(1)HexNAc(1)NeuAc(1)",
        formula="C31H50N2O22",
        monoisotopic_mass=802.285522,
        average_mass=802.7289,
        dict_composition={'C': 31, 'H': 50, 'O': 22, 'N': 2},
    ),
    "1589": UnimodInfo(
        id="1589",
        name="Hex(2)HexNAc(2)Sulf(1)",
        formula="C28H46N2O23S",
        monoisotopic_mass=810.221207,
        average_mass=810.7294,
        dict_composition={'O': 23, 'S': 1, 'C': 28, 'H': 46, 'N': 2},
    ),
    "1590": UnimodInfo(
        id="1590",
        name="Hex(5)",
        formula="C30H50O25",
        monoisotopic_mass=810.264117,
        average_mass=810.703,
        dict_composition={'C': 30, 'H': 50, 'O': 25},
    ),
    "1591": UnimodInfo(
        id="1591",
        name="HexNAc(4)",
        formula="C32H52N4O20",
        monoisotopic_mass=812.31749,
        average_mass=812.7701,
        dict_composition={'C': 32, 'H': 52, 'N': 4, 'O': 20},
    ),
    "1592": UnimodInfo(
        id="1592",
        name="HexNAc(1)NeuGc(2)",
        formula="C30H47N3O23",
        monoisotopic_mass=817.260035,
        average_mass=817.7005,
        dict_composition={'C': 30, 'H': 47, 'N': 3, 'O': 23},
    ),
    "1593": UnimodInfo(
        id="1593",
        name="dHex(1)Hex(1)HexNAc(1)NeuGc(1)",
        formula="C31H50N2O23",
        monoisotopic_mass=818.280436,
        average_mass=818.7283,
        dict_composition={'C': 31, 'H': 50, 'O': 23, 'N': 2},
    ),
    "1594": UnimodInfo(
        id="1594",
        name="dHex(2)Hex(2)HexNAc(1)",
        formula="C32H53NO23",
        monoisotopic_mass=819.300837,
        average_mass=819.7561,
        dict_composition={'C': 32, 'H': 53, 'O': 23, 'N': 1},
    ),
    "1595": UnimodInfo(
        id="1595",
        name="Hex(2)HexNAc(1)NeuGc(1)",
        formula="C31H50N2O24",
        monoisotopic_mass=834.275351,
        average_mass=834.7277,
        dict_composition={'C': 31, 'H': 50, 'O': 24, 'N': 2},
    ),
    "1596": UnimodInfo(
        id="1596",
        name="dHex(1)Hex(3)HexNAc(1)",
        formula="C32H53NO24",
        monoisotopic_mass=835.295752,
        average_mass=835.7555,
        dict_composition={'C': 32, 'H': 53, 'O': 24, 'N': 1},
    ),
    "1597": UnimodInfo(
        id="1597",
        name="dHex(1)Hex(2)HexA(1)HexNAc(1)",
        formula="C32H51NO25",
        monoisotopic_mass=849.275017,
        average_mass=849.739,
        dict_composition={'C': 32, 'H': 51, 'O': 25, 'N': 1},
    ),
    "1598": UnimodInfo(
        id="1598",
        name="Hex(1)HexNAc(3)Sulf(1)",
        formula="C30H49N3O23S",
        monoisotopic_mass=851.247756,
        average_mass=851.7814,
        dict_composition={'O': 23, 'S': 1, 'C': 30, 'H': 49, 'N': 3},
    ),
    "1599": UnimodInfo(
        id="1599",
        name="Hex(4)HexNAc(1)",
        formula="C32H53NO25",
        monoisotopic_mass=851.290667,
        average_mass=851.7549,
        dict_composition={'C': 32, 'H': 53, 'O': 25, 'N': 1},
    ),
    "1600": UnimodInfo(
        id="1600",
        name="Hex(1)HexNAc(2)NeuAc(1)",
        formula="C33H53N3O23",
        monoisotopic_mass=859.306985,
        average_mass=859.7802,
        dict_composition={'C': 33, 'H': 53, 'O': 23, 'N': 3},
    ),
    "1602": UnimodInfo(
        id="1602",
        name="Hex(1)HexNAc(2)NeuGc(1)",
        formula="C33H53N3O24",
        monoisotopic_mass=875.3019,
        average_mass=875.7796,
        dict_composition={'C': 33, 'H': 53, 'O': 24, 'N': 3},
    ),
    "1604": UnimodInfo(
        id="1604",
        name="Hex(5)Phos(1)",
        formula="C30H51O28P",
        monoisotopic_mass=890.230448,
        average_mass=890.6829,
        dict_composition={'H': 51, 'O': 28, 'P': 1, 'C': 30},
    ),
    "1606": UnimodInfo(
        id="1606",
        name="dHex(2)Hex(1)HexNAc(1)Kdn(1)",
        formula="C35H57NO26",
        monoisotopic_mass=907.316881,
        average_mass=907.8182,
        dict_composition={'C': 35, 'H': 57, 'O': 26, 'N': 1},
    ),
    "1607": UnimodInfo(
        id="1607",
        name="dHex(1)Hex(3)HexNAc(1)Sulf(1)",
        formula="C32H53NO27S",
        monoisotopic_mass=915.252567,
        average_mass=915.8187,
        dict_composition={'O': 27, 'S': 1, 'C': 32, 'H': 53, 'N': 1},
    ),
    "1608": UnimodInfo(
        id="1608",
        name="dHex(1)Hex(1)HexNAc(3)",
        formula="C36H59N3O24",
        monoisotopic_mass=917.34885,
        average_mass=917.8594,
        dict_composition={'C': 36, 'H': 59, 'O': 24, 'N': 3},
    ),
    "1609": UnimodInfo(
        id="1609",
        name="dHex(1)Hex(2)HexA(1)HexNAc(1)Sulf(1)",
        formula="C32H51NO28S",
        monoisotopic_mass=929.231831,
        average_mass=929.8022,
        dict_composition={'O': 28, 'S': 1, 'C': 32, 'H': 51, 'N': 1},
    ),
    "1610": UnimodInfo(
        id="1610",
        name="Hex(2)HexNAc(3)",
        formula="C36H59N3O25",
        monoisotopic_mass=933.343765,
        average_mass=933.8588,
        dict_composition={'C': 36, 'H': 59, 'O': 25, 'N': 3},
    ),
    "1611": UnimodInfo(
        id="1611",
        name="Hex(1)HexNAc(2)NeuAc(1)Sulf(1)",
        formula="C33H53N3O26S",
        monoisotopic_mass=939.2638,
        average_mass=939.8434,
        dict_composition={'O': 26, 'S': 1, 'C': 33, 'H': 53, 'N': 3},
    ),
    "1612": UnimodInfo(
        id="1612",
        name="dHex(2)Hex(4)",
        formula="C36H60O28",
        monoisotopic_mass=940.327112,
        average_mass=940.8448,
        dict_composition={'C': 36, 'H': 60, 'O': 28},
    ),
    "1614": UnimodInfo(
        id="1614",
        name="dHex(2)HexNAc(2)Kdn(1)",
        formula="C37H60N2O26",
        monoisotopic_mass=948.34343,
        average_mass=948.8701,
        dict_composition={'C': 37, 'H': 60, 'O': 26, 'N': 2},
    ),
    "1615": UnimodInfo(
        id="1615",
        name="dHex(1)Hex(2)HexNAc(2)Sulf(1)",
        formula="C34H56N2O27S",
        monoisotopic_mass=956.279116,
        average_mass=956.8706,
        dict_composition={'O': 27, 'S': 1, 'C': 34, 'H': 56, 'N': 2},
    ),
    "1616": UnimodInfo(
        id="1616",
        name="dHex(1)HexNAc(4)",
        formula="C38H62N4O24",
        monoisotopic_mass=958.375399,
        average_mass=958.9113,
        dict_composition={'C': 38, 'H': 62, 'O': 24, 'N': 4},
    ),
    "1617": UnimodInfo(
        id="1617",
        name="Hex(1)HexNAc(1)NeuAc(1)NeuGc(1)",
        formula="C36H57N3O27",
        monoisotopic_mass=963.317944,
        average_mass=963.8417,
        dict_composition={'C': 36, 'H': 57, 'O': 27, 'N': 3},
    ),
    "1618": UnimodInfo(
        id="1618",
        name="dHex(1)Hex(1)HexNAc(2)Kdn(1)",
        formula="C37H60N2O27",
        monoisotopic_mass=964.338345,
        average_mass=964.8695,
        dict_composition={'C': 37, 'H': 60, 'O': 27, 'N': 2},
    ),
    "1619": UnimodInfo(
        id="1619",
        name="Hex(1)HexNAc(1)NeuGc(2)",
        formula="C36H57N3O28",
        monoisotopic_mass=979.312859,
        average_mass=979.8411,
        dict_composition={'C': 36, 'H': 57, 'O': 28, 'N': 3},
    ),
    "1620": UnimodInfo(
        id="1620",
        name="Hex(1)HexNAc(1)NeuAc(2)Ac(1)",
        formula="C38H59N3O27",
        monoisotopic_mass=989.333594,
        average_mass=989.879,
        dict_composition={'C': 38, 'H': 59, 'O': 27, 'N': 3},
    ),
    "1621": UnimodInfo(
        id="1621",
        name="dHex(2)Hex(2)HexA(1)HexNAc(1)",
        formula="C38H61NO29",
        monoisotopic_mass=995.332925,
        average_mass=995.8802,
        dict_composition={'C': 38, 'H': 61, 'O': 29, 'N': 1},
    ),
    "1622": UnimodInfo(
        id="1622",
        name="dHex(1)Hex(1)HexNAc(3)Sulf(1)",
        formula="C36H59N3O27S",
        monoisotopic_mass=997.305665,
        average_mass=997.9226,
        dict_composition={'O': 27, 'S': 1, 'C': 36, 'H': 59, 'N': 3},
    ),
    "1623": UnimodInfo(
        id="1623",
        name="Hex(2)HexA(1)NeuAc(1)Pent(1)Sulf(1)",
        formula="C34H53NO31S",
        monoisotopic_mass=1003.232225,
        average_mass=1003.8377,
        dict_composition={'O': 31, 'S': 1, 'C': 34, 'H': 53, 'N': 1},
    ),
    "1624": UnimodInfo(
        id="1624",
        name="dHex(1)Hex(1)HexNAc(2)NeuAc(1)",
        formula="C39H63N3O27",
        monoisotopic_mass=1005.364894,
        average_mass=1005.9214,
        dict_composition={'C': 39, 'H': 63, 'O': 27, 'N': 3},
    ),
    "1625": UnimodInfo(
        id="1625",
        name="dHex(1)Hex(3)HexA(1)HexNAc(1)",
        formula="C38H61NO30",
        monoisotopic_mass=1011.32784,
        average_mass=1011.8796,
        dict_composition={'C': 38, 'H': 61, 'O': 30, 'N': 1},
    ),
    "1626": UnimodInfo(
        id="1626",
        name="Hex(2)HexNAc(3)Sulf(1)",
        formula="C36H59N3O28S",
        monoisotopic_mass=1013.300579,
        average_mass=1013.922,
        dict_composition={'O': 28, 'S': 1, 'C': 36, 'H': 59, 'N': 3},
    ),
    "1627": UnimodInfo(
        id="1627",
        name="Hex(5)HexNAc(1)",
        formula="C38H63NO30",
        monoisotopic_mass=1013.34349,
        average_mass=1013.8955,
        dict_composition={'C': 38, 'H': 63, 'O': 30, 'N': 1},
    ),
    "1628": UnimodInfo(
        id="1628",
        name="HexNAc(5)",
        formula="C40H65N5O25",
        monoisotopic_mass=1015.396863,
        average_mass=1015.9626,
        dict_composition={'C': 40, 'H': 65, 'N': 5, 'O': 25},
    ),
    "1630": UnimodInfo(
        id="1630",
        name="Hex(1)HexNAc(1)NeuAc(2)Ac(2)",
        formula="C40H61N3O28",
        monoisotopic_mass=1031.344159,
        average_mass=1031.9156,
        dict_composition={'C': 40, 'H': 61, 'O': 28, 'N': 3},
    ),
    "1631": UnimodInfo(
        id="1631",
        name="Hex(2)HexNAc(2)NeuGc(1)",
        formula="C39H63N3O29",
        monoisotopic_mass=1037.354723,
        average_mass=1037.9202,
        dict_composition={'C': 39, 'H': 63, 'O': 29, 'N': 3},
    ),
    "1632": UnimodInfo(
        id="1632",
        name="Hex(5)Phos(3)",
        formula="C30H53O34P3",
        monoisotopic_mass=1050.16311,
        average_mass=1050.6427,
        dict_composition={'H': 53, 'O': 34, 'P': 3, 'C': 30},
    ),
    "1633": UnimodInfo(
        id="1633",
        name="Hex(6)Phos(1)",
        formula="C36H61O33P",
        monoisotopic_mass=1052.283272,
        average_mass=1052.8235,
        dict_composition={'H': 61, 'O': 33, 'P': 1, 'C': 36},
    ),
    "1634": UnimodInfo(
        id="1634",
        name="dHex(1)Hex(2)HexA(1)HexNAc(2)",
        formula="C40H64N2O30",
        monoisotopic_mass=1052.354389,
        average_mass=1052.9316,
        dict_composition={'C': 40, 'H': 64, 'O': 30, 'N': 2},
    ),
    "1635": UnimodInfo(
        id="1635",
        name="dHex(2)Hex(3)HexNAc(1)Sulf(1)",
        formula="C38H63NO31S",
        monoisotopic_mass=1061.310475,
        average_mass=1061.9599,
        dict_composition={'O': 31, 'S': 1, 'C': 38, 'H': 63, 'N': 1},
    ),
    "1636": UnimodInfo(
        id="1636",
        name="Hex(1)HexNAc(3)NeuAc(1)",
        formula="C41H66N4O28",
        monoisotopic_mass=1062.386358,
        average_mass=1062.9727,
        dict_composition={'C': 41, 'H': 66, 'O': 28, 'N': 4},
    ),
    "1637": UnimodInfo(
        id="1637",
        name="dHex(2)Hex(1)HexNAc(3)",
        formula="C42H69N3O28",
        monoisotopic_mass=1063.406759,
        average_mass=1064.0006,
        dict_composition={'C': 42, 'H': 69, 'O': 28, 'N': 3},
    ),
    "1638": UnimodInfo(
        id="1638",
        name="Hex(1)HexNAc(3)NeuGc(1)",
        formula="C41H66N4O29",
        monoisotopic_mass=1078.381273,
        average_mass=1078.9721,
        dict_composition={'C': 41, 'H': 66, 'O': 29, 'N': 4},
    ),
    "1639": UnimodInfo(
        id="1639",
        name="dHex(1)Hex(1)HexNAc(2)NeuAc(1)Sulf(1)",
        formula="C39H63N3O30S",
        monoisotopic_mass=1085.321709,
        average_mass=1085.9846,
        dict_composition={'O': 30, 'S': 1, 'C': 39, 'H': 63, 'N': 3},
    ),
    "1640": UnimodInfo(
        id="1640",
        name="dHex(1)Hex(3)HexA(1)HexNAc(1)Sulf(1)",
        formula="C38H61NO33S",
        monoisotopic_mass=1091.284655,
        average_mass=1091.9428,
        dict_composition={'O': 33, 'S': 1, 'C': 38, 'H': 61, 'N': 1},
    ),
    "1641": UnimodInfo(
        id="1641",
        name="dHex(1)Hex(1)HexA(1)HexNAc(3)",
        formula="C42H67N3O30",
        monoisotopic_mass=1093.380938,
        average_mass=1093.9835,
        dict_composition={'C': 42, 'H': 67, 'O': 30, 'N': 3},
    ),
    "1642": UnimodInfo(
        id="1642",
        name="Hex(2)HexNAc(2)NeuAc(1)Sulf(1)",
        formula="C39H63N3O31S",
        monoisotopic_mass=1101.316623,
        average_mass=1101.984,
        dict_composition={'O': 31, 'S': 1, 'C': 39, 'H': 63, 'N': 3},
    ),
    "1643": UnimodInfo(
        id="1643",
        name="dHex(2)Hex(2)HexNAc(2)Sulf(1)",
        formula="C40H66N2O31S",
        monoisotopic_mass=1102.337025,
        average_mass=1103.0118,
        dict_composition={'O': 31, 'S': 1, 'C': 40, 'H': 66, 'N': 2},
    ),
    "1644": UnimodInfo(
        id="1644",
        name="dHex(2)Hex(1)HexNAc(2)Kdn(1)",
        formula="C43H70N2O31",
        monoisotopic_mass=1110.396254,
        average_mass=1111.0107,
        dict_composition={'C': 43, 'H': 70, 'O': 31, 'N': 2},
    ),
    "1645": UnimodInfo(
        id="1645",
        name="dHex(1)Hex(1)HexNAc(4)",
        formula="C44H72N4O29",
        monoisotopic_mass=1120.428223,
        average_mass=1121.0519,
        dict_composition={'C': 44, 'H': 72, 'O': 29, 'N': 4},
    ),
    "1646": UnimodInfo(
        id="1646",
        name="Hex(2)HexNAc(4)",
        formula="C44H72N4O30",
        monoisotopic_mass=1136.423137,
        average_mass=1137.0513,
        dict_composition={'C': 44, 'H': 72, 'O': 30, 'N': 4},
    ),
    "1647": UnimodInfo(
        id="1647",
        name="Hex(2)HexNAc(1)NeuGc(2)",
        formula="C42H67N3O33",
        monoisotopic_mass=1141.365682,
        average_mass=1141.9817,
        dict_composition={'C': 42, 'H': 67, 'O': 33, 'N': 3},
    ),
    "1648": UnimodInfo(
        id="1648",
        name="dHex(2)Hex(4)HexNAc(1)",
        formula="C44H73NO33",
        monoisotopic_mass=1143.406484,
        average_mass=1144.0373,
        dict_composition={'C': 44, 'H': 73, 'O': 33, 'N': 1},
    ),
    "1649": UnimodInfo(
        id="1649",
        name="Hex(1)HexNAc(2)NeuAc(2)",
        formula="C44H70N4O31",
        monoisotopic_mass=1150.402402,
        average_mass=1151.0348,
        dict_composition={'C': 44, 'H': 70, 'O': 31, 'N': 4},
    ),
    "1650": UnimodInfo(
        id="1650",
        name="dHex(2)Hex(1)HexNAc(2)NeuAc(1)",
        formula="C45H73N3O31",
        monoisotopic_mass=1151.422803,
        average_mass=1152.0626,
        dict_composition={'C': 45, 'H': 73, 'O': 31, 'N': 3},
    ),
    "1651": UnimodInfo(
        id="1651",
        name="dHex(1)Hex(2)HexNAc(3)Sulf(1)",
        formula="C42H69N3O32S",
        monoisotopic_mass=1159.358488,
        average_mass=1160.0632,
        dict_composition={'O': 32, 'S': 1, 'C': 42, 'H': 69, 'N': 3},
    ),
    "1652": UnimodInfo(
        id="1652",
        name="dHex(1)HexNAc(5)",
        formula="C46H75N5O29",
        monoisotopic_mass=1161.454772,
        average_mass=1162.1038,
        dict_composition={'C': 46, 'H': 75, 'O': 29, 'N': 5},
    ),
    "1653": UnimodInfo(
        id="1653",
        name="dHex(2)Hex(1)HexNAc(2)NeuGc(1)",
        formula="C45H73N3O32",
        monoisotopic_mass=1167.417718,
        average_mass=1168.062,
        dict_composition={'C': 45, 'H': 73, 'O': 32, 'N': 3},
    ),
    "1654": UnimodInfo(
        id="1654",
        name="dHex(3)Hex(2)HexNAc(2)",
        formula="C46H76N2O32",
        monoisotopic_mass=1168.438119,
        average_mass=1169.0898,
        dict_composition={'C': 46, 'H': 76, 'O': 32, 'N': 2},
    ),
    "1655": UnimodInfo(
        id="1655",
        name="Hex(3)HexNAc(3)Sulf(1)",
        formula="C42H69N3O33S",
        monoisotopic_mass=1175.353403,
        average_mass=1176.0626,
        dict_composition={'O': 33, 'S': 1, 'C': 42, 'H': 69, 'N': 3},
    ),
    "1656": UnimodInfo(
        id="1656",
        name="dHex(2)Hex(2)HexNAc(2)Sulf(2)",
        formula="C40H66N2O34S2",
        monoisotopic_mass=1182.293839,
        average_mass=1183.075,
        dict_composition={'O': 34, 'S': 2, 'C': 40, 'H': 66, 'N': 2},
    ),
    "1657": UnimodInfo(
        id="1657",
        name="dHex(1)Hex(2)HexNAc(2)NeuGc(1)",
        formula="C45H73N3O33",
        monoisotopic_mass=1183.412632,
        average_mass=1184.0614,
        dict_composition={'C': 45, 'H': 73, 'O': 33, 'N': 3},
    ),
    "1658": UnimodInfo(
        id="1658",
        name="dHex(1)Hex(1)HexNAc(3)NeuAc(1)",
        formula="C47H76N4O32",
        monoisotopic_mass=1208.444267,
        average_mass=1209.1139,
        dict_composition={'C': 47, 'H': 76, 'O': 32, 'N': 4},
    ),
    "1659": UnimodInfo(
        id="1659",
        name="Hex(6)Phos(3)",
        formula="C36H63O39P3",
        monoisotopic_mass=1212.215934,
        average_mass=1212.7833,
        dict_composition={'H': 63, 'O': 39, 'P': 3, 'C': 36},
    ),
    "1660": UnimodInfo(
        id="1660",
        name="dHex(1)Hex(3)HexA(1)HexNAc(2)",
        formula="C46H74N2O35",
        monoisotopic_mass=1214.407213,
        average_mass=1215.0722,
        dict_composition={'C': 46, 'H': 74, 'O': 35, 'N': 2},
    ),
    "1661": UnimodInfo(
        id="1661",
        name="dHex(1)Hex(1)HexNAc(3)NeuGc(1)",
        formula="C47H76N4O33",
        monoisotopic_mass=1224.439181,
        average_mass=1225.1133,
        dict_composition={'C': 47, 'H': 76, 'O': 33, 'N': 4},
    ),
    "1662": UnimodInfo(
        id="1662",
        name="Hex(1)HexNAc(2)NeuAc(2)Sulf(1)",
        formula="C44H70N4O34S",
        monoisotopic_mass=1230.359217,
        average_mass=1231.098,
        dict_composition={'O': 34, 'S': 1, 'C': 44, 'H': 70, 'N': 4},
    ),
    "1663": UnimodInfo(
        id="1663",
        name="dHex(2)Hex(3)HexA(1)HexNAc(1)Sulf(1)",
        formula="C44H71NO37S",
        monoisotopic_mass=1237.342563,
        average_mass=1238.084,
        dict_composition={'O': 37, 'S': 1, 'C': 44, 'H': 71, 'N': 1},
    ),
    "1664": UnimodInfo(
        id="1664",
        name="Hex(1)HexNAc(1)NeuAc(3)",
        formula="C47H74N4O34",
        monoisotopic_mass=1238.418446,
        average_mass=1239.0969,
        dict_composition={'C': 47, 'H': 74, 'O': 34, 'N': 4},
    ),
    "1665": UnimodInfo(
        id="1665",
        name="Hex(2)HexNAc(3)NeuGc(1)",
        formula="C47H76N4O34",
        monoisotopic_mass=1240.434096,
        average_mass=1241.1127,
        dict_composition={'C': 47, 'H': 76, 'O': 34, 'N': 4},
    ),
    "1666": UnimodInfo(
        id="1666",
        name="dHex(1)Hex(2)HexNAc(2)NeuAc(1)Sulf(1)",
        formula="C45H73N3O35S",
        monoisotopic_mass=1247.374532,
        average_mass=1248.1252,
        dict_composition={'O': 35, 'S': 1, 'C': 45, 'H': 73, 'N': 3},
    ),
    "1667": UnimodInfo(
        id="1667",
        name="dHex(3)Hex(1)HexNAc(2)Kdn(1)",
        formula="C49H80N2O35",
        monoisotopic_mass=1256.454163,
        average_mass=1257.1519,
        dict_composition={'C': 49, 'H': 80, 'O': 35, 'N': 2},
    ),
    "1668": UnimodInfo(
        id="1668",
        name="dHex(2)Hex(3)HexNAc(2)Sulf(1)",
        formula="C46H76N2O36S",
        monoisotopic_mass=1264.389848,
        average_mass=1265.1524,
        dict_composition={'O': 36, 'S': 1, 'C': 46, 'H': 76, 'N': 2},
    ),
    "1669": UnimodInfo(
        id="1669",
        name="dHex(2)Hex(2)HexNAc(2)Kdn(1)",
        formula="C49H80N2O36",
        monoisotopic_mass=1272.449077,
        average_mass=1273.1513,
        dict_composition={'C': 49, 'H': 80, 'O': 36, 'N': 2},
    ),
    "1670": UnimodInfo(
        id="1670",
        name="dHex(2)Hex(2)HexA(1)HexNAc(2)Sulf(1)",
        formula="C46H74N2O37S",
        monoisotopic_mass=1278.369113,
        average_mass=1279.136,
        dict_composition={'O': 37, 'S': 1, 'C': 46, 'H': 74, 'N': 2},
    ),
    "1671": UnimodInfo(
        id="1671",
        name="dHex(1)Hex(2)HexNAc(4)",
        formula="C50H82N4O34",
        monoisotopic_mass=1282.481046,
        average_mass=1283.1925,
        dict_composition={'C': 50, 'H': 82, 'O': 34, 'N': 4},
    ),
    "1672": UnimodInfo(
        id="1672",
        name="Hex(1)HexNAc(1)NeuGc(3)",
        formula="C47H74N4O37",
        monoisotopic_mass=1286.40319,
        average_mass=1287.0951,
        dict_composition={'C': 47, 'H': 74, 'O': 37, 'N': 4},
    ),
    "1673": UnimodInfo(
        id="1673",
        name="dHex(1)Hex(1)HexNAc(3)NeuAc(1)Sulf(1)",
        formula="C47H76N4O35S",
        monoisotopic_mass=1288.401081,
        average_mass=1289.1771,
        dict_composition={'O': 35, 'S': 1, 'C': 47, 'H': 76, 'N': 4},
    ),
    "1674": UnimodInfo(
        id="1674",
        name="dHex(1)Hex(3)HexA(1)HexNAc(2)Sulf(1)",
        formula="C46H74N2O38S",
        monoisotopic_mass=1294.364027,
        average_mass=1295.1354,
        dict_composition={'O': 38, 'S': 1, 'C': 46, 'H': 74, 'N': 2},
    ),
    "1675": UnimodInfo(
        id="1675",
        name="dHex(1)Hex(1)HexNAc(2)NeuAc(2)",
        formula="C50H80N4O35",
        monoisotopic_mass=1296.460311,
        average_mass=1297.176,
        dict_composition={'C': 50, 'H': 80, 'O': 35, 'N': 4},
    ),
    "1676": UnimodInfo(
        id="1676",
        name="dHex(3)HexNAc(3)Kdn(1)",
        formula="C51H83N3O35",
        monoisotopic_mass=1297.480712,
        average_mass=1298.2038,
        dict_composition={'C': 51, 'H': 83, 'O': 35, 'N': 3},
    ),
    "1678": UnimodInfo(
        id="1678",
        name="Hex(2)HexNAc(3)NeuAc(1)Sulf(1)",
        formula="C47H76N4O36S",
        monoisotopic_mass=1304.395996,
        average_mass=1305.1765,
        dict_composition={'O': 36, 'S': 1, 'C': 47, 'H': 76, 'N': 4},
    ),
    "1679": UnimodInfo(
        id="1679",
        name="dHex(2)Hex(2)HexNAc(3)Sulf(1)",
        formula="C48H79N3O36S",
        monoisotopic_mass=1305.416397,
        average_mass=1306.2044,
        dict_composition={'O': 36, 'S': 1, 'C': 48, 'H': 79, 'N': 3},
    ),
    "1680": UnimodInfo(
        id="1680",
        name="dHex(2)HexNAc(5)",
        formula="C52H85N5O33",
        monoisotopic_mass=1307.512681,
        average_mass=1308.245,
        dict_composition={'C': 52, 'H': 85, 'O': 33, 'N': 5},
    ),
    "1681": UnimodInfo(
        id="1681",
        name="Hex(2)HexNAc(2)NeuAc(2)",
        formula="C50H80N4O36",
        monoisotopic_mass=1312.455225,
        average_mass=1313.1754,
        dict_composition={'C': 50, 'H': 80, 'O': 36, 'N': 4},
    ),
    "1682": UnimodInfo(
        id="1682",
        name="dHex(2)Hex(2)HexNAc(2)NeuAc(1)",
        formula="C51H83N3O36",
        monoisotopic_mass=1313.475627,
        average_mass=1314.2032,
        dict_composition={'C': 51, 'H': 83, 'O': 36, 'N': 3},
    ),
    "1683": UnimodInfo(
        id="1683",
        name="dHex(1)Hex(3)HexNAc(3)Sulf(1)",
        formula="C48H79N3O37S",
        monoisotopic_mass=1321.411312,
        average_mass=1322.2038,
        dict_composition={'O': 37, 'S': 1, 'C': 48, 'H': 79, 'N': 3},
    ),
    "1684": UnimodInfo(
        id="1684",
        name="dHex(2)Hex(2)HexNAc(2)NeuGc(1)",
        formula="C51H83N3O37",
        monoisotopic_mass=1329.470541,
        average_mass=1330.2026,
        dict_composition={'C': 51, 'H': 83, 'O': 37, 'N': 3},
    ),
    "1685": UnimodInfo(
        id="1685",
        name="Hex(2)HexNAc(5)",
        formula="C52H85N5O35",
        monoisotopic_mass=1339.50251,
        average_mass=1340.2438,
        dict_composition={'C': 52, 'H': 85, 'O': 35, 'N': 5},
    ),
    "1686": UnimodInfo(
        id="1686",
        name="dHex(1)Hex(3)HexNAc(2)NeuGc(1)",
        formula="C51H83N3O38",
        monoisotopic_mass=1345.465456,
        average_mass=1346.202,
        dict_composition={'C': 51, 'H': 83, 'O': 38, 'N': 3},
    ),
    "1687": UnimodInfo(
        id="1687",
        name="Hex(1)HexNAc(3)NeuAc(2)",
        formula="C52H83N5O36",
        monoisotopic_mass=1353.481775,
        average_mass=1354.2273,
        dict_composition={'C': 52, 'H': 83, 'O': 36, 'N': 5},
    ),
    "1688": UnimodInfo(
        id="1688",
        name="dHex(1)Hex(2)HexNAc(3)NeuAc(1)",
        formula="C53H86N4O37",
        monoisotopic_mass=1370.49709,
        average_mass=1371.2545,
        dict_composition={'C': 53, 'H': 86, 'O': 37, 'N': 4},
    ),
    "1689": UnimodInfo(
        id="1689",
        name="dHex(3)Hex(2)HexNAc(3)",
        formula="C54H89N3O37",
        monoisotopic_mass=1371.517491,
        average_mass=1372.2824,
        dict_composition={'C': 54, 'H': 89, 'O': 37, 'N': 3},
    ),
    "1690": UnimodInfo(
        id="1690",
        name="Hex(7)Phos(3)",
        formula="C42H73O44P3",
        monoisotopic_mass=1374.268757,
        average_mass=1374.9239,
        dict_composition={'H': 73, 'O': 44, 'P': 3, 'C': 42},
    ),
    "1691": UnimodInfo(
        id="1691",
        name="dHex(1)Hex(4)HexA(1)HexNAc(2)",
        formula="C52H84N2O40",
        monoisotopic_mass=1376.460036,
        average_mass=1377.2128,
        dict_composition={'C': 52, 'H': 84, 'O': 40, 'N': 2},
    ),
    "1692": UnimodInfo(
        id="1692",
        name="Hex(3)HexNAc(3)NeuAc(1)",
        formula="C53H86N4O38",
        monoisotopic_mass=1386.492005,
        average_mass=1387.2539,
        dict_composition={'C': 53, 'H': 86, 'O': 38, 'N': 4},
    ),
    "1693": UnimodInfo(
        id="1693",
        name="dHex(1)Hex(3)HexA(2)HexNAc(2)",
        formula="C52H82N2O41",
        monoisotopic_mass=1390.439301,
        average_mass=1391.1963,
        dict_composition={'C': 52, 'H': 82, 'O': 41, 'N': 2},
    ),
    "1694": UnimodInfo(
        id="1694",
        name="Hex(2)HexNAc(2)NeuAc(2)Sulf(1)",
        formula="C50H80N4O39S",
        monoisotopic_mass=1392.41204,
        average_mass=1393.2386,
        dict_composition={'O': 39, 'S': 1, 'C': 50, 'H': 80, 'N': 4},
    ),
    "1695": UnimodInfo(
        id="1695",
        name="dHex(2)Hex(2)HexNAc(2)NeuAc(1)Sulf(1)",
        formula="C51H83N3O39S",
        monoisotopic_mass=1393.432441,
        average_mass=1394.2664,
        dict_composition={'O': 39, 'S': 1, 'C': 51, 'H': 83, 'N': 3},
    ),
    "1696": UnimodInfo(
        id="1696",
        name="Hex(3)HexNAc(3)NeuGc(1)",
        formula="C53H86N4O39",
        monoisotopic_mass=1402.48692,
        average_mass=1403.2533,
        dict_composition={'C': 53, 'H': 86, 'O': 39, 'N': 4},
    ),
    "1697": UnimodInfo(
        id="1697",
        name="dHex(4)Hex(1)HexNAc(2)Kdn(1)",
        formula="C55H90N2O39",
        monoisotopic_mass=1402.512072,
        average_mass=1403.2931,
        dict_composition={'C': 55, 'H': 90, 'O': 39, 'N': 2},
    ),
    "1698": UnimodInfo(
        id="1698",
        name="dHex(3)Hex(2)HexNAc(2)Kdn(1)",
        formula="C55H90N2O40",
        monoisotopic_mass=1418.506986,
        average_mass=1419.2925,
        dict_composition={'C': 55, 'H': 90, 'O': 40, 'N': 2},
    ),
    "1699": UnimodInfo(
        id="1699",
        name="dHex(3)Hex(2)HexA(1)HexNAc(2)Sulf(1)",
        formula="C52H84N2O41S",
        monoisotopic_mass=1424.427021,
        average_mass=1425.2772,
        dict_composition={'O': 41, 'S': 1, 'C': 52, 'H': 84, 'N': 2},
    ),
    "1700": UnimodInfo(
        id="1700",
        name="Hex(2)HexNAc(4)NeuAc(1)",
        formula="C55H89N5O38",
        monoisotopic_mass=1427.518554,
        average_mass=1428.3059,
        dict_composition={'C': 55, 'H': 89, 'O': 38, 'N': 5},
    ),
    "1701": UnimodInfo(
        id="1701",
        name="dHex(2)Hex(2)HexNAc(4)",
        formula="C56H92N4O38",
        monoisotopic_mass=1428.538955,
        average_mass=1429.3337,
        dict_composition={'C': 56, 'H': 92, 'O': 38, 'N': 4},
    ),
    "1702": UnimodInfo(
        id="1702",
        name="dHex(2)Hex(3)HexA(1)HexNAc(2)Sulf(1)",
        formula="C52H84N2O42S",
        monoisotopic_mass=1440.421936,
        average_mass=1441.2766,
        dict_composition={'O': 42, 'S': 1, 'C': 52, 'H': 84, 'N': 2},
    ),
    "1703": UnimodInfo(
        id="1703",
        name="dHex(4)HexNAc(3)Kdn(1)",
        formula="C57H93N3O39",
        monoisotopic_mass=1443.538621,
        average_mass=1444.345,
        dict_composition={'C': 57, 'H': 93, 'O': 39, 'N': 3},
    ),
    "1705": UnimodInfo(
        id="1705",
        name="Hex(2)HexNAc(1)NeuGc(3)",
        formula="C53H84N4O42",
        monoisotopic_mass=1448.456013,
        average_mass=1449.2357,
        dict_composition={'C': 53, 'H': 84, 'O': 42, 'N': 4},
    ),
    "1706": UnimodInfo(
        id="1706",
        name="dHex(4)Hex(1)HexNAc(1)Kdn(2)",
        formula="C56H91NO42",
        monoisotopic_mass=1449.501567,
        average_mass=1450.3032,
        dict_composition={'C': 56, 'H': 91, 'O': 42, 'N': 1},
    ),
    "1707": UnimodInfo(
        id="1707",
        name="dHex(1)Hex(2)HexNAc(3)NeuAc(1)Sulf(1)",
        formula="C53H86N4O40S",
        monoisotopic_mass=1450.453905,
        average_mass=1451.3177,
        dict_composition={'O': 40, 'S': 1, 'C': 53, 'H': 86, 'N': 4},
    ),
    "1708": UnimodInfo(
        id="1708",
        name="dHex(1)Hex(2)HexNAc(2)NeuAc(2)",
        formula="C56H90N4O40",
        monoisotopic_mass=1458.513134,
        average_mass=1459.3166,
        dict_composition={'C': 56, 'H': 90, 'O': 40, 'N': 4},
    ),
    "1709": UnimodInfo(
        id="1709",
        name="dHex(3)Hex(1)HexNAc(3)Kdn(1)",
        formula="C57H93N3O40",
        monoisotopic_mass=1459.533535,
        average_mass=1460.3444,
        dict_composition={'C': 57, 'H': 93, 'O': 40, 'N': 3},
    ),
    "1711": UnimodInfo(
        id="1711",
        name="Hex(3)HexNAc(3)NeuAc(1)Sulf(1)",
        formula="C53H86N4O41S",
        monoisotopic_mass=1466.44882,
        average_mass=1467.3171,
        dict_composition={'O': 41, 'S': 1, 'C': 53, 'H': 86, 'N': 4},
    ),
    "1712": UnimodInfo(
        id="1712",
        name="Hex(3)HexNAc(2)NeuAc(2)",
        formula="C56H90N4O41",
        monoisotopic_mass=1474.508049,
        average_mass=1475.316,
        dict_composition={'C': 56, 'H': 90, 'O': 41, 'N': 4},
    ),
    "1713": UnimodInfo(
        id="1713",
        name="Hex(3)HexNAc(3)NeuGc(1)Sulf(1)",
        formula="C53H86N4O42S",
        monoisotopic_mass=1482.443734,
        average_mass=1483.3165,
        dict_composition={'O': 42, 'S': 1, 'C': 53, 'H': 86, 'N': 4},
    ),
    "1714": UnimodInfo(
        id="1714",
        name="dHex(1)Hex(2)HexNAc(2)NeuGc(2)",
        formula="C56H90N4O42",
        monoisotopic_mass=1490.502964,
        average_mass=1491.3154,
        dict_composition={'C': 56, 'H': 90, 'O': 42, 'N': 4},
    ),
    "1715": UnimodInfo(
        id="1715",
        name="dHex(2)Hex(3)HexNAc(2)NeuGc(1)",
        formula="C57H93N3O42",
        monoisotopic_mass=1491.523365,
        average_mass=1492.3432,
        dict_composition={'C': 57, 'H': 93, 'O': 42, 'N': 3},
    ),
    "1716": UnimodInfo(
        id="1716",
        name="dHex(1)Hex(3)HexA(1)HexNAc(3)Sulf(1)",
        formula="C54H87N3O43S",
        monoisotopic_mass=1497.4434,
        average_mass=1498.3279,
        dict_composition={'O': 43, 'S': 1, 'C': 54, 'H': 87, 'N': 3},
    ),
    "1717": UnimodInfo(
        id="1717",
        name="Hex(2)HexNAc(3)NeuAc(2)",
        formula="C58H93N5O41",
        monoisotopic_mass=1515.534598,
        average_mass=1516.3679,
        dict_composition={'C': 58, 'H': 93, 'O': 41, 'N': 5},
    ),
    "1718": UnimodInfo(
        id="1718",
        name="dHex(2)Hex(2)HexNAc(3)NeuAc(1)",
        formula="C59H96N4O41",
        monoisotopic_mass=1516.554999,
        average_mass=1517.3957,
        dict_composition={'C': 59, 'H': 96, 'O': 41, 'N': 4},
    ),
    "1719": UnimodInfo(
        id="1719",
        name="dHex(4)Hex(2)HexNAc(3)",
        formula="C60H99N3O41",
        monoisotopic_mass=1517.5754,
        average_mass=1518.4236,
        dict_composition={'C': 60, 'H': 99, 'O': 41, 'N': 3},
    ),
    "1720": UnimodInfo(
        id="1720",
        name="Hex(2)HexNAc(3)NeuAc(1)NeuGc(1)",
        formula="C58H93N5O42",
        monoisotopic_mass=1531.529513,
        average_mass=1532.3673,
        dict_composition={'C': 58, 'H': 93, 'O': 42, 'N': 5},
    ),
    "1721": UnimodInfo(
        id="1721",
        name="dHex(2)Hex(2)HexNAc(3)NeuGc(1)",
        formula="C59H96N4O42",
        monoisotopic_mass=1532.549914,
        average_mass=1533.3951,
        dict_composition={'C': 59, 'H': 96, 'O': 42, 'N': 4},
    ),
    "1722": UnimodInfo(
        id="1722",
        name="dHex(3)Hex(3)HexNAc(3)",
        formula="C60H99N3O42",
        monoisotopic_mass=1533.570315,
        average_mass=1534.423,
        dict_composition={'C': 60, 'H': 99, 'O': 42, 'N': 3},
    ),
    "1723": UnimodInfo(
        id="1723",
        name="Hex(8)Phos(3)",
        formula="C48H83O49P3",
        monoisotopic_mass=1536.321581,
        average_mass=1537.0645,
        dict_composition={'H': 83, 'O': 49, 'P': 3, 'C': 48},
    ),
    "1724": UnimodInfo(
        id="1724",
        name="dHex(1)Hex(2)HexNAc(2)NeuAc(2)Sulf(1)",
        formula="C56H90N4O43S",
        monoisotopic_mass=1538.469949,
        average_mass=1539.3798,
        dict_composition={'O': 43, 'S': 1, 'C': 56, 'H': 90, 'N': 4},
    ),
    "1725": UnimodInfo(
        id="1725",
        name="Hex(2)HexNAc(3)NeuGc(2)",
        formula="C58H93N5O43",
        monoisotopic_mass=1547.524427,
        average_mass=1548.3667,
        dict_composition={'C': 58, 'H': 93, 'O': 43, 'N': 5},
    ),
    "1726": UnimodInfo(
        id="1726",
        name="dHex(4)Hex(2)HexNAc(2)Kdn(1)",
        formula="C61H100N2O44",
        monoisotopic_mass=1564.564895,
        average_mass=1565.4337,
        dict_composition={'C': 61, 'H': 100, 'O': 44, 'N': 2},
    ),
    "1727": UnimodInfo(
        id="1727",
        name="dHex(1)Hex(2)HexNAc(4)NeuAc(1)",
        formula="C61H99N5O42",
        monoisotopic_mass=1573.576463,
        average_mass=1574.4471,
        dict_composition={'C': 61, 'H': 99, 'O': 42, 'N': 5},
    ),
    "1728": UnimodInfo(
        id="1728",
        name="dHex(3)Hex(2)HexNAc(4)",
        formula="C62H102N4O42",
        monoisotopic_mass=1574.596864,
        average_mass=1575.4749,
        dict_composition={'C': 62, 'H': 102, 'O': 42, 'N': 4},
    ),
    "1729": UnimodInfo(
        id="1729",
        name="Hex(1)HexNAc(1)NeuGc(4)",
        formula="C58H91N5O46",
        monoisotopic_mass=1593.493521,
        average_mass=1594.349,
        dict_composition={'C': 58, 'H': 91, 'O': 46, 'N': 5},
    ),
    "1730": UnimodInfo(
        id="1730",
        name="dHex(4)Hex(1)HexNAc(3)Kdn(1)",
        formula="C63H103N3O44",
        monoisotopic_mass=1605.591444,
        average_mass=1606.4856,
        dict_composition={'C': 63, 'H': 103, 'O': 44, 'N': 3},
    ),
    "1732": UnimodInfo(
        id="1732",
        name="Hex(4)HexNAc(4)Sulf(2)",
        formula="C56H92N4O46S2",
        monoisotopic_mass=1620.442414,
        average_mass=1621.4589,
        dict_composition={'O': 46, 'S': 2, 'C': 56, 'H': 92, 'N': 4},
    ),
    "1733": UnimodInfo(
        id="1733",
        name="dHex(3)Hex(2)HexNAc(3)Kdn(1)",
        formula="C63H103N3O45",
        monoisotopic_mass=1621.586359,
        average_mass=1622.485,
        dict_composition={'C': 63, 'H': 103, 'O': 45, 'N': 3},
    ),
    "1735": UnimodInfo(
        id="1735",
        name="dHex(2)Hex(2)HexNAc(5)",
        formula="C64H105N5O43",
        monoisotopic_mass=1631.618328,
        average_mass=1632.5262,
        dict_composition={'C': 64, 'H': 105, 'O': 43, 'N': 5},
    ),
    "1736": UnimodInfo(
        id="1736",
        name="dHex(2)Hex(3)HexA(1)HexNAc(3)Sulf(1)",
        formula="C60H97N3O47S",
        monoisotopic_mass=1643.501309,
        average_mass=1644.4691,
        dict_composition={'O': 47, 'S': 1, 'C': 60, 'H': 97, 'N': 3},
    ),
    "1737": UnimodInfo(
        id="1737",
        name="dHex(1)Hex(4)HexA(1)HexNAc(3)Sulf(1)",
        formula="C60H97N3O48S",
        monoisotopic_mass=1659.496223,
        average_mass=1660.4685,
        dict_composition={'O': 48, 'S': 1, 'C': 60, 'H': 97, 'N': 3},
    ),
    "1738": UnimodInfo(
        id="1738",
        name="Hex(3)HexNAc(3)NeuAc(2)",
        formula="C64H103N5O46",
        monoisotopic_mass=1677.587422,
        average_mass=1678.5085,
        dict_composition={'C': 64, 'H': 103, 'O': 46, 'N': 5},
    ),
    "1739": UnimodInfo(
        id="1739",
        name="dHex(2)Hex(3)HexNAc(3)NeuAc(1)",
        formula="C65H106N4O46",
        monoisotopic_mass=1678.607823,
        average_mass=1679.5363,
        dict_composition={'C': 65, 'H': 106, 'O': 46, 'N': 4},
    ),
    "1740": UnimodInfo(
        id="1740",
        name="dHex(4)Hex(3)HexNAc(3)",
        formula="C66H109N3O46",
        monoisotopic_mass=1679.628224,
        average_mass=1680.5642,
        dict_composition={'C': 66, 'H': 109, 'O': 46, 'N': 3},
    ),
    "1742": UnimodInfo(
        id="1742",
        name="Hex(9)Phos(3)",
        formula="C54H93O54P3",
        monoisotopic_mass=1698.374404,
        average_mass=1699.2051,
        dict_composition={'H': 93, 'O': 54, 'P': 3, 'C': 54},
    ),
    "1743": UnimodInfo(
        id="1743",
        name="dHex(2)HexNAc(7)",
        formula="C68H111N7O43",
        monoisotopic_mass=1713.671426,
        average_mass=1714.63,
        dict_composition={'C': 68, 'H': 111, 'O': 43, 'N': 7},
    ),
    "1744": UnimodInfo(
        id="1744",
        name="Hex(2)HexNAc(1)NeuGc(4)",
        formula="C64H101N5O51",
        monoisotopic_mass=1755.546345,
        average_mass=1756.4896,
        dict_composition={'C': 64, 'H': 101, 'O': 51, 'N': 5},
    ),
    "1745": UnimodInfo(
        id="1745",
        name="Hex(3)HexNAc(3)NeuAc(2)Sulf(1)",
        formula="C64H103N5O49S",
        monoisotopic_mass=1757.544236,
        average_mass=1758.5717,
        dict_composition={'O': 49, 'S': 1, 'C': 64, 'H': 103, 'N': 5},
    ),
    "1746": UnimodInfo(
        id="1746",
        name="dHex(2)Hex(3)HexNAc(5)",
        formula="C70H115N5O48",
        monoisotopic_mass=1793.671151,
        average_mass=1794.6668,
        dict_composition={'C': 70, 'H': 115, 'O': 48, 'N': 5},
    ),
    "1747": UnimodInfo(
        id="1747",
        name="dHex(1)Hex(2)HexNAc(2)NeuGc(3)",
        formula="C67H107N5O51",
        monoisotopic_mass=1797.593295,
        average_mass=1798.5694,
        dict_composition={'C': 67, 'H': 107, 'O': 51, 'N': 5},
    ),
    "1748": UnimodInfo(
        id="1748",
        name="dHex(2)Hex(4)HexA(1)HexNAc(3)Sulf(1)",
        formula="C66H107N3O52S",
        monoisotopic_mass=1805.554132,
        average_mass=1806.6097,
        dict_composition={'O': 52, 'S': 1, 'C': 66, 'H': 107, 'N': 3},
    ),
    "1749": UnimodInfo(
        id="1749",
        name="Hex(2)HexNAc(3)NeuAc(3)",
        formula="C69H110N6O49",
        monoisotopic_mass=1806.630015,
        average_mass=1807.6225,
        dict_composition={'C': 69, 'H': 110, 'O': 49, 'N': 6},
    ),
    "1750": UnimodInfo(
        id="1750",
        name="dHex(1)Hex(3)HexNAc(3)NeuAc(2)",
        formula="C70H113N5O50",
        monoisotopic_mass=1823.64533,
        average_mass=1824.6497,
        dict_composition={'C': 70, 'H': 113, 'O': 50, 'N': 5},
    ),
    "1751": UnimodInfo(
        id="1751",
        name="dHex(3)Hex(3)HexNAc(3)NeuAc(1)",
        formula="C71H116N4O50",
        monoisotopic_mass=1824.665732,
        average_mass=1825.6775,
        dict_composition={'C': 71, 'H': 116, 'O': 50, 'N': 4},
    ),
    "1752": UnimodInfo(
        id="1752",
        name="Hex(2)HexNAc(3)NeuGc(3)",
        formula="C69H110N6O52",
        monoisotopic_mass=1854.614759,
        average_mass=1855.6207,
        dict_composition={'C': 69, 'H': 110, 'O': 52, 'N': 6},
    ),
    "1753": UnimodInfo(
        id="1753",
        name="Hex(10)Phos(3)",
        formula="C60H103O59P3",
        monoisotopic_mass=1860.427228,
        average_mass=1861.3457,
        dict_composition={'H': 103, 'O': 59, 'P': 3, 'C': 60},
    ),
    "1754": UnimodInfo(
        id="1754",
        name="dHex(1)Hex(2)HexNAc(4)NeuAc(2)",
        formula="C72H116N6O50",
        monoisotopic_mass=1864.67188,
        average_mass=1865.7016,
        dict_composition={'C': 72, 'H': 116, 'O': 50, 'N': 6},
    ),
    "1755": UnimodInfo(
        id="1755",
        name="Hex(1)HexNAc(1)NeuGc(5)",
        formula="C69H108N6O55",
        monoisotopic_mass=1900.583852,
        average_mass=1901.603,
        dict_composition={'C': 69, 'H': 108, 'O': 55, 'N': 6},
    ),
    "1756": UnimodInfo(
        id="1756",
        name="Hex(4)HexNAc(4)NeuAc(1)Sulf(2)",
        formula="C67H109N5O54S2",
        monoisotopic_mass=1911.53783,
        average_mass=1912.7135,
        dict_composition={'O': 54, 'S': 2, 'C': 67, 'H': 109, 'N': 5},
    ),
    "1757": UnimodInfo(
        id="1757",
        name="Hex(4)HexNAc(4)NeuGc(1)Sulf(2)",
        formula="C67H109N5O55S2",
        monoisotopic_mass=1927.532745,
        average_mass=1928.7129,
        dict_composition={'O': 55, 'S': 2, 'C': 67, 'H': 109, 'N': 5},
    ),
    "1758": UnimodInfo(
        id="1758",
        name="dHex(2)Hex(3)HexNAc(3)NeuAc(2)",
        formula="C76H123N5O54",
        monoisotopic_mass=1969.703239,
        average_mass=1970.7909,
        dict_composition={'C': 76, 'H': 123, 'O': 54, 'N': 5},
    ),
    "1759": UnimodInfo(
        id="1759",
        name="Hex(4)HexNAc(4)NeuAc(1)Sulf(3)",
        formula="C67H109N5O57S3",
        monoisotopic_mass=1991.494645,
        average_mass=1992.7767,
        dict_composition={'O': 57, 'S': 3, 'C': 67, 'H': 109, 'N': 5},
    ),
    "1760": UnimodInfo(
        id="1760",
        name="dHex(2)Hex(2)HexNAc(2)",
        formula="C40H66N2O28",
        monoisotopic_mass=1022.38021,
        average_mass=1022.9486,
        dict_composition={'C': 40, 'H': 66, 'O': 28, 'N': 2},
    ),
    "1761": UnimodInfo(
        id="1761",
        name="dHex(1)Hex(3)HexNAc(2)",
        formula="C40H66N2O29",
        monoisotopic_mass=1038.375125,
        average_mass=1038.948,
        dict_composition={'C': 40, 'H': 66, 'O': 29, 'N': 2},
    ),
    "1762": UnimodInfo(
        id="1762",
        name="dHex(1)Hex(2)HexNAc(3)",
        formula="C42H69N3O29",
        monoisotopic_mass=1079.401674,
        average_mass=1080.0,
        dict_composition={'C': 42, 'H': 69, 'O': 29, 'N': 3},
    ),
    "1763": UnimodInfo(
        id="1763",
        name="Hex(3)HexNAc(3)",
        formula="C42H69N3O30",
        monoisotopic_mass=1095.396588,
        average_mass=1095.9994,
        dict_composition={'C': 42, 'H': 69, 'O': 30, 'N': 3},
    ),
    "1764": UnimodInfo(
        id="1764",
        name="dHex(1)Hex(3)HexNAc(2)Sulf(1)",
        formula="C40H66N2O32S",
        monoisotopic_mass=1118.331939,
        average_mass=1119.0112,
        dict_composition={'O': 32, 'S': 1, 'C': 40, 'H': 66, 'N': 2},
    ),
    "1765": UnimodInfo(
        id="1765",
        name="dHex(2)Hex(3)HexNAc(2)",
        formula="C46H76N2O33",
        monoisotopic_mass=1184.433033,
        average_mass=1185.0892,
        dict_composition={'C': 46, 'H': 76, 'O': 33, 'N': 2},
    ),
    "1766": UnimodInfo(
        id="1766",
        name="dHex(1)Hex(4)HexNAc(2)",
        formula="C46H76N2O34",
        monoisotopic_mass=1200.427948,
        average_mass=1201.0886,
        dict_composition={'C': 46, 'H': 76, 'O': 34, 'N': 2},
    ),
    "1767": UnimodInfo(
        id="1767",
        name="dHex(2)Hex(2)HexNAc(3)",
        formula="C48H79N3O33",
        monoisotopic_mass=1225.459583,
        average_mass=1226.1412,
        dict_composition={'C': 48, 'H': 79, 'O': 33, 'N': 3},
    ),
    "1768": UnimodInfo(
        id="1768",
        name="dHex(1)Hex(3)HexNAc(3)",
        formula="C48H79N3O34",
        monoisotopic_mass=1241.454497,
        average_mass=1242.1406,
        dict_composition={'C': 48, 'H': 79, 'O': 34, 'N': 3},
    ),
    "1769": UnimodInfo(
        id="1769",
        name="Hex(4)HexNAc(3)",
        formula="C48H79N3O35",
        monoisotopic_mass=1257.449412,
        average_mass=1258.14,
        dict_composition={'C': 48, 'H': 79, 'O': 35, 'N': 3},
    ),
    "1770": UnimodInfo(
        id="1770",
        name="dHex(2)Hex(4)HexNAc(2)",
        formula="C52H86N2O38",
        monoisotopic_mass=1346.485857,
        average_mass=1347.2298,
        dict_composition={'C': 52, 'H': 86, 'O': 38, 'N': 2},
    ),
    "1771": UnimodInfo(
        id="1771",
        name="dHex(2)Hex(3)HexNAc(3)",
        formula="C54H89N3O38",
        monoisotopic_mass=1387.512406,
        average_mass=1388.2818,
        dict_composition={'C': 54, 'H': 89, 'O': 38, 'N': 3},
    ),
    "1772": UnimodInfo(
        id="1772",
        name="Hex(3)HexNAc(5)",
        formula="C58H95N5O40",
        monoisotopic_mass=1501.555334,
        average_mass=1502.3844,
        dict_composition={'C': 58, 'H': 95, 'O': 40, 'N': 5},
    ),
    "1773": UnimodInfo(
        id="1773",
        name="Hex(4)HexNAc(3)NeuAc(1)",
        formula="C59H96N4O43",
        monoisotopic_mass=1548.544828,
        average_mass=1549.3945,
        dict_composition={'C': 59, 'H': 96, 'O': 43, 'N': 4},
    ),
    "1774": UnimodInfo(
        id="1774",
        name="dHex(2)Hex(3)HexNAc(4)",
        formula="C62H102N4O43",
        monoisotopic_mass=1590.591779,
        average_mass=1591.4743,
        dict_composition={'C': 62, 'H': 102, 'O': 43, 'N': 4},
    ),
    "1775": UnimodInfo(
        id="1775",
        name="dHex(1)Hex(3)HexNAc(5)",
        formula="C64H105N5O44",
        monoisotopic_mass=1647.613242,
        average_mass=1648.5256,
        dict_composition={'C': 64, 'H': 105, 'O': 44, 'N': 5},
    ),
    "1776": UnimodInfo(
        id="1776",
        name="Hex(3)HexNAc(6)",
        formula="C66H108N6O45",
        monoisotopic_mass=1704.634706,
        average_mass=1705.5769,
        dict_composition={'C': 66, 'H': 108, 'O': 45, 'N': 6},
    ),
    "1777": UnimodInfo(
        id="1777",
        name="Hex(4)HexNAc(4)NeuAc(1)",
        formula="C67H109N5O48",
        monoisotopic_mass=1751.624201,
        average_mass=1752.5871,
        dict_composition={'C': 67, 'H': 109, 'O': 48, 'N': 5},
    ),
    "1778": UnimodInfo(
        id="1778",
        name="dHex(2)Hex(4)HexNAc(4)",
        formula="C68H112N4O48",
        monoisotopic_mass=1752.644602,
        average_mass=1753.6149,
        dict_composition={'C': 68, 'H': 112, 'O': 48, 'N': 4},
    ),
    "1779": UnimodInfo(
        id="1779",
        name="Hex(6)HexNAc(4)",
        formula="C68H112N4O50",
        monoisotopic_mass=1784.634431,
        average_mass=1785.6137,
        dict_composition={'C': 68, 'H': 112, 'O': 50, 'N': 4},
    ),
    "1780": UnimodInfo(
        id="1780",
        name="Hex(5)HexNAc(5)",
        formula="C70H115N5O50",
        monoisotopic_mass=1825.660981,
        average_mass=1826.6656,
        dict_composition={'C': 70, 'H': 115, 'O': 50, 'N': 5},
    ),
    "1781": UnimodInfo(
        id="1781",
        name="dHex(1)Hex(3)HexNAc(6)",
        formula="C72H118N6O49",
        monoisotopic_mass=1850.692615,
        average_mass=1851.7181,
        dict_composition={'C': 72, 'H': 118, 'O': 49, 'N': 6},
    ),
    "1782": UnimodInfo(
        id="1782",
        name="dHex(1)Hex(4)HexNAc(4)NeuAc(1)",
        formula="C73H119N5O52",
        monoisotopic_mass=1897.68211,
        average_mass=1898.7283,
        dict_composition={'C': 73, 'H': 119, 'O': 52, 'N': 5},
    ),
    "1783": UnimodInfo(
        id="1783",
        name="dHex(3)Hex(4)HexNAc(4)",
        formula="C74H122N4O52",
        monoisotopic_mass=1898.702511,
        average_mass=1899.7561,
        dict_composition={'C': 74, 'H': 122, 'O': 52, 'N': 4},
    ),
    "1784": UnimodInfo(
        id="1784",
        name="dHex(1)Hex(3)HexNAc(5)NeuAc(1)",
        formula="C75H122N6O52",
        monoisotopic_mass=1938.708659,
        average_mass=1939.7802,
        dict_composition={'C': 75, 'H': 122, 'O': 52, 'N': 6},
    ),
    "1785": UnimodInfo(
        id="1785",
        name="dHex(2)Hex(4)HexNAc(5)",
        formula="C76H125N5O53",
        monoisotopic_mass=1955.723975,
        average_mass=1956.8074,
        dict_composition={'C': 76, 'H': 125, 'O': 53, 'N': 5},
    ),
    "1786": UnimodInfo(
        id="1786",
        name="Hex(1)HexNAc(1)NeuAc(1)Ac(1)",
        formula="C27H42N2O19",
        monoisotopic_mass=698.238177,
        average_mass=698.6244,
        dict_composition={'C': 27, 'H': 42, 'O': 19, 'N': 2},
    ),
    "1787": UnimodInfo(
        id="1787",
        name="Label:13C(2)15N(2)",
        formula="C-2N-2",
        monoisotopic_mass=4.00078,
        average_mass=3.9721,
        dict_composition={'C': -2, 'N': -2},
    ),
    "1789": UnimodInfo(
        id="1789",
        name="Xlink:DSS[155]",
        formula="C8H13NO2",
        monoisotopic_mass=155.094629,
        average_mass=155.1943,
        dict_composition={'H': 13, 'C': 8, 'N': 1, 'O': 2},
    ),
    "1799": UnimodInfo(
        id="1799",
        name="NQIGG",
        formula="C19H31N7O7",
        monoisotopic_mass=469.228496,
        average_mass=469.4921,
        dict_composition={'H': 31, 'C': 19, 'N': 7, 'O': 7},
    ),
    "1800": UnimodInfo(
        id="1800",
        name="Carboxyethylpyrrole",
        formula="C7H6O2",
        monoisotopic_mass=122.036779,
        average_mass=122.1213,
        dict_composition={'H': 6, 'C': 7, 'O': 2},
    ),
    "1801": UnimodInfo(
        id="1801",
        name="Fluorescein-tyramine",
        formula="C29H19NO7",
        monoisotopic_mass=493.116152,
        average_mass=493.4637,
        dict_composition={'H': 19, 'C': 29, 'N': 1, 'O': 7},
    ),
    "1824": UnimodInfo(
        id="1824",
        name="GEE",
        formula="C4H6O2",
        monoisotopic_mass=86.036779,
        average_mass=86.0892,
        dict_composition={'H': 6, 'C': 4, 'O': 2},
    ),
    "1825": UnimodInfo(
        id="1825",
        name="RNPXL",
        formula="C9H13N2O9P",
        monoisotopic_mass=324.035867,
        average_mass=324.1813,
        dict_composition={'H': 13, 'C': 9, 'N': 2, 'O': 9, 'P': 1},
    ),
    "1826": UnimodInfo(
        id="1826",
        name="Glu->pyro-Glu+Methyl",
        formula="CO-1",
        monoisotopic_mass=-3.994915,
        average_mass=-3.9887,
        dict_composition={'C': 1, 'O': -1},
    ),
    "1827": UnimodInfo(
        id="1827",
        name="Glu->pyro-Glu+Methyl:2H(2)13C(1)",
        formula="H-2O-1",
        monoisotopic_mass=-0.979006,
        average_mass=-0.9837,
        dict_composition={'H': -2, 'C': 0, 'O': -1},
    ),
    "1828": UnimodInfo(
        id="1828",
        name="LRGG+methyl",
        formula="C17H31N7O4",
        monoisotopic_mass=397.243753,
        average_mass=397.4725,
        dict_composition={'H': 31, 'C': 17, 'N': 7, 'O': 4},
    ),
    "1829": UnimodInfo(
        id="1829",
        name="LRGG+dimethyl",
        formula="C18H33N7O4",
        monoisotopic_mass=411.259403,
        average_mass=411.4991,
        dict_composition={'H': 33, 'C': 18, 'N': 7, 'O': 4},
    ),
    "1830": UnimodInfo(
        id="1830",
        name="Biotin-tyramide",
        formula="C18H23N3O3S",
        monoisotopic_mass=361.146012,
        average_mass=361.4585,
        dict_composition={'H': 23, 'C': 18, 'N': 3, 'O': 3, 'S': 1},
    ),
    "1831": UnimodInfo(
        id="1831",
        name="Tris",
        formula="C4H10NO2",
        monoisotopic_mass=104.071154,
        average_mass=104.1277,
        dict_composition={'H': 10, 'C': 4, 'N': 1, 'O': 2},
    ),
    "1832": UnimodInfo(
        id="1832",
        name="IASD",
        formula="C18H16N2O8S2",
        monoisotopic_mass=452.034807,
        average_mass=452.4582,
        dict_composition={'H': 16, 'C': 18, 'N': 2, 'O': 8, 'S': 2},
    ),
    "1833": UnimodInfo(
        id="1833",
        name="NP40",
        formula="C15H24O",
        monoisotopic_mass=220.182715,
        average_mass=220.3505,
        dict_composition={'H': 24, 'C': 15, 'O': 1},
    ),
    "1834": UnimodInfo(
        id="1834",
        name="Tween20",
        formula="C12H21",
        monoisotopic_mass=165.164326,
        average_mass=165.2951,
        dict_composition={'H': 21, 'C': 12},
    ),
    "1835": UnimodInfo(
        id="1835",
        name="Tween80",
        formula="C18H31O",
        monoisotopic_mass=263.237491,
        average_mass=263.4381,
        dict_composition={'H': 31, 'C': 18, 'O': 1},
    ),
    "1836": UnimodInfo(
        id="1836",
        name="Triton",
        formula="C14H20",
        monoisotopic_mass=188.156501,
        average_mass=188.3086,
        dict_composition={'H': 20, 'C': 14},
    ),
    "1837": UnimodInfo(
        id="1837",
        name="Brij35",
        formula="C12H24",
        monoisotopic_mass=168.187801,
        average_mass=168.319,
        dict_composition={'H': 24, 'C': 12},
    ),
    "1838": UnimodInfo(
        id="1838",
        name="Brij58",
        formula="C16H32",
        monoisotopic_mass=224.250401,
        average_mass=224.4253,
        dict_composition={'H': 32, 'C': 16},
    ),
    "1839": UnimodInfo(
        id="1839",
        name="betaFNA",
        formula="C25H30N2O6",
        monoisotopic_mass=454.210387,
        average_mass=454.5155,
        dict_composition={'H': 30, 'C': 25, 'N': 2, 'O': 6},
    ),
    "1840": UnimodInfo(
        id="1840",
        name="dHex(1)Hex(7)HexNAc(4)",
        formula="C80H132N4O59",
        monoisotopic_mass=2092.745164,
        average_mass=2093.8955,
        dict_composition={'C': 80, 'H': 132, 'O': 59, 'N': 4},
    ),
    "1841": UnimodInfo(
        id="1841",
        name="Biotin:Thermo-21328",
        formula="C15H23N3O3S3",
        monoisotopic_mass=389.090154,
        average_mass=389.5564,
        dict_composition={'H': 23, 'C': 15, 'N': 3, 'O': 3, 'S': 3},
    ),
    "1843": UnimodInfo(
        id="1843",
        name="PhosphoCytidine",
        formula="C9H12N3O7P",
        monoisotopic_mass=305.041287,
        average_mass=305.1812,
        dict_composition={'H': 12, 'C': 9, 'N': 3, 'O': 7, 'P': 1},
    ),
    "1845": UnimodInfo(
        id="1845",
        name="AzidoF",
        formula="H-1N3",
        monoisotopic_mass=41.001397,
        average_mass=41.0122,
        dict_composition={'H': -1, 'N': 3},
    ),
    "1846": UnimodInfo(
        id="1846",
        name="Dimethylaminoethyl",
        formula="C4H9N",
        monoisotopic_mass=71.073499,
        average_mass=71.121,
        dict_composition={'H': 9, 'C': 4, 'N': 1},
    ),
    "1848": UnimodInfo(
        id="1848",
        name="Gluratylation",
        formula="C5H6O3",
        monoisotopic_mass=114.031694,
        average_mass=114.0993,
        dict_composition={'H': 6, 'C': 5, 'O': 3},
    ),
    "1849": UnimodInfo(
        id="1849",
        name="hydroxyisobutyryl",
        formula="C4H6O2",
        monoisotopic_mass=86.036779,
        average_mass=86.0892,
        dict_composition={'H': 6, 'C': 4, 'O': 2},
    ),
    "1868": UnimodInfo(
        id="1868",
        name="MeMePhosphorothioate",
        formula="C2H5OPS",
        monoisotopic_mass=107.979873,
        average_mass=108.0993,
        dict_composition={'H': 5, 'C': 2, 'O': 1, 'P': 1, 'S': 1},
    ),
    "1870": UnimodInfo(
        id="1870",
        name="Cation:Fe[III]",
        formula="H-3Fe",
        monoisotopic_mass=52.911464,
        average_mass=52.8212,
        dict_composition={'H': -3, 'Fe': 1},
    ),
    "1871": UnimodInfo(
        id="1871",
        name="DTT",
        formula="C4H8O2S2",
        monoisotopic_mass=151.996571,
        average_mass=152.2351,
        dict_composition={'H': 8, 'C': 4, 'O': 2, 'S': 2},
    ),
    "1872": UnimodInfo(
        id="1872",
        name="DYn-2",
        formula="C11H13O",
        monoisotopic_mass=161.09664,
        average_mass=161.2203,
        dict_composition={'H': 13, 'C': 11, 'O': 1},
    ),
    "1873": UnimodInfo(
        id="1873",
        name="MesitylOxide",
        formula="C6H10O",
        monoisotopic_mass=98.073165,
        average_mass=98.143,
        dict_composition={'H': 10, 'C': 6, 'O': 1},
    ),
    "1875": UnimodInfo(
        id="1875",
        name="methylol",
        formula="CH2O",
        monoisotopic_mass=30.010565,
        average_mass=30.026,
        dict_composition={'H': 2, 'C': 1, 'O': 1},
    ),
    "1877": UnimodInfo(
        id="1877",
        name="Xlink:DSS[259]",
        formula="C12H21NO5",
        monoisotopic_mass=259.141973,
        average_mass=259.2988,
        dict_composition={'H': 21, 'C': 12, 'N': 1, 'O': 5},
    ),
    "1878": UnimodInfo(
        id="1878",
        name="Xlink:DSSO[176]",
        formula="C6H8O4S",
        monoisotopic_mass=176.01433,
        average_mass=176.1903,
        dict_composition={'H': 8, 'C': 6, 'O': 4, 'S': 1},
    ),
    "1879": UnimodInfo(
        id="1879",
        name="Xlink:DSSO[175]",
        formula="C6H9NO3S",
        monoisotopic_mass=175.030314,
        average_mass=175.2056,
        dict_composition={'H': 9, 'C': 6, 'N': 1, 'O': 3, 'S': 1},
    ),
    "1880": UnimodInfo(
        id="1880",
        name="Xlink:DSSO[279]",
        formula="C10H17NO6S",
        monoisotopic_mass=279.077658,
        average_mass=279.3101,
        dict_composition={'H': 17, 'C': 10, 'N': 1, 'O': 6, 'S': 1},
    ),
    "1881": UnimodInfo(
        id="1881",
        name="Xlink:DSSO[54]",
        formula="C3H2O",
        monoisotopic_mass=54.010565,
        average_mass=54.0474,
        dict_composition={'H': 2, 'C': 3, 'O': 1},
    ),
    "1882": UnimodInfo(
        id="1882",
        name="Xlink:DSSO[86]",
        formula="C3H2OS",
        monoisotopic_mass=85.982635,
        average_mass=86.1124,
        dict_composition={'H': 2, 'C': 3, 'O': 1, 'S': 1},
    ),
    "1883": UnimodInfo(
        id="1883",
        name="Xlink:DSSO[104]",
        formula="C3H4O2S",
        monoisotopic_mass=103.9932,
        average_mass=104.1277,
        dict_composition={'H': 4, 'C': 3, 'O': 2, 'S': 1},
    ),
    "1885": UnimodInfo(
        id="1885",
        name="Xlink:BuUrBu[111]",
        formula="C5H5NO2",
        monoisotopic_mass=111.032028,
        average_mass=111.0987,
        dict_composition={'H': 5, 'C': 5, 'N': 1, 'O': 2},
    ),
    "1886": UnimodInfo(
        id="1886",
        name="Xlink:BuUrBu[85]",
        formula="C4H7NO",
        monoisotopic_mass=85.052764,
        average_mass=85.1045,
        dict_composition={'H': 7, 'C': 4, 'N': 1, 'O': 1},
    ),
    "1887": UnimodInfo(
        id="1887",
        name="Xlink:BuUrBu[213]",
        formula="C9H15N3O3",
        monoisotopic_mass=213.111341,
        average_mass=213.2337,
        dict_composition={'H': 15, 'C': 9, 'N': 3, 'O': 3},
    ),
    "1888": UnimodInfo(
        id="1888",
        name="Xlink:BuUrBu[214]",
        formula="C9H14N2O4",
        monoisotopic_mass=214.095357,
        average_mass=214.2185,
        dict_composition={'H': 14, 'C': 9, 'N': 2, 'O': 4},
    ),
    "1889": UnimodInfo(
        id="1889",
        name="Xlink:BuUrBu[317]",
        formula="C13H23N3O6",
        monoisotopic_mass=317.158686,
        average_mass=317.3382,
        dict_composition={'H': 23, 'C': 13, 'N': 3, 'O': 6},
    ),
    "1896": UnimodInfo(
        id="1896",
        name="Xlink:DSSO[158]",
        formula="C6H6O3S",
        monoisotopic_mass=158.003765,
        average_mass=158.175,
        dict_composition={'H': 6, 'C': 6, 'O': 3, 'S': 1},
    ),
    "1897": UnimodInfo(
        id="1897",
        name="Xlink:EGS[226]",
        formula="C10H10O6",
        monoisotopic_mass=226.047738,
        average_mass=226.1828,
        dict_composition={'H': 10, 'C': 10, 'O': 6},
    ),
    "1898": UnimodInfo(
        id="1898",
        name="Xlink:DSS[138]",
        formula="C8H10O2",
        monoisotopic_mass=138.06808,
        average_mass=138.1638,
        dict_composition={'H': 10, 'C': 8, 'O': 2},
    ),
    "1899": UnimodInfo(
        id="1899",
        name="Xlink:BuUrBu[196]",
        formula="C9H12N2O3",
        monoisotopic_mass=196.084792,
        average_mass=196.2032,
        dict_composition={'H': 12, 'C': 9, 'N': 2, 'O': 3},
    ),
    "1900": UnimodInfo(
        id="1900",
        name="Xlink:DTBP[172]",
        formula="C6H8N2S2",
        monoisotopic_mass=172.01289,
        average_mass=172.2711,
        dict_composition={'H': 8, 'C': 6, 'N': 2, 'S': 2},
    ),
    "1901": UnimodInfo(
        id="1901",
        name="Xlink:DST[114]",
        formula="C4H2O4",
        monoisotopic_mass=113.995309,
        average_mass=114.0563,
        dict_composition={'H': 2, 'C': 4, 'O': 4},
    ),
    "1902": UnimodInfo(
        id="1902",
        name="Xlink:DTSSP[174]",
        formula="C6H6O2S2",
        monoisotopic_mass=173.980921,
        average_mass=174.2406,
        dict_composition={'H': 6, 'C': 6, 'O': 2, 'S': 2},
    ),
    "1903": UnimodInfo(
        id="1903",
        name="Xlink:SMCC[219]",
        formula="C12H13NO3",
        monoisotopic_mass=219.089543,
        average_mass=219.2365,
        dict_composition={'H': 13, 'C': 12, 'N': 1, 'O': 3},
    ),
    "1905": UnimodInfo(
        id="1905",
        name="Xlink:BS2G[96]",
        formula="C5H4O2",
        monoisotopic_mass=96.021129,
        average_mass=96.0841,
        dict_composition={'H': 4, 'C': 5, 'O': 2},
    ),
    "1906": UnimodInfo(
        id="1906",
        name="Xlink:BS2G[113]",
        formula="C5H7NO2",
        monoisotopic_mass=113.047679,
        average_mass=113.1146,
        dict_composition={'H': 7, 'C': 5, 'N': 1, 'O': 2},
    ),
    "1907": UnimodInfo(
        id="1907",
        name="Xlink:BS2G[114]",
        formula="C5H6O3",
        monoisotopic_mass=114.031694,
        average_mass=114.0993,
        dict_composition={'H': 6, 'C': 5, 'O': 3},
    ),
    "1908": UnimodInfo(
        id="1908",
        name="Xlink:BS2G[217]",
        formula="C9H15NO5",
        monoisotopic_mass=217.095023,
        average_mass=217.2191,
        dict_composition={'H': 15, 'C': 9, 'N': 1, 'O': 5},
    ),
    "1910": UnimodInfo(
        id="1910",
        name="Cation:Al[III]",
        formula="H-3Al",
        monoisotopic_mass=23.958063,
        average_mass=23.9577,
        dict_composition={'H': -3, 'Al': 1},
    ),
    "1911": UnimodInfo(
        id="1911",
        name="Xlink:DMP[139]",
        formula="C7H13N3",
        monoisotopic_mass=139.110947,
        average_mass=139.1982,
        dict_composition={'H': 13, 'C': 7, 'N': 3},
    ),
    "1912": UnimodInfo(
        id="1912",
        name="Xlink:DMP[122]",
        formula="C7H10N2",
        monoisotopic_mass=122.084398,
        average_mass=122.1677,
        dict_composition={'H': 10, 'C': 7, 'N': 2},
    ),
    "1913": UnimodInfo(
        id="1913",
        name="glyoxalAGE",
        formula="C2H-2",
        monoisotopic_mass=21.98435,
        average_mass=22.0055,
        dict_composition={'H': -2, 'C': 2},
    ),
    "1914": UnimodInfo(
        id="1914",
        name="Met->AspSA",
        formula="C-1H-4OS-1",
        monoisotopic_mass=-32.008456,
        average_mass=-32.1081,
        dict_composition={'H': -4, 'C': -1, 'O': 1, 'S': -1},
    ),
    "1915": UnimodInfo(
        id="1915",
        name="Decarboxylation",
        formula="C-1H-2O-1",
        monoisotopic_mass=-30.010565,
        average_mass=-30.026,
        dict_composition={'H': -2, 'C': -1, 'O': -1},
    ),
    "1916": UnimodInfo(
        id="1916",
        name="Aspartylurea",
        formula="C-1H-2N-2O2",
        monoisotopic_mass=-10.031969,
        average_mass=-10.0412,
        dict_composition={'H': -2, 'C': -1, 'N': -2, 'O': 2},
    ),
    "1917": UnimodInfo(
        id="1917",
        name="Formylasparagine",
        formula="C-1H-1N-1O2",
        monoisotopic_mass=4.97893,
        average_mass=4.9735,
        dict_composition={'H': -1, 'C': -1, 'N': -1, 'O': 2},
    ),
    "1918": UnimodInfo(
        id="1918",
        name="Carbonyl",
        formula="H-2O",
        monoisotopic_mass=13.979265,
        average_mass=13.9835,
        dict_composition={'H': -2, 'O': 1},
    ),
    "1920": UnimodInfo(
        id="1920",
        name="AFB1_Dialdehyde",
        formula="C17H10O6",
        monoisotopic_mass=310.047738,
        average_mass=310.2577,
        dict_composition={'H': 10, 'C': 17, 'O': 6},
    ),
    "1922": UnimodInfo(
        id="1922",
        name="Pro->HAVA",
        formula="H2O",
        monoisotopic_mass=18.010565,
        average_mass=18.0153,
        dict_composition={'H': 2, 'O': 1},
    ),
    "1923": UnimodInfo(
        id="1923",
        name="Delta:H(-4)O(2)",
        formula="H-4O2",
        monoisotopic_mass=27.958529,
        average_mass=27.967,
        dict_composition={'H': -4, 'O': 2},
    ),
    "1924": UnimodInfo(
        id="1924",
        name="Delta:H(-4)O(3)",
        formula="H-4O3",
        monoisotopic_mass=43.953444,
        average_mass=43.9664,
        dict_composition={'H': -4, 'O': 3},
    ),
    "1925": UnimodInfo(
        id="1925",
        name="Delta:O(4)",
        formula="O4",
        monoisotopic_mass=63.979659,
        average_mass=63.9976,
        dict_composition={'O': 4},
    ),
    "1926": UnimodInfo(
        id="1926",
        name="Delta:H(4)C(3)O(2)",
        formula="C3H4O2",
        monoisotopic_mass=72.021129,
        average_mass=72.0627,
        dict_composition={'H': 4, 'C': 3, 'O': 2},
    ),
    "1927": UnimodInfo(
        id="1927",
        name="Delta:H(4)C(5)O(1)",
        formula="C5H4O",
        monoisotopic_mass=80.026215,
        average_mass=80.0847,
        dict_composition={'H': 4, 'C': 5, 'O': 1},
    ),
    "1928": UnimodInfo(
        id="1928",
        name="Delta:H(10)C(8)O(1)",
        formula="C8H10O",
        monoisotopic_mass=122.073165,
        average_mass=122.1644,
        dict_composition={'H': 10, 'C': 8, 'O': 1},
    ),
    "1929": UnimodInfo(
        id="1929",
        name="Delta:H(6)C(7)O(4)",
        formula="C7H6O4",
        monoisotopic_mass=154.026609,
        average_mass=154.1201,
        dict_composition={'H': 6, 'C': 7, 'O': 4},
    ),
    "1930": UnimodInfo(
        id="1930",
        name="Pent(2)",
        formula="C10H16O8",
        monoisotopic_mass=264.084518,
        average_mass=264.2292,
        dict_composition={'C': 10, 'H': 16, 'O': 8},
    ),
    "1931": UnimodInfo(
        id="1931",
        name="Pent(1)HexNAc(1)",
        formula="C13H21NO9",
        monoisotopic_mass=335.121631,
        average_mass=335.3071,
        dict_composition={'C': 13, 'H': 21, 'O': 9, 'N': 1},
    ),
    "1932": UnimodInfo(
        id="1932",
        name="Hex(2)Sulf(1)",
        formula="C12H20O13S",
        monoisotopic_mass=404.062462,
        average_mass=404.3444,
        dict_composition={'O': 13, 'S': 1, 'C': 12, 'H': 20},
    ),
    "1933": UnimodInfo(
        id="1933",
        name="Hex(1)Pent(2)Me(1)",
        formula="C17H28O13",
        monoisotopic_mass=440.152991,
        average_mass=440.3964,
        dict_composition={'C': 17, 'H': 28, 'O': 13},
    ),
    "1934": UnimodInfo(
        id="1934",
        name="HexNAc(2)Sulf(1)",
        formula="C16H26N2O13S",
        monoisotopic_mass=486.11556,
        average_mass=486.4482,
        dict_composition={'O': 13, 'S': 1, 'C': 16, 'H': 26, 'N': 2},
    ),
    "1935": UnimodInfo(
        id="1935",
        name="Hex(1)Pent(3)Me(1)",
        formula="C22H36O17",
        monoisotopic_mass=572.19525,
        average_mass=572.511,
        dict_composition={'C': 22, 'H': 36, 'O': 17},
    ),
    "1936": UnimodInfo(
        id="1936",
        name="Hex(2)Pent(2)",
        formula="C22H36O18",
        monoisotopic_mass=588.190165,
        average_mass=588.5104,
        dict_composition={'C': 22, 'H': 36, 'O': 18},
    ),
    "1937": UnimodInfo(
        id="1937",
        name="Hex(2)Pent(2)Me(1)",
        formula="C23H38O18",
        monoisotopic_mass=602.205815,
        average_mass=602.537,
        dict_composition={'C': 23, 'H': 38, 'O': 18},
    ),
    "1938": UnimodInfo(
        id="1938",
        name="Hex(4)HexA(1)",
        formula="C30H48O26",
        monoisotopic_mass=824.243382,
        average_mass=824.6865,
        dict_composition={'C': 30, 'H': 48, 'O': 26},
    ),
    "1939": UnimodInfo(
        id="1939",
        name="Hex(2)HexNAc(1)Pent(1)HexA(1)",
        formula="C31H49NO25",
        monoisotopic_mass=835.259366,
        average_mass=835.7125,
        dict_composition={'C': 31, 'H': 49, 'O': 25, 'N': 1},
    ),
    "1940": UnimodInfo(
        id="1940",
        name="Hex(3)HexNAc(1)HexA(1)",
        formula="C32H51NO26",
        monoisotopic_mass=865.269931,
        average_mass=865.7384,
        dict_composition={'C': 32, 'H': 51, 'O': 26, 'N': 1},
    ),
    "1941": UnimodInfo(
        id="1941",
        name="Hex(1)HexNAc(2)dHex(2)Sulf(1)",
        formula="C34H56N2O26S",
        monoisotopic_mass=940.284201,
        average_mass=940.8712,
        dict_composition={'O': 26, 'S': 1, 'C': 34, 'H': 56, 'N': 2},
    ),
    "1942": UnimodInfo(
        id="1942",
        name="HexA(2)HexNAc(3)",
        formula="C36H55N3O27",
        monoisotopic_mass=961.302294,
        average_mass=961.8258,
        dict_composition={'C': 36, 'H': 55, 'O': 27, 'N': 3},
    ),
    "1943": UnimodInfo(
        id="1943",
        name="dHex(1)Hex(4)HexA(1)",
        formula="C36H58O30",
        monoisotopic_mass=970.301291,
        average_mass=970.8277,
        dict_composition={'C': 36, 'H': 58, 'O': 30},
    ),
    "1944": UnimodInfo(
        id="1944",
        name="Hex(5)HexA(1)",
        formula="C36H58O31",
        monoisotopic_mass=986.296206,
        average_mass=986.8271,
        dict_composition={'C': 36, 'H': 58, 'O': 31},
    ),
    "1945": UnimodInfo(
        id="1945",
        name="Hex(4)HexA(1)HexNAc(1)",
        formula="C38H61NO31",
        monoisotopic_mass=1027.322755,
        average_mass=1027.879,
        dict_composition={'C': 38, 'H': 61, 'O': 31, 'N': 1},
    ),
    "1946": UnimodInfo(
        id="1946",
        name="dHex(3)Hex(3)HexNAc(1)",
        formula="C44H73NO32",
        monoisotopic_mass=1127.41157,
        average_mass=1128.0379,
        dict_composition={'C': 44, 'H': 73, 'O': 32, 'N': 1},
    ),
    "1947": UnimodInfo(
        id="1947",
        name="Hex(6)HexNAc(1)",
        formula="C44H73NO35",
        monoisotopic_mass=1175.396314,
        average_mass=1176.0361,
        dict_composition={'C': 44, 'H': 73, 'O': 35, 'N': 1},
    ),
    "1948": UnimodInfo(
        id="1948",
        name="Hex(1)HexNAc(4)dHex(1)Sulf(1)",
        formula="C44H72N4O32S",
        monoisotopic_mass=1200.385037,
        average_mass=1201.1151,
        dict_composition={'H': 72, 'O': 32, 'S': 1, 'C': 44, 'N': 4},
    ),
    "1949": UnimodInfo(
        id="1949",
        name="dHex(1)Hex(2)HexNAc(1)NeuAc(2)",
        formula="C48H77N3O35",
        monoisotopic_mass=1255.433762,
        average_mass=1256.1241,
        dict_composition={'C': 48, 'H': 77, 'O': 35, 'N': 3},
    ),
    "1950": UnimodInfo(
        id="1950",
        name="dHex(3)Hex(3)HexNAc(2)",
        formula="C52H86N2O37",
        monoisotopic_mass=1330.490942,
        average_mass=1331.2304,
        dict_composition={'C': 52, 'H': 86, 'O': 37, 'N': 2},
    ),
    "1951": UnimodInfo(
        id="1951",
        name="dHex(2)Hex(1)HexNAc(4)Sulf(1)",
        formula="C50H82N4O36S",
        monoisotopic_mass=1346.442946,
        average_mass=1347.2563,
        dict_composition={'H': 82, 'O': 36, 'S': 1, 'C': 50, 'N': 4},
    ),
    "1952": UnimodInfo(
        id="1952",
        name="dHex(1)Hex(2)HexNAc(4)Sulf(2)",
        formula="C50H82N4O40S2",
        monoisotopic_mass=1442.394675,
        average_mass=1443.3189,
        dict_composition={'H': 82, 'O': 40, 'S': 2, 'C': 50, 'N': 4},
    ),
    "1953": UnimodInfo(
        id="1953",
        name="Hex(9)",
        formula="C54H90O45",
        monoisotopic_mass=1458.475412,
        average_mass=1459.2654,
        dict_composition={'C': 54, 'H': 90, 'O': 45},
    ),
    "1954": UnimodInfo(
        id="1954",
        name="dHex(2)Hex(3)HexNAc(3)Sulf(1)",
        formula="C54H89N3O41S",
        monoisotopic_mass=1467.469221,
        average_mass=1468.345,
        dict_composition={'H': 89, 'O': 41, 'S': 1, 'C': 54, 'N': 3},
    ),
    "1955": UnimodInfo(
        id="1955",
        name="dHex(2)Hex(5)HexNAc(2)Me(1)",
        formula="C59H98N2O43",
        monoisotopic_mass=1522.554331,
        average_mass=1523.397,
        dict_composition={'C': 59, 'H': 98, 'O': 43, 'N': 2},
    ),
    "1956": UnimodInfo(
        id="1956",
        name="dHex(2)Hex(2)HexNAc(4)Sulf(2)",
        formula="C56H92N4O44S2",
        monoisotopic_mass=1588.452584,
        average_mass=1589.4601,
        dict_composition={'H': 92, 'O': 44, 'S': 2, 'C': 56, 'N': 4},
    ),
    "1957": UnimodInfo(
        id="1957",
        name="Hex(9)HexNAc(1)",
        formula="C62H103NO50",
        monoisotopic_mass=1661.554784,
        average_mass=1662.4579,
        dict_composition={'C': 62, 'H': 103, 'O': 50, 'N': 1},
    ),
    "1958": UnimodInfo(
        id="1958",
        name="dHex(3)Hex(2)HexNAc(4)Sulf(2)",
        formula="C62H102N4O48S2",
        monoisotopic_mass=1734.510493,
        average_mass=1735.6013,
        dict_composition={'H': 102, 'O': 48, 'S': 2, 'C': 62, 'N': 4},
    ),
    "1959": UnimodInfo(
        id="1959",
        name="Hex(4)HexNAc(4)NeuGc(1)",
        formula="C67H109N5O49",
        monoisotopic_mass=1767.619116,
        average_mass=1768.5865,
        dict_composition={'C': 67, 'H': 109, 'O': 49, 'N': 5},
    ),
    "1960": UnimodInfo(
        id="1960",
        name="dHex(4)Hex(3)HexNAc(2)NeuAc(1)",
        formula="C69H113N3O49",
        monoisotopic_mass=1767.644268,
        average_mass=1768.6262,
        dict_composition={'C': 69, 'H': 113, 'O': 49, 'N': 3},
    ),
    "1961": UnimodInfo(
        id="1961",
        name="Hex(3)HexNAc(5)NeuAc(1)",
        formula="C69H112N6O48",
        monoisotopic_mass=1792.65075,
        average_mass=1793.639,
        dict_composition={'C': 69, 'H': 112, 'O': 48, 'N': 6},
    ),
    "1962": UnimodInfo(
        id="1962",
        name="Hex(10)HexNAc(1)",
        formula="C68H113NO55",
        monoisotopic_mass=1823.607608,
        average_mass=1824.5985,
        dict_composition={'C': 68, 'H': 113, 'O': 55, 'N': 1},
    ),
    "1963": UnimodInfo(
        id="1963",
        name="dHex(1)Hex(8)HexNAc(2)",
        formula="C70H116N2O54",
        monoisotopic_mass=1848.639242,
        average_mass=1849.651,
        dict_composition={'C': 70, 'H': 116, 'O': 54, 'N': 2},
    ),
    "1964": UnimodInfo(
        id="1964",
        name="Hex(3)HexNAc(4)NeuAc(2)",
        formula="C72H116N6O51",
        monoisotopic_mass=1880.666794,
        average_mass=1881.701,
        dict_composition={'C': 72, 'H': 116, 'O': 51, 'N': 6},
    ),
    "1965": UnimodInfo(
        id="1965",
        name="dHex(2)Hex(3)HexNAc(4)NeuAc(1)",
        formula="C73H119N5O51",
        monoisotopic_mass=1881.687195,
        average_mass=1882.7289,
        dict_composition={'C': 73, 'H': 119, 'O': 51, 'N': 5},
    ),
    "1966": UnimodInfo(
        id="1966",
        name="dHex(2)Hex(2)HexNAc(6)Sulf(1)",
        formula="C72H118N6O51S",
        monoisotopic_mass=1914.654515,
        average_mass=1915.7819,
        dict_composition={'H': 118, 'O': 51, 'S': 1, 'C': 72, 'N': 6},
    ),
    "1967": UnimodInfo(
        id="1967",
        name="Hex(5)HexNAc(4)NeuAc(1)Ac(1)",
        formula="C75H121N5O54",
        monoisotopic_mass=1955.687589,
        average_mass=1956.7643,
        dict_composition={'C': 75, 'H': 121, 'O': 54, 'N': 5},
    ),
    "1968": UnimodInfo(
        id="1968",
        name="Hex(3)HexNAc(3)NeuAc(3)",
        formula="C75H120N6O54",
        monoisotopic_mass=1968.682838,
        average_mass=1969.7631,
        dict_composition={'C': 75, 'H': 120, 'O': 54, 'N': 6},
    ),
    "1969": UnimodInfo(
        id="1969",
        name="Hex(5)HexNAc(4)NeuAc(1)Ac(2)",
        formula="C77H123N5O55",
        monoisotopic_mass=1997.698154,
        average_mass=1998.801,
        dict_composition={'C': 77, 'H': 123, 'O': 55, 'N': 5},
    ),
    "1970": UnimodInfo(
        id="1970",
        name="Unknown:162",
        formula="C8H18O3",
        monoisotopic_mass=162.125595,
        average_mass=162.2267,
        dict_composition={'H': 18, 'C': 8, 'O': 3},
    ),
    "1971": UnimodInfo(
        id="1971",
        name="Unknown:177",
        formula="H-7Fe3O",
        monoisotopic_mass=176.744957,
        average_mass=176.4788,
        dict_composition={'H': -7, 'O': 1, 'Fe': 3},
    ),
    "1972": UnimodInfo(
        id="1972",
        name="Unknown:210",
        formula="C13H22O2",
        monoisotopic_mass=210.16198,
        average_mass=210.3126,
        dict_composition={'H': 22, 'C': 13, 'O': 2},
    ),
    "1973": UnimodInfo(
        id="1973",
        name="Unknown:216",
        formula="C10H16O5",
        monoisotopic_mass=216.099774,
        average_mass=216.231,
        dict_composition={'H': 16, 'C': 10, 'O': 5},
    ),
    "1974": UnimodInfo(
        id="1974",
        name="Unknown:234",
        formula="C9H14O7",
        monoisotopic_mass=234.073953,
        average_mass=234.2033,
        dict_composition={'H': 14, 'C': 9, 'O': 7},
    ),
    "1975": UnimodInfo(
        id="1975",
        name="Unknown:248",
        formula="C13H28O4",
        monoisotopic_mass=248.19876,
        average_mass=248.359,
        dict_composition={'H': 28, 'C': 13, 'O': 4},
    ),
    "1976": UnimodInfo(
        id="1976",
        name="Unknown:250",
        formula="C10H4NO5S",
        monoisotopic_mass=249.981018,
        average_mass=250.2075,
        dict_composition={'H': 4, 'C': 10, 'N': 1, 'O': 5, 'S': 1},
    ),
    "1977": UnimodInfo(
        id="1977",
        name="Unknown:302",
        formula="C4H8N5O7S2",
        monoisotopic_mass=301.986514,
        average_mass=302.2656,
        dict_composition={'H': 8, 'C': 4, 'N': 5, 'O': 7, 'S': 2},
    ),
    "1978": UnimodInfo(
        id="1978",
        name="Unknown:306",
        formula="C12H18O9",
        monoisotopic_mass=306.095082,
        average_mass=306.2659,
        dict_composition={'H': 18, 'C': 12, 'O': 9},
    ),
    "1979": UnimodInfo(
        id="1979",
        name="Unknown:420",
        formula="C12H24N2O6S4",
        monoisotopic_mass=420.051719,
        average_mass=420.5888,
        dict_composition={'H': 24, 'C': 12, 'N': 2, 'O': 6, 'S': 4},
    ),
    "1986": UnimodInfo(
        id="1986",
        name="Diethylphosphothione",
        formula="C4H9O2PS",
        monoisotopic_mass=152.006087,
        average_mass=152.1518,
        dict_composition={'H': 9, 'C': 4, 'O': 2, 'P': 1, 'S': 1},
    ),
    "1987": UnimodInfo(
        id="1987",
        name="Dimethylphosphothione",
        formula="C2H5O2PS",
        monoisotopic_mass=123.974787,
        average_mass=124.0987,
        dict_composition={'H': 5, 'C': 2, 'O': 2, 'P': 1, 'S': 1},
    ),
    "1989": UnimodInfo(
        id="1989",
        name="monomethylphosphothione",
        formula="CH3O2PS",
        monoisotopic_mass=109.959137,
        average_mass=110.0721,
        dict_composition={'H': 3, 'C': 1, 'O': 2, 'P': 1, 'S': 1},
    ),
    "1990": UnimodInfo(
        id="1990",
        name="CIGG",
        formula="C13H22N4O4S",
        monoisotopic_mass=330.136176,
        average_mass=330.4032,
        dict_composition={'H': 22, 'C': 13, 'N': 4, 'O': 4, 'S': 1},
    ),
    "1991": UnimodInfo(
        id="1991",
        name="GNLLFLACYCIGG",
        formula="C61H92N14O15S2",
        monoisotopic_mass=1324.6308,
        average_mass=1325.598,
        dict_composition={'H': 92, 'C': 61, 'N': 14, 'O': 15, 'S': 2},
    ),
    "1992": UnimodInfo(
        id="1992",
        name="serotonylation",
        formula="C10H9NO",
        monoisotopic_mass=159.068414,
        average_mass=159.1846,
        dict_composition={'H': 9, 'C': 10, 'N': 1, 'O': 1},
    ),
    "1993": UnimodInfo(
        id="1993",
        name="TMPP-Ac:13C(9)",
        formula="C20H33O10P",
        monoisotopic_mass=581.211328,
        average_mass=581.474,
        dict_composition={'H': 33, 'C': 20, 'O': 10, 'P': 1},
    ),
    "1999": UnimodInfo(
        id="1999",
        name="Xlink:DST[56]",
        formula="C2O2",
        monoisotopic_mass=55.989829,
        average_mass=56.0202,
        dict_composition={'C': 2, 'O': 2},
    ),
    "2001": UnimodInfo(
        id="2001",
        name="ZQG",
        formula="C15H16N2O6",
        monoisotopic_mass=320.100836,
        average_mass=320.2973,
        dict_composition={'H': 16, 'C': 15, 'N': 2, 'O': 6},
    ),
    "2006": UnimodInfo(
        id="2006",
        name="Haloxon",
        formula="C4H7Cl2O3P",
        monoisotopic_mass=203.950987,
        average_mass=204.9763,
        dict_composition={'H': 7, 'C': 4, 'O': 3, 'P': 1, 'Cl': 2},
    ),
    "2007": UnimodInfo(
        id="2007",
        name="Methamidophos-S",
        formula="CH4NOPS",
        monoisotopic_mass=108.975121,
        average_mass=109.0873,
        dict_composition={'H': 4, 'C': 1, 'N': 1, 'O': 1, 'P': 1, 'S': 1},
    ),
    "2008": UnimodInfo(
        id="2008",
        name="Methamidophos-O",
        formula="CH4NO2P",
        monoisotopic_mass=92.997965,
        average_mass=93.0217,
        dict_composition={'H': 4, 'C': 1, 'N': 1, 'O': 2, 'P': 1},
    ),
    "2014": UnimodInfo(
        id="2014",
        name="Nitrene",
        formula="H-1N",
        monoisotopic_mass=12.995249,
        average_mass=12.9988,
        dict_composition={'H': -1, 'N': 1},
    ),
    "2015": UnimodInfo(
        id="2015",
        name="shTMT",
        formula="C3H20O2",
        monoisotopic_mass=235.176741,
        average_mass=235.2201,
        dict_composition={'H': 20, 'C': 3, 'N': 0, 'O': 2},
    ),
    "2016": UnimodInfo(
        id="2016",
        name="TMTpro",
        formula="C8H25NO3",
        monoisotopic_mass=304.207146,
        average_mass=304.3127,
        dict_composition={'H': 25, 'C': 8, 'N': 1, 'O': 3},
    ),
    "2017": UnimodInfo(
        id="2017",
        name="TMTpro_zero",
        formula="C15H25N3O3",
        monoisotopic_mass=295.189592,
        average_mass=295.3773,
        dict_composition={'H': 25, 'C': 15, 'N': 3, 'O': 3},
    ),
    "2022": UnimodInfo(
        id="2022",
        name="Ser/Thr-KDO",
        formula="C8H12O7",
        monoisotopic_mass=220.058303,
        average_mass=220.1767,
        dict_composition={'H': 12, 'C': 8, 'O': 7},
    ),
    "2025": UnimodInfo(
        id="2025",
        name="Andro-H2O",
        formula="C20H28O4",
        monoisotopic_mass=332.19876,
        average_mass=332.4339,
        dict_composition={'H': 28, 'C': 20, 'O': 4},
    ),
    "2027": UnimodInfo(
        id="2027",
        name="His+O(2)",
        formula="C6H7N3O3",
        monoisotopic_mass=169.048741,
        average_mass=169.1381,
        dict_composition={'H': 7, 'C': 6, 'N': 3, 'O': 3},
    ),
    "2028": UnimodInfo(
        id="2028",
        name="Hex(6)HexNAc(5)NeuAc(3)",
        formula="C109H176N8O79",
        monoisotopic_mass=2861.000054,
        average_mass=2862.5699,
        dict_composition={'C': 109, 'H': 176, 'O': 79, 'N': 8},
    ),
    "2029": UnimodInfo(
        id="2029",
        name="Hex(7)HexNAc(6)",
        formula="C90H148N6O65",
        monoisotopic_mass=2352.846,
        average_mass=2354.1393,
        dict_composition={'C': 90, 'H': 148, 'O': 65, 'N': 6},
    ),
    "2033": UnimodInfo(
        id="2033",
        name="Met+O(2)",
        formula="C5H9NO3S",
        monoisotopic_mass=163.030314,
        average_mass=163.1949,
        dict_composition={'H': 9, 'C': 5, 'N': 1, 'O': 3, 'S': 1},
    ),
    "2034": UnimodInfo(
        id="2034",
        name="Gly+O(2)",
        formula="C2H3NO3",
        monoisotopic_mass=89.011293,
        average_mass=89.0501,
        dict_composition={'H': 3, 'C': 2, 'N': 1, 'O': 3},
    ),
    "2035": UnimodInfo(
        id="2035",
        name="Pro+O(2)",
        formula="C5H7NO3",
        monoisotopic_mass=129.042593,
        average_mass=129.114,
        dict_composition={'H': 7, 'C': 5, 'N': 1, 'O': 3},
    ),
    "2036": UnimodInfo(
        id="2036",
        name="Lys+O(2)",
        formula="C6H12N2O3",
        monoisotopic_mass=160.084792,
        average_mass=160.1711,
        dict_composition={'H': 12, 'C': 6, 'N': 2, 'O': 3},
    ),
    "2037": UnimodInfo(
        id="2037",
        name="Glu+O(2)",
        formula="C5H7NO5",
        monoisotopic_mass=161.032422,
        average_mass=161.1128,
        dict_composition={'H': 7, 'C': 5, 'N': 1, 'O': 5},
    ),
    "2039": UnimodInfo(
        id="2039",
        name="LTX+Lophotoxin",
        formula="C22H24O8",
        monoisotopic_mass=416.147118,
        average_mass=416.4212,
        dict_composition={'H': 24, 'C': 22, 'O': 8},
    ),
    "2040": UnimodInfo(
        id="2040",
        name="MBS+peptide",
        formula="C81H108N7O19",
        monoisotopic_mass=1482.77,
        average_mass=1483.7597,
        dict_composition={'H': 108, 'C': 81, 'N': 7, 'O': 19},
    ),
    "2041": UnimodInfo(
        id="2041",
        name="3-hydroxybenzyl-phosphate",
        formula="C7H7O4P",
        monoisotopic_mass=186.008196,
        average_mass=186.1018,
        dict_composition={'H': 7, 'C': 7, 'O': 4, 'P': 1},
    ),
    "2042": UnimodInfo(
        id="2042",
        name="phenyl-phosphate",
        formula="C6H5O3P",
        monoisotopic_mass=155.997631,
        average_mass=156.0759,
        dict_composition={'H': 5, 'C': 6, 'O': 3, 'P': 1},
    ),
    "2044": UnimodInfo(
        id="2044",
        name="RBS-ID_Uridine",
        formula="C9H12N2O6",
        monoisotopic_mass=244.069536,
        average_mass=244.2014,
        dict_composition={'H': 12, 'C': 9, 'N': 2, 'O': 6},
    ),
    "2050": UnimodInfo(
        id="2050",
        name="shTMTpro",
        formula="H25O3",
        monoisotopic_mass=313.231019,
        average_mass=313.2473,
        dict_composition={'H': 25, 'C': 0, 'N': 0, 'O': 3},
    ),
    "2052": UnimodInfo(
        id="2052",
        name="Biotin:Aha-DADPS",
        formula="C42H70N8O11SSi",
        monoisotopic_mass=922.465403,
        average_mass=923.2022,
        dict_composition={'H': 70, 'C': 42, 'N': 8, 'O': 11, 'Si': 1, 'S': 1},
    ),
    "2053": UnimodInfo(
        id="2053",
        name="Biotin:Aha-PC",
        formula="C29H38N8O10S",
        monoisotopic_mass=690.24316,
        average_mass=690.7246,
        dict_composition={'H': 38, 'C': 29, 'N': 8, 'O': 10, 'S': 1},
    ),
    "2054": UnimodInfo(
        id="2054",
        name="pRBS-ID_4-thiouridine",
        formula="C9H10N2O5",
        monoisotopic_mass=226.058972,
        average_mass=226.1861,
        dict_composition={'H': 10, 'C': 9, 'N': 2, 'O': 5},
    ),
    "2055": UnimodInfo(
        id="2055",
        name="pRBS-ID_6-thioguanosine",
        formula="C10H11N5O4",
        monoisotopic_mass=265.081104,
        average_mass=265.2254,
        dict_composition={'H': 11, 'C': 10, 'N': 5, 'O': 4},
    ),
    "2057": UnimodInfo(
        id="2057",
        name="6C-CysPAT",
        formula="C8H16NO4P",
        monoisotopic_mass=221.081695,
        average_mass=221.1907,
        dict_composition={'H': 16, 'C': 8, 'N': 1, 'O': 4, 'P': 1},
    ),
    "2058": UnimodInfo(
        id="2058",
        name="Xlink:DSPP[210]",
        formula="C8H3O5P",
        monoisotopic_mass=209.97181,
        average_mass=210.0802,
        dict_composition={'H': 3, 'C': 8, 'O': 5, 'P': 1},
    ),
    "2059": UnimodInfo(
        id="2059",
        name="Xlink:DSPP[228]",
        formula="C8H5O6P",
        monoisotopic_mass=227.982375,
        average_mass=228.0955,
        dict_composition={'H': 5, 'C': 8, 'O': 6, 'P': 1},
    ),
    "2060": UnimodInfo(
        id="2060",
        name="Xlink:DSPP[331]",
        formula="C12H14NO8P",
        monoisotopic_mass=331.045704,
        average_mass=331.2152,
        dict_composition={'H': 14, 'C': 12, 'N': 1, 'O': 8, 'P': 1},
    ),
    "2061": UnimodInfo(
        id="2061",
        name="Xlink:DSPP[226]",
        formula="C8H5NO5P",
        monoisotopic_mass=225.990534,
        average_mass=226.1028,
        dict_composition={'H': 5, 'C': 8, 'N': 1, 'O': 5, 'P': 1},
    ),
    "2062": UnimodInfo(
        id="2062",
        name="DBIA",
        formula="C14H24N4O3",
        monoisotopic_mass=296.184841,
        average_mass=296.3654,
        dict_composition={'H': 24, 'C': 14, 'N': 4, 'O': 3},
    ),
    "2067": UnimodInfo(
        id="2067",
        name="Mono_Ngamma-propargyl-L-Gln_desthiobiotin",
        formula="C26H44N8O8",
        monoisotopic_mass=596.328211,
        average_mass=596.6764,
        dict_composition={'H': 44, 'C': 26, 'N': 8, 'O': 8},
    ),
    "2068": UnimodInfo(
        id="2068",
        name="Di_L-Glu_Ngamma-propargyl-L-Gln_desthiobiotin",
        formula="C31H51N9O10",
        monoisotopic_mass=709.375889,
        average_mass=709.7909,
        dict_composition={'H': 51, 'C': 31, 'N': 9, 'O': 10},
    ),
    "2069": UnimodInfo(
        id="2069",
        name="Di_L-Gln_Ngamma-propargyl-L-Gln_desthiobiotin",
        formula="C31H52N10O9",
        monoisotopic_mass=708.391873,
        average_mass=708.8062,
        dict_composition={'H': 52, 'C': 31, 'N': 10, 'O': 9},
    ),
    "2070": UnimodInfo(
        id="2070",
        name="L-Gln",
        formula="C5H8N2O2",
        monoisotopic_mass=128.058578,
        average_mass=128.1292,
        dict_composition={'H': 8, 'C': 5, 'N': 2, 'O': 2},
    ),
    "2072": UnimodInfo(
        id="2072",
        name="Glyceroyl",
        formula="C3H4O3",
        monoisotopic_mass=88.016044,
        average_mass=88.0621,
        dict_composition={'H': 4, 'C': 3, 'O': 3},
    ),
    "2073": UnimodInfo(
        id="2073",
        name="N6pAMP",
        formula="C13H14N5O6P",
        monoisotopic_mass=367.06817,
        average_mass=367.2539,
        dict_composition={'H': 14, 'C': 13, 'N': 5, 'O': 6, 'P': 1},
    ),
    "2074": UnimodInfo(
        id="2074",
        name="DABCYL-C2-maleimide",
        formula="C21H21N5O3",
        monoisotopic_mass=391.16444,
        average_mass=391.4231,
        dict_composition={'H': 21, 'C': 21, 'N': 5, 'O': 3},
    ),
    "2079": UnimodInfo(
        id="2079",
        name="NBF",
        formula="C6HN3O3",
        monoisotopic_mass=163.001791,
        average_mass=163.0904,
        dict_composition={'H': 1, 'C': 6, 'N': 3, 'O': 3},
    ),
    "2080": UnimodInfo(
        id="2080",
        name="DCP",
        formula="C9H12O3",
        monoisotopic_mass=168.078644,
        average_mass=168.1898,
        dict_composition={'H': 12, 'C': 9, 'O': 3},
    ),
    "2081": UnimodInfo(
        id="2081",
        name="Ethynyl",
        formula="C2",
        monoisotopic_mass=24.0,
        average_mass=24.0214,
        dict_composition={'C': 2},
    ),
    "2082": UnimodInfo(
        id="2082",
        name="QQTGG",
        formula="C18H29N7O8",
        monoisotopic_mass=471.207761,
        average_mass=471.465,
        dict_composition={'H': 29, 'C': 18, 'N': 7, 'O': 8},
    ),
    "2083": UnimodInfo(
        id="2083",
        name="Pyro-QQTGG",
        formula="C18H26N6O8",
        monoisotopic_mass=454.181212,
        average_mass=454.4344,
        dict_composition={'H': 26, 'C': 18, 'N': 6, 'O': 8},
    ),
    "2084": UnimodInfo(
        id="2084",
        name="NQTGG",
        formula="C17H27N7O8",
        monoisotopic_mass=457.192111,
        average_mass=457.4384,
        dict_composition={'H': 27, 'C': 17, 'N': 7, 'O': 8},
    ),
    "2085": UnimodInfo(
        id="2085",
        name="DVFQQQTGG",
        formula="C41H60N12O15",
        monoisotopic_mass=960.43011,
        average_mass=960.9865,
        dict_composition={'H': 60, 'C': 41, 'N': 12, 'O': 15},
    ),
    "2086": UnimodInfo(
        id="2086",
        name="iST-NHS specific cysteine modification",
        formula="C6H11NO",
        monoisotopic_mass=113.084064,
        average_mass=113.1576,
        dict_composition={'H': 11, 'C': 6, 'N': 1, 'O': 1},
    ),
    "2088": UnimodInfo(
        id="2088",
        name="Label:13C(2)15N(1)",
        formula="C-2N-1",
        monoisotopic_mass=3.003745,
        average_mass=2.9787,
        dict_composition={'C': -2, 'N': -1},
    ),
    "2106": UnimodInfo(
        id="2106",
        name="DPIA",
        formula="C21H37N5O6",
        monoisotopic_mass=455.274384,
        average_mass=455.5484,
        dict_composition={'H': 37, 'C': 21, 'N': 5, 'O': 6},
    ),
    "2107": UnimodInfo(
        id="2107",
        name="Acetoacetyl",
        formula="C4H4O2",
        monoisotopic_mass=84.021129,
        average_mass=84.0734,
        dict_composition={'H': 4, 'C': 4, 'O': 2},
    ),
    "2108": UnimodInfo(
        id="2108",
        name="Isovaleryl",
        formula="C5H8O",
        monoisotopic_mass=84.057515,
        average_mass=84.1164,
        dict_composition={'H': 8, 'C': 5, 'O': 1},
    ),
    "2109": UnimodInfo(
        id="2109",
        name="2-methylbutyryl",
        formula="C5H8O",
        monoisotopic_mass=84.057515,
        average_mass=84.1164,
        dict_composition={'H': 8, 'C': 5, 'O': 1},
    ),
    "2110": UnimodInfo(
        id="2110",
        name="Tiglyl",
        formula="C5H6O",
        monoisotopic_mass=82.041865,
        average_mass=82.1005,
        dict_composition={'H': 6, 'C': 5, 'O': 1},
    ),
    "2111": UnimodInfo(
        id="2111",
        name="3-methylglutaryl",
        formula="C6H8O3",
        monoisotopic_mass=128.047344,
        average_mass=128.1259,
        dict_composition={'H': 8, 'C': 6, 'O': 3},
    ),
    "2112": UnimodInfo(
        id="2112",
        name="3-methylglutaconyl",
        formula="C6H6O3",
        monoisotopic_mass=126.031694,
        average_mass=126.11,
        dict_composition={'H': 6, 'C': 6, 'O': 3},
    ),
    "2113": UnimodInfo(
        id="2113",
        name="3-hydroxy-3-methylglutaryl",
        formula="C6H8O4",
        monoisotopic_mass=144.042259,
        average_mass=144.1253,
        dict_composition={'H': 8, 'C': 6, 'O': 4},
    ),
    "2114": UnimodInfo(
        id="2114",
        name="Lactylation",
        formula="C3H4O2",
        monoisotopic_mass=72.021129,
        average_mass=72.0627,
        dict_composition={'H': 4, 'C': 3, 'O': 2},
    ),
    "2115": UnimodInfo(
        id="2115",
        name="Pyruvoyl",
        formula="C3H2O2",
        monoisotopic_mass=70.005479,
        average_mass=70.0468,
        dict_composition={'H': 2, 'C': 3, 'O': 2},
    ),
    "2116": UnimodInfo(
        id="2116",
        name="Glyoxylyl",
        formula="C2O2",
        monoisotopic_mass=55.989829,
        average_mass=56.0202,
        dict_composition={'C': 2, 'O': 2},
    ),
    "2117": UnimodInfo(
        id="2117",
        name="Itaconatyl",
        formula="C5H6O4",
        monoisotopic_mass=130.026609,
        average_mass=130.0987,
        dict_composition={'H': 6, 'C': 5, 'O': 4},
    ),
    "2118": UnimodInfo(
        id="2118",
        name="Itaconyl",
        formula="C5H4O3",
        monoisotopic_mass=112.016044,
        average_mass=112.0835,
        dict_composition={'H': 4, 'C': 5, 'O': 3},
    ),
    "2119": UnimodInfo(
        id="2119",
        name="ValGly",
        formula="C7H12N2O2",
        monoisotopic_mass=156.089878,
        average_mass=156.1824,
        dict_composition={'H': 12, 'C': 7, 'N': 2, 'O': 2},
    ),
    "2120": UnimodInfo(
        id="2120",
        name="Pentanoyl",
        formula="C5H8O",
        monoisotopic_mass=84.057515,
        average_mass=84.1164,
        dict_composition={'H': 8, 'C': 5, 'O': 1},
    ),
    "2121": UnimodInfo(
        id="2121",
        name="Hexanoyl",
        formula="C6H10O",
        monoisotopic_mass=98.073165,
        average_mass=98.143,
        dict_composition={'H': 10, 'C': 6, 'O': 1},
    ),
    "2122": UnimodInfo(
        id="2122",
        name="Label:13C(6)15N(2)+TMT6plex",
        formula="C2H20N-1O2",
        monoisotopic_mass=237.177131,
        average_mass=237.2062,
        dict_composition={'H': 20, 'C': 2, 'N': -1, 'O': 2},
    ),
    "2123": UnimodInfo(
        id="2123",
        name="Label:13C(6)15N(2)+TMTpro",
        formula="C2H25N-1O3",
        monoisotopic_mass=312.221344,
        average_mass=312.2554,
        dict_composition={'H': 25, 'C': 2, 'N': -1, 'O': 3},
    ),
    "2126": UnimodInfo(
        id="2126",
        name="2PCA-triazole-ethanethiol",
        formula="C10H8N4S",
        monoisotopic_mass=216.046967,
        average_mass=216.2623,
        dict_composition={'H': 8, 'C': 10, 'N': 4, 'S': 1},
    ),
    "2127": UnimodInfo(
        id="2127",
        name="Desthiobiotin-Phenol",
        formula="C18H25N3O3",
        monoisotopic_mass=331.189592,
        average_mass=331.4094,
        dict_composition={'H': 25, 'C': 18, 'N': 3, 'O': 3},
    ),
    "2128": UnimodInfo(
        id="2128",
        name="Cys-vinyl sulfone amine probe addition",
        formula="C20H38N4O7S",
        monoisotopic_mass=478.24612,
        average_mass=478.6033,
        dict_composition={'H': 38, 'C': 20, 'N': 4, 'O': 7, 'S': 1},
    ),
    "2129": UnimodInfo(
        id="2129",
        name="Cys->fGly-diol",
        formula="O2S-1",
        monoisotopic_mass=0.017759,
        average_mass=-0.0662,
        dict_composition={'O': 2, 'S': -1},
    ),
    "2130": UnimodInfo(
        id="2130",
        name="Cys->sulfo-fGly-dio",
        formula="H-1O5",
        monoisotopic_mass=78.966748,
        average_mass=78.9891,
        dict_composition={'H': -1, 'O': 5},
    ),
    "2131": UnimodInfo(
        id="2131",
        name="Cys->Ser-O-sulfate",
        formula="O4",
        monoisotopic_mass=63.979659,
        average_mass=63.9976,
        dict_composition={'O': 4},
    ),
    "2132": UnimodInfo(
        id="2132",
        name="b-type-ion",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.0153,
        dict_composition={'H': -2, 'O': -1},
    ),
    "2135": UnimodInfo(
        id="2135",
        name="PnTAG",
        formula="C6H11O4P",
        monoisotopic_mass=178.039496,
        average_mass=178.1229,
        dict_composition={'H': 11, 'C': 6, 'O': 4, 'P': 1},
    ),
    "2136": UnimodInfo(
        id="2136",
        name="DMA-PEG3",
        formula="C11H21NO4",
        monoisotopic_mass=231.147058,
        average_mass=231.2887,
        dict_composition={'H': 21, 'C': 11, 'N': 1, 'O': 4},
    ),
    }

    UNIMOD_NAME_TO_ID: dict[str, str] = {
        mod.name: mod.id
        for mod in UNIMOD_MODIFICATIONS.values()
    }
except Exception as e:
    warnings.warn(
        f"Exception in unimod_data: {e}. Using empty dictionaries.",
        UserWarning,
        stacklevel=2
    )
    UNIMOD_MODIFICATIONS: dict[str, UnimodInfo] = {}
    UNIMOD_NAME_TO_ID: dict[str, str] = {}
